# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\totg.proto\x12\x03otg\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x89\x02\n\x06\x43onfig\x12\x18\n\x05ports\x18\x01 \x03(\x0b\x32\t.otg.Port\x12\x16\n\x04lags\x18\x02 \x03(\x0b\x32\x08.otg.Lag\x12\x1b\n\x06layer1\x18\x03 \x03(\x0b\x32\x0b.otg.Layer1\x12\x1e\n\x08\x63\x61ptures\x18\x04 \x03(\x0b\x32\x0c.otg.Capture\x12\x1c\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x0b.otg.Device\x12\x18\n\x05\x66lows\x18\x06 \x03(\x0b\x32\t.otg.Flow\x12\x1a\n\x06\x65vents\x18\x07 \x01(\x0b\x32\n.otg.Event\x12#\n\x07options\x18\x08 \x01(\x0b\x32\x12.otg.ConfigOptions\x12\x17\n\x04lldp\x18\t \x03(\x0b\x32\t.otg.Lldp\"g\n\rConfigOptions\x12&\n\x0cport_options\x18\x01 \x01(\x0b\x32\x10.otg.PortOptions\x12.\n\x10protocol_options\x18\x02 \x01(\x0b\x32\x14.otg.ProtocolOptions\"F\n\x04Port\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_locationB\x07\n\x05_name\"G\n\x0bPortOptions\x12 \n\x13location_preemption\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_location_preemption\"\x88\x01\n\x03Lag\x12\x1b\n\x05ports\x18\x01 \x03(\x0b\x32\x0c.otg.LagPort\x12\"\n\x08protocol\x18\x02 \x01(\x0b\x32\x10.otg.LagProtocol\x12\x16\n\tmin_links\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_min_linksB\x07\n\x05_name\"z\n\x07LagPort\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x04lacp\x18\x02 \x01(\x0b\x32\x10.otg.LagPortLacp\x12)\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x17.otg.DeviceEthernetBaseB\x0c\n\n_port_name\"\xd0\x01\n\x0bLagProtocol\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.LagProtocol.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x04lacp\x18\x02 \x01(\x0b\x32\x14.otg.LagProtocolLacp\x12&\n\x06static\x18\x03 \x01(\x0b\x32\x16.otg.LagProtocolStatic\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04lacp\x10\x01\x12\n\n\x06static\x10\x02\x42\t\n\x07_choice\"3\n\x11LagProtocolStatic\x12\x13\n\x06lag_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_lag_id\"\xa7\x01\n\x0fLagProtocolLacp\x12\x1c\n\x0f\x61\x63tor_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x63tor_system_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tactor_key\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x12\n\x10_actor_system_idB\x18\n\x16_actor_system_priorityB\x0c\n\n_actor_key\"\x93\x03\n\x0bLagPortLacp\x12\x1e\n\x11\x61\x63tor_port_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13\x61\x63tor_port_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12@\n\x0e\x61\x63tor_activity\x18\x03 \x01(\x0e\x32#.otg.LagPortLacp.ActorActivity.EnumH\x02\x88\x01\x01\x12*\n\x1dlacpdu_periodic_time_interval\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1b\n\x0elacpdu_timeout\x18\x05 \x01(\rH\x04\x88\x01\x01\x1a\x41\n\rActorActivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07passive\x10\x01\x12\n\n\x06\x61\x63tive\x10\x02\x42\x14\n\x12_actor_port_numberB\x16\n\x14_actor_port_priorityB\x11\n\x0f_actor_activityB \n\x1e_lacpdu_periodic_time_intervalB\x11\n\x0f_lacpdu_timeout\"\x84\x01\n\x12\x44\x65viceEthernetBase\x12\x10\n\x03mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03mtu\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x05vlans\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x06\n\x04_macB\x06\n\x04_mtuB\x07\n\x05_name\"\xe7\x02\n\x0e\x44\x65viceEthernet\x12+\n\nconnection\x18\x02 \x01(\x0b\x32\x17.otg.EthernetConnection\x12\'\n\x0eipv4_addresses\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceIpv4\x12\'\n\x0eipv6_addresses\x18\x04 \x03(\x0b\x32\x0f.otg.DeviceIpv6\x12\x10\n\x03mac\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03mtu\x18\x06 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x05vlans\x18\x07 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x11\n\x04name\x18\x08 \x01(\tH\x02\x88\x01\x01\x12\x32\n\x11\x64hcpv4_interfaces\x18\t \x03(\x0b\x32\x17.otg.DeviceDhcpv4client\x12\x32\n\x11\x64hcpv6_interfaces\x18\n \x03(\x0b\x32\x17.otg.DeviceDhcpv6clientB\x06\n\x04_macB\x06\n\x04_mtuB\x07\n\x05_name\"\xe3\x02\n\x12\x45thernetConnection\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.EthernetConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08lag_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nvxlan_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x32\n\x0esimulated_link\x18\x05 \x01(\x0b\x32\x1a.otg.EthernetSimulatedLink\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x12\x0c\n\x08lag_name\x10\x02\x12\x0e\n\nvxlan_name\x10\x03\x12\x12\n\x0esimulated_link\x10\x04\x42\t\n\x07_choiceB\x0c\n\n_port_nameB\x0b\n\t_lag_nameB\r\n\x0b_vxlan_name\"\xe6\x01\n\x15\x45thernetSimulatedLink\x12\"\n\x15remote_simulated_link\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\tlink_type\x18\x02 \x01(\x0e\x32(.otg.EthernetSimulatedLink.LinkType.EnumH\x01\x88\x01\x01\x1a?\n\x08LinkType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07primary\x10\x01\x12\r\n\tsecondary\x10\x02\x42\x18\n\x16_remote_simulated_linkB\x0c\n\n_link_type\"\xf3\x01\n\nDeviceVlan\x12,\n\x04tpid\x18\x01 \x01(\x0e\x32\x19.otg.DeviceVlan.Tpid.EnumH\x00\x88\x01\x01\x12\x15\n\x08priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x1aV\n\x04Tpid\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05x8100\x10\x01\x12\t\n\x05x88A8\x10\x02\x12\t\n\x05x9100\x10\x03\x12\t\n\x05x9200\x10\x04\x12\t\n\x05x9300\x10\x05\x42\x07\n\x05_tpidB\x0b\n\t_priorityB\x05\n\x03_idB\x07\n\x05_name\"\xbc\x01\n\nDeviceIpv4\x12\x14\n\x07gateway\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv4GatewayMAC\x12\x14\n\x07\x61\x64\x64ress\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\n\n\x08_gatewayB\n\n\x08_addressB\t\n\x07_prefixB\x07\n\x05_name\"v\n\x12\x44\x65viceIpv4Loopback\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_eth_nameB\n\n\x08_addressB\x07\n\x05_name\"\xcf\x01\n\x14\x44\x65viceIpv4GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv4GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xbc\x01\n\nDeviceIpv6\x12\x14\n\x07gateway\x18\x01 \x01(\tH\x00\x88\x01\x01\x12.\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv6GatewayMAC\x12\x14\n\x07\x61\x64\x64ress\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\n\n\x08_gatewayB\n\n\x08_addressB\t\n\x07_prefixB\x07\n\x05_name\"v\n\x12\x44\x65viceIpv6Loopback\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_eth_nameB\n\n\x08_addressB\x07\n\x05_name\"\xcf\x01\n\x14\x44\x65viceIpv6GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv6GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xce\x02\n\x12\x44\x65viceDhcpv4client\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x06\x63hoice\x18\x02 \x01(\x0e\x32#.otg.DeviceDhcpv4client.Choice.EnumH\x01\x88\x01\x01\x12\x1b\n\x0eserver_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tbroadcast\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x38\n\x17parameters_request_list\x18\x06 \x01(\x0b\x32\x17.otg.Dhcpv4ClientParams\x1aG\n\x06\x43hoice\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66irst_server\x10\x01\x12\x12\n\x0eserver_address\x10\x02\x42\x07\n\x05_nameB\t\n\x07_choiceB\x11\n\x0f_server_addressB\x0c\n\n_broadcast\"\xbe\x01\n\x12\x44hcpv4ClientParams\x12\x18\n\x0bsubnet_mask\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06router\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1a\n\rrenewal_timer\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1c\n\x0frebinding_timer\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x0e\n\x0c_subnet_maskB\t\n\x07_routerB\x10\n\x0e_renewal_timerB\x12\n\x10_rebinding_timer\"\xb1\x02\n\x12\x44\x65viceDhcpv6client\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0crapid_commit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12.\n\x07ia_type\x18\x03 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientIaType\x12\x32\n\tduid_type\x18\x04 \x01(\x0b\x32\x1f.otg.DeviceDhcpv6clientDuidType\x12>\n\x0foptions_request\x18\x05 \x01(\x0b\x32%.otg.DeviceDhcpv6ClientOptionsRequest\x12/\n\x07options\x18\x06 \x01(\x0b\x32\x1e.otg.DeviceDhcpv6ClientOptionsB\x07\n\x05_nameB\x0f\n\r_rapid_commit\"\xa7\x01\n DeviceDhcpv6ClientOptionsRequest\x12\x37\n\x07request\x18\x01 \x03(\x0b\x32&.otg.Dhcpv6ClientOptionsOptionsRequest\x12J\n\x18\x61ssociated_dhcp_messages\x18\x02 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessages\"\x80\x02\n\x19\x44\x65viceDhcpv6ClientOptions\x12\x43\n\x11server_identifier\x18\x01 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsServerIdentifier\x12\x39\n\x0cvendor_class\x18\x02 \x01(\x0b\x32#.otg.Dhcpv6ClientOptionsVendorClass\x12\x37\n\x0bvendor_info\x18\x03 \x01(\x0b\x32\".otg.Dhcpv6ClientOptionsVendorInfo\x12*\n\x04\x66qdn\x18\x04 \x01(\x0b\x32\x1c.otg.Dhcpv6ClientOptionsFqdn\"\xca\x02\n\x18\x44\x65viceDhcpv6clientIaType\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.DeviceDhcpv6clientIaType.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x04iana\x18\x02 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x12\x30\n\x04iapd\x18\x03 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x12\x32\n\x06ianapd\x18\x04 \x01(\x0b\x32\".otg.DeviceDhcpv6clientIaTimeValue\x1aK\n\x06\x43hoice\"A\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04iana\x10\x01\x12\x08\n\x04iata\x10\x02\x12\x08\n\x04iapd\x10\x03\x12\n\n\x06ianapd\x10\x04\x42\t\n\x07_choice\"O\n\x1d\x44\x65viceDhcpv6clientIaTimeValue\x12\x0f\n\x02t1\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02t2\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_t1B\x05\n\x03_t2\"\xaa\x02\n\x1a\x44\x65viceDhcpv6clientDuidType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.DeviceDhcpv6clientDuidType.Choice.EnumH\x00\x88\x01\x01\x12*\n\x03llt\x18\x02 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientNoDuid\x12,\n\x02\x65n\x18\x03 \x01(\x0b\x32 .otg.DeviceDhcpv6clientDuidValue\x12)\n\x02ll\x18\x04 \x01(\x0b\x32\x1d.otg.DeviceDhcpv6clientNoDuid\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03llt\x10\x01\x12\x06\n\x02\x65n\x10\x02\x12\x06\n\x02ll\x10\x03\x42\t\n\x07_choice\"q\n\x1b\x44\x65viceDhcpv6clientDuidValue\x12\x1a\n\renterprise_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tvendor_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x10\n\x0e_enterprise_idB\x0c\n\n_vendor_id\"\x1a\n\x18\x44\x65viceDhcpv6clientNoDuid\"\x9f\x03\n#Dhcpv6ClientOptionsServerIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ClientOptionsServerIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x08\x64uid_llt\x18\x02 \x01(\x0b\x32\x1f.otg.Dhcpv6ClientOptionsDuidLlt\x12/\n\x07\x64uid_en\x18\x03 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsDuidEn\x12/\n\x07\x64uid_ll\x18\x04 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsDuidLl\x12\x33\n\tduid_uuid\x18\x05 \x01(\x0b\x32 .otg.Dhcpv6ClientOptionsDuidUuid\x1aX\n\x06\x43hoice\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x64uid_llt\x10\x01\x12\x0b\n\x07\x64uid_en\x10\x02\x12\x0b\n\x07\x64uid_ll\x10\x03\x12\r\n\tduid_uuid\x10\x04\x42\t\n\x07_choice\"~\n\x1a\x44hcpv6ClientOptionsDuidLlt\x12\x11\n\x04time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x44\n\x12link_layer_address\x18\x02 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsLinkLayerAddressB\x07\n\x05_time\"y\n\x19\x44hcpv6ClientOptionsDuidEn\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\nidentifier\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x14\n\x12_enterprise_numberB\r\n\x0b_identifier\"a\n\x19\x44hcpv6ClientOptionsDuidLl\x12\x44\n\x12link_layer_address\x18\x01 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsLinkLayerAddress\"\xa3\x03\n\x1b\x44hcpv6ClientOptionsDuidUuid\x12\x38\n\x07version\x18\x01 \x01(\x0b\x32\'.otg.Dhcpv6ClientOptionsDuidUuidVersion\x12\x38\n\x07variant\x18\x02 \x01(\x0b\x32\'.otg.Dhcpv6ClientOptionsDuidUuidVariant\x12\x15\n\x08time_low\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08time_mid\x18\x04 \x01(\rH\x01\x88\x01\x01\x12 \n\x13time_hi_and_version\x18\x05 \x01(\rH\x02\x88\x01\x01\x12&\n\x19\x63lock_seq_hi_and_reserved\x18\x06 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\rclock_seq_low\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x11\n\x04node\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0b\n\t_time_lowB\x0b\n\t_time_midB\x16\n\x14_time_hi_and_versionB\x1c\n\x1a_clock_seq_hi_and_reservedB\x10\n\x0e_clock_seq_lowB\x07\n\x05_node\"\xc9\x01\n\"Dhcpv6ClientOptionsDuidUuidVersion\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.Dhcpv6ClientOptionsDuidUuidVersion.Choice.EnumH\x00\x88\x01\x01\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03v_1\x10\x01\x12\x07\n\x03v_2\x10\x02\x12\x07\n\x03v_3\x10\x03\x12\x07\n\x03v_4\x10\x04\x12\x07\n\x03v_5\x10\x05\x42\t\n\x07_choice\"\xca\x01\n\"Dhcpv6ClientOptionsDuidUuidVariant\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.Dhcpv6ClientOptionsDuidUuidVariant.Choice.EnumH\x00\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03ncs\x10\x01\x12\x07\n\x03\x64\x63\x65\x10\x02\x12\x08\n\x04guid\x10\x03\x12\x10\n\x0cvar_reserved\x10\x04\x42\t\n\x07_choice\"C\n#Dhcpv6ClientOptionsLinkLayerAddress\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xa6\x02\n!Dhcpv6ClientOptionsOptionsRequest\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.Dhcpv6ClientOptionsOptionsRequest.Choice.EnumH\x00\x88\x01\x01\x12.\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x1e.otg.Dhcpv6ClientOptionsCustom\x1a}\n\x06\x43hoice\"s\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12vendor_information\x10\x01\x12\x10\n\x0cname_servers\x10\x02\x12\x08\n\x04\x66qdn\x10\x03\x12\x10\n\x0c\x62ootfile_url\x10\x04\x12\x08\n\x04sztp\x10\x05\x12\n\n\x06\x63ustom\x10\x06\x42\t\n\x07_choice\"7\n\x19\x44hcpv6ClientOptionsCustom\x12\x11\n\x04type\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x07\n\x05_type\"\xb6\x01\n\x1e\x44hcpv6ClientOptionsVendorClass\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\nclass_data\x18\x02 \x03(\t\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xee\x01\n#Dhcpv6ClientOptionsIncludedMessages\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ClientOptionsIncludedMessages.Choice.EnumH\x00\x88\x01\x01\x12\x36\n\tmsg_types\x18\x02 \x03(\x0b\x32#.otg.Dhcpv6ClientOptionsMessageType\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\r\n\tmsg_types\x10\x02\x42\t\n\x07_choice\"\xe6\x01\n\x1e\x44hcpv6ClientOptionsMessageType\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.Dhcpv6ClientOptionsMessageType.Choice.EnumH\x00\x88\x01\x01\x1as\n\x06\x43hoice\"i\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07solicit\x10\x01\x12\x0b\n\x07request\x10\x02\x12\x12\n\x0einform_request\x10\x03\x12\x0b\n\x07release\x10\x04\x12\t\n\x05renew\x10\x05\x12\n\n\x06rebind\x10\x06\x42\t\n\x07_choice\"\xdf\x01\n\x1d\x44hcpv6ClientOptionsVendorInfo\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12<\n\x0boption_data\x18\x02 \x03(\x0b\x32\'.otg.Dhcpv6OptionsVendorSpecificOptions\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xdf\x01\n\x1d\x44hcpv6ServerOptionsVendorInfo\x12\x1e\n\x11\x65nterprise_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12<\n\x0boption_data\x18\x02 \x03(\x0b\x32\'.otg.Dhcpv6OptionsVendorSpecificOptions\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ServerOptionsIncludedMessagesB\x14\n\x12_enterprise_number\"\xee\x01\n#Dhcpv6ServerOptionsIncludedMessages\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.Dhcpv6ServerOptionsIncludedMessages.Choice.EnumH\x00\x88\x01\x01\x12\x36\n\tmsg_types\x18\x02 \x03(\x0b\x32#.otg.Dhcpv6ServerOptionsMessageType\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\r\n\tmsg_types\x10\x02\x42\t\n\x07_choice\"\xc0\x01\n\x1e\x44hcpv6ServerOptionsMessageType\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.Dhcpv6ServerOptionsMessageType.Choice.EnumH\x00\x88\x01\x01\x1aM\n\x06\x43hoice\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tadvertise\x10\x01\x12\t\n\x05reply\x10\x02\x12\x10\n\x0cre_configure\x10\x03\x42\t\n\x07_choice\"\\\n\"Dhcpv6OptionsVendorSpecificOptions\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04\x64\x61ta\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\x07\n\x05_data\"\xef\x01\n\x17\x44hcpv6ClientOptionsFqdn\x12\x13\n\x06\x66lag_s\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x66lag_o\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06\x66lag_n\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x18\n\x0b\x64omain_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12J\n\x18\x61ssociated_dhcp_messages\x18\x05 \x01(\x0b\x32(.otg.Dhcpv6ClientOptionsIncludedMessagesB\t\n\x07_flag_sB\t\n\x07_flag_oB\t\n\x07_flag_nB\x0e\n\x0c_domain_name\"\xc7\x01\n\x1e\x44hcpv6ServerOptionsBootfileUrl\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\x0f\x62ootfile_params\x18\x02 \x03(\x0b\x32&.otg.Dhcpv6ServerOptionsBootFileParams\x12J\n\x18\x61ssociated_dhcp_messages\x18\x03 \x01(\x0b\x32(.otg.Dhcpv6ServerOptionsIncludedMessagesB\x06\n\x04_url\"I\n!Dhcpv6ServerOptionsBootFileParams\x12\x16\n\tparameter\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_parameter\"\xa6\x06\n\x06Layer1\x12\x12\n\nport_names\x18\x01 \x03(\t\x12*\n\x05speed\x18\x02 \x01(\x0e\x32\x16.otg.Layer1.Speed.EnumH\x00\x88\x01\x01\x12*\n\x05media\x18\x03 \x01(\x0e\x32\x16.otg.Layer1.Media.EnumH\x01\x88\x01\x01\x12\x18\n\x0bpromiscuous\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03mtu\x18\x05 \x01(\rH\x03\x88\x01\x01\x12 \n\x13ieee_media_defaults\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1b\n\x0e\x61uto_negotiate\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x34\n\x10\x61uto_negotiation\x18\x08 \x01(\x0b\x32\x1a.otg.Layer1AutoNegotiation\x12,\n\x0c\x66low_control\x18\t \x01(\x0b\x32\x16.otg.Layer1FlowControl\x12\x11\n\x04name\x18\n \x01(\tH\x06\x88\x01\x01\x1a\xa9\x02\n\x05Speed\"\x9f\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10speed_10_fd_mbps\x10\x01\x12\x14\n\x10speed_10_hd_mbps\x10\x02\x12\x15\n\x11speed_100_fd_mbps\x10\x03\x12\x15\n\x11speed_100_hd_mbps\x10\x04\x12\x10\n\x0cspeed_1_gbps\x10\x05\x12\x11\n\rspeed_10_gbps\x10\x06\x12\x11\n\rspeed_25_gbps\x10\x07\x12\x11\n\rspeed_40_gbps\x10\x08\x12\x11\n\rspeed_50_gbps\x10\t\x12\x12\n\x0espeed_100_gbps\x10\n\x12\x12\n\x0espeed_200_gbps\x10\x0b\x12\x12\n\x0espeed_400_gbps\x10\x0c\x12\x12\n\x0espeed_800_gbps\x10\r\x1a\x42\n\x05Media\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63opper\x10\x01\x12\t\n\x05\x66iber\x10\x02\x12\t\n\x05sgmii\x10\x03\x42\x08\n\x06_speedB\x08\n\x06_mediaB\x0e\n\x0c_promiscuousB\x06\n\x04_mtuB\x16\n\x14_ieee_media_defaultsB\x11\n\x0f_auto_negotiateB\x07\n\x05_name\"\x93\x03\n\x15Layer1AutoNegotiation\x12 \n\x13\x61\x64vertise_1000_mbps\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_fd_mbps\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_hd_mbps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_fd_mbps\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_hd_mbps\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlink_training\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06rs_fec\x18\x07 \x01(\x08H\x06\x88\x01\x01\x42\x16\n\x14_advertise_1000_mbpsB\x18\n\x16_advertise_100_fd_mbpsB\x18\n\x16_advertise_100_hd_mbpsB\x17\n\x15_advertise_10_fd_mbpsB\x17\n\x15_advertise_10_hd_mbpsB\x10\n\x0e_link_trainingB\t\n\x07_rs_fec\"\xac\x02\n\x11Layer1FlowControl\x12\x1d\n\x10\x64irected_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\".otg.Layer1FlowControl.Choice.EnumH\x01\x88\x01\x01\x12-\n\rieee_802_1qbb\x18\x03 \x01(\x0b\x32\x16.otg.Layer1Ieee8021qbb\x12)\n\x0bieee_802_3x\x18\x04 \x01(\x0b\x32\x14.otg.Layer1Ieee8023x\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rieee_802_1qbb\x10\x01\x12\x0f\n\x0bieee_802_3x\x10\x02\x42\x13\n\x11_directed_addressB\t\n\x07_choice\"\x11\n\x0fLayer1Ieee8023x\"\x89\x03\n\x11Layer1Ieee8021qbb\x12\x16\n\tpfc_delay\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bpfc_class_0\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bpfc_class_1\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0bpfc_class_2\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0bpfc_class_3\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x18\n\x0bpfc_class_4\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0bpfc_class_5\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x18\n\x0bpfc_class_6\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x18\n\x0bpfc_class_7\x18\t \x01(\rH\x08\x88\x01\x01\x42\x0c\n\n_pfc_delayB\x0e\n\x0c_pfc_class_0B\x0e\n\x0c_pfc_class_1B\x0e\n\x0c_pfc_class_2B\x0e\n\x0c_pfc_class_3B\x0e\n\x0c_pfc_class_4B\x0e\n\x0c_pfc_class_5B\x0e\n\x0c_pfc_class_6B\x0e\n\x0c_pfc_class_7\"\xa1\x02\n\x07\x43\x61pture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.otg.CaptureFilter\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bpacket_size\x18\x04 \x01(\rH\x01\x88\x01\x01\x12-\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x18.otg.Capture.Format.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x06 \x01(\tH\x03\x88\x01\x01\x1a\x37\n\x06\x46ormat\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04pcap\x10\x01\x12\n\n\x06pcapng\x10\x02\x42\x0c\n\n_overwriteB\x0e\n\x0c_packet_sizeB\t\n\x07_formatB\x07\n\x05_name\"\xd6\x02\n\rCaptureFilter\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.CaptureFilter.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x12.otg.CaptureCustom\x12&\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x14.otg.CaptureEthernet\x12\x1e\n\x04vlan\x18\x04 \x01(\x0b\x32\x10.otg.CaptureVlan\x12\x1e\n\x04ipv4\x18\x05 \x01(\x0b\x32\x10.otg.CaptureIpv4\x12\x1e\n\x04ipv6\x18\x06 \x01(\x0b\x32\x10.otg.CaptureIpv6\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\x08\n\x04ipv4\x10\x04\x12\x08\n\x04ipv6\x10\x05\x42\t\n\x07_choice\"\xb1\x01\n\rCaptureCustom\x12\x13\n\x06offset\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\nbit_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mask\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06negate\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_offsetB\r\n\x0b_bit_lengthB\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"h\n\x0c\x43\x61ptureField\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04mask\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06negate\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"\x9e\x01\n\x0f\x43\x61ptureEthernet\x12\x1e\n\x03src\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12%\n\nether_type\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12$\n\tpfc_queue\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\"\x96\x01\n\x0b\x43\x61ptureVlan\x12#\n\x08priority\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1d\n\x02id\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08protocol\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\"\xb4\x04\n\x0b\x43\x61ptureIpv4\x12\"\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rheader_length\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08priority\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12\'\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0eidentification\x18\x05 \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08reserved\x18\x06 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rdont_fragment\x18\x07 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0emore_fragments\x18\x08 \x01(\x0b\x32\x11.otg.CaptureField\x12*\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\x11.otg.CaptureField\x12\'\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x11.otg.CaptureField\x12#\n\x08protocol\x18\x0b \x01(\x0b\x32\x11.otg.CaptureField\x12*\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03src\x18\r \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x0e \x01(\x0b\x32\x11.otg.CaptureField\"\xbb\x02\n\x0b\x43\x61ptureIpv6\x12\"\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureField\x12(\n\rtraffic_class\x18\x02 \x01(\x0b\x32\x11.otg.CaptureField\x12%\n\nflow_label\x18\x03 \x01(\x0b\x32\x11.otg.CaptureField\x12)\n\x0epayload_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureField\x12&\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x11.otg.CaptureField\x12$\n\thop_limit\x18\x06 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03src\x18\x07 \x01(\x0b\x32\x11.otg.CaptureField\x12\x1e\n\x03\x64st\x18\x08 \x01(\x0b\x32\x11.otg.CaptureField\"\xae\x03\n\x06\x44\x65vice\x12&\n\tethernets\x18\x01 \x03(\x0b\x32\x13.otg.DeviceEthernet\x12/\n\x0eipv4_loopbacks\x18\x02 \x03(\x0b\x32\x17.otg.DeviceIpv4Loopback\x12/\n\x0eipv6_loopbacks\x18\x03 \x03(\x0b\x32\x17.otg.DeviceIpv6Loopback\x12#\n\x04isis\x18\x04 \x01(\x0b\x32\x15.otg.DeviceIsisRouter\x12!\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x14.otg.DeviceBgpRouter\x12\x1f\n\x05vxlan\x18\x06 \x01(\x0b\x32\x10.otg.DeviceVxlan\x12\x11\n\x04name\x18\x07 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x04rsvp\x18\x08 \x01(\x0b\x32\x0f.otg.DeviceRsvp\x12*\n\x0b\x64hcp_server\x18\t \x01(\x0b\x32\x15.otg.DeviceDhcpServer\x12\'\n\x06ospfv2\x18\n \x01(\x0b\x32\x17.otg.DeviceOspfv2Router\x12!\n\x06macsec\x18\x0b \x01(\x0b\x32\x11.otg.DeviceMacsecB\x07\n\x05_name\"A\n\x0fProtocolOptions\x12\x1b\n\x0e\x61uto_start_all\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x11\n\x0f_auto_start_all\"\xa4\x03\n\x10\x44\x65viceIsisRouter\x12.\n\x08instance\x18\x01 \x01(\x0b\x32\x1c.otg.DeviceIsisMultiInstance\x12\x16\n\tsystem_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12&\n\ninterfaces\x18\x03 \x03(\x0b\x32\x12.otg.IsisInterface\x12\x1d\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32\x0e.otg.IsisBasic\x12#\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x11.otg.IsisAdvanced\x12,\n\x0brouter_auth\x18\x06 \x01(\x0b\x32\x17.otg.IsisAuthentication\x12(\n\tv4_routes\x18\x07 \x03(\x0b\x32\x15.otg.IsisV4RouteRange\x12(\n\tv6_routes\x18\x08 \x03(\x0b\x32\x15.otg.IsisV6RouteRange\x12\x11\n\x04name\x18\t \x01(\tH\x01\x88\x01\x01\x12\x30\n\x0fsegment_routing\x18\n \x01(\x0b\x32\x17.otg.IsisSegmentRoutingB\x0c\n\n_system_idB\x07\n\x05_name\"B\n\x17\x44\x65viceIsisMultiInstance\x12\x10\n\x03iid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\r\n\x05itids\x18\x02 \x03(\rB\x06\n\x04_iid\"\xc9\x06\n\rIsisInterface\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x02 \x01(\rH\x01\x88\x01\x01\x12>\n\x0cnetwork_type\x18\x03 \x01(\x0e\x32#.otg.IsisInterface.NetworkType.EnumH\x02\x88\x01\x01\x12:\n\nlevel_type\x18\x04 \x01(\x0e\x32!.otg.IsisInterface.LevelType.EnumH\x03\x88\x01\x01\x12,\n\x0bl1_settings\x18\x05 \x01(\x0b\x32\x17.otg.IsisInterfaceLevel\x12,\n\x0bl2_settings\x18\x06 \x01(\x0b\x32\x17.otg.IsisInterfaceLevel\x12\'\n\x12multi_topology_ids\x18\x07 \x03(\x0b\x32\x0b.otg.IsisMT\x12-\n\x13traffic_engineering\x18\x08 \x03(\x0b\x32\x10.otg.LinkStateTE\x12\x38\n\x0e\x61uthentication\x18\t \x01(\x0b\x32 .otg.IsisInterfaceAuthentication\x12,\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x1a.otg.IsisInterfaceAdvanced\x12\x39\n\x0flink_protection\x18\x0b \x01(\x0b\x32 .otg.IsisInterfaceLinkProtection\x12\x13\n\x0bsrlg_values\x18\x0c \x03(\r\x12\x11\n\x04name\x18\r \x01(\tH\x04\x88\x01\x01\x12\x36\n\x0e\x61\x64jacency_sids\x18\x0e \x03(\x0b\x32\x1e.otg.IsisInterfaceAdjacencySid\x1aI\n\x0bNetworkType\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\x0b\n\t_eth_nameB\t\n\x07_metricB\x0f\n\r_network_typeB\r\n\x0b_level_typeB\x07\n\x05_name\"\x96\x01\n\x12IsisInterfaceLevel\x12\x15\n\x08priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x0b\n\t_priorityB\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_interval\"P\n\x06IsisMT\x12\x12\n\x05mt_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_mt_idB\x0e\n\x0c_link_metric\"\xa4\x02\n\x0bLinkStateTE\x12!\n\x14\x61\x64ministrative_group\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cmetric_level\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0cmax_bandwith\x18\x03 \x01(\rH\x02\x88\x01\x01\x12%\n\x18max_reservable_bandwidth\x18\x04 \x01(\rH\x03\x88\x01\x01\x12=\n\x13priority_bandwidths\x18\x05 \x01(\x0b\x32 .otg.LinkStatepriorityBandwidthsB\x17\n\x15_administrative_groupB\x0f\n\r_metric_levelB\x0f\n\r_max_bandwithB\x1b\n\x19_max_reservable_bandwidth\"\xed\x01\n\x1bLinkStatepriorityBandwidths\x12\x10\n\x03pb0\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03pb1\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x10\n\x03pb2\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03pb3\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x10\n\x03pb4\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x10\n\x03pb5\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x10\n\x03pb6\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x10\n\x03pb7\x18\x08 \x01(\rH\x07\x88\x01\x01\x42\x06\n\x04_pb0B\x06\n\x04_pb1B\x06\n\x04_pb2B\x06\n\x04_pb3B\x06\n\x04_pb4B\x06\n\x04_pb5B\x06\n\x04_pb6B\x06\n\x04_pb7\"\xed\x01\n\x1bIsisInterfaceAuthentication\x12\x46\n\tauth_type\x18\x01 \x01(\x0e\x32..otg.IsisInterfaceAuthentication.AuthType.EnumH\x00\x88\x01\x01\x12\x10\n\x03md5\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x0c\n\n_auth_typeB\x06\n\x04_md5B\x0b\n\t_password\"\xd3\x02\n\x15IsisInterfaceAdvanced\x12\x1c\n\x0f\x61uto_adjust_mtu\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10\x61uto_adjust_area\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x1f\x61uto_adjust_supported_protocols\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65nable_3way_handshake\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12&\n\x19p2p_hellos_to_unicast_mac\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x12\n\x10_auto_adjust_mtuB\x13\n\x11_auto_adjust_areaB\"\n _auto_adjust_supported_protocolsB\x18\n\x16_enable_3way_handshakeB\x1c\n\x1a_p2p_hellos_to_unicast_mac\"\xf9\x02\n\x1bIsisInterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\x94\x03\n\x19IsisInterfaceAdjacencySid\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.IsisInterfaceAdjacencySid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\nsid_values\x18\x02 \x03(\r\x12\x13\n\x0bsid_indices\x18\x03 \x03(\r\x12\x13\n\x06\x66_flag\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06l_flag\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06s_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06p_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06weight\x18\t \x01(\rH\x06\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nsid_values\x10\x01\x12\x0f\n\x0bsid_indices\x10\x02\x42\t\n\x07_choiceB\t\n\x07_f_flagB\t\n\x07_b_flagB\t\n\x07_l_flagB\t\n\x07_s_flagB\t\n\x07_p_flagB\t\n\x07_weight\"\xd5\x01\n\tIsisBasic\x12\x1e\n\x11ipv4_te_router_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08hostname\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x65nable_wide_metric\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1f\n\x12learned_lsp_filter\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x14\n\x12_ipv4_te_router_idB\x0b\n\t_hostnameB\x15\n\x13_enable_wide_metricB\x15\n\x13_learned_lsp_filter\"\x8a\x04\n\x0cIsisAdvanced\x12!\n\x14\x65nable_hello_padding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12max_area_addresses\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\x0e\x61rea_addresses\x18\x03 \x03(\t\x12\x1d\n\x10lsp_refresh_rate\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0clsp_lifetime\x18\x05 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\rpsnp_interval\x18\x06 \x01(\rH\x04\x88\x01\x01\x12\x1a\n\rcsnp_interval\x18\x07 \x01(\rH\x05\x88\x01\x01\x12\x19\n\x0cmax_lsp_size\x18\x08 \x01(\rH\x06\x88\x01\x01\x12*\n\x1dlsp_mgroup_min_trans_interval\x18\t \x01(\rH\x07\x88\x01\x01\x12 \n\x13\x65nable_attached_bit\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x17\n\x15_enable_hello_paddingB\x15\n\x13_max_area_addressesB\x13\n\x11_lsp_refresh_rateB\x0f\n\r_lsp_lifetimeB\x10\n\x0e_psnp_intervalB\x10\n\x0e_csnp_intervalB\x0f\n\r_max_lsp_sizeB \n\x1e_lsp_mgroup_min_trans_intervalB\x16\n\x14_enable_attached_bit\"\xae\x01\n\x12IsisAuthentication\x12\x1f\n\x12ignore_receive_md5\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12.\n\tarea_auth\x18\x02 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBase\x12\x30\n\x0b\x64omain_auth\x18\x03 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseB\x15\n\x13_ignore_receive_md5\"\xe3\x01\n\x16IsisAuthenticationBase\x12\x41\n\tauth_type\x18\x01 \x01(\x0e\x32).otg.IsisAuthenticationBase.AuthType.EnumH\x00\x88\x01\x01\x12\x10\n\x03md5\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x0c\n\n_auth_typeB\x06\n\x04_md5B\x0b\n\t_password\"\x83\x05\n\x10IsisV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV4RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV4RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x07\x88\x01\x01\x12)\n\x0bprefix_sids\x18\n \x03(\x0b\x32\x14.otg.IsisSRPrefixSid\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x07\n\x05_nameB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"\x8c\x01\n\x0eV4RouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x8c\x01\n\x0eV6RouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x8d\x01\n\x0fMACRouteAddress\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\n\n\x08_addressB\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\x86\x03\n\x0fIsisSRPrefixSid\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.IsisSRPrefixSid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\nsid_values\x18\x02 \x03(\r\x12\x13\n\x0bsid_indices\x18\x03 \x03(\r\x12\x13\n\x06r_flag\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06n_flag\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06p_flag\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06l_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x16\n\talgorithm\x18\t \x01(\rH\x06\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nsid_values\x10\x01\x12\x0f\n\x0bsid_indices\x10\x02\x42\t\n\x07_choiceB\t\n\x07_r_flagB\t\n\x07_n_flagB\t\n\x07_p_flagB\t\n\x07_e_flagB\t\n\x07_l_flagB\x0c\n\n_algorithm\"\x83\x05\n\x10IsisV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\rH\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV6RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV6RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x07\x88\x01\x01\x12)\n\x0bprefix_sids\x18\n \x03(\x0b\x32\x14.otg.IsisSRPrefixSid\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x07\n\x05_nameB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"J\n\x12IsisSegmentRouting\x12\x34\n\x11router_capability\x18\x01 \x01(\x0b\x32\x19.otg.IsisRouterCapability\"\xe1\x04\n\x14IsisRouterCapability\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.IsisRouterCapability.Choice.EnumH\x00\x88\x01\x01\x12!\n\x14\x63ustom_router_cap_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x37\n\x05s_bit\x18\x03 \x01(\x0e\x32#.otg.IsisRouterCapability.SBit.EnumH\x02\x88\x01\x01\x12\x37\n\x05\x64_bit\x18\x04 \x01(\x0e\x32#.otg.IsisRouterCapability.DBit.EnumH\x03\x88\x01\x01\x12,\n\rsr_capability\x18\x05 \x01(\x0b\x32\x15.otg.IsisSRCapability\x12\x12\n\nalgorithms\x18\x06 \x03(\r\x12$\n\x0bsrlb_ranges\x18\x07 \x03(\x0b\x32\x0f.otg.IsisSRSrlb\x1a\x64\n\x06\x43hoice\"Z\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11ipv4_te_router_id\x10\x01\x12\x10\n\x0cinterface_ip\x10\x02\x12\x18\n\x14\x63ustom_router_cap_id\x10\x03\x1a\x39\n\x04SBit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lood\x10\x01\x12\r\n\tnot_flood\x10\x02\x1a\x37\n\x04\x44\x42it\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64own\x10\x01\x12\x0c\n\x08not_down\x10\x02\x42\t\n\x07_choiceB\x17\n\x15_custom_router_cap_idB\x08\n\x06_s_bitB\x08\n\x06_d_bit\"c\n\x10IsisSRCapability\x12)\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.IsisSRCapabilityFlags\x12$\n\x0bsrgb_ranges\x18\x02 \x03(\x0b\x32\x0f.otg.IsisSRSrgb\"c\n\x15IsisSRCapabilityFlags\x12\x16\n\tipv4_mpls\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tipv6_mpls\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0c\n\n_ipv4_mplsB\x0c\n\n_ipv6_mpls\"V\n\nIsisSRSrgb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"V\n\nIsisSRSrlb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"\x93\x01\n\x0f\x44\x65viceBgpRouter\x12\x16\n\trouter_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12,\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x13.otg.BgpV4Interface\x12,\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x13.otg.BgpV6InterfaceB\x0c\n\n_router_id\"\x90\x02\n\x1b\x44\x65viceBgpMessageHeaderError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpMessageHeaderError.Subcode.EnumH\x00\x88\x01\x01\x1a\x9f\x01\n\x07Subcode\"\x93\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12.\n*connection_not_synchronized_code1_subcode1\x10\x01\x12%\n!bad_message_length_code1_subcode2\x10\x02\x12#\n\x1f\x62\x61\x64_message_type_code1_subcode3\x10\x03\x42\n\n\x08_subcode\"\xaa\x03\n\x19\x44\x65viceBgpOpenMessageError\x12\x41\n\x07subcode\x18\x01 \x01(\x0e\x32+.otg.DeviceBgpOpenMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xbd\x02\n\x07Subcode\"\xb1\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12-\n)unsupported_version_number_code2_subcode1\x10\x01\x12 \n\x1c\x65rror_peer_as_code2_subcode2\x10\x02\x12\x1f\n\x1b\x65rror_bgp_id_code2_subcode3\x10\x03\x12\x31\n-unsupported_optional_parameter_code2_subcode4\x10\x04\x12\x1e\n\x1a\x61uth_failed_code2_subcode5\x10\x05\x12(\n$unsupported_hold_time_code2_subcode6\x10\x06\x12)\n%unsupported_capability_code2_subcode7\x10\x07\x42\n\n\x08_subcode\"\xdc\x04\n\x1b\x44\x65viceBgpUpdateMessageError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpUpdateMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xeb\x03\n\x07Subcode\"\xdf\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12(\n$malformed_attrib_list_code3_subcode1\x10\x01\x12\x30\n,unrecognized_wellknown_attrib_code3_subcode2\x10\x02\x12+\n\'wellknown_attrib_missing_code3_subcode3\x10\x03\x12%\n!attrib_flags_error_code3_subcode4\x10\x04\x12&\n\"attrib_length_error_code3_subcode5\x10\x05\x12(\n$invalid_origin_attrib_code3_subcode6\x10\x06\x12\"\n\x1e\x61s_routing_loop_code3_subcode7\x10\x07\x12&\n\"invalid_nhop_attrib_code3_subcode8\x10\x08\x12(\n$error_optional_attrib_code3_subcode9\x10\t\x12)\n%invalid_network_field_code3_subcode10\x10\n\x12#\n\x1f\x61\x62normal_aspath_code3_subcode11\x10\x0b\x42\n\n\x08_subcode\"\x1b\n\x19\x44\x65viceBgpHoldTimerExpired\"\"\n DeviceBgpFiniteStateMachineError\"\x83\x04\n\x13\x44\x65viceBgpCeaseError\x12;\n\x07subcode\x18\x01 \x01(\x0e\x32%.otg.DeviceBgpCeaseError.Subcode.EnumH\x00\x88\x01\x01\x1a\xa2\x03\n\x07Subcode\"\x96\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12,\n(max_number_prefix_reached_code6_subcode1\x10\x01\x12!\n\x1d\x61\x64min_shutdown_code6_subcode2\x10\x02\x12\x1f\n\x1bpeer_deleted_code6_subcode3\x10\x03\x12\x1e\n\x1a\x61\x64min_reset_code6_subcode4\x10\x04\x12$\n connection_reject_code6_subcode5\x10\x05\x12\'\n#other_config_changes_code6_subcode6\x10\x06\x12\x32\n.connection_collision_resolution_code6_subcode7\x10\x07\x12#\n\x1fout_of_resources_code6_subcode8\x10\x08\x12$\n bfd_session_down_code6_subcode10\x10\t\x12\x1d\n\x19hard_reset_code6_subcode9\x10\nB\n\n\x08_subcode\"T\n\x14\x44\x65viceBgpCustomError\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x14\n\x07subcode\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_subcode\"\xe0\x06\n\tBgpV4Peer\x12\x19\n\x0cpeer_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x02 \x03(\x0b\x32\x19.otg.BgpV4EthernetSegment\x12\x30\n\x07\x61s_type\x18\x03 \x01(\x0e\x32\x1a.otg.BgpV4Peer.AsType.EnumH\x01\x88\x01\x01\x12\x16\n\tas_number\x18\x04 \x01(\rH\x02\x88\x01\x01\x12?\n\x0f\x61s_number_width\x18\x05 \x01(\x0e\x32!.otg.BgpV4Peer.AsNumberWidth.EnumH\x03\x88\x01\x01\x12\"\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x10.otg.BgpAdvanced\x12&\n\ncapability\x18\x07 \x01(\x0b\x32\x12.otg.BgpCapability\x12\x44\n\x1alearned_information_filter\x18\x08 \x01(\x0b\x32 .otg.BgpLearnedInformationFilter\x12\'\n\tv4_routes\x18\t \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0b \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x11\n\x04name\x18\r \x01(\tH\x04\x88\x01\x01\x12\x31\n\x10graceful_restart\x18\x0e \x01(\x0b\x32\x17.otg.BgpGracefulRestart\x12,\n\x0ereplay_updates\x18\x0f \x01(\x0b\x32\x14.otg.BgpUpdateReplay\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x0f\n\r_peer_addressB\n\n\x08_as_typeB\x0c\n\n_as_numberB\x12\n\x10_as_number_widthB\x07\n\x05_name\"U\n\x0e\x42gpV4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV4PeerB\x0c\n\n_ipv4_name\"\xf0\x03\n\x14\x42gpV4EthernetSegment\x12\x36\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElection\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV4EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV4EthernetSegment.ActiveMode.EnumH\x01\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPath\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_label\"N\n\x1c\x42gpEthernetSegmentDfElection\x12\x1b\n\x0e\x65lection_timer\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x11\n\x0f_election_timer\"\xda\x03\n\x10\x42gpRouteAdvanced\x12-\n include_multi_exit_discriminator\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\x01 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0einclude_origin\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x36\n\x06origin\x18\x02 \x01(\x0e\x32!.otg.BgpRouteAdvanced.Origin.EnumH\x03\x88\x01\x01\x12%\n\x18include_local_preference\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1d\n\x10local_preference\x18\x06 \x01(\rH\x05\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42#\n!_include_multi_exit_discriminatorB\x1b\n\x19_multi_exit_discriminatorB\x11\n\x0f_include_originB\t\n\x07_originB\x1b\n\x19_include_local_preferenceB\x13\n\x11_local_preference\"\xa4\x02\n\x0c\x42gpCommunity\x12.\n\x04type\x18\x01 \x01(\x0e\x32\x1b.otg.BgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"\xf9\x03\n\x0f\x42gpExtCommunity\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\x1e.otg.BgpExtCommunity.Type.EnumH\x00\x88\x01\x01\x12\x37\n\x07subtype\x18\x02 \x01(\x0e\x32!.otg.BgpExtCommunity.Subtype.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\xbc\x01\n\x04Type\"\xb3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x61\x64ministrator_as_2octet\x10\x01\x12\x1e\n\x1a\x61\x64ministrator_ipv4_address\x10\x02\x12\x1b\n\x17\x61\x64ministrator_as_4octet\x10\x03\x12\n\n\x06opaque\x10\x04\x12\x08\n\x04\x65vpn\x10\x05\x12*\n&administrator_as_2octet_link_bandwidth\x10\x06\x1a\x87\x01\n\x07Subtype\"|\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0croute_target\x10\x01\x12\n\n\x06origin\x10\x02\x12\x16\n\x12\x65xtended_bandwidth\x10\x03\x12\t\n\x05\x63olor\x10\x04\x12\x11\n\rencapsulation\x10\x05\x12\x0f\n\x0bmac_address\x10\x06\x42\x07\n\x05_typeB\n\n\x08_subtypeB\x08\n\x06_value\"\xbe\x02\n\tBgpAsPath\x12\x37\n\x0b\x61s_set_mode\x18\x01 \x01(\x0e\x32\x1d.otg.BgpAsPath.AsSetMode.EnumH\x00\x88\x01\x01\x12\'\n\x08segments\x18\x02 \x03(\x0b\x32\x15.otg.BgpAsPathSegment\x1a\xbe\x01\n\tAsSetMode\"\xb0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x64o_not_include_local_as\x10\x01\x12\x12\n\x0einclude_as_seq\x10\x02\x12\x12\n\x0einclude_as_set\x10\x03\x12\x19\n\x15include_as_confed_seq\x10\x04\x12\x19\n\x15include_as_confed_set\x10\x05\x12\x1c\n\x18prepend_to_first_segment\x10\x06\x42\x0e\n\x0c_as_set_mode\"\xc2\x01\n\x10\x42gpAsPathSegment\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"\xa8\x01\n\rBgpV4EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV4EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12%\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV4EviVxlan\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choice\"\xe3\x05\n\rBgpV4EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV4EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV4EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisher\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\'\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPath\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_label\"\xb4\x01\n\x1c\x42gpV4EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"\xd2\x03\n\x0e\x42gpCMacIpRange\x12+\n\rmac_addresses\x18\x01 \x01(\x0b\x32\x14.otg.MACRouteAddress\x12\x12\n\x05l2vni\x18\x02 \x01(\rH\x00\x88\x01\x01\x12+\n\x0eipv4_addresses\x18\x03 \x01(\x0b\x32\x13.otg.V4RouteAddress\x12+\n\x0eipv6_addresses\x18\x04 \x01(\x0b\x32\x13.otg.V6RouteAddress\x12\x12\n\x05l3vni\x18\x05 \x01(\rH\x01\x88\x01\x01\x12$\n\x17include_default_gateway\x18\x06 \x01(\x08H\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x08 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\t \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12\x11\n\x04name\x18\x0b \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_l2vniB\x08\n\x06_l3vniB\x1a\n\x18_include_default_gatewayB\x07\n\x05_name\"\x98\x02\n\x15\x42gpRouteDistinguisher\x12<\n\x07rd_type\x18\x01 \x01(\x0e\x32&.otg.BgpRouteDistinguisher.RdType.EnumH\x00\x88\x01\x01\x12#\n\x16\x61uto_config_rd_ip_addr\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x15\n\x08rd_value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1aQ\n\x06RdType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rd_typeB\x19\n\x17_auto_config_rd_ip_addrB\x0b\n\t_rd_value\"\xca\x01\n\x0e\x42gpRouteTarget\x12\x35\n\x07rt_type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpRouteTarget.RtType.EnumH\x00\x88\x01\x01\x12\x15\n\x08rt_value\x18\x02 \x01(\tH\x01\x88\x01\x01\x1aQ\n\x06RtType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rt_typeB\x0b\n\t_rt_value\"\x83\x03\n\x0b\x42gpAdvanced\x12\x1f\n\x12hold_time_interval\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13keep_alive_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0fupdate_interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x14\n\x07md5_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0cpassive_mode\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0blisten_port\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x1a\n\rneighbor_port\x18\x08 \x01(\rH\x07\x88\x01\x01\x42\x15\n\x13_hold_time_intervalB\x16\n\x14_keep_alive_intervalB\x12\n\x10_update_intervalB\x0f\n\r_time_to_liveB\n\n\x08_md5_keyB\x0f\n\r_passive_modeB\x0e\n\x0c_listen_portB\x10\n\x0e_neighbor_port\"\x91\n\n\rBgpCapability\x12\x19\n\x0cipv4_unicast\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0eipv4_multicast\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0cipv6_unicast\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0eipv6_multicast\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04vpls\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rroute_refresh\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10route_constraint\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12link_state_non_vpn\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x1b\n\x0elink_state_vpn\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x11\n\x04\x65vpn\x18\n \x01(\x08H\t\x88\x01\x01\x12\'\n\x1a\x65xtended_next_hop_encoding\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x1f\n\x12ipv4_multicast_vpn\x18\x0c \x01(\x08H\x0b\x88\x01\x01\x12\x1a\n\ripv4_mpls_vpn\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\x15\n\x08ipv4_mdt\x18\x0e \x01(\x08H\r\x88\x01\x01\x12$\n\x17ipv4_multicast_mpls_vpn\x18\x0f \x01(\x08H\x0e\x88\x01\x01\x12#\n\x16ipv4_unicast_flow_spec\x18\x10 \x01(\x08H\x0f\x88\x01\x01\x12\x1e\n\x11ipv4_sr_te_policy\x18\x11 \x01(\x08H\x10\x88\x01\x01\x12\"\n\x15ipv4_unicast_add_path\x18\x12 \x01(\x08H\x11\x88\x01\x01\x12\x1f\n\x12ipv6_multicast_vpn\x18\x13 \x01(\x08H\x12\x88\x01\x01\x12\x1a\n\ripv6_mpls_vpn\x18\x14 \x01(\x08H\x13\x88\x01\x01\x12\x15\n\x08ipv6_mdt\x18\x15 \x01(\x08H\x14\x88\x01\x01\x12$\n\x17ipv6_multicast_mpls_vpn\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12#\n\x16ipv6_unicast_flow_spec\x18\x17 \x01(\x08H\x16\x88\x01\x01\x12\x1e\n\x11ipv6_sr_te_policy\x18\x18 \x01(\x08H\x17\x88\x01\x01\x12\"\n\x15ipv6_unicast_add_path\x18\x19 \x01(\x08H\x18\x88\x01\x01\x42\x0f\n\r_ipv4_unicastB\x11\n\x0f_ipv4_multicastB\x0f\n\r_ipv6_unicastB\x11\n\x0f_ipv6_multicastB\x07\n\x05_vplsB\x10\n\x0e_route_refreshB\x13\n\x11_route_constraintB\x15\n\x13_link_state_non_vpnB\x11\n\x0f_link_state_vpnB\x07\n\x05_evpnB\x1d\n\x1b_extended_next_hop_encodingB\x15\n\x13_ipv4_multicast_vpnB\x10\n\x0e_ipv4_mpls_vpnB\x0b\n\t_ipv4_mdtB\x1a\n\x18_ipv4_multicast_mpls_vpnB\x19\n\x17_ipv4_unicast_flow_specB\x14\n\x12_ipv4_sr_te_policyB\x18\n\x16_ipv4_unicast_add_pathB\x15\n\x13_ipv6_multicast_vpnB\x10\n\x0e_ipv6_mpls_vpnB\x0b\n\t_ipv6_mdtB\x1a\n\x18_ipv6_multicast_mpls_vpnB\x19\n\x17_ipv6_unicast_flow_specB\x14\n\x12_ipv6_sr_te_policyB\x18\n\x16_ipv6_unicast_add_path\"\x91\x01\n\x1b\x42gpLearnedInformationFilter\x12 \n\x13unicast_ipv4_prefix\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13unicast_ipv6_prefix\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x16\n\x14_unicast_ipv4_prefixB\x16\n\x14_unicast_ipv6_prefix\"\x94\x06\n\x0f\x42gpV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV4RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV4RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12\x1f\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPath\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x11\n\x04name\x18\n \x01(\tH\x04\x88\x01\x01\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x37\n\x14\x65xtended_communities\x18\x0c \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_name\".\n\nBgpAddPath\x12\x14\n\x07path_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\n\n\x08_path_id\"\xf3\x06\n\x14\x42gpExtendedCommunity\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.BgpExtendedCommunity.Choice.EnumH\x00\x88\x01\x01\x12R\n\x19transitive_2octet_as_type\x18\x02 \x01(\x0b\x32/.otg.BgpExtendedCommunityTransitive2OctetAsType\x12X\n\x1ctransitive_ipv4_address_type\x18\x03 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityTransitiveIpv4AddressType\x12R\n\x19transitive_4octet_as_type\x18\x04 \x01(\x0b\x32/.otg.BgpExtendedCommunityTransitive4OctetAsType\x12M\n\x16transitive_opaque_type\x18\x05 \x01(\x0b\x32-.otg.BgpExtendedCommunityTransitiveOpaqueType\x12I\n\x14transitive_evpn_type\x18\x06 \x01(\x0b\x32+.otg.BgpExtendedCommunityTransitiveEvpnType\x12Y\n\x1dnon_transitive_2octet_as_type\x18\x07 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityNonTransitive2OctetAsType\x12\x33\n\x06\x63ustom\x18\x08 \x01(\x0b\x32#.otg.BgpExtendedCommunityCustomType\x1a\xe7\x01\n\x06\x43hoice\"\xdc\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1d\n\x19transitive_2octet_as_type\x10\x01\x12 \n\x1ctransitive_ipv4_address_type\x10\x02\x12\x1d\n\x19transitive_4octet_as_type\x10\x03\x12\x1a\n\x16transitive_opaque_type\x10\x04\x12\x18\n\x14transitive_evpn_type\x10\x05\x12!\n\x1dnon_transitive_2octet_as_type\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\x9f\x01\n5BgpExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\x9f\x01\n5BgpExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\x94\x03\n*BgpExtendedCommunityTransitive2OctetAsType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.BgpExtendedCommunityTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12X\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12X\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa6\x01\n8BgpExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa6\x01\n8BgpExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa0\x03\n-BgpExtendedCommunityTransitiveIpv4AddressType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.BgpExtendedCommunityTransitiveIpv4AddressType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.BgpExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.BgpExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\x9f\x01\n5BgpExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\x9f\x01\n5BgpExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\x94\x03\n*BgpExtendedCommunityTransitive4OctetAsType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.BgpExtendedCommunityTransitive4OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12X\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12X\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"k\n-BgpExtendedCommunityTransitiveOpaqueTypeColor\x12\x12\n\x05\x66lags\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_color\"\x85\x01\n5BgpExtendedCommunityTransitiveOpaqueTypeEncapsulation\x12\x15\n\x08reserved\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0btunnel_type\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0b\n\t_reservedB\x0e\n\x0c_tunnel_type\"\xfc\x02\n(BgpExtendedCommunityTransitiveOpaqueType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.BgpExtendedCommunityTransitiveOpaqueType.Choice.EnumH\x00\x88\x01\x01\x12I\n\rcolor_subtype\x18\x02 \x01(\x0b\x32\x32.otg.BgpExtendedCommunityTransitiveOpaqueTypeColor\x12Y\n\x15\x65ncapsulation_subtype\x18\x03 \x01(\x0b\x32:.otg.BgpExtendedCommunityTransitiveOpaqueTypeEncapsulation\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rcolor_subtype\x10\x01\x12\x19\n\x15\x65ncapsulation_subtype\x10\x02\x42\t\n\x07_choice\"Y\n/BgpExtendedCommunityTransitiveEvpnTypeRouterMac\x12\x17\n\nrouter_mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_router_mac\"\x8e\x02\n&BgpExtendedCommunityTransitiveEvpnType\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.BgpExtendedCommunityTransitiveEvpnType.Choice.EnumH\x00\x88\x01\x01\x12P\n\x12router_mac_subtype\x18\x02 \x01(\x0b\x32\x34.otg.BgpExtendedCommunityTransitiveEvpnTypeRouterMac\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12router_mac_subtype\x10\x01\x42\t\n\x07_choice\"\x94\x01\n:BgpExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tbandwidth\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x0c\n\n_bandwidth\"\xaf\x02\n-BgpExtendedCommunityNonTransitive2OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.BgpExtendedCommunityNonTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12_\n\x16link_bandwidth_subtype\x18\x02 \x01(\x0b\x32?.otg.BgpExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16link_bandwidth_subtype\x10\x01\x42\t\n\x07_choice\"\xa4\x01\n\x1e\x42gpExtendedCommunityCustomType\x12\x1b\n\x0e\x63ommunity_type\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11\x63ommunity_subtype\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x11\n\x0f_community_typeB\x14\n\x12_community_subtypeB\x08\n\x06_value\"\x94\x06\n\x0f\x42gpV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV6RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV6RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12\x1f\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPath\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x11\n\x04name\x18\n \x01(\tH\x04\x88\x01\x01\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x37\n\x14\x65xtended_communities\x18\x0c \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_name\"\xfb\x06\n\x0f\x42gpSrteV4Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\ripv4_endpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV4Policy.NextHopMode.EnumH\x03\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV4Policy.NextHopAddressType.EnumH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV4TunnelTlv\x12\x11\n\x04name\x18\x0e \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\x08\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_ipv4_endpointB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_nameB\t\n\x07_active\"\xb6\x04\n\x12\x42gpSrteV4TunnelTlv\x12\x41\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlv\x12.\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlv\x12\x32\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlv\x12\x38\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlv\x12\x41\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlv\x12\x39\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlv\x12U\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlv\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x11\n\x04name\x18\t \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_active\"\xbe\x02\n\x1b\x42gpSrteRemoteEndpointSubTlv\x12\x16\n\tas_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12P\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32\x33.otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.EnumH\x01\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a<\n\rAddressFamily\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x0c\n\n_as_numberB\x11\n\x0f_address_familyB\x0f\n\r_ipv4_addressB\x0f\n\r_ipv6_address\"2\n\x12\x42gpSrteColorSubTlv\x12\x12\n\x05\x63olor\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_color\"\xea\x02\n\x14\x42gpSrteBindingSubTlv\x12L\n\x10\x62inding_sid_type\x18\x01 \x01(\x0e\x32-.otg.BgpSrteBindingSubTlv.BindingSidType.EnumH\x00\x88\x01\x01\x12\x1b\n\x0e\x66our_octet_sid\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08ipv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06s_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06i_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x1a[\n\x0e\x42indingSidType\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nno_binding\x10\x01\x12\x12\n\x0e\x66our_octet_sid\x10\x02\x12\x0c\n\x08ipv6_sid\x10\x03\x42\x13\n\x11_binding_sid_typeB\x11\n\x0f_four_octet_sidB\x0b\n\t_ipv6_sidB\t\n\x07_s_flagB\t\n\x07_i_flag\"A\n\x17\x42gpSrtePreferenceSubTlv\x12\x17\n\npreference\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\r\n\x0b_preference\"O\n\x1b\x42gpSrtePolicyPrioritySubTlv\x12\x1c\n\x0fpolicy_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x12\n\x10_policy_priority\"C\n\x17\x42gpSrtePolicyNameSubTlv\x12\x18\n\x0bpolicy_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_policy_name\"\xd6\x02\n$BgpSrteExplicitNullLabelPolicySubTlv\x12o\n\x1a\x65xplicit_null_label_policy\x18\x01 \x01(\x0e\x32\x46.otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.EnumH\x00\x88\x01\x01\x1a\x9d\x01\n\x17\x45xplicitNullLabelPolicy\"\x81\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rreserved_enlp\x10\x01\x12\x12\n\x0epush_ipv4_enlp\x10\x02\x12\x12\n\x0epush_ipv6_enlp\x10\x03\x12\x17\n\x13push_ipv4_ipv6_enlp\x10\x04\x12\x14\n\x10\x64o_not_push_enlp\x10\x05\x42\x1d\n\x1b_explicit_null_label_policy\"\x97\x01\n\x12\x42gpSrteSegmentList\x12\x13\n\x06weight\x18\x01 \x01(\rH\x00\x88\x01\x01\x12%\n\x08segments\x18\x02 \x03(\x0b\x32\x13.otg.BgpSrteSegment\x12\x11\n\x04name\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_weightB\x07\n\x05_nameB\t\n\x07_active\"\xdc\x06\n\x0e\x42gpSrteSegment\x12?\n\x0csegment_type\x18\x01 \x01(\x0e\x32$.otg.BgpSrteSegment.SegmentType.EnumH\x00\x88\x01\x01\x12.\n\x06type_a\x18\x02 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentATypeSubTlv\x12.\n\x06type_b\x18\x03 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentBTypeSubTlv\x12.\n\x06type_c\x18\x04 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentCTypeSubTlv\x12.\n\x06type_d\x18\x05 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentDTypeSubTlv\x12.\n\x06type_e\x18\x06 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentETypeSubTlv\x12.\n\x06type_f\x18\x07 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentFTypeSubTlv\x12.\n\x06type_g\x18\x08 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentGTypeSubTlv\x12.\n\x06type_h\x18\t \x01(\x0b\x32\x1e.otg.BgpSrteSegmentHTypeSubTlv\x12.\n\x06type_i\x18\n \x01(\x0b\x32\x1e.otg.BgpSrteSegmentITypeSubTlv\x12.\n\x06type_j\x18\x0b \x01(\x0b\x32\x1e.otg.BgpSrteSegmentJTypeSubTlv\x12.\n\x06type_k\x18\x0c \x01(\x0b\x32\x1e.otg.BgpSrteSegmentKTypeSubTlv\x12\x11\n\x04name\x18\r \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0e \x01(\x08H\x02\x88\x01\x01\x1a\xab\x01\n\x0bSegmentType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\x0f\n\r_segment_typeB\x07\n\x05_nameB\t\n\x07_active\"\x80\x01\n\x10\x42gpSrteSrMplsSid\x12\x12\n\x05label\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02tc\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05s_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xca\x01\n*BgpSrteSRv6SIDEndpointBehaviorAndStructure\x12\x16\n\tlb_length\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tln_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\narg_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"\xa7\x01\n\x19\x42gpSrteSegmentATypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05label\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02tc\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05s_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x10\n\x03ttl\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xb2\x01\n\x19\x42gpSrteSegmentBTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x02 \x01(\tH\x01\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x03 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0b\n\t_srv6_sid\"\xc7\x01\n\x19\x42gpSrteSegmentCTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv4_node_address\"\xc7\x01\n\x19\x42gpSrteSegmentDTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\xd3\x01\n\x19\x42gpSrteSegmentETypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x14\n\x12_ipv4_node_address\"\xd7\x01\n\x19\x42gpSrteSegmentFTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_ipv4_addressB\x16\n\x14_remote_ipv4_address\"\xdd\x02\n\x19\x42gpSrteSegmentGTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x05 \x01(\tH\x04\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\xd7\x01\n\x19\x42gpSrteSegmentHTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12*\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidB\x08\n\x06_flagsB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xe8\x01\n\x19\x42gpSrteSegmentITypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x04 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x14\n\x12_ipv6_node_addressB\x0b\n\t_srv6_sid\"\xd6\x03\n\x19\x42gpSrteSegmentJTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x05 \x01(\rH\x04\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x07 \x01(\tH\x06\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x08 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_addressB\x0b\n\t_srv6_sid\"\xd0\x02\n\x19\x42gpSrteSegmentKTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08srv6_sid\x18\x05 \x01(\tH\x04\x88\x01\x01\x12S\n\x1asrv6_sid_endpoint_behavior\x18\x06 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureB\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_addressB\x0b\n\t_srv6_sid\"\xfa\x06\n\x0f\x42gpSrteV6Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\ripv6_endpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV6Policy.NextHopMode.EnumH\x03\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV6Policy.NextHopAddressType.EnumH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12!\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPath\x12\x1f\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPath\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12,\n\x0e\x65xtcommunities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV6TunnelTlv\x12\x11\n\x04name\x18\x0e \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\x08\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_ipv6_endpointB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x07\n\x05_nameB\t\n\x07_active\"\xb6\x04\n\x12\x42gpSrteV6TunnelTlv\x12\x41\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlv\x12.\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlv\x12\x32\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlv\x12\x38\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlv\x12\x41\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlv\x12\x39\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlv\x12U\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlv\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x11\n\x04name\x18\t \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_active\"\xf2\x01\n\x12\x42gpGracefulRestart\x12\x16\n\tenable_gr\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0crestart_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x65nable_llgr\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstale_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12 \n\x13\x65nable_notification\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x0c\n\n_enable_grB\x0f\n\r_restart_timeB\x0e\n\x0c_enable_llgrB\r\n\x0b_stale_timeB\x16\n\x14_enable_notification\"\xf0\x01\n\x0f\x42gpUpdateReplay\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.BgpUpdateReplay.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0fstructured_pdus\x18\x02 \x01(\x0b\x32\x16.otg.BgpStructuredPdus\x12#\n\traw_bytes\x18\x03 \x01(\x0b\x32\x10.otg.BgpRawBytes\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fstructured_pdus\x10\x01\x12\r\n\traw_bytes\x10\x02\x42\t\n\x07_choice\"7\n\x0b\x42gpRawBytes\x12(\n\x07updates\x18\x01 \x03(\x0b\x32\x17.otg.BgpOneUpdateReplay\"d\n\x12\x42gpOneUpdateReplay\x12\x15\n\x08time_gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x19\n\x0cupdate_bytes\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_time_gapB\x0f\n\r_update_bytes\"G\n\x11\x42gpStructuredPdus\x12\x32\n\x07updates\x18\x01 \x03(\x0b\x32!.otg.BgpOneStructuredUpdateReplay\"\xf7\x01\n\x1c\x42gpOneStructuredUpdateReplay\x12\x15\n\x08time_gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12+\n\x0fpath_attributes\x18\x02 \x01(\x0b\x32\x12.otg.BgpAttributes\x12\x43\n\x19traditional_unreach_nlris\x18\x03 \x03(\x0b\x32 .otg.BgpOneTraditionalNlriPrefix\x12\x41\n\x17traditional_reach_nlris\x18\x04 \x03(\x0b\x32 .otg.BgpOneTraditionalNlriPrefixB\x0b\n\t_time_gap\"\x8a\x01\n\x1b\x42gpOneTraditionalNlriPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"\x83\x01\n\x14\x42gpOneIpv4NLRIPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"\x83\x01\n\x14\x42gpOneIpv6NLRIPrefix\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06prefix\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x07path_id\x18\x03 \x01(\x0b\x32\x18.otg.BgpNLRIPrefixPathIdB\n\n\x08_addressB\t\n\x07_prefix\"3\n\x13\x42gpNLRIPrefixPathId\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\x8b\x01\n\x19\x42gpIpv4SrPolicyNLRIPrefix\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x65ndpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x0b\n\t_endpoint\"\x8b\x01\n\x19\x42gpIpv6SrPolicyNLRIPrefix\x12\x1a\n\rdistinguisher\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x65ndpoint\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x0b\n\t_endpoint\"\xef\x07\n\rBgpAttributes\x12:\n\x10other_attributes\x18\x01 \x03(\x0b\x32 .otg.BgpAttributesOtherAttribute\x12\x33\n\x06origin\x18\x02 \x01(\x0e\x32\x1e.otg.BgpAttributes.Origin.EnumH\x00\x88\x01\x01\x12)\n\x07\x61s_path\x18\x03 \x01(\x0b\x32\x18.otg.BgpAttributesAsPath\x12+\n\x08\x61s4_path\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesAs4Path\x12+\n\x08next_hop\x18\x05 \x01(\x0b\x32\x19.otg.BgpAttributesNextHop\x12J\n\x18multi_exit_discriminator\x18\x06 \x01(\x0b\x32(.otg.BgpAttributesMultiExitDiscriminator\x12;\n\x10local_preference\x18\x07 \x01(\x0b\x32!.otg.BgpAttributesLocalPreference\x12&\n\x19include_atomic_aggregator\x18\x08 \x01(\x08H\x01\x88\x01\x01\x12\x30\n\naggregator\x18\t \x01(\x0b\x32\x1c.otg.BgpAttributesAggregator\x12\x37\n\x0e\x61s4_aggregator\x18\n \x01(\x0b\x32\x1f.otg.BgpAttributesAs4Aggregator\x12.\n\tcommunity\x18\x0b \x03(\x0b\x32\x1b.otg.BgpAttributesCommunity\x12\x35\n\roriginator_id\x18\x0c \x01(\x0b\x32\x1e.otg.BgpAttributesOriginatorId\x12\x13\n\x0b\x63luster_ids\x18\r \x03(\t\x12\x37\n\x14\x65xtended_communities\x18\x0e \x03(\x0b\x32\x19.otg.BgpExtendedCommunity\x12\x43\n\x14tunnel_encapsulation\x18\x0f \x01(\x0b\x32%.otg.BgpAttributesTunnelEncapsulation\x12/\n\x08mp_reach\x18\x10 \x01(\x0b\x32\x1d.otg.BgpAttributesMpReachNlri\x12\x33\n\nmp_unreach\x18\x11 \x01(\x0b\x32\x1f.otg.BgpAttributesMpUnreachNlri\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\t\n\x07_originB\x1c\n\x1a_include_atomic_aggregator\"\xa7\x02\n\x1b\x42gpAttributesOtherAttribute\x12\x1a\n\rflag_optional\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1c\n\x0f\x66lag_transitive\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0c\x66lag_partial\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x66lag_extended_length\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\traw_value\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x10\n\x0e_flag_optionalB\x12\n\x10_flag_transitiveB\x0f\n\r_flag_partialB\x17\n\x15_flag_extended_lengthB\x07\n\x05_typeB\x0c\n\n_raw_value\"\xaf\x02\n\x13\x42gpAttributesAsPath\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.BgpAttributesAsPath.Choice.EnumH\x00\x88\x01\x01\x12\x41\n\x11\x66our_byte_as_path\x18\x02 \x01(\x0b\x32&.otg.BgpAttributesAsPathFourByteAsPath\x12?\n\x10two_byte_as_path\x18\x03 \x01(\x0b\x32%.otg.BgpAttributesAsPathTwoByteAsPath\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11\x66our_byte_as_path\x10\x01\x12\x14\n\x10two_byte_as_path\x10\x02\x42\t\n\x07_choice\"^\n!BgpAttributesAsPathFourByteAsPath\x12\x39\n\x08segments\x18\x01 \x03(\x0b\x32\'.otg.BgpAttributesFourByteAsPathSegment\"\xe6\x01\n\"BgpAttributesFourByteAsPathSegment\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x31.otg.BgpAttributesFourByteAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"\\\n BgpAttributesAsPathTwoByteAsPath\x12\x38\n\x08segments\x18\x01 \x03(\x0b\x32&.otg.BgpAttributesTwoByteAsPathSegment\"\xe4\x01\n!BgpAttributesTwoByteAsPathSegment\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x30.otg.BgpAttributesTwoByteAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"Q\n\x14\x42gpAttributesAs4Path\x12\x39\n\x08segments\x18\x01 \x03(\x0b\x32\'.otg.BgpAttributesFourByteAsPathSegment\"\xab\x02\n\x17\x42gpAttributesAggregator\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.BgpAttributesAggregator.Choice.EnumH\x00\x88\x01\x01\x12\x19\n\x0c\x66our_byte_as\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0btwo_byte_as\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66our_byte_as\x10\x01\x12\x0f\n\x0btwo_byte_as\x10\x02\x42\t\n\x07_choiceB\x0f\n\r_four_byte_asB\x0e\n\x0c_two_byte_asB\x0f\n\r_ipv4_address\"h\n\x1a\x42gpAttributesAs4Aggregator\x12\x13\n\x06\x61s_num\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_as_numB\x0f\n\r_ipv4_address\"\xb1\x02\n\x16\x42gpAttributesCommunity\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.BgpAttributesCommunity.Choice.EnumH\x00\x88\x01\x01\x12;\n\x10\x63ustom_community\x18\x02 \x01(\x0b\x32!.otg.BgpAttributesCustomCommunity\x1a\x90\x01\n\x06\x43hoice\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x63ustom_community\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\t\n\x07_choice\"d\n\x1c\x42gpAttributesCustomCommunity\x12\x16\n\tas_number\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_as_numberB\t\n\x07_custom\"\xab\x02\n\x14\x42gpAttributesNextHop\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.BgpAttributesNextHop.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04ipv4\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04ipv6\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x45\n\x12ipv6_two_addresses\x18\x04 \x01(\x0b\x32).otg.BgpAttributesNextHopIpv6TwoAddresses\x1aM\n\x06\x43hoice\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x16\n\x12ipv6_two_addresses\x10\x03\x42\t\n\x07_choiceB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"d\n$BgpAttributesNextHopIpv6TwoAddresses\x12\x12\n\x05\x66irst\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06second\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_firstB\t\n\x07_second\"\xcf\x03\n\x18\x42gpAttributesMpReachNlri\x12+\n\x08next_hop\x18\x01 \x01(\x0b\x32\x19.otg.BgpAttributesNextHop\x12>\n\x06\x63hoice\x18\x02 \x01(\x0e\x32).otg.BgpAttributesMpReachNlri.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0cipv4_unicast\x18\x03 \x03(\x0b\x32\x19.otg.BgpOneIpv4NLRIPrefix\x12/\n\x0cipv6_unicast\x18\x04 \x03(\x0b\x32\x19.otg.BgpOneIpv6NLRIPrefix\x12\x35\n\ripv4_srpolicy\x18\x05 \x01(\x0b\x32\x1e.otg.BgpIpv4SrPolicyNLRIPrefix\x12\x35\n\ripv6_srpolicy\x18\x06 \x01(\x0b\x32\x1e.otg.BgpIpv6SrPolicyNLRIPrefix\x1ak\n\x06\x43hoice\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\x12\x11\n\ripv4_srpolicy\x10\x03\x12\x11\n\ripv6_srpolicy\x10\x04\x42\t\n\x07_choice\"\xa6\x03\n\x1a\x42gpAttributesMpUnreachNlri\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.BgpAttributesMpUnreachNlri.Choice.EnumH\x00\x88\x01\x01\x12/\n\x0cipv4_unicast\x18\x02 \x03(\x0b\x32\x19.otg.BgpOneIpv4NLRIPrefix\x12/\n\x0cipv6_unicast\x18\x03 \x03(\x0b\x32\x19.otg.BgpOneIpv6NLRIPrefix\x12\x35\n\ripv4_srpolicy\x18\x04 \x01(\x0b\x32\x1e.otg.BgpIpv4SrPolicyNLRIPrefix\x12\x35\n\ripv6_srpolicy\x18\x05 \x01(\x0b\x32\x1e.otg.BgpIpv6SrPolicyNLRIPrefix\x1ak\n\x06\x43hoice\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\x12\x11\n\ripv4_srpolicy\x10\x03\x12\x11\n\ripv6_srpolicy\x10\x04\x42\t\n\x07_choice\"C\n#BgpAttributesMultiExitDiscriminator\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"<\n\x1c\x42gpAttributesLocalPreference\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"9\n\x19\x42gpAttributesOriginatorId\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xe2\x01\n BgpAttributesTunnelEncapsulation\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.BgpAttributesTunnelEncapsulation.Choice.EnumH\x00\x88\x01\x01\x12\x39\n\tsr_policy\x18\x02 \x01(\x0b\x32&.otg.BgpAttributesSegmentRoutingPolicy\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsr_policy\x10\x01\x42\t\n\x07_choice\"\xac\x04\n!BgpAttributesSegmentRoutingPolicy\x12:\n\x1a\x62inding_segment_identifier\x18\x01 \x01(\x0b\x32\x16.otg.BgpAttributesBsid\x12\x43\n\x1fsrv6_binding_segment_identifier\x18\x02 \x03(\x0b\x32\x1a.otg.BgpAttributesSrv6Bsid\x12\x38\n\npreference\x18\x03 \x01(\x0b\x32$.otg.BgpAttributesSrPolicyPreference\x12\x34\n\x08priority\x18\x04 \x01(\x0b\x32\".otg.BgpAttributesSrPolicyPriority\x12\x39\n\x0bpolicy_name\x18\x05 \x01(\x0b\x32$.otg.BgpAttributesSrPolicyPolicyName\x12L\n\x15policy_candidate_name\x18\x06 \x01(\x0b\x32-.otg.BgpAttributesSrPolicyPolicyCandidateName\x12P\n\x1a\x65xplicit_null_label_policy\x18\x07 \x01(\x0b\x32,.otg.BgpAttributesSrPolicyExplicitNullPolicy\x12;\n\x0csegment_list\x18\x08 \x03(\x0b\x32%.otg.BgpAttributesSrPolicySegmentList\"\xe2\x01\n\x11\x42gpAttributesBsid\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.BgpAttributesBsid.Choice.EnumH\x00\x88\x01\x01\x12(\n\x04mpls\x18\x02 \x01(\x0b\x32\x1a.otg.BgpAttributesBsidMpls\x12(\n\x04srv6\x18\x03 \x01(\x0b\x32\x1a.otg.BgpAttributesBsidSrv6\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mpls\x10\x01\x12\x08\n\x04srv6\x10\x02\x42\t\n\x07_choice\"\xc8\x01\n\x15\x42gpAttributesBsidMpls\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12+\n\x08mpls_sid\x18\x03 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalid\"\xc1\x01\n\x15\x42gpAttributesBsidSrv6\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x16\n\tipv6_addr\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalidB\x0c\n\n_ipv6_addr\"\xf6\x02\n\x15\x42gpAttributesSrv6Bsid\x12%\n\x18\x66lag_specified_bsid_only\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16\x66lag_drop_upon_invalid\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12(\n\x1b\x66lag_srv6_endpoint_behavior\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x16\n\tipv6_addr\x18\x04 \x01(\tH\x03\x88\x01\x01\x12i\n\x16srv6_endpoint_behavior\x18\x05 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x1b\n\x19_flag_specified_bsid_onlyB\x19\n\x17_flag_drop_upon_invalidB\x1e\n\x1c_flag_srv6_endpoint_behaviorB\x0c\n\n_ipv6_addr\"\xa0\x01\n\x14\x42gpAttributesSidMpls\x12\x12\n\x05label\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rtraffic_class\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x66lag_bos\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x10\n\x0e_traffic_classB\x0b\n\t_flag_bosB\x06\n\x04_ttl\".\n\x14\x42gpAttributesSidSrv6\x12\x0f\n\x02ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_ip\"?\n\x1f\x42gpAttributesSrPolicyPreference\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"=\n\x1d\x42gpAttributesSrPolicyPriority\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"H\n(BgpAttributesSrPolicyPolicyCandidateName\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"?\n\x1f\x42gpAttributesSrPolicyPolicyName\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xf9\x01\n\'BgpAttributesSrPolicyExplicitNullPolicy\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.BgpAttributesSrPolicyExplicitNullPolicy.Choice.EnumH\x00\x88\x01\x01\x1at\n\x06\x43hoice\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unknown\x10\x01\x12\r\n\tpush_ipv4\x10\x02\x12\r\n\tpush_ipv6\x10\x03\x12\x16\n\x12push_ipv4_and_ipv6\x10\x04\x12\x0e\n\ndonot_push\x10\x05\x42\t\n\x07_choice\"\xb7\x01\n BgpAttributesSrPolicySegmentList\x12G\n\x06weight\x18\x01 \x01(\x0b\x32\x37.otg.BgpAttributesSegmentRoutingPolicySegmentListWeight\x12J\n\x08segments\x18\x02 \x03(\x0b\x32\x38.otg.BgpAttributesSegmentRoutingPolicySegmentListSegment\"R\n2BgpAttributesSegmentRoutingPolicySegmentListWeight\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xe3\x07\n3BgpAttributesSegmentRoutingPolicySegmentListSegment\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.BgpAttributesSegmentRoutingPolicySegmentListSegment.Choice.EnumH\x00\x88\x01\x01\x12;\n\x06type_a\x18\x02 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeA\x12;\n\x06type_b\x18\x03 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeB\x12;\n\x06type_c\x18\x04 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeC\x12;\n\x06type_d\x18\x05 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeD\x12;\n\x06type_e\x18\x06 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeE\x12;\n\x06type_f\x18\x07 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeF\x12;\n\x06type_g\x18\x08 \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeG\x12;\n\x06type_h\x18\t \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeH\x12;\n\x06type_i\x18\n \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeI\x12;\n\x06type_j\x18\x0b \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeJ\x12;\n\x06type_k\x18\x0c \x01(\x0b\x32+.otg.BgpAttributesSegmentRoutingPolicyTypeK\x1a\xa6\x01\n\x06\x43hoice\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\t\n\x07_choice\"\x95\x01\n&BgpAttributesSegmentRoutingPolicyTypeA\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12+\n\x08mpls_sid\x18\x02 \x01(\x0b\x32\x19.otg.BgpAttributesSidMpls\"\xf7\x01\n&BgpAttributesSegmentRoutingPolicyTypeB\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x15\n\x08srv6_sid\x18\x02 \x01(\tH\x00\x88\x01\x01\x12i\n\x16srv6_endpoint_behavior\x18\x03 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0b\n\t_srv6_sid\"\xfa\x01\n&BgpAttributesSegmentRoutingPolicyTypeC\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv4_node_address\"\xfa\x01\n&BgpAttributesSegmentRoutingPolicyTypeD\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\x86\x02\n&BgpAttributesSegmentRoutingPolicyTypeE\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv4_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_interface_idB\x14\n\x12_ipv4_node_address\"\x8a\x02\n&BgpAttributesSegmentRoutingPolicyTypeF\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_ipv4_address\x18\x02 \x01(\tH\x00\x88\x01\x01\x12 \n\x13remote_ipv4_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_ipv4_addressB\x16\n\x14_remote_ipv4_address\"\x90\x03\n&BgpAttributesSegmentRoutingPolicyTypeG\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\x8a\x02\n&BgpAttributesSegmentRoutingPolicyTypeH\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x1f\n\x12local_ipv6_address\x18\x02 \x01(\tH\x00\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12.\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x19.otg.BgpAttributesSidMplsB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xe2\x02\n&BgpAttributesSegmentRoutingPolicyTypeI\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11ipv6_node_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\x08srv6_sid\x18\x04 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x05 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x14\n\x12_ipv6_node_address\"\xa4\x04\n&BgpAttributesSegmentRoutingPolicyTypeJ\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\rH\x01\x88\x01\x01\x12$\n\x17local_ipv6_node_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12 \n\x13remote_interface_id\x18\x05 \x01(\rH\x03\x88\x01\x01\x12%\n\x18remote_ipv6_node_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12+\n\x08srv6_sid\x18\x07 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x08 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x1a\n\x18_local_ipv6_node_addressB\x16\n\x14_remote_interface_idB\x1b\n\x19_remote_ipv6_node_address\"\x9e\x03\n&BgpAttributesSegmentRoutingPolicyTypeK\x12>\n\x05\x66lags\x18\x01 \x01(\x0b\x32/.otg.BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12local_ipv6_address\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13remote_ipv6_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12+\n\x08srv6_sid\x18\x05 \x01(\x0b\x32\x19.otg.BgpAttributesSidSrv6\x12i\n\x16srv6_endpoint_behavior\x18\x06 \x01(\x0b\x32I.otg.BgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructureB\x0f\n\r_sr_algorithmB\x15\n\x13_local_ipv6_addressB\x16\n\x14_remote_ipv6_address\"\xac\x01\n*BgpAttributesSegmentRoutingPolicyTypeFlags\x12\x13\n\x06v_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x61_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06s_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\t\n\x07_v_flagB\t\n\x07_a_flagB\t\n\x07_s_flagB\t\n\x07_b_flag\"\x9c\x02\nDBgpAttributesSegmentRoutingPolicySRv6SIDEndpointBehaviorAndStructure\x12\x1f\n\x12\x65ndpoint_behaviour\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tlb_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tln_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x17\n\narg_length\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x15\n\x13_endpoint_behaviourB\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"H\n(BgpNLRIPrefixSegmentRoutingDistinguisher\x12\x12\n\x05value\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_value\"\x93\x07\n\tBgpV6Peer\x12\x19\n\x0cpeer_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x31\n\x0fsegment_routing\x18\x02 \x01(\x0b\x32\x18.otg.BgpV6SegmentRouting\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x03 \x03(\x0b\x32\x19.otg.BgpV6EthernetSegment\x12\x30\n\x07\x61s_type\x18\x04 \x01(\x0e\x32\x1a.otg.BgpV6Peer.AsType.EnumH\x01\x88\x01\x01\x12\x16\n\tas_number\x18\x05 \x01(\rH\x02\x88\x01\x01\x12?\n\x0f\x61s_number_width\x18\x06 \x01(\x0e\x32!.otg.BgpV6Peer.AsNumberWidth.EnumH\x03\x88\x01\x01\x12\"\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x10.otg.BgpAdvanced\x12&\n\ncapability\x18\x08 \x01(\x0b\x32\x12.otg.BgpCapability\x12\x44\n\x1alearned_information_filter\x18\t \x01(\x0b\x32 .otg.BgpLearnedInformationFilter\x12\'\n\tv4_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\x0b \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\r \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x11\n\x04name\x18\x0e \x01(\tH\x04\x88\x01\x01\x12\x31\n\x10graceful_restart\x18\x0f \x01(\x0b\x32\x17.otg.BgpGracefulRestart\x12,\n\x0ereplay_updates\x18\x10 \x01(\x0b\x32\x14.otg.BgpUpdateReplay\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x0f\n\r_peer_addressB\n\n\x08_as_typeB\x0c\n\n_as_numberB\x12\n\x10_as_number_widthB\x07\n\x05_name\"U\n\x0e\x42gpV6Interface\x12\x16\n\tipv6_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV6PeerB\x0c\n\n_ipv6_name\"\xf1\x03\n\x13\x42gpV6SegmentRouting\x12!\n\x14ingress_supports_vpn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15reduced_encapsulation\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x11\x63opy_time_to_live\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10max_sids_per_srh\x18\x05 \x01(\rH\x04\x88\x01\x01\x12-\n auto_generate_segment_left_value\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1f\n\x12segment_left_value\x18\x07 \x01(\rH\x06\x88\x01\x01\x12#\n\x16\x61\x64vertise_sr_te_policy\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x17\n\x15_ingress_supports_vpnB\x18\n\x16_reduced_encapsulationB\x14\n\x12_copy_time_to_liveB\x0f\n\r_time_to_liveB\x13\n\x11_max_sids_per_srhB#\n!_auto_generate_segment_left_valueB\x15\n\x13_segment_left_valueB\x19\n\x17_advertise_sr_te_policy\"\xf0\x03\n\x14\x42gpV6EthernetSegment\x12\x36\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElection\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV6EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV6EthernetSegment.ActiveMode.EnumH\x01\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPath\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_label\"\xa8\x01\n\rBgpV6EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV6EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12%\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV6EviVxlan\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choice\"\xe3\x05\n\rBgpV6EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV6EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV6EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisher\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\'\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvanced\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12\x1f\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPath\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_label\"\xb4\x01\n\x1c\x42gpV6EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"]\n\x0b\x44\x65viceVxlan\x12&\n\nv4_tunnels\x18\x01 \x03(\x0b\x32\x12.otg.VxlanV4Tunnel\x12&\n\nv6_tunnels\x18\x02 \x03(\x0b\x32\x12.otg.VxlanV6Tunnel\"\xbb\x01\n\rVxlanV4Tunnel\x12\x1d\n\x10source_interface\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV4TunnelDestinationIPMode\x12\x10\n\x03vni\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_source_interfaceB\x06\n\x04_vniB\x07\n\x05_name\"\xbb\x01\n\rVxlanV6Tunnel\x12\x1d\n\x10source_interface\x18\x01 \x01(\tH\x00\x88\x01\x01\x12@\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV6TunnelDestinationIPMode\x12\x10\n\x03vni\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_source_interfaceB\x06\n\x04_vniB\x07\n\x05_name\"\xae\x02\n\x1eVxlanV4TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV4TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12;\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV4TunnelDestinationIPModeUnicast\x12?\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV4TunnelDestinationIPModeMulticast\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choice\"\xae\x02\n\x1eVxlanV6TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV6TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12;\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV6TunnelDestinationIPModeUnicast\x12?\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV6TunnelDestinationIPModeMulticast\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choice\"f\n%VxlanV4TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV4TunnelDestinationIPModeUnicastVtep\"f\n%VxlanV6TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV6TunnelDestinationIPModeUnicastVtep\"\x96\x01\n6VxlanTunnelDestinationIPModeUnicastArpSuppressionCache\x12\x1a\n\rremote_vm_mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eremote_vm_ipv4\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_remote_vm_macB\x11\n\x0f_remote_vm_ipv4\"\xc1\x01\n)VxlanV4TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"\xc1\x01\n)VxlanV6TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"K\n\'VxlanV4TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"K\n\'VxlanV6TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"\x91\x01\n\nDeviceRsvp\x12/\n\x0fipv4_interfaces\x18\x01 \x03(\x0b\x32\x16.otg.RsvpIpv4Interface\x12\x36\n\x13lsp_ipv4_interfaces\x18\x02 \x03(\x0b\x32\x19.otg.RsvpLspIpv4Interface\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\xc5\x04\n\x11RsvpIpv4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bneighbor_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x11label_space_start\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0flabel_space_end\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18\x65nable_refresh_reduction\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12%\n\x18summary_refresh_interval\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0bsend_bundle\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1d\n\x10\x62undle_threshold\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x19\n\x0c\x65nable_hello\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\n \x01(\rH\t\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x0b \x01(\rH\n\x88\x01\x01\x42\x0c\n\n_ipv4_nameB\x0e\n\x0c_neighbor_ipB\x14\n\x12_label_space_startB\x12\n\x10_label_space_endB\x1b\n\x19_enable_refresh_reductionB\x1b\n\x19_summary_refresh_intervalB\x0e\n\x0c_send_bundleB\x13\n\x11_bundle_thresholdB\x0f\n\r_enable_helloB\x11\n\x0f_hello_intervalB\x15\n\x13_timeout_multiplier\"\xd0\x01\n\x14RsvpLspIpv4Interface\x12\x16\n\tipv4_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12G\n\x14p2p_egress_ipv4_lsps\x18\x02 \x01(\x0b\x32).otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp\x12I\n\x15p2p_ingress_ipv4_lsps\x18\x03 \x03(\x0b\x32*.otg.RsvpLspIpv4InterfaceP2PIngressIpv4LspB\x0c\n\n_ipv4_name\"\xf1\x03\n$RsvpLspIpv4InterfaceP2PEgressIpv4Lsp\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10refresh_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x03 \x01(\rH\x02\x88\x01\x01\x12_\n\x11reservation_style\x18\x04 \x01(\x0e\x32?.otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp.ReservationStyle.EnumH\x03\x88\x01\x01\x12\x1f\n\x12\x65nable_fixed_label\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1e\n\x11\x66ixed_label_value\x18\x06 \x01(\rH\x05\x88\x01\x01\x1a\\\n\x10ReservationStyle\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fshared_explicit\x10\x01\x12\x10\n\x0c\x66ixed_filter\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x42\x07\n\x05_nameB\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x14\n\x12_reservation_styleB\x15\n\x13_enable_fixed_labelB\x14\n\x12_fixed_label_value\"\xab\x04\n%RsvpLspIpv4InterfaceP2PIngressIpv4Lsp\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eremote_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\ttunnel_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10refresh_interval\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x1a\n\rbackup_lsp_id\x18\x07 \x01(\rH\x06\x88\x01\x01\x12!\n\x14lsp_switchover_delay\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x34\n\x11session_attribute\x18\t \x01(\x0b\x32\x19.otg.RsvpSessionAttribute\x12\x1d\n\x05tspec\x18\n \x01(\x0b\x32\x0e.otg.RsvpTspec\x12*\n\x0c\x66\x61st_reroute\x18\x0b \x01(\x0b\x32\x14.otg.RsvpFastReroute\x12\x19\n\x03\x65ro\x18\x0c \x01(\x0b\x32\x0c.otg.RsvpEroB\x07\n\x05_nameB\x11\n\x0f_remote_addressB\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x10\n\x0e_backup_lsp_idB\x17\n\x15_lsp_switchover_delay\"\xf0\x04\n\x14RsvpSessionAttribute\x12\'\n\x1a\x61uto_generate_session_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0csession_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0esetup_priority\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12%\n\x18local_protection_desired\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12$\n\x17label_recording_desired\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10se_style_desired\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12)\n\x1c\x62\x61ndwidth_protection_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17node_protection_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x38\n\x13resource_affinities\x18\n \x01(\x0b\x32\x1b.otg.RsvpResourceAffinitiesB\x1d\n\x1b_auto_generate_session_nameB\x0f\n\r_session_nameB\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x1b\n\x19_local_protection_desiredB\x1a\n\x18_label_recording_desiredB\x13\n\x11_se_style_desiredB\x1f\n\x1d_bandwidth_protection_desiredB\x1a\n\x18_node_protection_desired\"\x96\x01\n\x16RsvpResourceAffinities\x12\x18\n\x0b\x65xclude_any\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_all\"\x9f\x02\n\tRsvpTspec\x12\x1e\n\x11token_bucket_rate\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1e\n\x11token_bucket_size\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1b\n\x0epeak_data_rate\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12!\n\x14minimum_policed_unit\x18\x04 \x01(\rH\x03\x88\x01\x01\x12!\n\x14maximum_policed_unit\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x14\n\x12_token_bucket_rateB\x14\n\x12_token_bucket_sizeB\x11\n\x0f_peak_data_rateB\x17\n\x15_minimum_policed_unitB\x17\n\x15_maximum_policed_unit\"\xc7\x03\n\x0fRsvpFastReroute\x12\x1b\n\x0esetup_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\thop_limit\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tbandwidth\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x18\n\x0b\x65xclude_any\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x07 \x01(\tH\x06\x88\x01\x01\x12&\n\x19one_to_one_backup_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17\x66\x61\x63ility_backup_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x42\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0c\n\n_hop_limitB\x0c\n\n_bandwidthB\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_allB\x1c\n\x1a_one_to_one_backup_desiredB\x1a\n\x18_facility_backup_desired\"\xa8\x02\n\x07RsvpEro\x12\x45\n\x13prepend_neighbor_ip\x18\x01 \x01(\x0e\x32#.otg.RsvpEro.PrependNeighborIp.EnumH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\nsubobjects\x18\x03 \x03(\x0b\x32\x15.otg.RsvpEroSubobject\x1a\x65\n\x11PrependNeighborIp\"P\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x64ont_prepend\x10\x01\x12\x11\n\rprepend_loose\x10\x02\x12\x12\n\x0eprepend_strict\x10\x03\x42\x16\n\x14_prepend_neighbor_ipB\x10\n\x0e_prefix_length\"\x8c\x03\n\x10RsvpEroSubobject\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.RsvpEroSubobject.Type.EnumH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tas_number\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x39\n\x08hop_type\x18\x05 \x01(\x0e\x32\".otg.RsvpEroSubobject.HopType.EnumH\x04\x88\x01\x01\x1a\x38\n\x04Type\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\r\n\tas_number\x10\x02\x1a\x39\n\x07HopType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06strict\x10\x01\x12\t\n\x05loose\x10\x02\x42\x07\n\x05_typeB\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x0c\n\n_as_numberB\x0b\n\t_hop_type\"j\n\x10\x44\x65viceDhcpServer\x12*\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x11.otg.DhcpServerV4\x12*\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x11.otg.DhcpServerV6\"~\n\x0c\x44hcpServerV4\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv4_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\raddress_pools\x18\x03 \x03(\x0b\x32\x15.otg.DhcpServerV4PoolB\x07\n\x05_nameB\x0c\n\n_ipv4_name\"\x9a\x02\n\x10\x44hcpServerV4Pool\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nlease_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1a\n\rstart_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x11\n\x04step\x18\x06 \x01(\rH\x05\x88\x01\x01\x12,\n\x07options\x18\x07 \x01(\x0b\x32\x1b.otg.DhcpServerV4PoolOptionB\x07\n\x05_nameB\r\n\x0b_lease_timeB\x10\n\x0e_start_addressB\x10\n\x0e_prefix_lengthB\x08\n\x06_countB\x07\n\x05_step\"\xfc\x01\n\x16\x44hcpServerV4PoolOption\x12\x1b\n\x0erouter_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12primary_dns_server\x18\x02 \x01(\tH\x01\x88\x01\x01\x12!\n\x14secondary_dns_server\x18\x03 \x01(\tH\x02\x88\x01\x01\x12#\n\x16\x65\x63ho_relay_with_tlv_82\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x11\n\x0f_router_addressB\x15\n\x13_primary_dns_serverB\x17\n\x15_secondary_dns_serverB\x19\n\x17_echo_relay_with_tlv_82\"\x99\x02\n\x0c\x44hcpServerV6\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv6_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0crapid_commit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12(\n\x1breconfigure_via_relay_agent\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12&\n\x06leases\x18\x05 \x03(\x0b\x32\x16.otg.DhcpV6ServerLease\x12)\n\x07options\x18\x06 \x01(\x0b\x32\x18.otg.Dhcpv6ServerOptionsB\x07\n\x05_nameB\x0c\n\n_ipv6_nameB\x0f\n\r_rapid_commitB\x1e\n\x1c_reconfigure_via_relay_agent\"\xac\x01\n\x13\x44hcpv6ServerOptions\x12!\n\x03\x64ns\x18\x01 \x01(\x0b\x32\x14.otg.DhcpV6ServerDns\x12\x37\n\x0bvendor_info\x18\x02 \x01(\x0b\x32\".otg.Dhcpv6ServerOptionsVendorInfo\x12\x39\n\x0c\x62ootfile_url\x18\x03 \x01(\x0b\x32#.otg.Dhcpv6ServerOptionsBootfileUrl\"e\n\x11\x44hcpV6ServerLease\x12\x17\n\nlease_time\x18\x01 \x01(\rH\x00\x88\x01\x01\x12(\n\x07ia_type\x18\x05 \x01(\x0b\x32\x17.otg.Dhcpv6ServerIaTypeB\r\n\x0b_lease_time\"\xd6\x02\n\x12\x44hcpv6ServerIaType\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.Dhcpv6ServerIaType.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x04iana\x18\x02 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12\'\n\x04iata\x18\x03 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12+\n\x04iapd\x18\x04 \x01(\x0b\x32\x1d.otg.Dhcpv6ServerIapdPoolInfo\x12/\n\x06ianapd\x18\x05 \x01(\x0b\x32\x1f.otg.Dhcpv6ServerIanapdPoolInfo\x1aK\n\x06\x43hoice\"A\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04iana\x10\x01\x12\x08\n\x04iata\x10\x02\x12\x08\n\x04iapd\x10\x03\x12\n\n\x06ianapd\x10\x04\x42\t\n\x07_choice\"\xa4\x01\n\x14\x44hcpv6ServerPoolInfo\x12\x1a\n\rstart_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nprefix_len\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x10\n\x0e_start_addressB\r\n\x0b_prefix_lenB\x07\n\x05_sizeB\x07\n\x05_step\"\xa6\x02\n\x18\x44hcpv6ServerIapdPoolInfo\x12!\n\x14start_prefix_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x63onfigured_prefix_len\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bprefix_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0bprefix_step\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\"\n\x15\x61\x64vertised_prefix_len\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\x17\n\x15_start_prefix_addressB\x18\n\x16_configured_prefix_lenB\x0e\n\x0c_prefix_sizeB\x0e\n\x0c_prefix_stepB\x18\n\x16_advertised_prefix_len\"r\n\x1a\x44hcpv6ServerIanapdPoolInfo\x12\'\n\x04iana\x18\x01 \x01(\x0b\x32\x19.otg.Dhcpv6ServerPoolInfo\x12+\n\x04iapd\x18\x02 \x01(\x0b\x32\x1d.otg.Dhcpv6ServerIapdPoolInfo\"i\n\x0f\x44hcpV6ServerDns\x12\x14\n\x07primary\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x34\n\rsecondary_dns\x18\x02 \x03(\x0b\x32\x1d.otg.DhcpV6ServerSecondaryDnsB\n\n\x08_primary\"2\n\x18\x44hcpV6ServerSecondaryDns\x12\x0f\n\x02ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_ip\"\xa8\x04\n\x12\x44\x65viceOspfv2Router\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\trouter_id\x18\x02 \x01(\x0b\x32\x13.otg.Ospfv2RouterId\x12 \n\x13lsa_retransmit_time\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x10lsa_refresh_time\x18\x04 \x01(\rH\x02\x88\x01\x01\x12%\n\x18inter_burst_lsu_interval\x18\x05 \x01(\rH\x03\x88\x01\x01\x12$\n\x17max_flood_lsu_per_burst\x18\x06 \x01(\rH\x04\x88\x01\x01\x12\x34\n\x10graceful_restart\x18\x07 \x01(\x0b\x32\x1a.otg.Ospfv2GracefulRestart\x12\x16\n\tstore_lsa\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12(\n\x0c\x63\x61pabilities\x18\t \x01(\x0b\x32\x12.otg.Ospfv2Options\x12(\n\ninterfaces\x18\n \x03(\x0b\x32\x14.otg.Ospfv2Interface\x12*\n\tv4_routes\x18\x0b \x03(\x0b\x32\x17.otg.Ospfv2V4RouteRangeB\x07\n\x05_nameB\x16\n\x14_lsa_retransmit_timeB\x13\n\x11_lsa_refresh_timeB\x1b\n\x19_inter_burst_lsu_intervalB\x1a\n\x18_max_flood_lsu_per_burstB\x0c\n\n_store_lsa\"\xb2\x01\n\x0eOspfv2RouterId\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.Ospfv2RouterId.Choice.EnumH\x00\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cinterface_ip\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choiceB\t\n\x07_custom\"\xdd\x02\n\rOspfv2Options\x12\x12\n\x05t_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x12\n\x05\x65_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06mc_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06np_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65\x61_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06\x64\x63_bit\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x12\n\x05o_bit\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nunused_bit\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x16\n\tlsa_b_bit\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x16\n\tlsa_e_bit\x18\n \x01(\x08H\t\x88\x01\x01\x42\x08\n\x06_t_bitB\x08\n\x06_e_bitB\t\n\x07_mc_bitB\t\n\x07_np_bitB\t\n\x07_ea_bitB\t\n\x07_dc_bitB\x08\n\x06_o_bitB\r\n\x0b_unused_bitB\x0c\n\n_lsa_b_bitB\x0c\n\n_lsa_e_bit\"A\n\x15Ospfv2GracefulRestart\x12\x18\n\x0bhelper_mode\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_helper_mode\"\x9f\x03\n\x0fOspfv2Interface\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tipv4_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x04\x61rea\x18\x03 \x01(\x0b\x32\x18.otg.Ospfv2InterfaceArea\x12\x35\n\x0cnetwork_type\x18\x04 \x01(\x0b\x32\x1f.otg.Ospfv2InterfaceNetworkType\x12-\n\x13traffic_engineering\x18\x05 \x03(\x0b\x32\x10.otg.LinkStateTE\x12:\n\x0e\x61uthentication\x18\x06 \x01(\x0b\x32\".otg.Ospfv2InterfaceAuthentication\x12.\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x1c.otg.Ospfv2InterfaceAdvanced\x12;\n\x0flink_protection\x18\x08 \x01(\x0b\x32\".otg.Ospfv2InterfaceLinkProtection\x12\x13\n\x0bsrlg_values\x18\t \x03(\rB\x07\n\x05_nameB\x0c\n\n_ipv4_name\"\xbe\x01\n\x13Ospfv2InterfaceArea\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.Ospfv2InterfaceArea.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0f\n\x02ip\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x31\n\x06\x43hoice\"\'\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02id\x10\x01\x12\x06\n\x02ip\x10\x02\x42\t\n\x07_choiceB\x05\n\x03_idB\x05\n\x03_ip\"\x83\x02\n\x1aOspfv2InterfaceNetworkType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.Ospfv2InterfaceNetworkType.Choice.EnumH\x00\x88\x01\x01\x12\x39\n\x13point_to_multipoint\x18\x02 \x03(\x0b\x32\x1c.otg.Ospfv2InterfaceNeighbor\x1a]\n\x06\x43hoice\"S\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x12\x17\n\x13point_to_multipoint\x10\x03\x42\t\n\x07_choice\"C\n\x17Ospfv2InterfaceNeighbor\x12\x18\n\x0bneighbor_ip\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_neighbor_ip\"\x89\x02\n\x17Ospfv2InterfaceAdvanced\x12\x1b\n\x0ehello_interval\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0erouting_metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x15\n\x08priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\"\n\x15validate_received_mtu\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_intervalB\x11\n\x0f_routing_metricB\x0b\n\t_priorityB\x18\n\x16_validate_received_mtu\"\x9a\x02\n\x16Ospfv2InterfaceOptions\x12\x12\n\x05t_bit\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x12\n\x05\x65_bit\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06mc_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06np_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06\x65\x61_bit\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06\x64\x63_bit\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x12\n\x05o_bit\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nunused_bit\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x08\n\x06_t_bitB\x08\n\x06_e_bitB\t\n\x07_mc_bitB\t\n\x07_np_bitB\t\n\x07_ea_bitB\t\n\x07_dc_bitB\x08\n\x06_o_bitB\r\n\x0b_unused_bit\"\x80\x02\n\x1dOspfv2InterfaceAuthentication\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.Ospfv2InterfaceAuthentication.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04md5s\x18\x02 \x03(\x0b\x32\x1c.otg.Ospfv2AuthenticationMd5\x12\x17\n\nclear_text\x18\x04 \x01(\tH\x01\x88\x01\x01\x1a;\n\x06\x43hoice\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04md5s\x10\x01\x12\x0e\n\nclear_text\x10\x02\x42\t\n\x07_choiceB\r\n\x0b_clear_text\"S\n\x17Ospfv2AuthenticationMd5\x12\x13\n\x06key_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03key\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_key_idB\x06\n\x04_key\"\xfb\x02\n\x1dOspfv2InterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\xaa\x01\n\x12Ospfv2V4RouteRange\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\taddresses\x18\x02 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x30\n\x0croute_origin\x18\x04 \x01(\x0b\x32\x1a.otg.Ospfv2V4RRRouteOriginB\x07\n\x05_nameB\t\n\x07_metric\"\xdd\x03\n\x15Ospfv2V4RRRouteOrigin\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.Ospfv2V4RRRouteOrigin.Choice.EnumH\x00\x88\x01\x01\x12,\n\nintra_area\x18\x02 \x01(\x0b\x32\x18.otg.Ospfv2V4RRIntraArea\x12,\n\ninter_area\x18\x03 \x01(\x0b\x32\x18.otg.Ospfv2V4RRInterArea\x12\x35\n\x0f\x65xternal_type_1\x18\x04 \x01(\x0b\x32\x1c.otg.Ospfv2V4RRExternalType1\x12\x35\n\x0f\x65xternal_type_2\x18\x05 \x01(\x0b\x32\x1c.otg.Ospfv2V4RRExternalType2\x12\x32\n\rnssa_external\x18\x06 \x01(\x0b\x32\x1b.otg.Ospfv2V4RRNssaExternal\x1a~\n\x06\x43hoice\"t\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nintra_area\x10\x01\x12\x0e\n\ninter_area\x10\x02\x12\x13\n\x0f\x65xternal_type_1\x10\x03\x12\x13\n\x0f\x65xternal_type_2\x10\x04\x12\x11\n\rnssa_external\x10\x05\x42\t\n\x07_choice\"D\n\x13Ospfv2V4RRIntraArea\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"D\n\x13Ospfv2V4RRInterArea\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"H\n\x17Ospfv2V4RRExternalType1\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"H\n\x17Ospfv2V4RRExternalType2\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\"q\n\x16Ospfv2V4RRNssaExternal\x12-\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1e.otg.Ospfv2V4RRExtdPrefixFlags\x12\x18\n\x0bpropagation\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x0e\n\x0c_propagation\"[\n\x19Ospfv2V4RRExtdPrefixFlags\x12\x13\n\x06\x61_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06n_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_a_flagB\t\n\x07_n_flag\"O\n\x0c\x44\x65viceMacsec\x12?\n\x13\x65thernet_interfaces\x18\x01 \x03(\x0b\x32\".otg.DeviceMacsecEthernetInterface\"m\n\x1d\x44\x65viceMacsecEthernetInterface\x12\x15\n\x08\x65th_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\rsecure_entity\x18\x02 \x01(\x0b\x32\x11.otg.SecureEntityB\x0b\n\t_eth_name\"\xa3\x01\n\x0cSecureEntity\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12G\n\x17key_generation_protocol\x18\x02 \x01(\x0b\x32&.otg.SecureEntityKeyGenerationProtocol\x12.\n\ndata_plane\x18\x03 \x01(\x0b\x32\x1a.otg.SecureEntityDataPlaneB\x07\n\x05_name\"\xfa\x01\n!SecureEntityKeyGenerationProtocol\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.SecureEntityKeyGenerationProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x15\n\x03mka\x18\x02 \x01(\x0b\x32\x08.otg.Mka\x12.\n\nstatic_key\x18\x03 \x01(\x0b\x32\x1a.otg.SecureEntityStaticKey\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03mka\x10\x01\x12\x0e\n\nstatic_key\x10\x02\x42\t\n\x07_choice\"\xeb\x01\n\x15SecureEntityDataPlane\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.SecureEntityDataPlane.Choice.EnumH\x00\x88\x01\x01\x12>\n\rencapsulation\x18\x02 \x01(\x0b\x32\'.otg.SecureEntityDataPlaneEncapsulation\x1aJ\n\x06\x43hoice\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rencapsulation\x10\x01\x12\x14\n\x10no_encapsulation\x10\x02\x42\t\n\x07_choice\"\xae\x01\n\"SecureEntityDataPlaneEncapsulation\x12(\n\x02tx\x18\x01 \x01(\x0b\x32\x1c.otg.SecureEntityDataPlaneTx\x12(\n\x02rx\x18\x02 \x01(\x0b\x32\x1c.otg.SecureEntityDataPlaneRx\x12\x34\n\rcrypto_engine\x18\x03 \x01(\x0b\x32\x1d.otg.SecureEntityCryptoEngine\"m\n\x17SecureEntityDataPlaneTx\x12\x18\n\x0b\x65nd_station\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0binclude_sci\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0e\n\x0c_end_stationB\x0e\n\x0c_include_sci\"}\n\x17SecureEntityDataPlaneRx\x12\x1e\n\x11replay_protection\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rreplay_window\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_replay_protectionB\x10\n\x0e_replay_window\"\xda\x01\n\x18SecureEntityCryptoEngine\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.SecureEntityCryptoEngine.Choice.EnumH\x00\x88\x01\x01\x12>\n\x0c\x65ncrypt_only\x18\x02 \x01(\x0b\x32(.otg.SecureEntityCryptoEngineEncryptOnly\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x65ncrypt_only\x10\x01\x42\t\n\x07_choice\"\xbd\x01\n#SecureEntityCryptoEngineEncryptOnly\x12\x45\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32,.otg.SecureEntityCryptoEngineEncryptOnlyTxSc\x12O\n\x0ftraffic_options\x18\x02 \x01(\x0b\x32\x36.otg.SecureEntityCryptoEngineEncryptOnlyTrafficOptions\"j\n\'SecureEntityCryptoEngineEncryptOnlyTxSc\x12?\n\x05tx_pn\x18\x01 \x01(\x0b\x32\x30.otg.SecureEntityCryptoEngineEncryptOnlyTxScTxPn\"\xdf\x02\n+SecureEntityCryptoEngineEncryptOnlyTxScTxPn\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.SecureEntityCryptoEngineEncryptOnlyTxScTxPn.Choice.EnumH\x00\x88\x01\x01\x12>\n\x05\x66ixed\x18\x02 \x01(\x0b\x32/.otg.SecureEntityCryptoEngineEncryptOnlyFixedPn\x12L\n\x0cincrementing\x18\x03 \x01(\x0b\x32\x36.otg.SecureEntityCryptoEngineEncryptOnlyIncrementingPn\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x66ixed_pn\x10\x01\x12\x13\n\x0fincrementing_pn\x10\x02\x42\t\n\x07_choice\"^\n*SecureEntityCryptoEngineEncryptOnlyFixedPn\x12\x0f\n\x02pn\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03xpn\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_pnB\x06\n\x04_xpn\"\xa7\x01\n1SecureEntityCryptoEngineEncryptOnlyIncrementingPn\x12\x12\n\x05\x63ount\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bstarting_pn\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0cstarting_xpn\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_countB\x0e\n\x0c_starting_pnB\x0f\n\r_starting_xpn\"m\n1SecureEntityCryptoEngineEncryptOnlyTrafficOptions\x12 \n\x13send_gratuitous_arp\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_send_gratuitous_arp\"~\n\x03Mka\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\r.otg.MkaBasic\x12%\n\nkey_server\x18\x03 \x01(\x0b\x32\x11.otg.MkaKeyServer\x12\x16\n\x02tx\x18\x04 \x01(\x0b\x32\n.otg.MkaTxB\x07\n\x05_name\"\xfe\x08\n\x08MkaBasic\x12N\n\x17key_derivation_function\x18\x01 \x01(\x0e\x32(.otg.MkaBasic.KeyDerivationFunction.EnumH\x00\x88\x01\x01\x12*\n\nkey_source\x18\x02 \x01(\x0b\x32\x16.otg.MkaBasicKeySource\x12\x1b\n\x0e\x61\x63tor_priority\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0emacsec_desired\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x43\n\x11macsec_capability\x18\x05 \x01(\x0e\x32#.otg.MkaBasic.MacsecCapability.EnumH\x03\x88\x01\x01\x12\x43\n\x17supported_cipher_suites\x18\x06 \x01(\x0b\x32\".otg.MkaBasicSupportedCipherSuites\x12 \n\x13\x65\x61pol_ethernet_type\x18\x07 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bmka_version\x18\x08 \x01(\rH\x05\x88\x01\x01\x12\x1b\n\x0emka_hello_time\x18\t \x01(\rH\x06\x88\x01\x01\x12\x1a\n\rmka_life_time\x18\n \x01(\rH\x07\x88\x01\x01\x12)\n\x1csend_icv_indicatior_in_mkpdu\x18\x0b \x01(\x08H\x08\x88\x01\x01\x12\x1a\n\rdelay_protect\x18\x0c \x01(\x08H\t\x88\x01\x01\x12*\n\nrekey_mode\x18\r \x01(\x0b\x32\x16.otg.MkaBasicRekeyMode\x12<\n\x14psk_chain_start_time\x18\x0e \x01(\x0b\x32\x1e.otg.MkaBasicPskChainStartTime\x1aT\n\x15KeyDerivationFunction\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x61\x65s_cmac_128\x10\x01\x12\x10\n\x0c\x61\x65s_cmac_256\x10\x02\x1a\xdd\x01\n\x10MacsecCapability\"\xc8\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16macsec_not_implemented\x10\x01\x12,\n(macsec_integrity_without_confidentiality\x10\x02\x12\x33\n/macsec_integrity_with_no_confidentiality_offset\x10\x03\x12\x30\n,macsec_integrity_with_confidentiality_offset\x10\x04\x42\x1a\n\x18_key_derivation_functionB\x11\n\x0f_actor_priorityB\x11\n\x0f_macsec_desiredB\x14\n\x12_macsec_capabilityB\x16\n\x14_eapol_ethernet_typeB\x0e\n\x0c_mka_versionB\x11\n\x0f_mka_hello_timeB\x10\n\x0e_mka_life_timeB\x1f\n\x1d_send_icv_indicatior_in_mkpduB\x10\n\x0e_delay_protect\"\xd7\x01\n\x1dMkaBasicSupportedCipherSuites\x12\x18\n\x0bgcm_aes_128\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bgcm_aes_256\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1c\n\x0fgcm_aes_xpn_128\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1c\n\x0fgcm_aes_xpn_256\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x0e\n\x0c_gcm_aes_128B\x0e\n\x0c_gcm_aes_256B\x12\n\x10_gcm_aes_xpn_128B\x12\n\x10_gcm_aes_xpn_256\"\xb5\x01\n\x11MkaBasicKeySource\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.MkaBasicKeySource.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x04psks\x18\x02 \x03(\x0b\x32\x19.otg.MkaBasicKeySourcePsk\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03psk\x10\x01\x12\x07\n\x03msk\x10\x02\x42\t\n\x07_choice\"\xce\x01\n\x14MkaBasicKeySourcePsk\x12\x16\n\tcak_value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x63\x61k_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x37\n\x11start_offset_time\x18\x03 \x01(\x0b\x32\x1c.otg.MkaBasicStartOffsetTime\x12\x33\n\x0f\x65nd_offset_time\x18\x04 \x01(\x0b\x32\x1a.otg.MkaBasicEndOffsetTimeB\x0c\n\n_cak_valueB\x0b\n\t_cak_name\"I\n\x17MkaBasicStartOffsetTime\x12\x0f\n\x02hh\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02mm\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_hhB\x05\n\x03_mm\"G\n\x15MkaBasicEndOffsetTime\x12\x0f\n\x02hh\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x0f\n\x02mm\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x05\n\x03_hhB\x05\n\x03_mm\"\xb6\x01\n\x19MkaBasicPskChainStartTime\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.MkaBasicPskChainStartTime.Choice.EnumH\x00\x88\x01\x01\x12!\n\x03utc\x18\x02 \x01(\x0b\x32\x14.otg.MkaBasicTimeUtc\x1a*\n\x06\x43hoice\" \n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03utc\x10\x01\x42\t\n\x07_choice\"\xc1\x01\n\x0fMkaBasicTimeUtc\x12\x10\n\x03\x64\x61y\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05month\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04year\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x11\n\x04hour\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x13\n\x06minute\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x13\n\x06second\x18\x06 \x01(\rH\x05\x88\x01\x01\x42\x06\n\x04_dayB\x08\n\x06_monthB\x07\n\x05_yearB\x07\n\x05_hourB\t\n\x07_minuteB\t\n\x07_second\"\xe0\x01\n\x11MkaBasicRekeyMode\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.MkaBasicRekeyMode.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x0btimer_based\x18\x02 \x01(\x0b\x32 .otg.MkaBasicRekeyModeTimerBased\x1aP\n\x06\x43hoice\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ndont_rekey\x10\x01\x12\x0f\n\x0btimer_based\x10\x02\x12\x0c\n\x08pn_based\x10\x03\x42\t\n\x07_choice\"\xfd\x01\n\x1bMkaBasicRekeyModeTimerBased\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.MkaBasicRekeyModeTimerBased.Choice.EnumH\x00\x88\x01\x01\x12\x18\n\x0b\x66ixed_count\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ncontinuous\x10\x01\x12\x0f\n\x0b\x66ixed_count\x10\x02\x42\t\n\x07_choiceB\x0e\n\x0c_fixed_countB\x0b\n\t_interval\"\xe1\x05\n\x0cMkaKeyServer\x12O\n\x15\x63onfidentialty_offset\x18\x01 \x01(\x0e\x32+.otg.MkaKeyServer.ConfidentialtyOffset.EnumH\x00\x88\x01\x01\x12=\n\x0c\x63ipher_suite\x18\x02 \x01(\x0e\x32\".otg.MkaKeyServer.CipherSuite.EnumH\x01\x88\x01\x01\x12 \n\x13starting_key_number\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17starting_distributed_an\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1f\n\x12rekey_threshold_pn\x18\x05 \x01(\tH\x04\x88\x01\x01\x12 \n\x13rekey_threshold_xpn\x18\x06 \x01(\tH\x05\x88\x01\x01\x1a\xb3\x01\n\x14\x43onfidentialtyOffset\"\x9a\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12no_confidentiality\x10\x01\x12\x1d\n\x19no_confidentiality_offset\x10\x02\x12$\n confidentiality_offset_30_octets\x10\x03\x12$\n confidentiality_offset_50_octets\x10\x04\x1ar\n\x0b\x43ipherSuite\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bgcm_aes_128\x10\x01\x12\x0f\n\x0bgcm_aes_256\x10\x02\x12\x13\n\x0fgcm_aes_xpn_128\x10\x03\x12\x13\n\x0fgcm_aes_xpn_256\x10\x04\x42\x18\n\x16_confidentialty_offsetB\x0f\n\r_cipher_suiteB\x16\n\x14_starting_key_numberB\x1a\n\x18_starting_distributed_anB\x15\n\x13_rekey_threshold_pnB\x16\n\x14_rekey_threshold_xpn\".\n\x05MkaTx\x12%\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x0c.otg.MkaTxSc\"\xaf\x01\n\x07MkaTxSc\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tsystem_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_id\x18\x03 \x01(\rH\x02\x88\x01\x01\x12$\n\x17starting_message_number\x18\x04 \x01(\x04H\x03\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_system_idB\n\n\x08_port_idB\x1a\n\x18_starting_message_number\"\xb4\x04\n\x15SecureEntityStaticKey\x12\x46\n\x0c\x63ipher_suite\x18\x01 \x01(\x0e\x32+.otg.SecureEntityStaticKey.CipherSuite.EnumH\x00\x88\x01\x01\x12\x1c\n\x0f\x63onfidentiality\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12Z\n\x16\x63onfidentiality_offset\x18\x03 \x01(\x0e\x32\x35.otg.SecureEntityStaticKey.ConfidentialityOffset.EnumH\x02\x88\x01\x01\x12(\n\x02tx\x18\x04 \x01(\x0b\x32\x1c.otg.SecureEntityStaticKeyTx\x12(\n\x02rx\x18\x05 \x01(\x0b\x32\x1c.otg.SecureEntityStaticKeyRx\x1ar\n\x0b\x43ipherSuite\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bgcm_aes_128\x10\x01\x12\x0f\n\x0bgcm_aes_256\x10\x02\x12\x13\n\x0fgcm_aes_xpn_128\x10\x03\x12\x13\n\x0fgcm_aes_xpn_256\x10\x04\x1aQ\n\x15\x43onfidentialityOffset\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04zero\x10\x01\x12\n\n\x06thirty\x10\x02\x12\t\n\x05\x66ifty\x10\x03\x42\x0f\n\r_cipher_suiteB\x12\n\x10_confidentialityB\x19\n\x17_confidentiality_offset\"\x87\x02\n\x1eSecureEntityStaticKeyRekeyMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.SecureEntityStaticKeyRekeyMode.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0btimer_based\x18\x02 \x01(\x0b\x32-.otg.SecureEntityStaticKeyRekeyModeTimerBased\x1aP\n\x06\x43hoice\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ndont_rekey\x10\x01\x12\x0f\n\x0btimer_based\x10\x02\x12\x0c\n\x08pn_based\x10\x03\x42\t\n\x07_choice\"\x97\x02\n(SecureEntityStaticKeyRekeyModeTimerBased\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.SecureEntityStaticKeyRekeyModeTimerBased.Choice.EnumH\x00\x88\x01\x01\x12\x18\n\x0b\x66ixed_count\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x15\n\x08interval\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ncontinuous\x10\x01\x12\x0f\n\x0b\x66ixed_count\x10\x02\x42\t\n\x07_choiceB\x0e\n\x0c_fixed_countB\x0b\n\t_interval\"l\n\x18SecureEntityStaticKeySak\x12\x10\n\x03sak\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04ssci\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04salt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x06\n\x04_sakB\x07\n\x05_ssciB\x07\n\x05_salt\"\x8b\x01\n\x17SecureEntityStaticKeyTx\x12\x37\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x1e.otg.SecureEntityStaticKeyTxSc\x12\x37\n\nrekey_mode\x18\x02 \x01(\x0b\x32#.otg.SecureEntityStaticKeyRekeyMode\"\x90\x01\n\x19SecureEntityStaticKeyTxSc\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12+\n\x04saks\x18\x03 \x03(\x0b\x32\x1d.otg.SecureEntityStaticKeySakB\x0c\n\n_system_idB\n\n\x08_port_id\"R\n\x17SecureEntityStaticKeyRx\x12\x37\n\x0fsecure_channels\x18\x01 \x03(\x0b\x32\x1e.otg.SecureEntityStaticKeyRxSc\"\xda\x01\n\x19SecureEntityStaticKeyRxSc\x12\x1e\n\x11\x64ut_sci_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0f\x64ut_sci_port_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x64ut_msb_xpn\x18\x03 \x01(\rH\x02\x88\x01\x01\x12+\n\x04saks\x18\x04 \x03(\x0b\x32\x1d.otg.SecureEntityStaticKeySakB\x14\n\x12_dut_sci_system_idB\x12\n\x10_dut_sci_port_idB\x0e\n\x0c_dut_msb_xpn\"\x8b\x02\n\x04\x46low\x12\x1c\n\x05tx_rx\x18\x01 \x01(\x0b\x32\r.otg.FlowTxRx\x12\x1f\n\x06packet\x18\x02 \x03(\x0b\x32\x0f.otg.FlowHeader\x12&\n\regress_packet\x18\t \x03(\x0b\x32\x0f.otg.FlowHeader\x12\x1b\n\x04size\x18\x03 \x01(\x0b\x32\r.otg.FlowSize\x12\x1b\n\x04rate\x18\x04 \x01(\x0b\x32\r.otg.FlowRate\x12#\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x11.otg.FlowDuration\x12!\n\x07metrics\x18\x06 \x01(\x0b\x32\x10.otg.FlowMetrics\x12\x11\n\x04name\x18\x07 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\xbc\x01\n\x08\x46lowTxRx\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowTxRx.Choice.EnumH\x00\x88\x01\x01\x12\x1b\n\x04port\x18\x02 \x01(\x0b\x32\r.otg.FlowPort\x12\x1f\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x0f.otg.FlowRouter\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x42\t\n\x07_choice\"`\n\x08\x46lowPort\x12\x14\n\x07tx_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07rx_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08rx_names\x18\x03 \x03(\tB\n\n\x08_tx_nameB\n\n\x08_rx_name\"\xa2\x01\n\nFlowRouter\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x19.otg.FlowRouter.Mode.EnumH\x00\x88\x01\x01\x12\x10\n\x08tx_names\x18\x02 \x03(\t\x12\x10\n\x08rx_names\x18\x03 \x03(\t\x1a\x39\n\x04Mode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mesh\x10\x01\x12\x0e\n\none_to_one\x10\x02\x42\x07\n\x05_mode\"\xe9\x07\n\nFlowHeader\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowHeader.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x0f.otg.FlowCustom\x12#\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x11.otg.FlowEthernet\x12\x1b\n\x04vlan\x18\x04 \x01(\x0b\x32\r.otg.FlowVlan\x12\x1d\n\x05vxlan\x18\x05 \x01(\x0b\x32\x0e.otg.FlowVxlan\x12\x1b\n\x04ipv4\x18\x06 \x01(\x0b\x32\r.otg.FlowIpv4\x12\x1b\n\x04ipv6\x18\x07 \x01(\x0b\x32\r.otg.FlowIpv6\x12#\n\x08pfcpause\x18\x08 \x01(\x0b\x32\x11.otg.FlowPfcPause\x12-\n\rethernetpause\x18\t \x01(\x0b\x32\x16.otg.FlowEthernetPause\x12\x19\n\x03tcp\x18\n \x01(\x0b\x32\x0c.otg.FlowTcp\x12\x19\n\x03udp\x18\x0b \x01(\x0b\x32\x0c.otg.FlowUdp\x12\x19\n\x03gre\x18\x0c \x01(\x0b\x32\x0c.otg.FlowGre\x12\x1d\n\x05gtpv1\x18\r \x01(\x0b\x32\x0e.otg.FlowGtpv1\x12\x1d\n\x05gtpv2\x18\x0e \x01(\x0b\x32\x0e.otg.FlowGtpv2\x12\x19\n\x03\x61rp\x18\x0f \x01(\x0b\x32\x0c.otg.FlowArp\x12\x1b\n\x04icmp\x18\x10 \x01(\x0b\x32\r.otg.FlowIcmp\x12\x1f\n\x06icmpv6\x18\x11 \x01(\x0b\x32\x0f.otg.FlowIcmpv6\x12\x19\n\x03ppp\x18\x12 \x01(\x0b\x32\x0c.otg.FlowPpp\x12\x1f\n\x06igmpv1\x18\x13 \x01(\x0b\x32\x0f.otg.FlowIgmpv1\x12\x1b\n\x04mpls\x18\x14 \x01(\x0b\x32\r.otg.FlowMpls\x12!\n\x07snmpv2c\x18\x15 \x01(\x0b\x32\x10.otg.FlowSnmpv2c\x12\x1b\n\x04rsvp\x18\x16 \x01(\x0b\x32\r.otg.FlowRsvp\x1a\x8c\x02\n\x06\x43hoice\"\x81\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\t\n\x05vxlan\x10\x04\x12\x08\n\x04ipv4\x10\x05\x12\x08\n\x04ipv6\x10\x06\x12\x0c\n\x08pfcpause\x10\x07\x12\x11\n\rethernetpause\x10\x08\x12\x07\n\x03tcp\x10\t\x12\x07\n\x03udp\x10\n\x12\x07\n\x03gre\x10\x0b\x12\t\n\x05gtpv1\x10\x0c\x12\t\n\x05gtpv2\x10\r\x12\x07\n\x03\x61rp\x10\x0e\x12\x08\n\x04icmp\x10\x0f\x12\n\n\x06icmpv6\x10\x10\x12\x07\n\x03ppp\x10\x11\x12\n\n\x06igmpv1\x10\x12\x12\x08\n\x04mpls\x10\x13\x12\x0b\n\x07snmpv2c\x10\x14\x12\x08\n\x04rsvp\x10\x15\x42\t\n\x07_choice\"Y\n\nFlowCustom\x12\x12\n\x05\x62ytes\x18\x01 \x01(\tH\x00\x88\x01\x01\x12-\n\x0bmetric_tags\x18\x02 \x03(\x0b\x32\x18.otg.FlowCustomMetricTagB\x08\n\x06_bytes\"q\n\x13\x46lowCustomMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xce\x01\n\x0c\x46lowEthernet\x12(\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetDst\x12(\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetSrc\x12\x35\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowEthernetEtherType\x12\x33\n\tpfc_queue\x18\x04 \x01(\x0b\x32 .otg.PatternFlowEthernetPfcQueue\"\xac\x01\n\x08\x46lowVlan\x12.\n\x08priority\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowVlanPriority\x12$\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x17.otg.PatternFlowVlanCfi\x12\"\n\x02id\x18\x03 \x01(\x0b\x32\x16.otg.PatternFlowVlanId\x12&\n\x04tpid\x18\x04 \x01(\x0b\x32\x18.otg.PatternFlowVlanTpid\"\xc3\x01\n\tFlowVxlan\x12)\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowVxlanFlags\x12\x31\n\treserved0\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved0\x12%\n\x03vni\x18\x03 \x01(\x0b\x32\x18.otg.PatternFlowVxlanVni\x12\x31\n\treserved1\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved1\"\x84\x06\n\x08\x46lowIpv4\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4Version\x12\x37\n\rheader_length\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv4HeaderLength\x12\'\n\x08priority\x18\x03 \x01(\x0b\x32\x15.otg.FlowIpv4Priority\x12\x35\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TotalLength\x12:\n\x0eidentification\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4Identification\x12.\n\x08reserved\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4Reserved\x12\x37\n\rdont_fragment\x18\x07 \x01(\x0b\x32 .otg.PatternFlowIpv4DontFragment\x12\x39\n\x0emore_fragments\x18\x08 \x01(\x0b\x32!.otg.PatternFlowIpv4MoreFragments\x12;\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\".otg.PatternFlowIpv4FragmentOffset\x12\x34\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x1e.otg.PatternFlowIpv4TimeToLive\x12.\n\x08protocol\x18\x0b \x01(\x0b\x32\x1c.otg.PatternFlowIpv4Protocol\x12;\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\".otg.PatternFlowIpv4HeaderChecksum\x12$\n\x03src\x18\r \x01(\x0b\x32\x17.otg.PatternFlowIpv4Src\x12$\n\x03\x64st\x18\x0e \x01(\x0b\x32\x17.otg.PatternFlowIpv4Dst\x12%\n\x07options\x18\x0f \x03(\x0b\x32\x14.otg.FlowIpv4Options\"\xc0\x01\n\x0f\x46lowIpv4Options\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowIpv4Options.Choice.EnumH\x00\x88\x01\x01\x12*\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x1a.otg.FlowIpv4OptionsCustom\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crouter_alert\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x42\t\n\x07_choice\"\x95\x01\n\x15\x46lowIpv4OptionsCustom\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.FlowIpv4OptionsCustomType\x12\x30\n\x06length\x18\x02 \x01(\x0b\x32 .otg.FlowIpv4OptionsCustomLength\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\"\xf3\x01\n\x19\x46lowIpv4OptionsCustomType\x12\x44\n\x0b\x63opied_flag\x18\x01 \x01(\x0b\x32/.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlag\x12\x46\n\x0coption_class\x18\x02 \x01(\x0b\x32\x30.otg.PatternFlowIpv4OptionsCustomTypeOptionClass\x12H\n\roption_number\x18\x03 \x01(\x0b\x32\x31.otg.PatternFlowIpv4OptionsCustomTypeOptionNumber\"\xdd\x01\n\x1b\x46lowIpv4OptionsCustomLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowIpv4OptionsCustomLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x82\x02\n\x10\x46lowIpv4Priority\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.FlowIpv4Priority.Choice.EnumH\x00\x88\x01\x01\x12,\n\x03raw\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4PriorityRaw\x12\x1d\n\x03tos\x18\x03 \x01(\x0b\x32\x10.otg.FlowIpv4Tos\x12\x1f\n\x04\x64scp\x18\x04 \x01(\x0b\x32\x11.otg.FlowIpv4Dscp\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03raw\x10\x01\x12\x07\n\x03tos\x10\x02\x12\x08\n\x04\x64scp\x10\x03\x42\t\n\x07_choice\"b\n\x0c\x46lowIpv4Dscp\x12(\n\x03phb\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpPhb\x12(\n\x03\x65\x63n\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpEcn\"\xc3\x02\n\x0b\x46lowIpv4Tos\x12\x35\n\nprecedence\x18\x01 \x01(\x0b\x32!.otg.PatternFlowIpv4TosPrecedence\x12+\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4TosDelay\x12\x35\n\nthroughput\x18\x03 \x01(\x0b\x32!.otg.PatternFlowIpv4TosThroughput\x12\x37\n\x0breliability\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIpv4TosReliability\x12\x31\n\x08monetary\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TosMonetary\x12-\n\x06unused\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowIpv4TosUnused\"z\n\x0c\x46lowIpv4Auto\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowIpv4Auto.Choice.EnumH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64hcp\x10\x01\x42\t\n\x07_choice\"\x91\x03\n\x08\x46lowIpv6\x12,\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv6Version\x12\x37\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv6TrafficClass\x12\x31\n\nflow_label\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowIpv6FlowLabel\x12\x39\n\x0epayload_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowIpv6PayloadLength\x12\x33\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6NextHeader\x12/\n\thop_limit\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv6HopLimit\x12$\n\x03src\x18\x07 \x01(\x0b\x32\x17.otg.PatternFlowIpv6Src\x12$\n\x03\x64st\x18\x08 \x01(\x0b\x32\x17.otg.PatternFlowIpv6Dst\"z\n\x0c\x46lowIpv6Auto\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowIpv6Auto.Choice.EnumH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64hcp\x10\x01\x42\t\n\x07_choice\"\x81\x06\n\x0c\x46lowPfcPause\x12(\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseDst\x12(\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseSrc\x12\x35\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowPfcPauseEtherType\x12>\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32%.otg.PatternFlowPfcPauseControlOpCode\x12\x46\n\x13\x63lass_enable_vector\x18\x05 \x01(\x0b\x32).otg.PatternFlowPfcPauseClassEnableVector\x12:\n\rpause_class_0\x18\x06 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass0\x12:\n\rpause_class_1\x18\x07 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass1\x12:\n\rpause_class_2\x18\x08 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass2\x12:\n\rpause_class_3\x18\t \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass3\x12:\n\rpause_class_4\x18\n \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass4\x12:\n\rpause_class_5\x18\x0b \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass5\x12:\n\rpause_class_6\x18\x0c \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass6\x12:\n\rpause_class_7\x18\r \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass7\"\xa3\x02\n\x11\x46lowEthernetPause\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseDst\x12-\n\x03src\x18\x02 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseSrc\x12:\n\nether_type\x18\x03 \x01(\x0b\x32&.otg.PatternFlowEthernetPauseEtherType\x12\x43\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32*.otg.PatternFlowEthernetPauseControlOpCode\x12/\n\x04time\x18\x05 \x01(\x0b\x32!.otg.PatternFlowEthernetPauseTime\"\xd7\x05\n\x07\x46lowTcp\x12,\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowTcpSrcPort\x12,\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowTcpDstPort\x12*\n\x07seq_num\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowTcpSeqNum\x12*\n\x07\x61\x63k_num\x18\x04 \x01(\x0b\x32\x19.otg.PatternFlowTcpAckNum\x12\x32\n\x0b\x64\x61ta_offset\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowTcpDataOffset\x12(\n\x06\x65\x63n_ns\x18\x06 \x01(\x0b\x32\x18.otg.PatternFlowTcpEcnNs\x12*\n\x07\x65\x63n_cwr\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowTcpEcnCwr\x12,\n\x08\x65\x63n_echo\x18\x08 \x01(\x0b\x32\x1a.otg.PatternFlowTcpEcnEcho\x12*\n\x07\x63tl_urg\x18\t \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlUrg\x12*\n\x07\x63tl_ack\x18\n \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlAck\x12*\n\x07\x63tl_psh\x18\x0b \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlPsh\x12*\n\x07\x63tl_rst\x18\x0c \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlRst\x12*\n\x07\x63tl_syn\x18\r \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlSyn\x12*\n\x07\x63tl_fin\x18\x0e \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlFin\x12)\n\x06window\x18\x0f \x01(\x0b\x32\x19.otg.PatternFlowTcpWindow\x12-\n\x08\x63hecksum\x18\x10 \x01(\x0b\x32\x1b.otg.PatternFlowTcpChecksum\"\xbf\x01\n\x07\x46lowUdp\x12,\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowUdpSrcPort\x12,\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowUdpDstPort\x12)\n\x06length\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowUdpLength\x12-\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowUdpChecksum\"\xb4\x02\n\x07\x46lowGre\x12<\n\x10\x63hecksum_present\x18\x01 \x01(\x0b\x32\".otg.PatternFlowGreChecksumPresent\x12/\n\treserved0\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved0\x12+\n\x07version\x18\x03 \x01(\x0b\x32\x1a.otg.PatternFlowGreVersion\x12-\n\x08protocol\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGreProtocol\x12-\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\x1b.otg.PatternFlowGreChecksum\x12/\n\treserved1\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved1\"\xbf\x05\n\tFlowGtpv1\x12-\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv1Version\x12\x38\n\rprotocol_type\x18\x02 \x01(\x0b\x32!.otg.PatternFlowGtpv1ProtocolType\x12/\n\x08reserved\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv1Reserved\x12*\n\x06\x65_flag\x18\x04 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1EFlag\x12*\n\x06s_flag\x18\x05 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1SFlag\x12,\n\x07pn_flag\x18\x06 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv1PnFlag\x12\x36\n\x0cmessage_type\x18\x07 \x01(\x0b\x32 .otg.PatternFlowGtpv1MessageType\x12:\n\x0emessage_length\x18\x08 \x01(\x0b\x32\".otg.PatternFlowGtpv1MessageLength\x12\'\n\x04teid\x18\t \x01(\x0b\x32\x19.otg.PatternFlowGtpv1Teid\x12:\n\x0esquence_number\x18\n \x01(\x0b\x32\".otg.PatternFlowGtpv1SquenceNumber\x12\x35\n\x0cn_pdu_number\x18\x0b \x01(\x0b\x32\x1f.otg.PatternFlowGtpv1NPduNumber\x12P\n\x1anext_extension_header_type\x18\x0c \x01(\x0b\x32,.otg.PatternFlowGtpv1NextExtensionHeaderType\x12\x30\n\x11\x65xtension_headers\x18\r \x03(\x0b\x32\x15.otg.FlowGtpExtension\"\xe1\x01\n\x10\x46lowGtpExtension\x12\x45\n\x10\x65xtension_length\x18\x01 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionExtensionLength\x12\x36\n\x08\x63ontents\x18\x02 \x01(\x0b\x32$.otg.PatternFlowGtpExtensionContents\x12N\n\x15next_extension_header\x18\x03 \x01(\x0b\x32/.otg.PatternFlowGtpExtensionNextExtensionHeader\"\xe3\x03\n\tFlowGtpv2\x12-\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv2Version\x12@\n\x11piggybacking_flag\x18\x02 \x01(\x0b\x32%.otg.PatternFlowGtpv2PiggybackingFlag\x12\x30\n\tteid_flag\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv2TeidFlag\x12+\n\x06spare1\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare1\x12\x36\n\x0cmessage_type\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2MessageType\x12:\n\x0emessage_length\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2MessageLength\x12\'\n\x04teid\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowGtpv2Teid\x12<\n\x0fsequence_number\x18\x08 \x01(\x0b\x32#.otg.PatternFlowGtpv2SequenceNumber\x12+\n\x06spare2\x18\t \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare2\"\xb6\x04\n\x07\x46lowArp\x12\x36\n\rhardware_type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowArpHardwareType\x12\x36\n\rprotocol_type\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowArpProtocolType\x12:\n\x0fhardware_length\x18\x03 \x01(\x0b\x32!.otg.PatternFlowArpHardwareLength\x12:\n\x0fprotocol_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowArpProtocolLength\x12/\n\toperation\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowArpOperation\x12\x43\n\x14sender_hardware_addr\x18\x06 \x01(\x0b\x32%.otg.PatternFlowArpSenderHardwareAddr\x12\x43\n\x14sender_protocol_addr\x18\x07 \x01(\x0b\x32%.otg.PatternFlowArpSenderProtocolAddr\x12\x43\n\x14target_hardware_addr\x18\x08 \x01(\x0b\x32%.otg.PatternFlowArpTargetHardwareAddr\x12\x43\n\x14target_protocol_addr\x18\t \x01(\x0b\x32%.otg.PatternFlowArpTargetProtocolAddr\"\x93\x01\n\x08\x46lowIcmp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowIcmp.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x11.otg.FlowIcmpEcho\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choice\"\x93\x02\n\x0c\x46lowIcmpEcho\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoType\x12*\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoCode\x12\x32\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowIcmpEchoChecksum\x12\x36\n\nidentifier\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIcmpEchoIdentifier\x12?\n\x0fsequence_number\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIcmpEchoSequenceNumber\"\x99\x01\n\nFlowIcmpv6\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowIcmpv6.Choice.EnumH\x00\x88\x01\x01\x12!\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x13.otg.FlowIcmpv6Echo\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choice\"\x9f\x02\n\x0e\x46lowIcmpv6Echo\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoType\x12,\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoCode\x12\x38\n\nidentifier\x18\x03 \x01(\x0b\x32$.otg.PatternFlowIcmpv6EchoIdentifier\x12\x41\n\x0fsequence_number\x18\x04 \x01(\x0b\x32(.otg.PatternFlowIcmpv6EchoSequenceNumber\x12\x34\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIcmpv6EchoChecksum\"\x9b\x01\n\x07\x46lowPpp\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowPppAddress\x12+\n\x07\x63ontrol\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowPppControl\x12\x36\n\rprotocol_type\x18\x03 \x01(\x0b\x32\x1f.otg.PatternFlowPppProtocolType\"\x81\x02\n\nFlowIgmpv1\x12.\n\x07version\x18\x01 \x01(\x0b\x32\x1d.otg.PatternFlowIgmpv1Version\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowIgmpv1Type\x12,\n\x06unused\x18\x03 \x01(\x0b\x32\x1c.otg.PatternFlowIgmpv1Unused\x12\x30\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowIgmpv1Checksum\x12\x39\n\rgroup_address\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIgmpv1GroupAddress\"\xdf\x01\n\x08\x46lowMpls\x12(\n\x05label\x18\x01 \x01(\x0b\x32\x19.otg.PatternFlowMplsLabel\x12\x37\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowMplsTrafficClass\x12:\n\x0f\x62ottom_of_stack\x18\x03 \x01(\x0b\x32!.otg.PatternFlowMplsBottomOfStack\x12\x34\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowMplsTimeToLive\"\x88\x01\n\x0b\x46lowSnmpv2c\x12/\n\x07version\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowSnmpv2cVersion\x12\x16\n\tcommunity\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\"\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.otg.FlowSnmpv2cDataB\x0c\n\n_community\"\xde\x04\n\x0f\x46lowSnmpv2cData\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowSnmpv2cData.Choice.EnumH\x00\x88\x01\x01\x12(\n\x0bget_request\x18\x02 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12-\n\x10get_next_request\x18\x03 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12%\n\x08response\x18\x04 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12(\n\x0bset_request\x18\x05 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12\x31\n\x10get_bulk_request\x18\x06 \x01(\x0b\x32\x17.otg.FlowSnmpv2cBulkPDU\x12+\n\x0einform_request\x18\x07 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12(\n\x0bsnmpv2_trap\x18\x08 \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x12#\n\x06report\x18\t \x01(\x0b\x32\x13.otg.FlowSnmpv2cPDU\x1a\xaf\x01\n\x06\x43hoice\"\xa4\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bget_request\x10\x01\x12\x14\n\x10get_next_request\x10\x02\x12\x0c\n\x08response\x10\x03\x12\x0f\n\x0bset_request\x10\x04\x12\x14\n\x10get_bulk_request\x10\x05\x12\x12\n\x0einform_request\x10\x06\x12\x0f\n\x0bsnmpv2_trap\x10\x07\x12\n\n\x06report\x10\x08\x42\t\n\x07_choice\"\x93\x05\n\x0e\x46lowSnmpv2cPDU\x12\x37\n\nrequest_id\x18\x01 \x01(\x0b\x32#.otg.PatternFlowSnmpv2cPDURequestId\x12?\n\x0c\x65rror_status\x18\x02 \x01(\x0e\x32$.otg.FlowSnmpv2cPDU.ErrorStatus.EnumH\x00\x88\x01\x01\x12\x39\n\x0b\x65rror_index\x18\x03 \x01(\x0b\x32$.otg.PatternFlowSnmpv2cPDUErrorIndex\x12:\n\x11variable_bindings\x18\x04 \x03(\x0b\x32\x1f.otg.FlowSnmpv2cVariableBinding\x1a\xfe\x02\n\x0b\x45rrorStatus\"\xee\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08no_error\x10\x01\x12\x0b\n\x07too_big\x10\x02\x12\x10\n\x0cno_such_name\x10\x03\x12\r\n\tbad_value\x10\x04\x12\r\n\tread_only\x10\x05\x12\x0b\n\x07gen_err\x10\x06\x12\r\n\tno_access\x10\x07\x12\x0e\n\nwrong_type\x10\x08\x12\x10\n\x0cwrong_length\x10\t\x12\x12\n\x0ewrong_encoding\x10\n\x12\x0f\n\x0bwrong_value\x10\x0b\x12\x0f\n\x0bno_creation\x10\x0c\x12\x16\n\x12inconsistent_value\x10\r\x12\x18\n\x14resource_unavailable\x10\x0e\x12\x11\n\rcommit_failed\x10\x0f\x12\x0f\n\x0bundo_failed\x10\x10\x12\x17\n\x13\x61uthorization_error\x10\x11\x12\x10\n\x0cnot_writable\x10\x12\x12\x15\n\x11inconsistent_name\x10\x13\x42\x0f\n\r_error_status\"\x97\x02\n\x12\x46lowSnmpv2cBulkPDU\x12;\n\nrequest_id\x18\x01 \x01(\x0b\x32\'.otg.PatternFlowSnmpv2cBulkPDURequestId\x12\x41\n\rnon_repeaters\x18\x02 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cBulkPDUNonRepeaters\x12\x45\n\x0fmax_repetitions\x18\x03 \x01(\x0b\x32,.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitions\x12:\n\x11variable_bindings\x18\x04 \x03(\x0b\x32\x1f.otg.FlowSnmpv2cVariableBinding\"\x87\x01\n\x1a\x46lowSnmpv2cVariableBinding\x12\x1e\n\x11object_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.otg.FlowSnmpv2cVariableBindingValueB\x14\n\x12_object_identifier\"\xa5\x08\n\x1f\x46lowSnmpv2cVariableBindingValue\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowSnmpv2cVariableBindingValue.Choice.EnumH\x00\x88\x01\x01\x12N\n\rinteger_value\x18\x02 \x01(\x0b\x32\x37.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValue\x12@\n\x0cstring_value\x18\x03 \x01(\x0b\x32*.otg.FlowSnmpv2cVariableBindingStringValue\x12$\n\x17object_identifier_value\x18\x04 \x01(\tH\x01\x88\x01\x01\x12S\n\x10ip_address_value\x18\x05 \x01(\x0b\x32\x39.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValue\x12N\n\rcounter_value\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowSnmpv2cVariableBindingValueCounterValue\x12R\n\x0ftimeticks_value\x18\x07 \x01(\x0b\x32\x39.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValue\x12\x1c\n\x0f\x61rbitrary_value\x18\x08 \x01(\tH\x02\x88\x01\x01\x12U\n\x11\x62ig_counter_value\x18\t \x01(\x0b\x32:.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValue\x12_\n\x16unsigned_integer_value\x18\n \x01(\x0b\x32?.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue\x1a\xf8\x01\n\x06\x43hoice\"\xed\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08no_value\x10\x01\x12\x11\n\rinteger_value\x10\x02\x12\x10\n\x0cstring_value\x10\x03\x12\x1b\n\x17object_identifier_value\x10\x04\x12\x14\n\x10ip_address_value\x10\x05\x12\x11\n\rcounter_value\x10\x06\x12\x13\n\x0ftimeticks_value\x10\x07\x12\x13\n\x0f\x61rbitrary_value\x10\x08\x12\x15\n\x11\x62ig_counter_value\x10\t\x12\x1a\n\x16unsigned_integer_value\x10\nB\t\n\x07_choiceB\x1a\n\x18_object_identifier_valueB\x12\n\x10_arbitrary_value\"\xee\x01\n%FlowSnmpv2cVariableBindingStringValue\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.FlowSnmpv2cVariableBindingStringValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x61scii\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03raw\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x61scii\x10\x01\x12\x07\n\x03raw\x10\x02\x42\t\n\x07_choiceB\x08\n\x06_asciiB\x06\n\x04_raw\"\xb9\x03\n\x08\x46lowRsvp\x12\x14\n\x07version\x18\x01 \x01(\rH\x00\x88\x01\x01\x12*\n\x04\x66lag\x18\x02 \x01(\x0e\x32\x17.otg.FlowRsvp.Flag.EnumH\x01\x88\x01\x01\x12\x37\n\rrsvp_checksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowRsvpRsvpChecksum\x12\x34\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowRsvpTimeToLive\x12.\n\x08reserved\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowRsvpReserved\x12(\n\x0brsvp_length\x18\x06 \x01(\x0b\x32\x13.otg.FlowRSVPLength\x12*\n\x0cmessage_type\x18\x07 \x01(\x0b\x32\x14.otg.FlowRSVPMessage\x1a\x61\n\x04\x46lag\"Y\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12!\n\x1dnot_refresh_reduction_capable\x10\x01\x12\x1d\n\x19refresh_reduction_capable\x10\x02\x42\n\n\x08_versionB\x07\n\x05_flag\"\xc3\x01\n\x0e\x46lowRSVPLength\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.FlowRSVPLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xa8\x01\n\x0f\x46lowRSVPMessage\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.FlowRSVPMessage.Choice.EnumH\x00\x88\x01\x01\x12&\n\x04path\x18\x02 \x01(\x0b\x32\x18.otg.FlowRSVPPathMessage\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04path\x10\x01\x42\t\n\x07_choice\"@\n\x13\x46lowRSVPPathMessage\x12)\n\x07objects\x18\x01 \x03(\x0b\x32\x18.otg.FlowRSVPPathObjects\"G\n\x13\x46lowRSVPPathObjects\x12\x30\n\tclass_num\x18\x01 \x01(\x0b\x32\x1d.otg.FlowRSVPPathObjectsClass\"\xcf\x01\n\x14\x46lowRSVPObjectLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.FlowRSVPObjectLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xac\x07\n\x18\x46lowRSVPPathObjectsClass\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.FlowRSVPPathObjectsClass.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x07session\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsClassSession\x12\x36\n\x08rsvp_hop\x18\x03 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsClassRsvpHop\x12<\n\x0btime_values\x18\x04 \x01(\x0b\x32\'.otg.FlowRSVPPathObjectsClassTimeValues\x12\x42\n\x0e\x65xplicit_route\x18\x05 \x01(\x0b\x32*.otg.FlowRSVPPathObjectsClassExplicitRoute\x12@\n\rlabel_request\x18\x06 \x01(\x0b\x32).otg.FlowRSVPPathObjectsClassLabelRequest\x12H\n\x11session_attribute\x18\x07 \x01(\x0b\x32-.otg.FlowRSVPPathObjectsClassSessionAttribute\x12\x44\n\x0fsender_template\x18\x08 \x01(\x0b\x32+.otg.FlowRSVPPathObjectsClassSenderTemplate\x12>\n\x0csender_tspec\x18\t \x01(\x0b\x32(.otg.FlowRSVPPathObjectsClassSenderTspec\x12>\n\x0crecord_route\x18\n \x01(\x0b\x32(.otg.FlowRSVPPathObjectsClassRecordRoute\x12.\n\x06\x63ustom\x18\x0b \x01(\x0b\x32\x1e.otg.FlowRSVPPathObjectsCustom\x1a\xd1\x01\n\x06\x43hoice\"\xc6\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07session\x10\x01\x12\x0c\n\x08rsvp_hop\x10\x02\x12\x0f\n\x0btime_values\x10\x03\x12\x12\n\x0e\x65xplicit_route\x10\x04\x12\x11\n\rlabel_request\x10\x05\x12\x15\n\x11session_attribute\x10\x06\x12\x13\n\x0fsender_template\x10\x07\x12\x10\n\x0csender_tspec\x10\x08\x12\x10\n\x0crecord_route\x10\t\x12\n\n\x06\x63ustom\x10\nB\t\n\x07_choice\"\x82\x01\n\x1f\x46lowRSVPPathObjectsClassSession\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x34\n\x06\x63_type\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsSessionCType\"\xeb\x01\n\x1f\x46lowRSVPPathObjectsSessionCType\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowRSVPPathObjectsSessionCType.Choice.EnumH\x00\x88\x01\x01\x12>\n\x0flsp_tunnel_ipv4\x18\x02 \x01(\x0b\x32%.otg.FlowRSVPPathSessionLspTunnelIpv4\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flsp_tunnel_ipv4\x10\x01\x42\t\n\x07_choice\"\xe2\x02\n FlowRSVPPathSessionLspTunnelIpv4\x12l\n\x1dipv4_tunnel_end_point_address\x18\x01 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress\x12\x46\n\x08reserved\x18\x02 \x01(\x0b\x32\x34.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Reserved\x12G\n\ttunnel_id\x18\x03 \x01(\x0b\x32\x34.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId\x12?\n\x12\x65xtended_tunnel_id\x18\x04 \x01(\x0b\x32#.otg.FlowRSVPPathSessionExtTunnelId\"\xbd\x02\n\x1e\x46lowRSVPPathSessionExtTunnelId\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.FlowRSVPPathSessionExtTunnelId.Choice.EnumH\x00\x88\x01\x01\x12G\n\nas_integer\x18\x02 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSessionExtTunnelIdAsInteger\x12\x41\n\x07\x61s_ipv4\x18\x03 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nas_integer\x10\x01\x12\x0b\n\x07\x61s_ipv4\x10\x02\x42\t\n\x07_choice\"\x82\x01\n\x1f\x46lowRSVPPathObjectsClassRsvpHop\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x34\n\x06\x63_type\x18\x02 \x01(\x0b\x32$.otg.FlowRSVPPathObjectsRsvpHopCType\"\xcc\x01\n\x1f\x46lowRSVPPathObjectsRsvpHopCType\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.FlowRSVPPathObjectsRsvpHopCType.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04ipv4\x18\x02 \x01(\x0b\x32\x1c.otg.FlowRSVPPathRsvpHopIpv4\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x42\t\n\x07_choice\"\xbc\x01\n\x17\x46lowRSVPPathRsvpHopIpv4\x12\x44\n\x0cipv4_address\x18\x01 \x01(\x0b\x32..otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4Address\x12[\n\x18logical_interface_handle\x18\x02 \x01(\x0b\x32\x39.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle\"\x88\x01\n\"FlowRSVPPathObjectsClassTimeValues\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x37\n\x06\x63_type\x18\x02 \x01(\x0b\x32\'.otg.FlowRSVPPathObjectsTimeValuesCType\"\xda\x01\n\"FlowRSVPPathObjectsTimeValuesCType\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.FlowRSVPPathObjectsTimeValuesCType.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x06type_1\x18\x02 \x01(\x0b\x32 .otg.FlowRSVPPathTimeValuesType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"n\n\x1b\x46lowRSVPPathTimeValuesType1\x12O\n\x10refresh_period_r\x18\x01 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodR\"\x93\x01\n%FlowRSVPPathObjectsClassExplicitRoute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12?\n\x06\x63_type\x18\x02 \x01(\x0b\x32/.otg.FlowRSVPPathObjectsClassExplicitRouteCType\"\xed\x01\n*FlowRSVPPathObjectsClassExplicitRouteCType\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.FlowRSVPPathObjectsClassExplicitRouteCType.Choice.EnumH\x00\x88\x01\x01\x12\x33\n\x06type_1\x18\x02 \x01(\x0b\x32#.otg.FlowRSVPPathExplicitRouteType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"_\n\x1e\x46lowRSVPPathExplicitRouteType1\x12=\n\nsubobjects\x18\x01 \x03(\x0b\x32).otg.FlowRSVPType1ExplicitRouteSubobjects\"c\n$FlowRSVPType1ExplicitRouteSubobjects\x12;\n\x04type\x18\x01 \x01(\x0b\x32-.otg.FlowRSVPType1ExplicitRouteSubobjectsType\"\xcc\x02\n(FlowRSVPType1ExplicitRouteSubobjectsType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.FlowRSVPType1ExplicitRouteSubobjectsType.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0bipv4_prefix\x18\x02 \x01(\x0b\x32-.otg.FlowRSVPPathExplicitRouteType1Ipv4Prefix\x12>\n\tas_number\x18\x03 \x01(\x0b\x32+.otg.FlowRSVPPathExplicitRouteType1ASNumber\x1a\x41\n\x06\x43hoice\"7\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0bipv4_prefix\x10\x01\x12\r\n\tas_number\x10\x02\x42\t\n\x07_choice\"\x9c\x02\n(FlowRSVPPathExplicitRouteType1Ipv4Prefix\x12G\n\x05l_bit\x18\x01 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit\x12\x30\n\x06length\x18\x02 \x01(\x0b\x32 .otg.FlowRSVPExplicitRouteLength\x12U\n\x0cipv4_address\x18\x03 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address\x12\x13\n\x06prefix\x18\x04 \x01(\rH\x00\x88\x01\x01\x42\t\n\x07_prefix\"\xcf\x01\n&FlowRSVPPathExplicitRouteType1ASNumber\x12\x45\n\x05l_bit\x18\x01 \x01(\x0b\x32\x36.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBit\x12\x38\n\x06length\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPExplicitRouteASNumberLength\x12\x16\n\tas_number\x18\x03 \x01(\rH\x00\x88\x01\x01\x42\x0c\n\n_as_number\"\xdd\x01\n\x1b\x46lowRSVPExplicitRouteLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowRSVPExplicitRouteLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xed\x01\n#FlowRSVPExplicitRouteASNumberLength\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPExplicitRouteASNumberLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x8c\x01\n$FlowRSVPPathObjectsClassLabelRequest\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x39\n\x06\x63_type\x18\x02 \x01(\x0b\x32).otg.FlowRSVPPathObjectsLabelRequestCType\"\x86\x02\n$FlowRSVPPathObjectsLabelRequestCType\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.FlowRSVPPathObjectsLabelRequestCType.Choice.EnumH\x00\x88\x01\x01\x12K\n\x13without_label_range\x18\x02 \x01(\x0b\x32..otg.FlowRSVPPathLabelRequestWithoutLabelRange\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13without_label_range\x10\x01\x42\t\n\x07_choice\"\xc7\x01\n)FlowRSVPPathLabelRequestWithoutLabelRange\x12O\n\x08reserved\x18\x01 \x01(\x0b\x32=.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved\x12I\n\x05l3pid\x18\x02 \x01(\x0b\x32:.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid\"\x94\x01\n(FlowRSVPPathObjectsClassSessionAttribute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12=\n\x06\x63_type\x18\x02 \x01(\x0b\x32-.otg.FlowRSVPPathObjectsSessionAttributeCType\"\xd0\x02\n(FlowRSVPPathObjectsSessionAttributeCType\x12N\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x39.otg.FlowRSVPPathObjectsSessionAttributeCType.Choice.EnumH\x00\x88\x01\x01\x12>\n\nlsp_tunnel\x18\x02 \x01(\x0b\x32*.otg.FlowRSVPPathSessionAttributeLspTunnel\x12\x43\n\rlsp_tunnel_ra\x18\x03 \x01(\x0b\x32,.otg.FlowRSVPPathSessionAttributeLspTunnelRa\x1a\x44\n\x06\x43hoice\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nlsp_tunnel\x10\x01\x12\x11\n\rlsp_tunnel_ra\x10\x02\x42\t\n\x07_choice\"\xa0\x02\n%FlowRSVPPathSessionAttributeLspTunnel\x12\x1b\n\x0esetup_priority\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x1a.otg.FlowRSVPLspTunnelFlag\x12<\n\x0bname_length\x18\x04 \x01(\x0b\x32\'.otg.FlowRSVPSessionAttributeNameLength\x12\x19\n\x0csession_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0f\n\r_session_name\"\xa0\x03\n\'FlowRSVPPathSessionAttributeLspTunnelRa\x12\x18\n\x0b\x65xclude_any\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0esetup_priority\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x05 \x01(\rH\x04\x88\x01\x01\x12)\n\x05\x66lags\x18\x06 \x01(\x0b\x32\x1a.otg.FlowRSVPLspTunnelFlag\x12<\n\x0bname_length\x18\x07 \x01(\x0b\x32\'.otg.FlowRSVPSessionAttributeNameLength\x12\x19\n\x0csession_name\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_allB\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0f\n\r_session_name\"\xd3\x01\n\x15\x46lowRSVPLspTunnelFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.FlowRSVPLspTunnelFlag.Choice.EnumH\x00\x88\x01\x01\x1ar\n\x06\x43hoice\"h\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1c\n\x18local_protection_desired\x10\x01\x12\x1b\n\x17label_recording_desired\x10\x02\x12\x14\n\x10se_style_desired\x10\x03\x42\t\n\x07_choice\"\xeb\x01\n\"FlowRSVPSessionAttributeNameLength\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.FlowRSVPSessionAttributeNameLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x90\x01\n&FlowRSVPPathObjectsClassSenderTemplate\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12;\n\x06\x63_type\x18\x02 \x01(\x0b\x32+.otg.FlowRSVPPathObjectsSenderTemplateCType\"\x80\x02\n&FlowRSVPPathObjectsSenderTemplateCType\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.FlowRSVPPathObjectsSenderTemplateCType.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\x0flsp_tunnel_ipv4\x18\x02 \x01(\x0b\x32,.otg.FlowRSVPPathSenderTemplateLspTunnelIpv4\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flsp_tunnel_ipv4\x10\x01\x42\t\n\x07_choice\"\xb2\x02\n\'FlowRSVPPathSenderTemplateLspTunnelIpv4\x12n\n\x1aipv4_tunnel_sender_address\x18\x01 \x01(\x0b\x32J.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress\x12M\n\x08reserved\x18\x02 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved\x12H\n\x06lsp_id\x18\x03 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId\"\x8a\x01\n#FlowRSVPPathObjectsClassSenderTspec\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x38\n\x06\x63_type\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPPathObjectsSenderTspecCType\"\xe3\x01\n#FlowRSVPPathObjectsSenderTspecCType\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPPathObjectsSenderTspecCType.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x08int_serv\x18\x02 \x01(\x0b\x32#.otg.FlowRSVPPathSenderTspecIntServ\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08int_serv\x10\x01\x42\t\n\x07_choice\"\xb0\t\n\x1e\x46lowRSVPPathSenderTspecIntServ\x12\x42\n\x07version\x18\x01 \x01(\x0b\x32\x31.otg.PatternFlowRSVPPathSenderTspecIntServVersion\x12\x46\n\treserved1\x18\x02 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSenderTspecIntServReserved1\x12O\n\x0eoverall_length\x18\x03 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSenderTspecIntServOverallLength\x12O\n\x0eservice_header\x18\x04 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeader\x12\x43\n\x08zero_bit\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowRSVPPathSenderTspecIntServZeroBit\x12\x46\n\treserved2\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowRSVPPathSenderTspecIntServReserved2\x12]\n\x16length_of_service_data\x18\x07 \x01(\x0b\x32=.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData\x12n\n\x1fparameter_id_token_bucket_tspec\x18\x08 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec\x12V\n\x12parameter_127_flag\x18\t \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Flag\x12Z\n\x14parameter_127_length\x18\n \x01(\x0b\x32<.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Length\x12\x1e\n\x11token_bucket_rate\x18\x0b \x01(\x02H\x00\x88\x01\x01\x12\x1e\n\x11token_bucket_size\x18\x0c \x01(\x02H\x01\x88\x01\x01\x12\x1b\n\x0epeak_data_rate\x18\r \x01(\x02H\x02\x88\x01\x01\x12Z\n\x14minimum_policed_unit\x18\x0e \x01(\x0b\x32<.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit\x12X\n\x13maximum_packet_size\x18\x0f \x01(\x0b\x32;.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeB\x14\n\x12_token_bucket_rateB\x14\n\x12_token_bucket_sizeB\x11\n\x0f_peak_data_rate\"\x8a\x01\n#FlowRSVPPathObjectsClassRecordRoute\x12)\n\x06length\x18\x01 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x38\n\x06\x63_type\x18\x02 \x01(\x0b\x32(.otg.FlowRSVPPathObjectsRecordRouteCType\"\xdd\x01\n#FlowRSVPPathObjectsRecordRouteCType\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.FlowRSVPPathObjectsRecordRouteCType.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x06type_1\x18\x02 \x01(\x0b\x32!.otg.FlowRSVPPathRecordRouteType1\x1a-\n\x06\x43hoice\"#\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_1\x10\x01\x42\t\n\x07_choice\"[\n\x1c\x46lowRSVPPathRecordRouteType1\x12;\n\nsubobjects\x18\x01 \x03(\x0b\x32\'.otg.FlowRSVPType1RecordRouteSubobjects\"d\n\"FlowRSVPType1RecordRouteSubobjects\x12>\n\x04type\x18\x01 \x01(\x0b\x32\x30.otg.FlowRSVPPathObjectsRecordRouteSubObjectType\"\xc6\x02\n+FlowRSVPPathObjectsRecordRouteSubObjectType\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.FlowRSVPPathObjectsRecordRouteSubObjectType.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\x0cipv4_address\x18\x02 \x01(\x0b\x32,.otg.FlowRSVPPathRecordRouteType1Ipv4Address\x12\x35\n\x05label\x18\x03 \x01(\x0b\x32&.otg.FlowRSVPPathRecordRouteType1Label\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_address\x10\x01\x12\t\n\x05label\x10\x02\x42\t\n\x07_choice\"\xb8\x02\n\'FlowRSVPPathRecordRouteType1Ipv4Address\x12.\n\x06length\x18\x01 \x01(\x0b\x32\x1e.otg.FlowRSVPRouteRecordLength\x12T\n\x0cipv4_address\x18\x02 \x01(\x0b\x32>.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address\x12V\n\rprefix_length\x18\x03 \x01(\x0b\x32?.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength\x12/\n\x05\x66lags\x18\x04 \x01(\x0b\x32 .otg.FlowRSVPRecordRouteIPv4Flag\"\xcb\x01\n\x1b\x46lowRSVPRecordRouteIPv4Flag\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.FlowRSVPRecordRouteIPv4Flag.Choice.EnumH\x00\x88\x01\x01\x1a^\n\x06\x43hoice\"T\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1e\n\x1alocal_protection_available\x10\x01\x12\x1b\n\x17local_protection_in_use\x10\x02\x42\t\n\x07_choice\"\x8c\x02\n!FlowRSVPPathRecordRouteType1Label\x12.\n\x06length\x18\x01 \x01(\x0b\x32\x1e.otg.FlowRSVPRouteRecordLength\x12\x41\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x32.otg.PatternFlowRSVPPathRecordRouteType1LabelFlags\x12\x42\n\x06\x63_type\x18\x03 \x01(\x0b\x32\x32.otg.PatternFlowRSVPPathRecordRouteType1LabelCType\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.otg.FlowRSVPPathRecordRouteLabel\"\xf4\x01\n\x1c\x46lowRSVPPathRecordRouteLabel\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.FlowRSVPPathRecordRouteLabel.Choice.EnumH\x00\x88\x01\x01\x12\x17\n\nas_integer\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06\x61s_hex\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nas_integer\x10\x01\x12\n\n\x06\x61s_hex\x10\x02\x42\t\n\x07_choiceB\r\n\x0b_as_integerB\t\n\x07_as_hex\"\xd9\x01\n\x19\x46lowRSVPRouteRecordLength\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowRSVPRouteRecordLength.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x9d\x01\n\x19\x46lowRSVPPathObjectsCustom\x12\x37\n\x04type\x18\x01 \x01(\x0b\x32).otg.PatternFlowRSVPPathObjectsCustomType\x12)\n\x06length\x18\x02 \x01(\x0b\x32\x19.otg.FlowRSVPObjectLength\x12\x12\n\x05\x62ytes\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_bytes\"\xbe\x02\n\x08\x46lowSize\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x66ixed\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\tincrement\x18\x03 \x01(\x0b\x32\x16.otg.FlowSizeIncrement\x12#\n\x06random\x18\x04 \x01(\x0b\x32\x13.otg.FlowSizeRandom\x12.\n\x0cweight_pairs\x18\x05 \x01(\x0b\x32\x18.otg.FlowSizeWeightPairs\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\r\n\tincrement\x10\x02\x12\n\n\x06random\x10\x03\x12\x10\n\x0cweight_pairs\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_fixed\"g\n\x11\x46lowSizeIncrement\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03\x65nd\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04step\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x06\n\x04_endB\x07\n\x05_step\"D\n\x0e\x46lowSizeRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"\x8d\x03\n\x13\x46lowSizeWeightPairs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.FlowSizeWeightPairs.Choice.EnumH\x00\x88\x01\x01\x12\x41\n\npredefined\x18\x02 \x01(\x0e\x32(.otg.FlowSizeWeightPairs.Predefined.EnumH\x01\x88\x01\x01\x12.\n\x06\x63ustom\x18\x03 \x03(\x0b\x32\x1e.otg.FlowSizeWeightPairsCustom\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\npredefined\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1ao\n\nPredefined\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04imix\x10\x01\x12\x0e\n\nipsec_imix\x10\x02\x12\r\n\tipv6_imix\x10\x03\x12\x11\n\rstandard_imix\x10\x04\x12\x0c\n\x08tcp_imix\x10\x05\x42\t\n\x07_choiceB\r\n\x0b_predefined\"W\n\x19\x46lowSizeWeightPairsCustom\x12\x11\n\x04size\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06weight\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x07\n\x05_sizeB\t\n\x07_weight\"\xd8\x02\n\x08\x46lowRate\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowRate.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03pps\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x10\n\x03\x62ps\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x11\n\x04kbps\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x11\n\x04mbps\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x11\n\x04gbps\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x17\n\npercentage\x18\x07 \x01(\x02H\x06\x88\x01\x01\x1a\x61\n\x06\x43hoice\"W\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03pps\x10\x01\x12\x07\n\x03\x62ps\x10\x02\x12\x08\n\x04kbps\x10\x03\x12\x08\n\x04mbps\x10\x04\x12\x08\n\x04gbps\x10\x05\x12\x0e\n\npercentage\x10\x06\x42\t\n\x07_choiceB\x06\n\x04_ppsB\x06\n\x04_bpsB\x07\n\x05_kbpsB\x07\n\x05_mbpsB\x07\n\x05_gbpsB\r\n\x0b_percentage\"\xd5\x02\n\x0c\x46lowDuration\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowDuration.Choice.EnumH\x00\x88\x01\x01\x12,\n\rfixed_packets\x18\x02 \x01(\x0b\x32\x15.otg.FlowFixedPackets\x12,\n\rfixed_seconds\x18\x03 \x01(\x0b\x32\x15.otg.FlowFixedSeconds\x12\x1d\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x0e.otg.FlowBurst\x12\'\n\ncontinuous\x18\x05 \x01(\x0b\x32\x13.otg.FlowContinuous\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rfixed_packets\x10\x01\x12\x11\n\rfixed_seconds\x10\x02\x12\t\n\x05\x62urst\x10\x03\x12\x0e\n\ncontinuous\x10\x04\x42\t\n\x07_choice\"I\n\x0e\x46lowContinuous\x12\x10\n\x03gap\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x0e.otg.FlowDelayB\x06\n\x04_gap\"\x8c\x02\n\tFlowDelay\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.FlowDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"m\n\x10\x46lowFixedPackets\x12\x14\n\x07packets\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayB\n\n\x08_packetsB\x06\n\x04_gap\"m\n\x10\x46lowFixedSeconds\x12\x14\n\x07seconds\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1d\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayB\n\n\x08_secondsB\x06\n\x04_gap\"\xa0\x01\n\tFlowBurst\x12\x13\n\x06\x62ursts\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x14\n\x07packets\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x10\n\x03gap\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x37\n\x0finter_burst_gap\x18\x04 \x01(\x0b\x32\x1e.otg.FlowDurationInterBurstGapB\t\n\x07_burstsB\n\n\x08_packetsB\x06\n\x04_gap\"\xac\x02\n\x19\x46lowDurationInterBurstGap\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowDurationInterBurstGap.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"\xfd\x01\n\x0b\x46lowMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x11\n\x04loss\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\'\n\x0brx_tx_ratio\x18\x06 \x01(\x0b\x32\x12.otg.FlowRxTxRatio\x12\x17\n\ntimestamps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12(\n\x07latency\x18\x04 \x01(\x0b\x32\x17.otg.FlowLatencyMetrics\x12\x37\n\x16predefined_metric_tags\x18\x05 \x01(\x0b\x32\x17.otg.FlowPredefinedTagsB\t\n\x07_enableB\x07\n\x05_lossB\r\n\x0b_timestamps\"\xb8\x01\n\x12\x46lowLatencyMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32!.otg.FlowLatencyMetrics.Mode.EnumH\x01\x88\x01\x01\x1a\x43\n\x04Mode\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rstore_forward\x10\x01\x12\x0f\n\x0b\x63ut_through\x10\x02\x42\t\n\x07_enableB\x07\n\x05_mode\"6\n\x12\x46lowPredefinedTags\x12\x14\n\x07rx_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_rx_name\"\xd6\x01\n\rFlowRxTxRatio\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.FlowRxTxRatio.Choice.EnumH\x00\x88\x01\x01\x12+\n\x08rx_count\x18\x02 \x01(\x0b\x32\x19.otg.FlowRxTxRatioRxCount\x12\x12\n\x05value\x18\x03 \x01(\x02H\x01\x88\x01\x01\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08rx_count\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x08\n\x06_value\"\x16\n\x14\x46lowRxTxRatioRxCount\"U\n\x05\x45vent\x12%\n\tcp_events\x18\x01 \x01(\x0b\x32\x12.otg.EventCPEvents\x12%\n\tdp_events\x18\x02 \x01(\x0b\x32\x12.otg.EventDPEvents\"/\n\rEventCPEvents\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"e\n\rEventDPEvents\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1e\n\x11rx_rate_threshold\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_enableB\x14\n\x12_rx_rate_threshold\"\xf5\x01\n\x0c\x45ventRequest\x12)\n\x04type\x18\x01 \x03(\x0e\x32\x1b.otg.EventRequest.Type.Enum\x12\x0e\n\x06source\x18\x02 \x03(\t\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\"b\n\x11\x45ventSubscription\x12!\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x11.otg.EventRequest\x12\x19\n\x0c\x63\x61llback_url\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_callback_url\"\xca\x02\n\x04Lldp\x12\'\n\nconnection\x18\x01 \x01(\x0b\x32\x13.otg.LldpConnection\x12&\n\nchassis_id\x18\x02 \x01(\x0b\x32\x12.otg.LldpChassisId\x12 \n\x07port_id\x18\x03 \x01(\x0b\x32\x0f.otg.LldpPortId\x12(\n\x0bsystem_name\x18\x04 \x01(\x0b\x32\x13.otg.LldpSystemName\x12\x16\n\thold_time\x18\x05 \x01(\rH\x00\x88\x01\x01\x12#\n\x16\x61\x64vertisement_interval\x18\x06 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04name\x18\x07 \x01(\tH\x02\x88\x01\x01\x12#\n\torg_infos\x18\x08 \x03(\x0b\x32\x10.otg.LldpOrgInfoB\x0c\n\n_hold_timeB\x19\n\x17_advertisement_intervalB\x07\n\x05_name\"\xa9\x01\n\x0eLldpConnection\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x42\t\n\x07_choiceB\x0c\n\n_port_name\"\xe1\x02\n\rLldpChassisId\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.LldpChassisId.Choice.EnumH\x00\x88\x01\x01\x12\x37\n\x13mac_address_subtype\x18\x02 \x01(\x0b\x32\x1a.otg.LldpChassisMacSubType\x12#\n\x16interface_name_subtype\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x02\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x19\n\x17_interface_name_subtypeB\x10\n\x0e_local_subtype\"\xdf\x02\n\nLldpPortId\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.LldpPortId.Choice.EnumH\x00\x88\x01\x01\x12 \n\x13mac_address_subtype\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x41\n\x16interface_name_subtype\x18\x03 \x01(\x0b\x32!.otg.LldpPortInterfaceNameSubType\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x02\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x16\n\x14_mac_address_subtypeB\x10\n\x0e_local_subtype\"\xd1\x01\n\x15LldpChassisMacSubType\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.LldpChassisMacSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xdf\x01\n\x1cLldpPortInterfaceNameSubType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.LldpPortInterfaceNameSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xc3\x01\n\x0eLldpSystemName\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpSystemName.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"t\n\x0bLldpOrgInfo\x12\x10\n\x03oui\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07subtype\x18\x02 \x01(\rH\x01\x88\x01\x01\x12)\n\x0binformation\x18\x03 \x01(\x0b\x32\x14.otg.LldpOrgInfoTypeB\x06\n\x04_ouiB\n\n\x08_subtype\"\x9c\x01\n\x0fLldpOrgInfoType\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.LldpOrgInfoType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04info\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04info\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_info\"\xa4\x01\n\x05\x45rror\x12\x11\n\x04\x63ode\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\'\n\x04kind\x18\x02 \x01(\x0e\x32\x14.otg.Error.Kind.EnumH\x01\x88\x01\x01\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\x1a=\n\x04Kind\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nvalidation\x10\x01\x12\x0c\n\x08internal\x10\x02\x42\x07\n\x05_codeB\x07\n\x05_kind\"\x1b\n\x07Warning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"\x9c\x01\n\x0c\x43onfigUpdate\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ConfigUpdate.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x10.otg.FlowsUpdate\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lows\x10\x01\x42\t\n\x07_choice\"\xa2\x01\n\x0b\x46lowsUpdate\x12;\n\x0eproperty_names\x18\x01 \x03(\x0e\x32#.otg.FlowsUpdate.PropertyNames.Enum\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a<\n\rPropertyNames\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04rate\x10\x01\x12\x08\n\x04size\x10\x02\"\xfd\x01\n\x0c\x43ontrolState\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ControlState.Choice.EnumH\x00\x88\x01\x01\x12\x1c\n\x04port\x18\x02 \x01(\x0b\x32\x0e.otg.StatePort\x12$\n\x08protocol\x18\x03 \x01(\x0b\x32\x12.otg.StateProtocol\x12\"\n\x07traffic\x18\x04 \x01(\x0b\x32\x11.otg.StateTraffic\x1a\x46\n\x06\x43hoice\"<\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x0c\n\x08protocol\x10\x02\x12\x0b\n\x07traffic\x10\x03\x42\t\n\x07_choice\"\xcb\x01\n\tStatePort\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.StatePort.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04link\x18\x02 \x01(\x0b\x32\x12.otg.StatePortLink\x12&\n\x07\x63\x61pture\x18\x03 \x01(\x0b\x32\x15.otg.StatePortCapture\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04link\x10\x01\x12\x0b\n\x07\x63\x61pture\x10\x02\x42\t\n\x07_choice\"\xb9\x01\n\x0cStateTraffic\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.StateTraffic.Choice.EnumH\x00\x88\x01\x01\x12\x34\n\rflow_transmit\x18\x02 \x01(\x0b\x32\x1d.otg.StateTrafficFlowTransmit\x1a\x34\n\x06\x43hoice\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rflow_transmit\x10\x01\x42\t\n\x07_choice\"\x95\x03\n\rStateProtocol\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StateProtocol.Choice.EnumH\x00\x88\x01\x01\x12\"\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.otg.StateProtocolAll\x12&\n\x05route\x18\x03 \x01(\x0b\x32\x17.otg.StateProtocolRoute\x12$\n\x04lacp\x18\x04 \x01(\x0b\x32\x16.otg.StateProtocolLacp\x12\"\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x15.otg.StateProtocolBgp\x12$\n\x04isis\x18\x06 \x01(\x0b\x32\x16.otg.StateProtocolIsis\x12(\n\x06ospfv2\x18\x07 \x01(\x0b\x32\x18.otg.StateProtocolOspfv2\x1a^\n\x06\x43hoice\"T\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\t\n\x05route\x10\x02\x12\x08\n\x04lacp\x10\x03\x12\x07\n\x03\x62gp\x10\x04\x12\x08\n\x04isis\x10\x05\x12\n\n\x06ospfv2\x10\x06\x42\t\n\x07_choice\"\x94\x01\n\rStatePortLink\x12\x12\n\nport_names\x18\x01 \x03(\t\x12\x31\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.StatePortLink.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\x9d\x01\n\x10StatePortCapture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12\x34\n\x05state\x18\x02 \x01(\x0e\x32 .otg.StatePortCapture.State.EnumH\x00\x88\x01\x01\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x42\x08\n\x06_state\"\xc4\x01\n\x18StateTrafficFlowTransmit\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateTrafficFlowTransmit.State.EnumH\x00\x88\x01\x01\x1aL\n\x05State\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\x12\n\n\x06resume\x10\x04\x42\x08\n\x06_state\"\x89\x01\n\x10StateProtocolAll\x12\x34\n\x05state\x18\x01 \x01(\x0e\x32 .otg.StateProtocolAll.State.EnumH\x00\x88\x01\x01\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x42\x08\n\x06_state\"\xa4\x01\n\x12StateProtocolRoute\x12\r\n\x05names\x18\x01 \x03(\t\x12\x36\n\x05state\x18\x02 \x01(\x0e\x32\".otg.StateProtocolRoute.State.EnumH\x00\x88\x01\x01\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\x42\x08\n\x06_state\"\xfc\x01\n\x11StateProtocolLacp\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.StateProtocolLacp.Choice.EnumH\x00\x88\x01\x01\x12*\n\x05\x61\x64min\x18\x02 \x01(\x0b\x32\x1b.otg.StateProtocolLacpAdmin\x12\x37\n\x0cmember_ports\x18\x03 \x01(\x0b\x32!.otg.StateProtocolLacpMemberPorts\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x61\x64min\x10\x01\x12\x10\n\x0cmember_ports\x10\x02\x42\t\n\x07_choice\"\xac\x01\n\x16StateProtocolLacpAdmin\x12\x18\n\x10lag_member_names\x18\x01 \x03(\t\x12:\n\x05state\x18\x02 \x01(\x0e\x32&.otg.StateProtocolLacpAdmin.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xb8\x01\n\x1cStateProtocolLacpMemberPorts\x12\x18\n\x10lag_member_names\x18\x01 \x03(\t\x12@\n\x05state\x18\x02 \x01(\x0e\x32,.otg.StateProtocolLacpMemberPorts.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xae\x01\n\x10StateProtocolBgp\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.StateProtocolBgp.Choice.EnumH\x00\x88\x01\x01\x12)\n\x05peers\x18\x02 \x01(\x0b\x32\x1a.otg.StateProtocolBgpPeers\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05peers\x10\x01\x42\t\n\x07_choice\"\xa4\x01\n\x15StateProtocolBgpPeers\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x39\n\x05state\x18\x02 \x01(\x0e\x32%.otg.StateProtocolBgpPeers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xb7\x01\n\x11StateProtocolIsis\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.StateProtocolIsis.Choice.EnumH\x00\x88\x01\x01\x12.\n\x07routers\x18\x02 \x01(\x0b\x32\x1d.otg.StateProtocolIsisRouters\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07routers\x10\x01\x42\t\n\x07_choice\"\xac\x01\n\x18StateProtocolIsisRouters\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateProtocolIsisRouters.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xbd\x01\n\x13StateProtocolOspfv2\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.StateProtocolOspfv2.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x07routers\x18\x02 \x01(\x0b\x32\x1f.otg.StateProtocolOspfv2Routers\x1a.\n\x06\x43hoice\"$\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07routers\x10\x01\x42\t\n\x07_choice\"\xb0\x01\n\x1aStateProtocolOspfv2Routers\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x05state\x18\x02 \x01(\x0e\x32*.otg.StateProtocolOspfv2Routers.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\xa7\x01\n\rControlAction\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.ControlAction.Choice.EnumH\x00\x88\x01\x01\x12%\n\x08protocol\x18\x02 \x01(\x0b\x32\x13.otg.ActionProtocol\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\t\n\x07_choice\"P\n\x15\x43ontrolActionResponse\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12%\n\x08response\x18\x02 \x01(\x0b\x32\x13.otg.ActionResponse\"\xb1\x01\n\x0e\x41\x63tionResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x08protocol\x18\x02 \x01(\x0b\x32\x1b.otg.ActionResponseProtocol\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\t\n\x07_choice\"\x84\x02\n\x0e\x41\x63tionProtocol\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionProtocol.Choice.EnumH\x00\x88\x01\x01\x12%\n\x04ipv4\x18\x02 \x01(\x0b\x32\x17.otg.ActionProtocolIpv4\x12%\n\x04ipv6\x18\x03 \x01(\x0b\x32\x17.otg.ActionProtocolIpv6\x12#\n\x03\x62gp\x18\x04 \x01(\x0b\x32\x16.otg.ActionProtocolBgp\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x62gp\x10\x03\x42\t\n\x07_choice\"\xf6\x01\n\x16\x41\x63tionResponseProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.ActionResponseProtocol.Choice.EnumH\x00\x88\x01\x01\x12-\n\x04ipv4\x18\x02 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv4\x12-\n\x04ipv6\x18\x03 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv6\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\t\n\x07_choice\"\xb1\x01\n\x12\x41\x63tionProtocolIpv4\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv4.Choice.EnumH\x00\x88\x01\x01\x12)\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv4Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"\xc9\x01\n\x1a\x41\x63tionResponseProtocolIpv4\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv4.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv4Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"N\n\x16\x41\x63tionProtocolIpv4Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv4PingRequest\"c\n\x1d\x41\x63tionProtocolIpv4PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv4Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv4PingResponse\"\x83\x02\n&ActionResponseProtocolIpv4PingResponse\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12L\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv4PingResponse.Result.EnumH\x02\x88\x01\x01\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb1\x01\n\x12\x41\x63tionProtocolIpv6\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv6.Choice.EnumH\x00\x88\x01\x01\x12)\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv6Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"\xc9\x01\n\x1a\x41\x63tionResponseProtocolIpv6\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv6.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv6Ping\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\t\n\x07_choice\"N\n\x16\x41\x63tionProtocolIpv6Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv6PingRequest\"c\n\x1d\x41\x63tionProtocolIpv6PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv6Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv6PingResponse\"\x83\x02\n&ActionResponseProtocolIpv6PingResponse\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12L\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv6PingResponse.Result.EnumH\x02\x88\x01\x01\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb7\x02\n\x11\x41\x63tionProtocolBgp\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.ActionProtocolBgp.Choice.EnumH\x00\x88\x01\x01\x12\x38\n\x0cnotification\x18\x02 \x01(\x0b\x32\".otg.ActionProtocolBgpNotification\x12P\n\x19initiate_graceful_restart\x18\x03 \x01(\x0b\x32-.otg.ActionProtocolBgpInitiateGracefulRestart\x1aR\n\x06\x43hoice\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cnotification\x10\x01\x12\x1d\n\x19initiate_graceful_restart\x10\x02\x42\t\n\x07_choice\"\xd5\x05\n\x1d\x41\x63tionProtocolBgpNotification\x12\r\n\x05names\x18\x01 \x03(\t\x12\x43\n\x06\x63hoice\x18\x02 \x01(\x0e\x32..otg.ActionProtocolBgpNotification.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x05\x63\x65\x61se\x18\x03 \x01(\x0b\x32\x18.otg.DeviceBgpCeaseError\x12>\n\x14message_header_error\x18\x04 \x01(\x0b\x32 .otg.DeviceBgpMessageHeaderError\x12:\n\x12open_message_error\x18\x05 \x01(\x0b\x32\x1e.otg.DeviceBgpOpenMessageError\x12>\n\x14update_message_error\x18\x06 \x01(\x0b\x32 .otg.DeviceBgpUpdateMessageError\x12:\n\x12hold_timer_expired\x18\x07 \x01(\x0b\x32\x1e.otg.DeviceBgpHoldTimerExpired\x12I\n\x1a\x66inite_state_machine_error\x18\x08 \x01(\x0b\x32%.otg.DeviceBgpFiniteStateMachineError\x12)\n\x06\x63ustom\x18\t \x01(\x0b\x32\x19.otg.DeviceBgpCustomError\x1a\xbd\x01\n\x06\x43hoice\"\xb2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x63\x65\x61se\x10\x01\x12\x18\n\x14message_header_error\x10\x02\x12\x16\n\x12open_message_error\x10\x03\x12\x18\n\x14update_message_error\x10\x04\x12\x16\n\x12hold_timer_expired\x10\x05\x12\x1e\n\x1a\x66inite_state_machine_error\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\xb5\x01\n(ActionProtocolBgpInitiateGracefulRestart\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x1a\n\rrestart_delay\x18\x02 \x01(\rH\x00\x88\x01\x01\x12G\n\x0cnotification\x18\x03 \x01(\x0b\x32\x31.otg.ActionProtocolBgpGracefulRestartNotificationB\x10\n\x0e_restart_delay\"\xe4\x05\n,ActionProtocolBgpGracefulRestartNotification\x12R\n\x06\x63hoice\x18\x02 \x01(\x0e\x32=.otg.ActionProtocolBgpGracefulRestartNotification.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x05\x63\x65\x61se\x18\x03 \x01(\x0b\x32\x18.otg.DeviceBgpCeaseError\x12>\n\x14message_header_error\x18\x04 \x01(\x0b\x32 .otg.DeviceBgpMessageHeaderError\x12:\n\x12open_message_error\x18\x05 \x01(\x0b\x32\x1e.otg.DeviceBgpOpenMessageError\x12>\n\x14update_message_error\x18\x06 \x01(\x0b\x32 .otg.DeviceBgpUpdateMessageError\x12:\n\x12hold_timer_expired\x18\x07 \x01(\x0b\x32\x1e.otg.DeviceBgpHoldTimerExpired\x12I\n\x1a\x66inite_state_machine_error\x18\x08 \x01(\x0b\x32%.otg.DeviceBgpFiniteStateMachineError\x12)\n\x06\x63ustom\x18\t \x01(\x0b\x32\x19.otg.DeviceBgpCustomError\x1a\xbd\x01\n\x06\x43hoice\"\xb2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x63\x65\x61se\x10\x01\x12\x18\n\x14message_header_error\x10\x02\x12\x16\n\x12open_message_error\x10\x03\x12\x18\n\x14update_message_error\x10\x04\x12\x16\n\x12hold_timer_expired\x10\x05\x12\x1e\n\x1a\x66inite_state_machine_error\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choice\"\xb9\x08\n\x0eMetricsRequest\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12%\n\x04port\x18\x02 \x01(\x0b\x32\x17.otg.PortMetricsRequest\x12%\n\x04\x66low\x18\x03 \x01(\x0b\x32\x17.otg.FlowMetricsRequest\x12\'\n\x05\x62gpv4\x18\x04 \x01(\x0b\x32\x18.otg.Bgpv4MetricsRequest\x12\'\n\x05\x62gpv6\x18\x05 \x01(\x0b\x32\x18.otg.Bgpv6MetricsRequest\x12%\n\x04isis\x18\x06 \x01(\x0b\x32\x17.otg.IsisMetricsRequest\x12#\n\x03lag\x18\x07 \x01(\x0b\x32\x16.otg.LagMetricsRequest\x12%\n\x04lacp\x18\x08 \x01(\x0b\x32\x17.otg.LacpMetricsRequest\x12%\n\x04lldp\x18\t \x01(\x0b\x32\x17.otg.LldpMetricsRequest\x12%\n\x04rsvp\x18\n \x01(\x0b\x32\x17.otg.RsvpMetricsRequest\x12\x36\n\rdhcpv4_client\x18\x0b \x01(\x0b\x32\x1f.otg.Dhcpv4ClientMetricsRequest\x12\x36\n\rdhcpv4_server\x18\x0c \x01(\x0b\x32\x1f.otg.Dhcpv4ServerMetricsRequest\x12\x36\n\rdhcpv6_client\x18\r \x01(\x0b\x32\x1f.otg.Dhcpv6ClientMetricsRequest\x12\x36\n\rdhcpv6_server\x18\x0e \x01(\x0b\x32\x1f.otg.Dhcpv6ServerMetricsRequest\x12)\n\x06ospfv2\x18\x0f \x01(\x0b\x32\x19.otg.Ospfv2MetricsRequest\x12,\n\x0b\x63onvergence\x18\x10 \x01(\x0b\x32\x17.otg.ConvergenceRequest\x12)\n\x06macsec\x18\x11 \x01(\x0b\x32\x19.otg.MacsecMetricsRequest\x12#\n\x03mka\x18\x12 \x01(\x0b\x32\x16.otg.MkaMetricsRequest\x1a\xfb\x01\n\x06\x43hoice\"\xf0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x08\n\x04\x66low\x10\x02\x12\t\n\x05\x62gpv4\x10\x03\x12\t\n\x05\x62gpv6\x10\x04\x12\x08\n\x04isis\x10\x05\x12\x07\n\x03lag\x10\x06\x12\x08\n\x04lacp\x10\x07\x12\x08\n\x04lldp\x10\x08\x12\x08\n\x04rsvp\x10\t\x12\x11\n\rdhcpv4_client\x10\n\x12\x11\n\rdhcpv4_server\x10\x0b\x12\x11\n\rdhcpv6_client\x10\x0c\x12\x11\n\rdhcpv6_server\x10\r\x12\n\n\x06ospfv2\x10\x0e\x12\x0f\n\x0b\x63onvergence\x10\x0f\x12\n\n\x06macsec\x10\x10\x12\x07\n\x03mka\x10\x11\x42\t\n\x07_choice\"\xa6\t\n\x0fMetricsResponse\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.MetricsResponse.Choice.EnumH\x00\x88\x01\x01\x12%\n\x0cport_metrics\x18\x02 \x03(\x0b\x32\x0f.otg.PortMetric\x12%\n\x0c\x66low_metrics\x18\x03 \x03(\x0b\x32\x0f.otg.FlowMetric\x12\'\n\rbgpv4_metrics\x18\x04 \x03(\x0b\x32\x10.otg.Bgpv4Metric\x12\'\n\rbgpv6_metrics\x18\x05 \x03(\x0b\x32\x10.otg.Bgpv6Metric\x12%\n\x0cisis_metrics\x18\x06 \x03(\x0b\x32\x0f.otg.IsisMetric\x12#\n\x0blag_metrics\x18\x07 \x03(\x0b\x32\x0e.otg.LagMetric\x12%\n\x0clacp_metrics\x18\x08 \x03(\x0b\x32\x0f.otg.LacpMetric\x12%\n\x0clldp_metrics\x18\t \x03(\x0b\x32\x0f.otg.LldpMetric\x12%\n\x0crsvp_metrics\x18\n \x03(\x0b\x32\x0f.otg.RsvpMetric\x12\x35\n\x14\x64hcpv4client_metrics\x18\x0b \x03(\x0b\x32\x17.otg.Dhcpv4ClientMetric\x12\x35\n\x14\x64hcpv4server_metrics\x18\x0c \x03(\x0b\x32\x17.otg.Dhcpv4ServerMetric\x12\x35\n\x14\x64hcpv6client_metrics\x18\r \x03(\x0b\x32\x17.otg.Dhcpv6ClientMetric\x12\x35\n\x14\x64hcpv6server_metrics\x18\x0e \x03(\x0b\x32\x17.otg.Dhcpv6ServerMetric\x12)\n\x0eospfv2_metrics\x18\x0f \x03(\x0b\x32\x11.otg.Ospfv2Metric\x12\x33\n\x13\x63onvergence_metrics\x18\x10 \x03(\x0b\x32\x16.otg.ConvergenceMetric\x12)\n\x0emacsec_metrics\x18\x11 \x03(\x0b\x32\x11.otg.MacsecMetric\x12#\n\x0bmka_metrics\x18\x12 \x03(\x0b\x32\x0e.otg.MkaMetric\x1a\xe3\x02\n\x06\x43hoice\"\xd8\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66low_metrics\x10\x01\x12\x10\n\x0cport_metrics\x10\x02\x12\x11\n\rbgpv4_metrics\x10\x03\x12\x11\n\rbgpv6_metrics\x10\x04\x12\x10\n\x0cisis_metrics\x10\x05\x12\x0f\n\x0blag_metrics\x10\x06\x12\x10\n\x0clacp_metrics\x10\x07\x12\x10\n\x0clldp_metrics\x10\x08\x12\x10\n\x0crsvp_metrics\x10\t\x12\x11\n\rdhcpv4_client\x10\n\x12\x11\n\rdhcpv4_server\x10\x0b\x12\x11\n\rdhcpv6_client\x10\x0c\x12\x11\n\rdhcpv6_server\x10\r\x12\x12\n\x0eospfv2_metrics\x10\x0e\x12\x17\n\x13\x63onvergence_metrics\x10\x0f\x12\x12\n\x0emacsec_metrics\x10\x10\x12\x0f\n\x0bmka_metrics\x10\x11\x42\t\n\x07_choice\"\xde\x02\n\x12PortMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.PortMetricsRequest.ColumnNames.Enum\x1a\xf3\x01\n\x0b\x43olumnNames\"\xe3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\x0c\n\x08location\x10\x02\x12\x08\n\x04link\x10\x03\x12\x0b\n\x07\x63\x61pture\x10\x04\x12\r\n\tframes_tx\x10\x05\x12\r\n\tframes_rx\x10\x06\x12\x0c\n\x08\x62ytes_tx\x10\x07\x12\x0c\n\x08\x62ytes_rx\x10\x08\x12\x12\n\x0e\x66rames_tx_rate\x10\t\x12\x12\n\x0e\x66rames_rx_rate\x10\n\x12\x11\n\rbytes_tx_rate\x10\x0b\x12\x11\n\rbytes_rx_rate\x10\x0c\x12\x0f\n\x0blast_change\x10\r\"\xb0\x06\n\nPortMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08location\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\x04link\x18\x03 \x01(\x0e\x32\x19.otg.PortMetric.Link.EnumH\x02\x88\x01\x01\x12\x32\n\x07\x63\x61pture\x18\x04 \x01(\x0e\x32\x1c.otg.PortMetric.Capture.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x12\x34\n\x08transmit\x18\r \x01(\x0e\x32\x1d.otg.PortMetric.Transmit.EnumH\x0c\x88\x01\x01\x12\x18\n\x0blast_change\x18\x0e \x01(\x04H\r\x88\x01\x01\x1a\x31\n\x04Link\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a<\n\x07\x43\x61pture\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x1a=\n\x08Transmit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_locationB\x07\n\x05_linkB\n\n\x08_captureB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rateB\x0b\n\t_transmitB\x0e\n\x0c_last_change\"\xf0\x03\n\x12\x46lowMetricsRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12>\n\x0cmetric_names\x18\x03 \x03(\x0e\x32(.otg.FlowMetricsRequest.MetricNames.Enum\x12\x34\n\x0etagged_metrics\x18\x04 \x01(\x0b\x32\x1c.otg.FlowTaggedMetricsFilter\x1a\xcf\x02\n\x0bMetricNames\"\xbf\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\r\n\tframes_rx\x10\x03\x12\x0c\n\x08\x62ytes_tx\x10\x04\x12\x0c\n\x08\x62ytes_rx\x10\x05\x12\x12\n\x0e\x66rames_tx_rate\x10\x06\x12\x12\n\x0e\x66rames_rx_rate\x10\x07\x12\x12\n\x0etx_l1_rate_bps\x10\x08\x12\x12\n\x0erx_l1_rate_bps\x10\t\x12\x11\n\rtx_rate_bytes\x10\n\x12\x11\n\rrx_rate_bytes\x10\x0b\x12\x0f\n\x0btx_rate_bps\x10\x0c\x12\x0f\n\x0brx_rate_bps\x10\r\x12\x10\n\x0ctx_rate_kbps\x10\x0e\x12\x10\n\x0crx_rate_kbps\x10\x0f\x12\x10\n\x0ctx_rate_mbps\x10\x10\x12\x10\n\x0crx_rate_mbps\x10\x11\"\xad\x04\n\x17\x46lowTaggedMetricsFilter\x12\x14\n\x07include\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15include_empty_metrics\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x43\n\x0cmetric_names\x18\x03 \x03(\x0e\x32-.otg.FlowTaggedMetricsFilter.MetricNames.Enum\x12)\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x18.otg.FlowMetricTagFilter\x1a\xc1\x02\n\x0bMetricNames\"\xb1\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_tx\x10\x01\x12\r\n\tframes_rx\x10\x02\x12\x0c\n\x08\x62ytes_tx\x10\x03\x12\x0c\n\x08\x62ytes_rx\x10\x04\x12\x12\n\x0e\x66rames_tx_rate\x10\x05\x12\x12\n\x0e\x66rames_rx_rate\x10\x06\x12\x12\n\x0etx_l1_rate_bps\x10\x07\x12\x12\n\x0erx_l1_rate_bps\x10\x08\x12\x11\n\rtx_rate_bytes\x10\t\x12\x11\n\rrx_rate_bytes\x10\n\x12\x0f\n\x0btx_rate_bps\x10\x0b\x12\x0f\n\x0brx_rate_bps\x10\x0c\x12\x10\n\x0ctx_rate_kbps\x10\r\x12\x10\n\x0crx_rate_kbps\x10\x0e\x12\x10\n\x0ctx_rate_mbps\x10\x0f\x12\x10\n\x0crx_rate_mbps\x10\x10\x42\n\n\x08_includeB\x18\n\x16_include_empty_metrics\"A\n\x13\x46lowMetricTagFilter\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06values\x18\x02 \x03(\tB\x07\n\x05_name\"\xc8\x08\n\nFlowMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x34\n\x08transmit\x18\x05 \x01(\x0e\x32\x1d.otg.FlowMetric.Transmit.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x08 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\t \x01(\x04H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\n \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x0b \x01(\x02H\t\x88\x01\x01\x12\x11\n\x04loss\x18\x0c \x01(\x02H\n\x88\x01\x01\x12(\n\ntimestamps\x18\r \x01(\x0b\x32\x14.otg.MetricTimestamp\x12#\n\x07latency\x18\x0e \x01(\x0b\x32\x12.otg.MetricLatency\x12-\n\x0etagged_metrics\x18\x0f \x03(\x0b\x32\x15.otg.FlowTaggedMetric\x12\x1b\n\x0etx_l1_rate_bps\x18\x10 \x01(\x02H\x0b\x88\x01\x01\x12\x1b\n\x0erx_l1_rate_bps\x18\x11 \x01(\x02H\x0c\x88\x01\x01\x12\x1a\n\rtx_rate_bytes\x18\x12 \x01(\x02H\r\x88\x01\x01\x12\x1a\n\rrx_rate_bytes\x18\x13 \x01(\x02H\x0e\x88\x01\x01\x12\x18\n\x0btx_rate_bps\x18\x14 \x01(\x02H\x0f\x88\x01\x01\x12\x18\n\x0brx_rate_bps\x18\x15 \x01(\x02H\x10\x88\x01\x01\x12\x19\n\x0ctx_rate_kbps\x18\x16 \x01(\x02H\x11\x88\x01\x01\x12\x19\n\x0crx_rate_kbps\x18\x17 \x01(\x02H\x12\x88\x01\x01\x12\x19\n\x0ctx_rate_mbps\x18\x18 \x01(\x02H\x13\x88\x01\x01\x12\x19\n\x0crx_rate_mbps\x18\x19 \x01(\x02H\x14\x88\x01\x01\x1aI\n\x08Transmit\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x12\n\n\x06paused\x10\x03\x42\x07\n\x05_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\x0b\n\t_transmitB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\x11\n\x0f_tx_l1_rate_bpsB\x11\n\x0f_rx_l1_rate_bpsB\x10\n\x0e_tx_rate_bytesB\x10\n\x0e_rx_rate_bytesB\x0e\n\x0c_tx_rate_bpsB\x0e\n\x0c_rx_rate_bpsB\x0f\n\r_tx_rate_kbpsB\x0f\n\r_rx_rate_kbpsB\x0f\n\r_tx_rate_mbpsB\x0f\n\r_rx_rate_mbps\"\xd3\x06\n\x10\x46lowTaggedMetric\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.otg.FlowMetricTag\x12\x16\n\tframes_tx\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x06 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x11\n\x04loss\x18\x08 \x01(\x02H\x06\x88\x01\x01\x12(\n\ntimestamps\x18\t \x01(\x0b\x32\x14.otg.MetricTimestamp\x12#\n\x07latency\x18\n \x01(\x0b\x32\x12.otg.MetricLatency\x12\x1b\n\x0etx_l1_rate_bps\x18\x0b \x01(\x02H\x07\x88\x01\x01\x12\x1b\n\x0erx_l1_rate_bps\x18\x0c \x01(\x02H\x08\x88\x01\x01\x12\x1a\n\rtx_rate_bytes\x18\r \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rrx_rate_bytes\x18\x0e \x01(\x02H\n\x88\x01\x01\x12\x18\n\x0btx_rate_bps\x18\x0f \x01(\x02H\x0b\x88\x01\x01\x12\x18\n\x0brx_rate_bps\x18\x10 \x01(\x02H\x0c\x88\x01\x01\x12\x19\n\x0ctx_rate_kbps\x18\x11 \x01(\x02H\r\x88\x01\x01\x12\x19\n\x0crx_rate_kbps\x18\x12 \x01(\x02H\x0e\x88\x01\x01\x12\x19\n\x0ctx_rate_mbps\x18\x13 \x01(\x02H\x0f\x88\x01\x01\x12\x19\n\x0crx_rate_mbps\x18\x14 \x01(\x02H\x10\x88\x01\x01\x42\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\x11\n\x0f_tx_l1_rate_bpsB\x11\n\x0f_rx_l1_rate_bpsB\x10\n\x0e_tx_rate_bytesB\x10\n\x0e_rx_rate_bytesB\x0e\n\x0c_tx_rate_bpsB\x0e\n\x0c_rx_rate_bpsB\x0f\n\r_tx_rate_kbpsB\x0f\n\r_rx_rate_kbpsB\x0f\n\r_tx_rate_mbpsB\x0f\n\r_rx_rate_mbps\"S\n\rFlowMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.otg.FlowMetricTagValueB\x07\n\x05_name\"\xc2\x01\n\x12\x46lowMetricTagValue\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.FlowMetricTagValue.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03hex\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03str\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03hex\x10\x01\x12\x07\n\x03str\x10\x02\x42\t\n\x07_choiceB\x06\n\x04_hexB\x06\n\x04_str\"\x7f\n\x0fMetricTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\x87\x01\n\rMetricLatency\x12\x17\n\nminimum_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x17\n\nmaximum_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naverage_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\r\n\x0b_minimum_nsB\r\n\x0b_maximum_nsB\r\n\x0b_average_ns\"\xf9\x03\n\x13\x42gpv4MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv4MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv4Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv4Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x04H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv4Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\xf9\x03\n\x13\x42gpv6MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv6MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv6Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv6Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x04H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv6Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\x92\x06\n\x12IsisMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.IsisMetricsRequest.ColumnNames.Enum\x1a\xa5\x05\n\x0b\x43olumnNames\"\x95\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0el1_sessions_up\x10\x01\x12\x13\n\x0fl1_session_flap\x10\x02\x12\x14\n\x10l1_database_size\x10\x03\x12\x1c\n\x18l1_broadcast_hellos_sent\x10\x04\x12 \n\x1cl1_broadcast_hellos_received\x10\x05\x12!\n\x1dl1_point_to_point_hellos_sent\x10\x06\x12%\n!l1_point_to_point_hellos_received\x10\x07\x12\x10\n\x0cl1_psnp_sent\x10\x08\x12\x14\n\x10l1_psnp_received\x10\t\x12\x10\n\x0cl1_csnp_sent\x10\n\x12\x14\n\x10l1_csnp_received\x10\x0b\x12\x0f\n\x0bl1_lsp_sent\x10\x0c\x12\x13\n\x0fl1_lsp_received\x10\r\x12\x12\n\x0el2_sessions_up\x10\x0e\x12\x13\n\x0fl2_session_flap\x10\x0f\x12\x14\n\x10l2_database_size\x10\x10\x12\x1c\n\x18l2_broadcast_hellos_sent\x10\x11\x12 \n\x1cl2_broadcast_hellos_received\x10\x12\x12!\n\x1dl2_point_to_point_hellos_sent\x10\x13\x12%\n!l2_point_to_point_hellos_received\x10\x14\x12\x10\n\x0cl2_psnp_sent\x10\x15\x12\x14\n\x10l2_psnp_received\x10\x16\x12\x10\n\x0cl2_csnp_sent\x10\x17\x12\x14\n\x10l2_csnp_received\x10\x18\x12\x0f\n\x0bl2_lsp_sent\x10\x19\x12\x13\n\x0fl2_lsp_received\x10\x1a\"\xf4\x0b\n\nIsisMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0el1_sessions_up\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1c\n\x0fl1_session_flap\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12%\n\x18l1_broadcast_hellos_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12)\n\x1cl1_broadcast_hellos_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12*\n\x1dl1_point_to_point_hellos_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12.\n!l1_point_to_point_hellos_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1d\n\x10l1_database_size\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x19\n\x0cl1_psnp_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1d\n\x10l1_psnp_received\x18\n \x01(\x04H\t\x88\x01\x01\x12\x19\n\x0cl1_csnp_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1d\n\x10l1_csnp_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x18\n\x0bl1_lsp_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1c\n\x0fl1_lsp_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1b\n\x0el2_sessions_up\x18\x0f \x01(\rH\x0e\x88\x01\x01\x12\x1c\n\x0fl2_session_flap\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12%\n\x18l2_broadcast_hellos_sent\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12)\n\x1cl2_broadcast_hellos_received\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12*\n\x1dl2_point_to_point_hellos_sent\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12.\n!l2_point_to_point_hellos_received\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x1d\n\x10l2_database_size\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12\x19\n\x0cl2_psnp_sent\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x1d\n\x10l2_psnp_received\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12\x19\n\x0cl2_csnp_sent\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x1d\n\x10l2_csnp_received\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\x18\n\x0bl2_lsp_sent\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x1c\n\x0fl2_lsp_received\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_l1_sessions_upB\x12\n\x10_l1_session_flapB\x1b\n\x19_l1_broadcast_hellos_sentB\x1f\n\x1d_l1_broadcast_hellos_receivedB \n\x1e_l1_point_to_point_hellos_sentB$\n\"_l1_point_to_point_hellos_receivedB\x13\n\x11_l1_database_sizeB\x0f\n\r_l1_psnp_sentB\x13\n\x11_l1_psnp_receivedB\x0f\n\r_l1_csnp_sentB\x13\n\x11_l1_csnp_receivedB\x0e\n\x0c_l1_lsp_sentB\x12\n\x10_l1_lsp_receivedB\x11\n\x0f_l2_sessions_upB\x12\n\x10_l2_session_flapB\x1b\n\x19_l2_broadcast_hellos_sentB\x1f\n\x1d_l2_broadcast_hellos_receivedB \n\x1e_l2_point_to_point_hellos_sentB$\n\"_l2_point_to_point_hellos_receivedB\x13\n\x11_l2_database_sizeB\x0f\n\r_l2_psnp_sentB\x13\n\x11_l2_psnp_receivedB\x0f\n\r_l2_csnp_sentB\x13\n\x11_l2_csnp_receivedB\x0e\n\x0c_l2_lsp_sentB\x12\n\x10_l2_lsp_received\"\xbd\x02\n\x11LagMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12=\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\'.otg.LagMetricsRequest.ColumnNames.Enum\x1a\xd5\x01\n\x0b\x43olumnNames\"\xc5\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0boper_status\x10\x01\x12\x13\n\x0fmember_ports_up\x10\x02\x12\r\n\tframes_tx\x10\x03\x12\r\n\tframes_rx\x10\x04\x12\x0c\n\x08\x62ytes_tx\x10\x05\x12\x0c\n\x08\x62ytes_rx\x10\x06\x12\x12\n\x0e\x66rames_tx_rate\x10\x07\x12\x12\n\x0e\x66rames_rx_rate\x10\x08\x12\x11\n\rbytes_tx_rate\x10\t\x12\x11\n\rbytes_rx_rate\x10\n\"\xac\x04\n\tLagMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x0boper_status\x18\x02 \x01(\x0e\x32\x1e.otg.LagMetric.OperStatus.EnumH\x01\x88\x01\x01\x12\x1c\n\x0fmember_ports_up\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x16\n\tframes_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x16\n\tframes_rx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x1a\x37\n\nOperStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x0e\n\x0c_oper_statusB\x12\n\x10_member_ports_upB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rate\"\xb4\x03\n\x12LacpMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12\x1d\n\x15lag_member_port_names\x18\x02 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x03 \x03(\x0e\x32(.otg.LacpMetricsRequest.ColumnNames.Enum\x1a\xab\x02\n\x0b\x43olumnNames\"\x9b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flacp_packets_rx\x10\x01\x12\x13\n\x0flacp_packets_tx\x10\x02\x12\x12\n\x0elacp_rx_errors\x10\x03\x12\x0c\n\x08\x61\x63tivity\x10\x04\x12\x0b\n\x07timeout\x10\x05\x12\x13\n\x0fsynchronization\x10\x06\x12\x10\n\x0c\x61ggregatable\x10\x07\x12\x0e\n\ncollecting\x10\x08\x12\x10\n\x0c\x64istributing\x10\t\x12\r\n\tsystem_id\x10\n\x12\x0c\n\x08oper_key\x10\x0b\x12\x0e\n\npartner_id\x10\x0c\x12\x0f\n\x0bpartner_key\x10\r\x12\x0c\n\x08port_num\x10\x0e\x12\x14\n\x10partner_port_num\x10\x0f\"\x8d\x08\n\nLacpMetric\x12\x15\n\x08lag_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14lag_member_port_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0flacp_packets_rx\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0flacp_packets_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0elacp_rx_errors\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x34\n\x08\x61\x63tivity\x18\x06 \x01(\x0e\x32\x1d.otg.LacpMetric.Activity.EnumH\x05\x88\x01\x01\x12\x32\n\x07timeout\x18\x07 \x01(\x0e\x32\x1c.otg.LacpMetric.Timeout.EnumH\x06\x88\x01\x01\x12\x42\n\x0fsynchronization\x18\x08 \x01(\x0e\x32$.otg.LacpMetric.Synchronization.EnumH\x07\x88\x01\x01\x12\x19\n\x0c\x61ggregatable\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x17\n\ncollecting\x18\n \x01(\x08H\t\x88\x01\x01\x12\x19\n\x0c\x64istributing\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x16\n\tsystem_id\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x15\n\x08oper_key\x18\r \x01(\rH\x0c\x88\x01\x01\x12\x17\n\npartner_id\x18\x0e \x01(\tH\r\x88\x01\x01\x12\x18\n\x0bpartner_key\x18\x0f \x01(\rH\x0e\x88\x01\x01\x12\x15\n\x08port_num\x18\x10 \x01(\rH\x0f\x88\x01\x01\x12\x1d\n\x10partner_port_num\x18\x11 \x01(\rH\x10\x88\x01\x01\x1a<\n\x08\x41\x63tivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61\x63tive\x10\x01\x12\x0b\n\x07passive\x10\x02\x1a\x37\n\x07Timeout\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05short\x10\x01\x12\x08\n\x04long\x10\x02\x1a\x45\n\x0fSynchronization\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07in_sync\x10\x01\x12\x0c\n\x08out_sync\x10\x02\x42\x0b\n\t_lag_nameB\x17\n\x15_lag_member_port_nameB\x12\n\x10_lacp_packets_rxB\x12\n\x10_lacp_packets_txB\x11\n\x0f_lacp_rx_errorsB\x0b\n\t_activityB\n\n\x08_timeoutB\x12\n\x10_synchronizationB\x0f\n\r_aggregatableB\r\n\x0b_collectingB\x0f\n\r_distributingB\x0c\n\n_system_idB\x0b\n\t_oper_keyB\r\n\x0b_partner_idB\x0e\n\x0c_partner_keyB\x0b\n\t_port_numB\x13\n\x11_partner_port_num\"\xfd\x01\n\x12LldpMetricsRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.LldpMetricsRequest.ColumnNames.Enum\x1a\x92\x01\n\x0b\x43olumnNames\"\x82\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_rx\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\x13\n\x0f\x66rames_error_rx\x10\x03\x12\x12\n\x0e\x66rames_discard\x10\x04\x12\x10\n\x0ctlvs_discard\x10\x05\x12\x10\n\x0ctlvs_unknown\x10\x06\"\xae\x02\n\nLldpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x16\n\tframes_tx\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0f\x66rames_error_rx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_discard\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x19\n\x0ctlvs_discard\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x19\n\x0ctlvs_unknown\x18\x07 \x01(\x04H\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_frames_rxB\x0c\n\n_frames_txB\x12\n\x10_frames_error_rxB\x11\n\x0f_frames_discardB\x0f\n\r_tlvs_discardB\x0f\n\r_tlvs_unknown\"\xc2\x05\n\x12RsvpMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.RsvpMetricsRequest.ColumnNames.Enum\x1a\xd5\x04\n\x0b\x43olumnNames\"\xc5\x04\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1f\n\x1bingress_p2p_lsps_configured\x10\x01\x12\x17\n\x13ingress_p2p_lsps_up\x10\x02\x12\x16\n\x12\x65gress_p2p_lsps_up\x10\x03\x12\x12\n\x0elsp_flap_count\x10\x04\x12\x0c\n\x08paths_tx\x10\x05\x12\x0c\n\x08paths_rx\x10\x06\x12\x0c\n\x08resvs_tx\x10\x07\x12\x0c\n\x08resvs_rx\x10\x08\x12\x11\n\rpath_tears_tx\x10\t\x12\x11\n\rpath_tears_rx\x10\n\x12\x11\n\rresv_tears_tx\x10\x0b\x12\x11\n\rresv_tears_rx\x10\x0c\x12\x12\n\x0epath_errors_tx\x10\r\x12\x12\n\x0epath_errors_rx\x10\x0e\x12\x12\n\x0eresv_errors_tx\x10\x0f\x12\x12\n\x0eresv_errors_rx\x10\x10\x12\x10\n\x0cresv_conf_tx\x10\x11\x12\x10\n\x0cresv_conf_rx\x10\x12\x12\r\n\thellos_tx\x10\x13\x12\r\n\thellos_rx\x10\x14\x12\x0b\n\x07\x61\x63ks_tx\x10\x15\x12\x0b\n\x07\x61\x63ks_rx\x10\x16\x12\x0c\n\x08nacks_tx\x10\x17\x12\x0c\n\x08nacks_rx\x10\x18\x12\x0f\n\x0bsrefresh_tx\x10\x19\x12\x0f\n\x0bsrefresh_rx\x10\x1a\x12\r\n\tbundle_tx\x10\x1b\x12\r\n\tbundle_rx\x10\x1c\x12 \n\x1cpath_reevaluation_request_tx\x10\x1d\x12\x18\n\x14path_reoptimizations\x10\x1e\"\xf4\n\n\nRsvpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\x1bingress_p2p_lsps_configured\x18\x02 \x01(\rH\x01\x88\x01\x01\x12 \n\x13ingress_p2p_lsps_up\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12\x65gress_p2p_lsps_up\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1b\n\x0elsp_flap_count\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x15\n\x08paths_tx\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08paths_rx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x15\n\x08resvs_tx\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x15\n\x08resvs_rx\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1a\n\rpath_tears_tx\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1a\n\rpath_tears_rx\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1a\n\rresv_tears_tx\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x1a\n\rresv_tears_rx\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1b\n\x0epath_errors_tx\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1b\n\x0epath_errors_rx\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1b\n\x0eresv_errors_tx\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x1b\n\x0eresv_errors_rx\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12\x19\n\x0cresv_conf_tx\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x19\n\x0cresv_conf_rx\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12\x16\n\thellos_tx\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x16\n\thellos_rx\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12\x14\n\x07\x61\x63ks_tx\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x14\n\x07\x61\x63ks_rx\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12\x15\n\x08nacks_tx\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x15\n\x08nacks_rx\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\x18\n\x0bsrefresh_tx\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x18\n\x0bsrefresh_rx\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x16\n\tbundle_tx\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x16\n\tbundle_rx\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12)\n\x1cpath_reevaluation_request_tx\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12!\n\x14path_reoptimizations\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x42\x07\n\x05_nameB\x1e\n\x1c_ingress_p2p_lsps_configuredB\x16\n\x14_ingress_p2p_lsps_upB\x15\n\x13_egress_p2p_lsps_upB\x11\n\x0f_lsp_flap_countB\x0b\n\t_paths_txB\x0b\n\t_paths_rxB\x0b\n\t_resvs_txB\x0b\n\t_resvs_rxB\x10\n\x0e_path_tears_txB\x10\n\x0e_path_tears_rxB\x10\n\x0e_resv_tears_txB\x10\n\x0e_resv_tears_rxB\x11\n\x0f_path_errors_txB\x11\n\x0f_path_errors_rxB\x11\n\x0f_resv_errors_txB\x11\n\x0f_resv_errors_rxB\x0f\n\r_resv_conf_txB\x0f\n\r_resv_conf_rxB\x0c\n\n_hellos_txB\x0c\n\n_hellos_rxB\n\n\x08_acks_txB\n\n\x08_acks_rxB\x0b\n\t_nacks_txB\x0b\n\t_nacks_rxB\x0e\n\x0c_srefresh_txB\x0e\n\x0c_srefresh_rxB\x0c\n\n_bundle_txB\x0c\n\n_bundle_rxB\x1f\n\x1d_path_reevaluation_request_txB\x17\n\x15_path_reoptimizations\"\xad\x02\n\x1a\x44hcpv4ClientMetricsRequest\x12\x14\n\x0c\x63lient_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv4ClientMetricsRequest.ColumnNames.Enum\x1a\xb0\x01\n\x0b\x43olumnNames\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0e\x64iscovers_sent\x10\x01\x12\x13\n\x0foffers_received\x10\x02\x12\x11\n\rrequests_sent\x10\x03\x12\x11\n\racks_received\x10\x04\x12\x12\n\x0enacks_received\x10\x05\x12\x11\n\rreleases_sent\x10\x06\x12\x11\n\rdeclines_sent\x10\x07\"\xfa\x02\n\x12\x44hcpv4ClientMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0e\x64iscovers_sent\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1c\n\x0foffers_received\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1a\n\rrequests_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1a\n\racks_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1b\n\x0enacks_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1a\n\rreleases_sent\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1a\n\rdeclines_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_discovers_sentB\x12\n\x10_offers_receivedB\x10\n\x0e_requests_sentB\x10\n\x0e_acks_receivedB\x11\n\x0f_nacks_receivedB\x10\n\x0e_releases_sentB\x10\n\x0e_declines_sent\"\xb1\x02\n\x1a\x44hcpv4ServerMetricsRequest\x12\x14\n\x0cserver_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv4ServerMetricsRequest.ColumnNames.Enum\x1a\xb4\x01\n\x0b\x43olumnNames\"\xa4\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x16\n\x12\x64iscovers_received\x10\x01\x12\x0f\n\x0boffers_sent\x10\x02\x12\x15\n\x11requests_received\x10\x03\x12\r\n\tacks_sent\x10\x04\x12\x0e\n\nnacks_sent\x10\x05\x12\x15\n\x11releases_received\x10\x06\x12\x15\n\x11\x64\x65\x63lines_received\x10\x07\"\x82\x03\n\x12\x44hcpv4ServerMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12\x64iscovers_received\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x18\n\x0boffers_sent\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1e\n\x11requests_received\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x16\n\tacks_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nnacks_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1e\n\x11releases_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1e\n\x11\x64\x65\x63lines_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x42\x07\n\x05_nameB\x15\n\x13_discovers_receivedB\x0e\n\x0c_offers_sentB\x14\n\x12_requests_receivedB\x0c\n\n_acks_sentB\r\n\x0b_nacks_sentB\x14\n\x12_releases_receivedB\x14\n\x12_declines_received\"\xe0\x03\n\x1a\x44hcpv6ClientMetricsRequest\x12\x14\n\x0c\x63lient_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv6ClientMetricsRequest.ColumnNames.Enum\x1a\xe3\x02\n\x0b\x43olumnNames\"\xd3\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsolicits_sent\x10\x01\x12\x1b\n\x17\x61\x64vertisements_received\x10\x02\x12\x1a\n\x16\x61\x64vertisements_ignored\x10\x03\x12\x11\n\rrequests_sent\x10\x04\x12\x12\n\x0enacks_received\x10\x05\x12\x14\n\x10replies_received\x10\x06\x12\x1d\n\x19information_requests_sent\x10\x07\x12\x0f\n\x0brenews_sent\x10\x08\x12\x10\n\x0crebinds_sent\x10\t\x12\x11\n\rreleases_sent\x10\n\x12\x19\n\x15reconfigures_received\x10\x0b\x12\x1e\n\x1arapid_commit_solicits_sent\x10\x0c\x12!\n\x1drapid_commit_replies_received\x10\r\"\x90\x06\n\x12\x44hcpv6ClientMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rsolicits_sent\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12$\n\x17\x61\x64vertisements_received\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12#\n\x16\x61\x64vertisements_ignored\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1a\n\rrequests_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1b\n\x0enacks_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1d\n\x10replies_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12&\n\x19information_requests_sent\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x18\n\x0brenews_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x19\n\x0crebinds_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1a\n\rreleases_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\"\n\x15reconfigures_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\'\n\x1arapid_commit_solicits_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12*\n\x1drapid_commit_replies_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_solicits_sentB\x1a\n\x18_advertisements_receivedB\x19\n\x17_advertisements_ignoredB\x10\n\x0e_requests_sentB\x11\n\x0f_nacks_receivedB\x13\n\x11_replies_receivedB\x1c\n\x1a_information_requests_sentB\x0e\n\x0c_renews_sentB\x0f\n\r_rebinds_sentB\x10\n\x0e_releases_sentB\x18\n\x16_reconfigures_receivedB\x1d\n\x1b_rapid_commit_solicits_sentB \n\x1e_rapid_commit_replies_received\"\x84\x04\n\x1a\x44hcpv6ServerMetricsRequest\x12\x14\n\x0cserver_names\x18\x01 \x03(\t\x12\x46\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\x30.otg.Dhcpv6ServerMetricsRequest.ColumnNames.Enum\x1a\x87\x03\n\x0b\x43olumnNames\"\xf7\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11solicits_received\x10\x01\x12\x14\n\x10solicits_ignored\x10\x02\x12\x17\n\x13\x61\x64vertisements_sent\x10\x03\x12\x15\n\x11requests_received\x10\x04\x12\x0e\n\nnacks_sent\x10\x05\x12\x15\n\x11\x63onfirms_received\x10\x06\x12\x15\n\x11renewals_received\x10\x07\x12\x14\n\x10rebinds_received\x10\x08\x12\x10\n\x0creplies_sent\x10\t\x12\x15\n\x11releases_received\x10\n\x12\x15\n\x11\x64\x65\x63lines_received\x10\x0b\x12!\n\x1dinformation_requests_received\x10\x0c\x12\x1b\n\x17relay_forwards_received\x10\r\x12\x16\n\x12relay_replies_sent\x10\x0e\x12\x15\n\x11reconfigures_sent\x10\x0f\"\xe8\x06\n\x12\x44hcpv6ServerMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11solicits_received\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10solicits_ignored\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12 \n\x13\x61\x64vertisements_sent\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1e\n\x11requests_received\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nnacks_sent\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x1e\n\x11\x63onfirms_received\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1e\n\x11renewals_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1d\n\x10rebinds_received\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x19\n\x0creplies_sent\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1e\n\x11releases_received\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1e\n\x11\x64\x65\x63lines_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12*\n\x1dinformation_requests_received\x18\r \x01(\x04H\x0c\x88\x01\x01\x12$\n\x17relay_forwards_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1f\n\x12relay_replies_sent\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1e\n\x11reconfigures_sent\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x42\x07\n\x05_nameB\x14\n\x12_solicits_receivedB\x13\n\x11_solicits_ignoredB\x16\n\x14_advertisements_sentB\x14\n\x12_requests_receivedB\r\n\x0b_nacks_sentB\x14\n\x12_confirms_receivedB\x14\n\x12_renewals_receivedB\x13\n\x11_rebinds_receivedB\x0f\n\r_replies_sentB\x14\n\x12_releases_receivedB\x14\n\x12_declines_receivedB \n\x1e_information_requests_receivedB\x1a\n\x18_relay_forwards_receivedB\x15\n\x13_relay_replies_sentB\x14\n\x12_reconfigures_sent\"\xe5\x06\n\x14Ospfv2MetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12@\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32*.otg.Ospfv2MetricsRequest.ColumnNames.Enum\x1a\xf4\x05\n\x0b\x43olumnNames\"\xe4\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x66ull_state_count\x10\x01\x12\x14\n\x10\x64own_state_count\x10\x02\x12\x11\n\rsessions_flap\x10\x03\x12\x0f\n\x0bhellos_sent\x10\x04\x12\x13\n\x0fhellos_received\x10\x05\x12\x0c\n\x08\x64\x62\x64_sent\x10\x06\x12\x10\n\x0c\x64\x62\x64_received\x10\x07\x12\x13\n\x0fls_request_sent\x10\x08\x12\x17\n\x13ls_request_received\x10\t\x12\x12\n\x0els_update_sent\x10\n\x12\x16\n\x12ls_update_received\x10\x0b\x12\x0f\n\x0bls_ack_sent\x10\x0c\x12\x13\n\x0fls_ack_received\x10\r\x12\x0c\n\x08lsa_sent\x10\x0e\x12\x10\n\x0clsa_received\x10\x0f\x12\x10\n\x0clsa_ack_sent\x10\x10\x12\x14\n\x10lsa_ack_received\x10\x11\x12\x13\n\x0frouter_lsa_sent\x10\x12\x12\x17\n\x13router_lsa_received\x10\x13\x12\x14\n\x10network_lsa_sent\x10\x14\x12\x18\n\x14network_lsa_received\x10\x15\x12\x14\n\x10summary_lsa_sent\x10\x16\x12\x18\n\x14summary_lsa_received\x10\x17\x12\x15\n\x11\x65xternal_lsa_sent\x10\x18\x12\x19\n\x15\x65xternal_lsa_received\x10\x19\x12\x11\n\rnssa_lsa_sent\x10\x1a\x12\x15\n\x11nssa_lsa_received\x10\x1b\x12\x15\n\x11opaque_local_sent\x10\x1c\x12\x19\n\x15opaque_local_received\x10\x1d\x12\x14\n\x10opaque_area_sent\x10\x1e\x12\x18\n\x14opaque_area_received\x10\x1f\x12\x16\n\x12opaque_domain_sent\x10 \x12\x1a\n\x16opaque_domain_received\x10!\"\xcc\r\n\x0cOspfv2Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x10\x66ull_state_count\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x1d\n\x10\x64own_state_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1a\n\rsessions_flap\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x18\n\x0bhellos_sent\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fhellos_received\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08\x64\x62\x64_sent\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x19\n\x0c\x64\x62\x64_received\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x1c\n\x0fls_request_sent\x18\t \x01(\x04H\x08\x88\x01\x01\x12 \n\x13ls_request_received\x18\n \x01(\x04H\t\x88\x01\x01\x12\x1b\n\x0els_update_sent\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1f\n\x12ls_update_received\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12\x18\n\x0bls_ack_sent\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1c\n\x0fls_ack_received\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x15\n\x08lsa_sent\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x19\n\x0clsa_received\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12\x19\n\x0clsa_ack_sent\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12\x1d\n\x10lsa_ack_received\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12\x1c\n\x0frouter_lsa_sent\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12 \n\x13router_lsa_received\x18\x14 \x01(\x04H\x13\x88\x01\x01\x12\x1d\n\x10network_lsa_sent\x18\x15 \x01(\x04H\x14\x88\x01\x01\x12!\n\x14network_lsa_received\x18\x16 \x01(\x04H\x15\x88\x01\x01\x12\x1d\n\x10summary_lsa_sent\x18\x17 \x01(\x04H\x16\x88\x01\x01\x12!\n\x14summary_lsa_received\x18\x18 \x01(\x04H\x17\x88\x01\x01\x12\x1e\n\x11\x65xternal_lsa_sent\x18\x19 \x01(\x04H\x18\x88\x01\x01\x12\"\n\x15\x65xternal_lsa_received\x18\x1a \x01(\x04H\x19\x88\x01\x01\x12\x1a\n\rnssa_lsa_sent\x18\x1b \x01(\x04H\x1a\x88\x01\x01\x12\x1e\n\x11nssa_lsa_received\x18\x1c \x01(\x04H\x1b\x88\x01\x01\x12\x1e\n\x11opaque_local_sent\x18\x1d \x01(\x04H\x1c\x88\x01\x01\x12\"\n\x15opaque_local_received\x18\x1e \x01(\x04H\x1d\x88\x01\x01\x12\x1d\n\x10opaque_area_sent\x18\x1f \x01(\x04H\x1e\x88\x01\x01\x12!\n\x14opaque_area_received\x18  \x01(\x04H\x1f\x88\x01\x01\x12\x1f\n\x12opaque_domain_sent\x18! \x01(\x04H \x88\x01\x01\x12#\n\x16opaque_domain_received\x18\" \x01(\x04H!\x88\x01\x01\x42\x07\n\x05_nameB\x13\n\x11_full_state_countB\x13\n\x11_down_state_countB\x10\n\x0e_sessions_flapB\x0e\n\x0c_hellos_sentB\x12\n\x10_hellos_receivedB\x0b\n\t_dbd_sentB\x0f\n\r_dbd_receivedB\x12\n\x10_ls_request_sentB\x16\n\x14_ls_request_receivedB\x11\n\x0f_ls_update_sentB\x15\n\x13_ls_update_receivedB\x0e\n\x0c_ls_ack_sentB\x12\n\x10_ls_ack_receivedB\x0b\n\t_lsa_sentB\x0f\n\r_lsa_receivedB\x0f\n\r_lsa_ack_sentB\x13\n\x11_lsa_ack_receivedB\x12\n\x10_router_lsa_sentB\x16\n\x14_router_lsa_receivedB\x13\n\x11_network_lsa_sentB\x17\n\x15_network_lsa_receivedB\x13\n\x11_summary_lsa_sentB\x17\n\x15_summary_lsa_receivedB\x14\n\x12_external_lsa_sentB\x18\n\x16_external_lsa_receivedB\x10\n\x0e_nssa_lsa_sentB\x14\n\x12_nssa_lsa_receivedB\x14\n\x12_opaque_local_sentB\x18\n\x16_opaque_local_receivedB\x13\n\x11_opaque_area_sentB\x17\n\x15_opaque_area_receivedB\x15\n\x13_opaque_domain_sentB\x19\n\x17_opaque_domain_received\"(\n\x12\x43onvergenceRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\"\xfe\x01\n\x11\x43onvergenceMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12&\n\x19\x64\x61ta_plane_convergence_us\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x34\n\'control_plane_data_plane_convergence_us\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12%\n\x06\x65vents\x18\x04 \x03(\x0b\x32\x15.otg.ConvergenceEventB\x07\n\x05_nameB\x1c\n\x1a_data_plane_convergence_usB*\n(_control_plane_data_plane_convergence_us\"\x87\x03\n\x10\x43onvergenceEvent\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.ConvergenceEvent.Type.EnumH\x00\x88\x01\x01\x12\x13\n\x06source\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x62\x65gin_timestamp_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1d\n\x10\x65nd_timestamp_ns\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\x42\x07\n\x05_typeB\t\n\x07_sourceB\x15\n\x13_begin_timestamp_nsB\x13\n\x11_end_timestamp_ns\"\xc8\x04\n\x14MacsecMetricsRequest\x12\x1b\n\x13secure_entity_names\x18\x01 \x03(\t\x12@\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32*.otg.MacsecMetricsRequest.ColumnNames.Enum\x1a\xd0\x03\n\x0b\x43olumnNames\"\xc0\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x16\n\x12out_pkts_protected\x10\x03\x12\x16\n\x12out_pkts_encrypted\x10\x04\x12\x0e\n\nin_pkts_ok\x10\x05\x12\x0f\n\x0bin_pkts_bad\x10\x06\x12\x13\n\x0fin_pkts_bad_tag\x10\x07\x12\x10\n\x0cin_pkts_late\x10\x08\x12\x12\n\x0ein_pkts_no_sci\x10\t\x12\x18\n\x14in_pkts_not_using_sa\x10\n\x12\x15\n\x11in_pkts_not_valid\x10\x0b\x12\x17\n\x13in_pkts_unknown_sci\x10\x0c\x12\x15\n\x11in_pkts_unused_sa\x10\r\x12\x13\n\x0fin_pkts_invalid\x10\x0e\x12\x14\n\x10in_pkts_untagged\x10\x0f\x12\x18\n\x14out_octets_protected\x10\x10\x12\x18\n\x14out_octets_encrypted\x10\x11\x12\x17\n\x13in_octets_validated\x10\x12\x12\x17\n\x13in_octets_decrypted\x10\x13\"\xf4\x08\n\x0cMacsecMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\rsession_state\x18\x02 \x01(\x0e\x32#.otg.MacsecMetric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x1f\n\x12out_pkts_protected\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x1f\n\x12out_pkts_encrypted\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x17\n\nin_pkts_ok\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12\x18\n\x0b\x62\x61\x64_pkts_rx\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x1c\n\x0fin_pkts_bad_tag\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12\x19\n\x0cin_pkts_late\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1b\n\x0ein_pkts_no_sci\x18\n \x01(\x04H\t\x88\x01\x01\x12!\n\x14in_pkts_not_using_sa\x18\x0b \x01(\x04H\n\x88\x01\x01\x12\x1e\n\x11in_pkts_not_valid\x18\x0c \x01(\x04H\x0b\x88\x01\x01\x12 \n\x13in_pkts_unknown_sci\x18\r \x01(\x04H\x0c\x88\x01\x01\x12\x1e\n\x11in_pkts_unused_sa\x18\x0e \x01(\x04H\r\x88\x01\x01\x12\x1c\n\x0fin_pkts_invalid\x18\x0f \x01(\x04H\x0e\x88\x01\x01\x12\x1d\n\x10in_pkts_untagged\x18\x10 \x01(\x04H\x0f\x88\x01\x01\x12!\n\x14out_octets_protected\x18\x11 \x01(\x04H\x10\x88\x01\x01\x12!\n\x14out_octets_encrypted\x18\x12 \x01(\x04H\x11\x88\x01\x01\x12 \n\x13in_octets_validated\x18\x13 \x01(\x04H\x12\x88\x01\x01\x12 \n\x13in_octets_decrypted\x18\x14 \x01(\x04H\x13\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x15\n\x13_out_pkts_protectedB\x15\n\x13_out_pkts_encryptedB\r\n\x0b_in_pkts_okB\x0e\n\x0c_bad_pkts_rxB\x12\n\x10_in_pkts_bad_tagB\x0f\n\r_in_pkts_lateB\x11\n\x0f_in_pkts_no_sciB\x17\n\x15_in_pkts_not_using_saB\x14\n\x12_in_pkts_not_validB\x16\n\x14_in_pkts_unknown_sciB\x14\n\x12_in_pkts_unused_saB\x12\n\x10_in_pkts_invalidB\x13\n\x11_in_pkts_untaggedB\x17\n\x15_out_octets_protectedB\x17\n\x15_out_octets_encryptedB\x16\n\x14_in_octets_validatedB\x16\n\x14_in_octets_decrypted\"\xe9\x02\n\x11MkaMetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12=\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\'.otg.MkaMetricsRequest.ColumnNames.Enum\x1a\x80\x02\n\x0b\x43olumnNames\"\xf0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x0c\n\x08mkpdu_tx\x10\x03\x12\x0c\n\x08mkpdu_rx\x10\x04\x12\x13\n\x0flive_peer_count\x10\x05\x12\x18\n\x14potential_peer_count\x10\x06\x12\x1c\n\x18latest_key_tx_peer_count\x10\x07\x12\x1c\n\x18latest_key_rx_peer_count\x10\x08\x12\x13\n\x0fmalformed_mkpdu\x10\t\x12\x10\n\x0cicv_mismatch\x10\n\"\x86\x05\n\tMkaMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12<\n\rsession_state\x18\x02 \x01(\x0e\x32 .otg.MkaMetric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x15\n\x08mkpdu_tx\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x15\n\x08mkpdu_rx\x18\x05 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0flive_peer_count\x18\x06 \x01(\x04H\x05\x88\x01\x01\x12!\n\x14potential_peer_count\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12%\n\x18latest_key_tx_peer_count\x18\x08 \x01(\x04H\x07\x88\x01\x01\x12%\n\x18latest_key_rx_peer_count\x18\t \x01(\x04H\x08\x88\x01\x01\x12\x1c\n\x0fmalformed_mkpdu\x18\n \x01(\x04H\t\x88\x01\x01\x12\x19\n\x0cicv_mismatch\x18\x0b \x01(\x04H\n\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x0b\n\t_mkpdu_txB\x0b\n\t_mkpdu_rxB\x12\n\x10_live_peer_countB\x17\n\x15_potential_peer_countB\x1b\n\x19_latest_key_tx_peer_countB\x1b\n\x19_latest_key_rx_peer_countB\x12\n\x10_malformed_mkpduB\x0f\n\r_icv_mismatch\"\x8f\x07\n\rStatesRequest\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StatesRequest.Choice.EnumH\x00\x88\x01\x01\x12\x35\n\x0eipv4_neighbors\x18\x02 \x01(\x0b\x32\x1d.otg.Neighborsv4StatesRequest\x12\x35\n\x0eipv6_neighbors\x18\x03 \x01(\x0b\x32\x1d.otg.Neighborsv6StatesRequest\x12\x30\n\x0c\x62gp_prefixes\x18\x04 \x01(\x0b\x32\x1a.otg.BgpPrefixStateRequest\x12,\n\tisis_lsps\x18\x05 \x01(\x0b\x32\x19.otg.IsisLspsStateRequest\x12\x36\n\x0elldp_neighbors\x18\x06 \x01(\x0b\x32\x1e.otg.LldpNeighborsStateRequest\x12,\n\trsvp_lsps\x18\x07 \x01(\x0b\x32\x19.otg.RsvpLspsStateRequest\x12;\n\x11\x64hcpv4_interfaces\x18\x08 \x01(\x0b\x32 .otg.Dhcpv4InterfaceStateRequest\x12\x33\n\rdhcpv4_leases\x18\t \x01(\x0b\x32\x1c.otg.Dhcpv4LeaseStateRequest\x12;\n\x11\x64hcpv6_interfaces\x18\n \x01(\x0b\x32 .otg.Dhcpv6InterfaceStateRequest\x12\x33\n\rdhcpv6_leases\x18\x0b \x01(\x0b\x32\x1c.otg.Dhcpv6LeaseStateRequest\x12\x30\n\x0bospfv2_lsas\x18\x0c \x01(\x0b\x32\x1b.otg.Ospfv2LsasStateRequest\x1a\xf3\x01\n\x06\x43hoice\"\xe8\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x12\x15\n\x11\x64hcpv4_interfaces\x10\x07\x12\x11\n\rdhcpv4_leases\x10\x08\x12\x15\n\x11\x64hcpv6_interfaces\x10\t\x12\x11\n\rdhcpv6_leases\x10\n\x12\x0f\n\x0bospfv2_lsas\x10\x0b\x42\t\n\x07_choice\"\xc5\x06\n\x0eStatesResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.StatesResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x0eipv4_neighbors\x18\x02 \x03(\x0b\x32\x15.otg.Neighborsv4State\x12-\n\x0eipv6_neighbors\x18\x03 \x03(\x0b\x32\x15.otg.Neighborsv6State\x12+\n\x0c\x62gp_prefixes\x18\x04 \x03(\x0b\x32\x15.otg.BgpPrefixesState\x12%\n\tisis_lsps\x18\x05 \x03(\x0b\x32\x12.otg.IsisLspsState\x12/\n\x0elldp_neighbors\x18\x06 \x03(\x0b\x32\x17.otg.LldpNeighborsState\x12%\n\trsvp_lsps\x18\x07 \x03(\x0b\x32\x12.otg.RsvpLspsState\x12\x34\n\x11\x64hcpv4_interfaces\x18\x08 \x03(\x0b\x32\x19.otg.Dhcpv4InterfaceState\x12-\n\rdhcpv4_leases\x18\t \x03(\x0b\x32\x16.otg.Dhcpv4LeasesState\x12\x34\n\x11\x64hcpv6_interfaces\x18\n \x03(\x0b\x32\x19.otg.Dhcpv6InterfaceState\x12-\n\rdhcpv6_leases\x18\x0b \x03(\x0b\x32\x16.otg.Dhcpv6LeasesState\x12(\n\x0bospfv2_lsas\x18\x0c \x03(\x0b\x32\x13.otg.Ospfv2LsaState\x1a\xf3\x01\n\x06\x43hoice\"\xe8\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x12\x15\n\x11\x64hcpv4_interfaces\x10\x07\x12\x11\n\rdhcpv4_leases\x10\x08\x12\x15\n\x11\x64hcpv6_interfaces\x10\t\x12\x11\n\rdhcpv6_leases\x10\n\x12\x0f\n\x0bospfv2_lsas\x10\x0b\x42\t\n\x07_choice\"2\n\x18Neighborsv4StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"\xa4\x01\n\x10Neighborsv4State\x12\x1a\n\rethernet_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_ethernet_nameB\x0f\n\r_ipv4_addressB\x15\n\x13_link_layer_address\"2\n\x18Neighborsv6StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"\xa4\x01\n\x10Neighborsv6State\x12\x1a\n\rethernet_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_ethernet_nameB\x0f\n\r_ipv6_addressB\x15\n\x13_link_layer_address\"\xc2\x02\n\x15\x42gpPrefixStateRequest\x12\x16\n\x0e\x62gp_peer_names\x18\x01 \x03(\t\x12\x45\n\x0eprefix_filters\x18\x02 \x03(\x0e\x32-.otg.BgpPrefixStateRequest.PrefixFilters.Enum\x12=\n\x14ipv4_unicast_filters\x18\x03 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv4UnicastFilter\x12=\n\x14ipv6_unicast_filters\x18\x04 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv6UnicastFilter\x1aL\n\rPrefixFilters\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\"\x91\x02\n\x1a\x42gpPrefixIpv4UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv4UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\x91\x02\n\x1a\x42gpPrefixIpv6UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv6UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\xbe\x01\n\x10\x42gpPrefixesState\x12\x1a\n\rbgp_peer_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12=\n\x15ipv4_unicast_prefixes\x18\x02 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv4UnicastState\x12=\n\x15ipv6_unicast_prefixes\x18\x03 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv6UnicastStateB\x10\n\x0e_bgp_peer_name\"\x8d\x05\n\x19\x42gpPrefixIpv4UnicastState\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv4UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12:\n\x14\x65xtended_communities\x18\x0b \x03(\x0b\x32\x1c.otg.ResultExtendedCommunity\x12%\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPath\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x06\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x07\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"\x8d\x05\n\x19\x42gpPrefixIpv6UnicastState\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv6UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12:\n\x14\x65xtended_communities\x18\x0b \x03(\x0b\x32\x1c.otg.ResultExtendedCommunity\x12%\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPath\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x06\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x07\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"o\n\x17ResultExtendedCommunity\x12\x10\n\x03raw\x18\x01 \x01(\tH\x00\x88\x01\x01\x12:\n\nstructured\x18\x02 \x01(\x0b\x32&.otg.ResultExtendedCommunityStructuredB\x06\n\x04_raw\"\xf6\x05\n!ResultExtendedCommunityStructured\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.ResultExtendedCommunityStructured.Choice.EnumH\x00\x88\x01\x01\x12U\n\x19transitive_2octet_as_type\x18\x02 \x01(\x0b\x32\x32.otg.ResultExtendedCommunityTransitive2OctetAsType\x12[\n\x1ctransitive_ipv4_address_type\x18\x03 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityTransitiveIpv4AddressType\x12U\n\x19transitive_4octet_as_type\x18\x04 \x01(\x0b\x32\x32.otg.ResultExtendedCommunityTransitive4OctetAsType\x12P\n\x16transitive_opaque_type\x18\x05 \x01(\x0b\x32\x30.otg.ResultExtendedCommunityTransitiveOpaqueType\x12\\\n\x1dnon_transitive_2octet_as_type\x18\x06 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityNonTransitive2OctetAsType\x1a\xc1\x01\n\x06\x43hoice\"\xb6\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1d\n\x19transitive_2octet_as_type\x10\x01\x12 \n\x1ctransitive_ipv4_address_type\x10\x02\x12\x1d\n\x19transitive_4octet_as_type\x10\x03\x12\x1a\n\x16transitive_opaque_type\x10\x04\x12!\n\x1dnon_transitive_2octet_as_type\x10\x05\x42\t\n\x07_choice\"\xa2\x01\n8ResultExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\xa2\x01\n8ResultExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_4byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x14\n\x12_local_4byte_admin\"\xa0\x03\n-ResultExtendedCommunityTransitive2OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.ResultExtendedCommunityTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive2OctetAsTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive2OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa9\x01\n;ResultExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xa9\x01\n;ResultExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12\x1e\n\x11global_ipv4_admin\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x14\n\x12_global_ipv4_adminB\x14\n\x12_local_2byte_admin\"\xac\x03\n0ResultExtendedCommunityTransitiveIpv4AddressType\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.ResultExtendedCommunityTransitiveIpv4AddressType.Choice.EnumH\x00\x88\x01\x01\x12^\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32@.otg.ResultExtendedCommunityTransitiveIpv4AddressTypeRouteTarget\x12^\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32@.otg.ResultExtendedCommunityTransitiveIpv4AddressTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"\xa2\x01\n8ResultExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\xa2\x01\n8ResultExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x12\x1c\n\x0fglobal_4byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11local_2byte_admin\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x12\n\x10_global_4byte_asB\x14\n\x12_local_2byte_admin\"\xa0\x03\n-ResultExtendedCommunityTransitive4OctetAsType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.ResultExtendedCommunityTransitive4OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12[\n\x14route_target_subtype\x18\x02 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive4OctetAsTypeRouteTarget\x12[\n\x14route_origin_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitive4OctetAsTypeRouteOrigin\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x18\n\x14route_target_subtype\x10\x01\x12\x18\n\x14route_origin_subtype\x10\x02\x42\t\n\x07_choice\"n\n0ResultExtendedCommunityTransitiveOpaqueTypeColor\x12\x12\n\x05\x66lags\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_color\"\x88\x01\n8ResultExtendedCommunityTransitiveOpaqueTypeEncapsulation\x12\x15\n\x08reserved\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0btunnel_type\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0b\n\t_reservedB\x0e\n\x0c_tunnel_type\"\x88\x03\n+ResultExtendedCommunityTransitiveOpaqueType\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.ResultExtendedCommunityTransitiveOpaqueType.Choice.EnumH\x00\x88\x01\x01\x12L\n\rcolor_subtype\x18\x02 \x01(\x0b\x32\x35.otg.ResultExtendedCommunityTransitiveOpaqueTypeColor\x12\\\n\x15\x65ncapsulation_subtype\x18\x03 \x01(\x0b\x32=.otg.ResultExtendedCommunityTransitiveOpaqueTypeEncapsulation\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rcolor_subtype\x10\x01\x12\x19\n\x15\x65ncapsulation_subtype\x10\x02\x42\t\n\x07_choice\"\x97\x01\n=ResultExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x12\x1c\n\x0fglobal_2byte_as\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tbandwidth\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x12\n\x10_global_2byte_asB\x0c\n\n_bandwidth\"\xb8\x02\n0ResultExtendedCommunityNonTransitive2OctetAsType\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.ResultExtendedCommunityNonTransitive2OctetAsType.Choice.EnumH\x00\x88\x01\x01\x12\x62\n\x16link_bandwidth_subtype\x18\x02 \x01(\x0b\x32\x42.otg.ResultExtendedCommunityNonTransitive2OctetAsTypeLinkBandwidth\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1a\n\x16link_bandwidth_subtype\x10\x01\x42\t\n\x07_choice\"\xb0\x02\n\x12ResultBgpCommunity\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32!.otg.ResultBgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"@\n\x0fResultBgpAsPath\x12-\n\x08segments\x18\x01 \x03(\x0b\x32\x1b.otg.ResultBgpAsPathSegment\"\xce\x01\n\x16ResultBgpAsPathSegment\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32%.otg.ResultBgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\r\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"1\n\x14IsisLspsStateRequest\x12\x19\n\x11isis_router_names\x18\x01 \x03(\t\"d\n\rIsisLspsState\x12\x1d\n\x10isis_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x04lsps\x18\x02 \x03(\x0b\x32\x11.otg.IsisLspStateB\x13\n\x11_isis_router_name\"\xa6\x03\n\x0cIsisLspState\x12\x13\n\x06lsp_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x35\n\x08pdu_type\x18\x02 \x01(\x0e\x32\x1e.otg.IsisLspState.PduType.EnumH\x01\x88\x01\x01\x12\x1f\n\x12remaining_lifetime\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x04 \x01(\x04H\x03\x88\x01\x01\x12\x17\n\npdu_length\x18\x05 \x01(\rH\x04\x88\x01\x01\x12 \n\x05\x66lags\x18\x06 \x01(\x0b\x32\x11.otg.IsisLspFlags\x12\x14\n\x07is_type\x18\x07 \x01(\rH\x05\x88\x01\x01\x12\x1e\n\x04tlvs\x18\x08 \x01(\x0b\x32\x10.otg.IsisLspTlvs\x1a<\n\x07PduType\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x42\t\n\x07_lsp_idB\x0b\n\t_pdu_typeB\x15\n\x13_remaining_lifetimeB\x12\n\x10_sequence_numberB\r\n\x0b_pdu_lengthB\n\n\x08_is_type\"\xb1\x04\n\x0bIsisLspTlvs\x12+\n\rhostname_tlvs\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspHostname\x12;\n\x14is_reachability_tlvs\x18\x02 \x03(\x0b\x32\x1d.otg.IsisLspIsReachabilityTlv\x12L\n\x1d\x65xtended_is_reachability_tlvs\x18\x03 \x03(\x0b\x32%.otg.IsisLspExtendedIsReachabilityTlv\x12P\n\x1fipv4_internal_reachability_tlvs\x18\x04 \x03(\x0b\x32\'.otg.IsisLspIpv4InternalReachabilityTlv\x12P\n\x1fipv4_external_reachability_tlvs\x18\x05 \x03(\x0b\x32\'.otg.IsisLspIpv4ExternalReachabilityTlv\x12P\n\x1f\x65xtended_ipv4_reachability_tlvs\x18\x06 \x03(\x0b\x32\'.otg.IsisLspExtendedIpv4ReachabilityTlv\x12?\n\x16ipv6_reachability_tlvs\x18\x07 \x03(\x0b\x32\x1f.otg.IsisLspIpv6ReachabilityTlv\x12\x33\n\x13router_capabilities\x18\x08 \x03(\x0b\x32\x16.otg.IsisLspCapability\"5\n\x0fIsisLspHostname\x12\x15\n\x08hostname\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_hostname\"\xae\x02\n\x0cIsisLspFlags\x12\x1d\n\x10partition_repair\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0e\x61ttached_error\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1d\n\x10\x61ttached_expense\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0e\x61ttached_delay\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1d\n\x10\x61ttached_default\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08overload\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\x13\n\x11_partition_repairB\x11\n\x0f_attached_errorB\x13\n\x11_attached_expenseB\x11\n\x0f_attached_delayB\x13\n\x11_attached_defaultB\x0b\n\t_overload\"C\n\x18IsisLspIsReachabilityTlv\x12\'\n\tneighbors\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspneighbor\"S\n IsisLspExtendedIsReachabilityTlv\x12/\n\tneighbors\x18\x01 \x03(\x0b\x32\x1c.otg.IsisLspExtendedNeighbor\"7\n\x0fIsisLspneighbor\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_system_id\"q\n\x17IsisLspExtendedNeighbor\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x30\n\x0e\x61\x64jacency_sids\x18\x02 \x03(\x0b\x32\x18.otg.IsisLspAdjacencySidB\x0c\n\n_system_id\"L\n\"IsisLspIpv4InternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"L\n\"IsisLspIpv4ExternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"\xd7\x03\n\x0fIsisLspV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12N\n\x13redistribution_type\x18\x03 \x01(\x0e\x32,.otg.IsisLspV4Prefix.RedistributionType.EnumH\x02\x88\x01\x01\x12\x1b\n\x0e\x64\x65\x66\x61ult_metric\x18\x04 \x01(\rH\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV4Prefix.OriginType.EnumH\x04\x88\x01\x01\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x16\n\x14_redistribution_typeB\x11\n\x0f_default_metricB\x0e\n\x0c_origin_type\"T\n\"IsisLspExtendedIpv4ReachabilityTlv\x12.\n\x08prefixes\x18\x01 \x03(\x0b\x32\x1c.otg.IsisLspExtendedV4Prefix\"\xa9\x03\n\x17IsisLspExtendedV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12V\n\x13redistribution_type\x18\x04 \x01(\x0e\x32\x34.otg.IsisLspExtendedV4Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12\x37\n\x11prefix_attributes\x18\x05 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributes\x12*\n\x0bprefix_sids\x18\x06 \x03(\x0b\x32\x15.otg.IsisLspPrefixSid\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_type\"D\n\x1aIsisLspIpv6ReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV6Prefix\"\xac\x04\n\x0fIsisLspV6Prefix\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x02\x88\x01\x01\x12N\n\x13redistribution_type\x18\x04 \x01(\x0e\x32,.otg.IsisLspV6Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV6Prefix.OriginType.EnumH\x04\x88\x01\x01\x12\x37\n\x11prefix_attributes\x18\x06 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributes\x12*\n\x0bprefix_sids\x18\x07 \x03(\x0b\x32\x15.otg.IsisLspPrefixSid\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_typeB\x0e\n\x0c_origin_type\"y\n\x17IsisLspPrefixAttributes\x12\x13\n\x06x_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06r_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06n_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"q\n\x10IsisLspPrefixSid\x12\x0c\n\x04sids\x18\x01 \x03(\r\x12)\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x1a.otg.IsisLspPrefixSidFlags\x12\x16\n\talgorithm\x18\x03 \x01(\rH\x00\x88\x01\x01\x42\x0c\n\n_algorithm\"\xa1\x03\n\x11IsisLspCapability\x12\x1a\n\rrouter_cap_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x34\n\x05s_bit\x18\x02 \x01(\x0e\x32 .otg.IsisLspCapability.SBit.EnumH\x01\x88\x01\x01\x12\x34\n\x05\x64_bit\x18\x03 \x01(\x0e\x32 .otg.IsisLspCapability.DBit.EnumH\x02\x88\x01\x01\x12/\n\rsr_capability\x18\x04 \x01(\x0b\x32\x18.otg.IsisLspSRCapability\x12\x12\n\nalgorithms\x18\x05 \x03(\r\x12%\n\x0bsrlb_ranges\x18\x06 \x03(\x0b\x32\x10.otg.IsisLspSrlb\x1a\x39\n\x04SBit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lood\x10\x01\x12\r\n\tnot_flood\x10\x02\x1a\x37\n\x04\x44\x42it\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x64own\x10\x01\x12\x0c\n\x08not_down\x10\x02\x42\x10\n\x0e_router_cap_idB\x08\n\x06_s_bitB\x08\n\x06_d_bit\"c\n\x13IsisLspSRCapability\x12%\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x16.otg.IsisLspCapasFlags\x12%\n\x0bsrgb_ranges\x18\x02 \x03(\x0b\x32\x10.otg.IsisLspSrgb\"_\n\x11IsisLspCapasFlags\x12\x16\n\tipv4_mpls\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tipv6_mpls\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x0c\n\n_ipv4_mplsB\x0c\n\n_ipv6_mpls\"W\n\x0bIsisLspSrgb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"W\n\x0bIsisLspSrlb\x12\x19\n\x0cstarting_sid\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05range\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_starting_sidB\x08\n\x06_range\"\xea\x01\n\x13IsisLspAdjacencySid\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\".otg.IsisLspAdjacencySid.Type.EnumH\x00\x88\x01\x01\x12\x0c\n\x04sids\x18\x02 \x03(\r\x12&\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x17.otg.IsisLspAdjSidFlags\x12\x13\n\x06weight\x18\x04 \x01(\rH\x01\x88\x01\x01\x1a=\n\x04Type\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07\x61\x64j_sid\x10\x01\x12\x0f\n\x0blan_adj_sid\x10\x02\x42\x07\n\x05_typeB\t\n\x07_weight\"\xd7\x01\n\x15IsisLspPrefixSidFlags\x12\x13\n\x06r_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06n_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06p_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06\x65_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06v_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06l_flag\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\t\n\x07_r_flagB\t\n\x07_n_flagB\t\n\x07_p_flagB\t\n\x07_e_flagB\t\n\x07_v_flagB\t\n\x07_l_flag\"\xd4\x01\n\x12IsisLspAdjSidFlags\x12\x13\n\x06\x66_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x62_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06v_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x13\n\x06l_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06s_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06p_flag\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\t\n\x07_f_flagB\t\n\x07_b_flagB\t\n\x07_v_flagB\t\n\x07_l_flagB\t\n\x07_s_flagB\t\n\x07_p_flag\"L\n\x19LldpNeighborsStateRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12\x1b\n\x13neighbor_id_filters\x18\x02 \x03(\t\"\x8b\t\n\x12LldpNeighborsState\x12\x16\n\tlldp_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsystem_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12system_description\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nchassis_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12H\n\x0f\x63hassis_id_type\x18\x05 \x01(\x0e\x32*.otg.LldpNeighborsState.ChassisIdType.EnumH\x04\x88\x01\x01\x12\x18\n\x0bneighbor_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x18\n\x0blast_update\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x10\n\x03ttl\x18\t \x01(\rH\x08\x88\x01\x01\x12\x14\n\x07port_id\x18\n \x01(\tH\t\x88\x01\x01\x12\x42\n\x0cport_id_type\x18\x0b \x01(\x0e\x32\'.otg.LldpNeighborsState.PortIdType.EnumH\n\x88\x01\x01\x12\x1d\n\x10port_description\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1f\n\x12management_address\x18\r \x01(\tH\x0c\x88\x01\x01\x12$\n\x17management_address_type\x18\x0e \x01(\tH\r\x88\x01\x01\x12,\n\x0b\x63ustom_tlvs\x18\x0f \x03(\x0b\x32\x17.otg.LldpCustomTLVState\x12.\n\x0c\x63\x61pabilities\x18\x10 \x03(\x0b\x32\x18.otg.LldpCapabilityState\x1a\xae\x01\n\rChassisIdType\"\x9c\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x15\n\x11\x63hassis_component\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x1a\xaa\x01\n\nPortIdType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x14\n\x10\x61gent_circuit_id\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x42\x0c\n\n_lldp_nameB\x0e\n\x0c_system_nameB\x15\n\x13_system_descriptionB\r\n\x0b_chassis_idB\x12\n\x10_chassis_id_typeB\x0e\n\x0c_neighbor_idB\x06\n\x04_ageB\x0e\n\x0c_last_updateB\x06\n\x04_ttlB\n\n\x08_port_idB\x0f\n\r_port_id_typeB\x13\n\x11_port_descriptionB\x15\n\x13_management_addressB\x1a\n\x18_management_address_type\"\xac\x01\n\x12LldpCustomTLVState\x12\x18\n\x0b\x63ustom_type\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03oui\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0boui_subtype\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0binformation\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x0e\n\x0c_custom_typeB\x06\n\x04_ouiB\x0e\n\x0c_oui_subtypeB\x0e\n\x0c_information\"\x90\x03\n\x13LldpCapabilityState\x12J\n\x0f\x63\x61pability_name\x18\x01 \x01(\x0e\x32,.otg.LldpCapabilityState.CapabilityName.EnumH\x00\x88\x01\x01\x12\x1f\n\x12\x63\x61pability_enabled\x18\x02 \x01(\x08H\x01\x88\x01\x01\x1a\xe0\x01\n\x0e\x43\x61pabilityName\"\xcd\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nmac_bridge\x10\x01\x12\x16\n\x12two_port_mac_relay\x10\x02\x12\x0c\n\x08repeater\x10\x03\x12\x17\n\x13\x64ocsis_cable_device\x10\x04\x12\n\n\x06s_vlan\x10\x05\x12\r\n\ttelephone\x10\x06\x12\t\n\x05other\x10\x07\x12\n\n\x06router\x10\x08\x12\n\n\x06\x63_vlan\x10\t\x12\x10\n\x0cstation_only\x10\n\x12\x15\n\x11wlan_access_point\x10\x0b\x42\x12\n\x10_capability_nameB\x15\n\x13_capability_enabled\"1\n\x14RsvpLspsStateRequest\x12\x19\n\x11rsvp_router_names\x18\x01 \x03(\t\"m\n\rRsvpLspsState\x12\x1d\n\x10rsvp_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\tipv4_lsps\x18\x02 \x03(\x0b\x32\x15.otg.RsvpIPv4LspStateB\x13\n\x11_rsvp_router_name\"\xe2\x01\n\x10RsvpIPv4LspState\x12\x1b\n\x0esource_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x64\x65stination_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1e\n\x03lsp\x18\x03 \x01(\x0b\x32\x11.otg.RsvpLspState\x12!\n\x04rros\x18\x04 \x03(\x0b\x32\x13.otg.RsvpLspIpv4Rro\x12!\n\x04\x65ros\x18\x05 \x03(\x0b\x32\x13.otg.RsvpLspIpv4EroB\x11\n\x0f_source_addressB\x16\n\x14_destination_address\"\xb4\x04\n\x0cRsvpLspState\x12\x16\n\ttunnel_id\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0csession_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08label_in\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x16\n\tlabel_out\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x0esession_status\x18\x06 \x01(\x0e\x32$.otg.RsvpLspState.SessionStatus.EnumH\x05\x88\x01\x01\x12\x44\n\x10last_flap_reason\x18\x07 \x01(\x0e\x32%.otg.RsvpLspState.LastFlapReason.EnumH\x06\x88\x01\x01\x12\x14\n\x07up_time\x18\x08 \x01(\x04H\x07\x88\x01\x01\x1a:\n\rSessionStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1aY\n\x0eLastFlapReason\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tresv_tear\x10\x01\x12\r\n\tpath_tear\x10\x02\x12\x10\n\x0cpath_timeout\x10\x03\x42\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x0f\n\r_session_nameB\x0b\n\t_label_inB\x0c\n\n_label_outB\x11\n\x0f_session_statusB\x13\n\x11_last_flap_reasonB\n\n\x08_up_time\"b\n\x0eRsvpLspIpv4Rro\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0ereported_label\x18\x02 \x01(\rH\x01\x88\x01\x01\x42\n\n\x08_addressB\x11\n\x0f_reported_label\"\xf2\x01\n\x0eRsvpLspIpv4Ero\x12\x13\n\x06prefix\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03\x61sn\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x30\n\x04type\x18\x03 \x01(\x0e\x32\x1d.otg.RsvpLspIpv4Ero.Type.EnumH\x02\x88\x01\x01\x1ak\n\x04Type\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x61sn\x10\x03\x12\x08\n\x04\x61sn4\x10\x04\x12\t\n\x05label\x10\x05\x12\x18\n\x14unnumbered_interface\x10\x06\x42\t\n\x07_prefixB\x06\n\x04_asnB\x07\n\x05_type\"8\n\x1b\x44hcpv4InterfaceStateRequest\x12\x19\n\x11\x64hcp_client_names\x18\x01 \x03(\t\"\xd0\x02\n\x14\x44hcpv4InterfaceState\x12\x1d\n\x10\x64hcp_client_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x1c\n\x0fgateway_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nlease_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x17\n\nrenew_time\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x07 \x01(\rH\x06\x88\x01\x01\x42\x13\n\x11_dhcp_client_nameB\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x12\n\x10_gateway_addressB\r\n\x0b_lease_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_time\"4\n\x17\x44hcpv4LeaseStateRequest\x12\x19\n\x11\x64hcp_server_names\x18\x01 \x03(\t\"n\n\x11\x44hcpv4LeasesState\x12\x1d\n\x10\x64hcp_server_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x06leases\x18\x02 \x03(\x0b\x32\x15.otg.Dhcpv4LeaseStateB\x13\n\x11_dhcp_server_name\"\xd2\x02\n\x10\x44hcpv4LeaseState\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nvalid_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0epreferred_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\nrenew_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\tclient_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\ncircuit_id\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tremote_id\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\n\n\x08_addressB\r\n\x0b_valid_timeB\x11\n\x0f_preferred_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_timeB\x0c\n\n_client_idB\r\n\x0b_circuit_idB\x0c\n\n_remote_id\"8\n\x1b\x44hcpv6InterfaceStateRequest\x12\x19\n\x11\x64hcp_client_names\x18\x01 \x03(\t\"\xaa\x01\n\x14\x44hcpv6InterfaceState\x12\x1d\n\x10\x64hcp_client_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x30\n\x0eiapd_addresses\x18\x02 \x03(\x0b\x32\x18.otg.Dhcpv6InterfaceIapd\x12,\n\x0cia_addresses\x18\x03 \x03(\x0b\x32\x16.otg.Dhcpv6InterfaceIaB\x13\n\x11_dhcp_client_name\"\x8d\x01\n\x13\x44hcpv6InterfaceIapd\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x17\n\nlease_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\n\n\x08_addressB\x10\n\x0e_prefix_lengthB\r\n\x0b_lease_time\"\x7f\n\x11\x44hcpv6InterfaceIa\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07gateway\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlease_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\n\n\x08_addressB\n\n\x08_gatewayB\r\n\x0b_lease_time\"4\n\x17\x44hcpv6LeaseStateRequest\x12\x19\n\x11\x64hcp_server_names\x18\x01 \x03(\t\"t\n\x11\x44hcpv6LeasesState\x12\x1d\n\x10\x64hcp_server_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12+\n\x06leases\x18\x02 \x03(\x0b\x32\x1b.otg.Dhcpv6ServerLeaseStateB\x13\n\x11_dhcp_server_name\"\xdc\x02\n\x16\x44hcpv6ServerLeaseState\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nvalid_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0epreferred_time\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\nrenew_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0brebind_time\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x16\n\tclient_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tremote_id\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x19\n\x0cinterface_id\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\n\n\x08_addressB\r\n\x0b_valid_timeB\x11\n\x0f_preferred_timeB\r\n\x0b_renew_timeB\x0e\n\x0c_rebind_timeB\x0c\n\n_client_idB\x0c\n\n_remote_idB\x0f\n\r_interface_id\".\n\x16Ospfv2LsasStateRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\"\x86\x03\n\x0eOspfv2LsaState\x12\x18\n\x0brouter_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\x0brouter_lsas\x18\x02 \x03(\x0b\x32\x14.otg.Ospfv2RouterLsa\x12+\n\x0cnetwork_lsas\x18\x03 \x03(\x0b\x32\x15.otg.Ospfv2NetworkLsa\x12:\n\x14network_summary_lsas\x18\x04 \x03(\x0b\x32\x1c.otg.Ospfv2NetworkSummaryLsa\x12\x30\n\x0fsummary_as_lsas\x18\x05 \x03(\x0b\x32\x17.otg.Ospfv2SummaryAsLsa\x12\x32\n\x10\x65xternal_as_lsas\x18\x06 \x03(\x0b\x32\x18.otg.Ospfv2ExternalAsLsa\x12%\n\tnssa_lsas\x18\x07 \x03(\x0b\x32\x12.otg.Ospfv2NssaLsa\x12)\n\x0bopaque_lsas\x18\x08 \x03(\x0b\x32\x14.otg.Ospfv2OpaqueLsaB\x0e\n\x0c_router_name\"W\n\x0fOspfv2RouterLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x1e\n\x05links\x18\x02 \x03(\x0b\x32\x0f.otg.Ospfv2Link\"\x81\x01\n\x10Ospfv2NetworkLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x13neighbor_router_ids\x18\x03 \x03(\tB\x0f\n\r_network_mask\"\x8b\x01\n\x17Ospfv2NetworkSummaryLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metric\"\x86\x01\n\x12Ospfv2SummaryAsLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metric\"\xb1\x01\n\x13Ospfv2ExternalAsLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bmetric_type\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metricB\x0e\n\x0c_metric_type\"\xe3\x01\n\rOspfv2NssaLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x19\n\x0cnetwork_mask\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0bmetric_type\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x1f\n\x12\x66orwarding_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x0f\n\r_network_maskB\t\n\x07_metricB\x0e\n\x0c_metric_typeB\x15\n\x13_forwarding_address\"\xb5\x01\n\x0fOspfv2OpaqueLsa\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.otg.Ospfv2LsaHeader\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32\x1e.otg.Ospfv2OpaqueLsa.Type.EnumH\x00\x88\x01\x01\x1a@\n\x04Type\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05local\x10\x01\x12\x08\n\x04\x61rea\x10\x02\x12\n\n\x06\x64omain\x10\x03\x42\x07\n\x05_type\"\xe5\x01\n\x0fOspfv2LsaHeader\x12\x13\n\x06lsa_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertising_router_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x18\n\x0boption_bits\x18\x05 \x01(\rH\x04\x88\x01\x01\x42\t\n\x07_lsa_idB\x18\n\x16_advertising_router_idB\x12\n\x10_sequence_numberB\x06\n\x04_ageB\x0e\n\x0c_option_bits\"\xf0\x01\n\nOspfv2Link\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x19.otg.Ospfv2Link.Type.EnumH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04\x64\x61ta\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06metric\x18\x04 \x01(\rH\x03\x88\x01\x01\x1aW\n\x04Type\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0epoint_to_point\x10\x01\x12\x0b\n\x07transit\x10\x02\x12\x08\n\x04stub\x10\x03\x12\x0b\n\x07virtual\x10\x04\x42\x07\n\x05_typeB\x05\n\x03_idB\x07\n\x05_dataB\t\n\x07_metric\"6\n\x0e\x43\x61ptureRequest\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_port_name\"w\n\x1dPatternFlowEthernetDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowEthernetDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowEthernetDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x11\n\x04\x61uto\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x35\n\tincrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounter\x12\x35\n\tdecrement\x18\x07 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounter\x12\x39\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32$.otg.PatternFlowEthernetDstMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"w\n\x1dPatternFlowEthernetSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowEthernetSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowEthernetSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowEthernetSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowEthernetEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowEthernetEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowEthernetEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowEthernetEtherTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"|\n\"PatternFlowEthernetPfcQueueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPfcQueueMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPfcQueue\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPfcQueue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPfcQueueMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowVlanPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowVlanPriorityMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowVlanPriority\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowVlanPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowVlanPriorityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowVlanCfiCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowVlanCfiMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xfc\x02\n\x12PatternFlowVlanCfi\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowVlanCfi.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowVlanCfiMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"r\n\x18PatternFlowVlanIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"x\n\x1aPatternFlowVlanIdMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xf7\x02\n\x11PatternFlowVlanId\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.PatternFlowVlanId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x30\n\tincrement\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounter\x12\x30\n\tdecrement\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounter\x12\x34\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x1f.otg.PatternFlowVlanIdMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowVlanTpidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowVlanTpidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x81\x03\n\x13PatternFlowVlanTpid\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVlanTpid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x32\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounter\x12\x32\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounter\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowVlanTpidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowVxlanFlagsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowVxlanFlagsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowVxlanFlags\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowVxlanFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowVxlanFlagsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowVxlanReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowVxlanReserved0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowVxlanReserved0\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0Counter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0Counter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowVxlanVniCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowVxlanVniMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x13PatternFlowVxlanVni\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVxlanVni.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x32\n\tincrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounter\x12\x32\n\tdecrement\x18\x07 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounter\x12\x36\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32!.otg.PatternFlowVxlanVniMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowVxlanReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowVxlanReserved1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowVxlanReserved1\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1Counter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1Counter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv4HeaderLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv4HeaderLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowIpv4HeaderLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4HeaderLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12:\n\tincrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounter\x12:\n\tdecrement\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounter\x12>\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32).otg.PatternFlowIpv4HeaderLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"{\n!PatternFlowIpv4TotalLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4TotalLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowIpv4TotalLength\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TotalLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounter\x12\x39\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounter\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowIpv4TotalLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"~\n$PatternFlowIpv4IdentificationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4IdentificationMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4Identification\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4Identification.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4IdentificationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4ReservedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv4Reserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv4DontFragmentCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv4DontFragmentMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowIpv4DontFragment\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4DontFragment.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv4DontFragmentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4MoreFragmentsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4MoreFragmentsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4MoreFragments\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4MoreFragments.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4MoreFragmentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowIpv4FragmentOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4FragmentOffsetMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4FragmentOffset\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4FragmentOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4FragmentOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIpv4TimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIpv4TimeToLiveMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIpv4TimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv4TimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIpv4TimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4ProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4ProtocolMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIpv4Protocol\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Protocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounter\x12\x36\n\tdecrement\x18\x07 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounter\x12:\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32%.otg.PatternFlowIpv4ProtocolMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"\xdf\x02\n\x1dPatternFlowIpv4HeaderChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4HeaderChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIpv4HeaderChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"s\n\x19PatternFlowIpv4SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv4SrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x88\x01\n\x18PatternFlowIpv4SrcRandom\x12\x10\n\x03min\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xe2\x03\n\x12PatternFlowIpv4Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4SrcMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv4Auto\x12-\n\x06random\x18\t \x01(\x0b\x32\x1d.otg.PatternFlowIpv4SrcRandom\x1al\n\x06\x43hoice\"b\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv4DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv4DstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x88\x01\n\x18PatternFlowIpv4DstRandom\x12\x10\n\x03min\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xe2\x03\n\x12PatternFlowIpv4Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4DstMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv4Auto\x12-\n\x06random\x18\t \x01(\x0b\x32\x1d.otg.PatternFlowIpv4DstRandom\x1al\n\x06\x43hoice\"b\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8b\x01\n1PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa5\x03\n*PatternFlowIpv4OptionsCustomTypeCopiedFlag\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowIpv4OptionsCustomTypeCopiedFlagCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8c\x01\n2PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa9\x03\n+PatternFlowIpv4OptionsCustomTypeOptionClass\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.PatternFlowIpv4OptionsCustomTypeOptionClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x37.otg.PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowIpv4OptionsCustomTypeOptionClassCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowIpv4OptionsCustomTypeOptionNumber\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowIpv4OptionsCustomTypeOptionNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowIpv4OptionsCustomTypeOptionNumberCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowIpv4PriorityRawCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4PriorityRawMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowIpv4PriorityRaw\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4PriorityRaw.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4PriorityRawMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4DscpPhbCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4DscpPhbMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4DscpPhb\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpPhb.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpPhbMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv4DscpEcnCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv4DscpEcnMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv4DscpEcn\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpEcn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpEcnMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4TosPrecedenceCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4TosPrecedenceMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4TosPrecedence\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosPrecedence.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosPrecedenceMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIpv4TosDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv4TosDelayMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv4TosDelay\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4TosDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4TosDelayMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv4TosThroughputCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv4TosThroughputMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowIpv4TosThroughput\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosThroughput.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosThroughputMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowIpv4TosReliabilityCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIpv4TosReliabilityMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIpv4TosReliability\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4TosReliability.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4TosReliabilityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowIpv4TosMonetaryCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowIpv4TosMonetaryMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowIpv4TosMonetary\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TosMonetary.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4TosMonetaryMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowIpv4TosUnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIpv4TosUnusedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowIpv4TosUnused\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv4TosUnused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv4TosUnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowIpv6VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowIpv6VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowIpv6Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv6Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv6VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowIpv6TrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowIpv6TrafficClassMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowIpv6TrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv6TrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv6TrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowIpv6FlowLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIpv6FlowLabelMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8e\x01\n\x1ePatternFlowIpv6FlowLabelRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xdb\x03\n\x18PatternFlowIpv6FlowLabel\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv6FlowLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv6FlowLabelMetricTag\x12\x33\n\x06random\x18\x08 \x01(\x0b\x32#.otg.PatternFlowIpv6FlowLabelRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowIpv6PayloadLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowIpv6PayloadLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowIpv6PayloadLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv6PayloadLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowIpv6PayloadLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowIpv6NextHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIpv6NextHeaderMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowIpv6NextHeader\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv6NextHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounter\x12\x38\n\tdecrement\x18\x07 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounter\x12<\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\'.otg.PatternFlowIpv6NextHeaderMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"x\n\x1ePatternFlowIpv6HopLimitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIpv6HopLimitMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIpv6HopLimit\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv6HopLimit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv6HopLimitMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv6SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv6SrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x12PatternFlowIpv6Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6SrcMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv6Auto\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_value\"s\n\x19PatternFlowIpv6DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n\x1bPatternFlowIpv6DstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x12PatternFlowIpv6Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x31\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounter\x12\x31\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounter\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6DstMetricTag\x12\x1f\n\x04\x61uto\x18\x08 \x01(\x0b\x32\x11.otg.FlowIpv6Auto\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowPfcPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowPfcPauseDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowPfcPauseDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowPfcPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowPfcPauseSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowPfcPauseSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowPfcPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowPfcPauseEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowPfcPauseEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowPfcPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowPfcPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowPfcPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowPfcPauseControlOpCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowPfcPauseControlOpCode\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowPfcPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowPfcPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowPfcPauseClassEnableVectorCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8b\x01\n-PatternFlowPfcPauseClassEnableVectorMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd6\x03\n$PatternFlowPfcPauseClassEnableVector\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowPfcPauseClassEnableVector.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounter\x12G\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x32.otg.PatternFlowPfcPauseClassEnableVectorMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass0\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass1\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass2MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass2\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass3Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass3MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass3\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass3.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass3MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass4Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass4MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass4\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass4MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass5Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass5MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass5\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass5.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass5MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass6Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass6MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass6\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass6.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass6MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowPfcPausePauseClass7Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowPfcPausePauseClass7MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowPfcPausePauseClass7\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass7.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7Counter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7Counter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass7MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowEthernetPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPauseDstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPauseDst\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowEthernetPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowEthernetPauseSrcMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowEthernetPauseSrc\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowEthernetPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x88\x01\n*PatternFlowEthernetPauseEtherTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc7\x03\n!PatternFlowEthernetPauseEtherType\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowEthernetPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounter\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowEthernetPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x86\x01\n,PatternFlowEthernetPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8c\x01\n.PatternFlowEthernetPauseControlOpCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xdb\x03\n%PatternFlowEthernetPauseControlOpCode\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowEthernetPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounter\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounter\x12H\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x33.otg.PatternFlowEthernetPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowEthernetPauseTimeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowEthernetPauseTimeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowEthernetPauseTime\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetPauseTime.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowEthernetPauseTimeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpSrcPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowTcpSrcPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowTcpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpSrcPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowTcpSrcPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpDstPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowTcpDstPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowTcpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpDstPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowTcpDstPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpSeqNumCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpSeqNumMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpSeqNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpSeqNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpSeqNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpAckNumCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpAckNumMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpAckNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpAckNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpAckNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowTcpDataOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowTcpDataOffsetMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowTcpDataOffset\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowTcpDataOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowTcpDataOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"t\n\x1aPatternFlowTcpEcnNsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n\x1cPatternFlowTcpEcnNsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x81\x03\n\x13PatternFlowTcpEcnNs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowTcpEcnNs.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x32\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounter\x12\x32\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounter\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowTcpEcnNsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpEcnCwrCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpEcnCwrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpEcnCwr\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpEcnCwr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpEcnCwrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowTcpEcnEchoCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowTcpEcnEchoMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowTcpEcnEcho\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpEcnEcho.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpEcnEchoMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlUrgCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlUrgMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlUrg\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlUrg.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlUrgMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlAckCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlAckMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlAck\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlAck.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlAckMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlPshCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlPshMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlPsh\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlPsh.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlPshMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlRstCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlRstMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlRst\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlRst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlRstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlSynCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlSynMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlSyn\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlSyn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlSynMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpCtlFinCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpCtlFinMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpCtlFin\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlFin.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlFinMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowTcpWindowCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowTcpWindowMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowTcpWindow\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpWindow.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpWindowMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xca\x02\n\x16PatternFlowTcpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowTcpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowTcpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowUdpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowUdpSrcPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowUdpSrcPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowUdpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpSrcPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowUdpSrcPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowUdpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowUdpDstPortMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x01\n\x1bPatternFlowUdpDstPortRandom\x12\x10\n\x03min\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x11\n\x04seed\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_maxB\x07\n\x05_seedB\x08\n\x06_count\"\xc9\x03\n\x15PatternFlowUdpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpDstPortMetricTag\x12\x30\n\x06random\x18\x08 \x01(\x0b\x32 .otg.PatternFlowUdpDstPortRandom\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\n\n\x06random\x10\x06\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowUdpLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowUdpLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowUdpLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowUdpLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowUdpLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xca\x02\n\x16PatternFlowUdpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowUdpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowUdpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowGreChecksumPresentCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGreChecksumPresentMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGreChecksumPresent\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGreChecksumPresent.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGreChecksumPresentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGreReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGreReserved0MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGreReserved0\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved0Counter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved0Counter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGreVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGreVersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGreVersion\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGreVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGreVersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGreProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGreProtocolMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGreProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGreProtocolMetricTag\x12\x11\n\x04\x61uto\x18\x08 \x01(\rH\x02\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x12\x08\n\x04\x61uto\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"\xca\x02\n\x16PatternFlowGreChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowGreChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"x\n\x1ePatternFlowGreReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGreReserved1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGreReserved1\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved1Counter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved1Counter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGtpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGtpv1VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGtpv1Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowGtpv1ProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowGtpv1ProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowGtpv1ProtocolType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowGtpv1ProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowGtpv1ProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowGtpv1ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowGtpv1ReservedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowGtpv1Reserved\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv1Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv1ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGtpv1EFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGtpv1EFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGtpv1EFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1EFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1EFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowGtpv1SFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowGtpv1SFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowGtpv1SFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1SFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1SFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv1PnFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv1PnFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv1PnFlag\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv1PnFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv1PnFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowGtpv1MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowGtpv1MessageTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowGtpv1MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv1MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv1MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv1MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv1MessageLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv1MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowGtpv1TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowGtpv1TeidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowGtpv1Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv1Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv1TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv1SquenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv1SquenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv1SquenceNumber\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1SquenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1SquenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowGtpv1NPduNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowGtpv1NPduNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowGtpv1NPduNumber\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowGtpv1NPduNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowGtpv1NPduNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8e\x01\n0PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe5\x03\n\'PatternFlowGtpv1NextExtensionHeaderType\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x87\x01\n-PatternFlowGtpExtensionExtensionLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x01\n/PatternFlowGtpExtensionExtensionLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe0\x03\n&PatternFlowGtpExtensionExtensionLength\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowGtpExtensionExtensionLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounter\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounter\x12I\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x34.otg.PatternFlowGtpExtensionExtensionLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowGtpExtensionContentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x86\x01\n(PatternFlowGtpExtensionContentsMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbd\x03\n\x1fPatternFlowGtpExtensionContents\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowGtpExtensionContents.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x04\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounter\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowGtpExtensionContentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8b\x01\n1PatternFlowGtpExtensionNextExtensionHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x01\n3PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xf4\x03\n*PatternFlowGtpExtensionNextExtensionHeader\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounter\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounter\x12M\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x38.otg.PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowGtpv2VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowGtpv2VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowGtpv2Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv2Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv2VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowGtpv2PiggybackingFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowGtpv2PiggybackingFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowGtpv2PiggybackingFlag\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowGtpv2PiggybackingFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowGtpv2PiggybackingFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"y\n\x1fPatternFlowGtpv2TeidFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowGtpv2TeidFlagMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowGtpv2TeidFlag\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv2TeidFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv2TeidFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv2Spare1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv2Spare1MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv2Spare1\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1Counter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1Counter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"|\n\"PatternFlowGtpv2MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowGtpv2MessageTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowGtpv2MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv2MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv2MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"~\n$PatternFlowGtpv2MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowGtpv2MessageLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowGtpv2MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv2MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv2MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowGtpv2TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowGtpv2TeidMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x86\x03\n\x14PatternFlowGtpv2Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv2Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x33\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounter\x12\x33\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounter\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv2TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowGtpv2SequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x01\n\'PatternFlowGtpv2SequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb8\x03\n\x1ePatternFlowGtpv2SequenceNumber\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowGtpv2SequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounter\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowGtpv2SequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"w\n\x1dPatternFlowGtpv2Spare2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n\x1fPatternFlowGtpv2Spare2MetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x90\x03\n\x16PatternFlowGtpv2Spare2\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2Counter\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2Counter\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowArpHardwareTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowArpHardwareTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowArpHardwareType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpHardwareType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpHardwareTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowArpProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowArpProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa4\x03\n\x1aPatternFlowArpProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounter\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounter\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowArpHardwareLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowArpHardwareLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowArpHardwareLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpHardwareLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpHardwareLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowArpProtocolLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowArpProtocolLengthMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xae\x03\n\x1cPatternFlowArpProtocolLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpProtocolLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12;\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounter\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounter\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpProtocolLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowArpOperationCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowArpOperationMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowArpOperation\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowArpOperation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowArpOperationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpSenderHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpSenderHardwareAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpSenderHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpSenderProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpSenderProtocolAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpSenderProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpTargetHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpTargetHardwareAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpTargetHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x81\x01\n\'PatternFlowArpTargetProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x87\x01\n)PatternFlowArpTargetProtocolAddrMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc2\x03\n PatternFlowArpTargetProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounter\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounter\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIcmpEchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIcmpEchoTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIcmpEchoType\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIcmpEchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIcmpEchoCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIcmpEchoCode\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd9\x02\n\x1bPatternFlowIcmpEchoChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIcmpEchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowIcmpEchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIcmpEchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIcmpEchoIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIcmpEchoIdentifier\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpEchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIcmpEchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowIcmpEchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x88\x01\n*PatternFlowIcmpEchoSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xc7\x03\n!PatternFlowIcmpEchoSequenceNumber\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowIcmpEchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounter\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowIcmpEchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xdf\x02\n\x1dPatternFlowIcmpCommonChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpCommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpCommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\x84\x01\n*PatternFlowIcmpNextFieldsIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8a\x01\n,PatternFlowIcmpNextFieldsIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd1\x03\n#PatternFlowIcmpNextFieldsIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpNextFieldsIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounter\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounter\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpNextFieldsIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8e\x01\n0PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xe5\x03\n\'PatternFlowIcmpNextFieldsSequenceNumber\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIcmpv6EchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIcmpv6EchoTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIcmpv6EchoType\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowIcmpv6EchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowIcmpv6EchoCodeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowIcmpv6EchoCode\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowIcmpv6EchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x86\x01\n(PatternFlowIcmpv6EchoIdentifierMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xbd\x03\n\x1fPatternFlowIcmpv6EchoIdentifier\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6EchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounter\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowIcmpv6EchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x84\x01\n*PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8a\x01\n,PatternFlowIcmpv6EchoSequenceNumberMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd1\x03\n#PatternFlowIcmpv6EchoSequenceNumber\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpv6EchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xdf\x02\n\x1dPatternFlowIcmpv6EchoChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpv6EchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpv6EchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\xe5\x02\n\x1fPatternFlowIcmpv6CommonChecksum\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6CommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12K\n\tgenerated\x18\x02 \x01(\x0e\x32\x33.otg.PatternFlowIcmpv6CommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowPppAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowPppAddressMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowPppAddress\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowPppControlCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowPppControlMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowPppControl\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppControl.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppControlCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppControlCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppControlMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"{\n!PatternFlowPppProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x01\n#PatternFlowPppProtocolTypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowPppProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowPppProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounter\x12\x39\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounter\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowPppProtocolTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"y\n\x1fPatternFlowIgmpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n!PatternFlowIgmpv1VersionMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9a\x03\n\x18PatternFlowIgmpv1Version\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIgmpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounter\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounter\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIgmpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"v\n\x1cPatternFlowIgmpv1TypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n\x1ePatternFlowIgmpv1TypeMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x8b\x03\n\x15PatternFlowIgmpv1Type\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowIgmpv1Type.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x34\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounter\x12\x34\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounter\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowIgmpv1TypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowIgmpv1UnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n PatternFlowIgmpv1UnusedMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x95\x03\n\x17PatternFlowIgmpv1Unused\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIgmpv1Unused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounter\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIgmpv1UnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd3\x02\n\x19PatternFlowIgmpv1Checksum\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIgmpv1Checksum.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\tgenerated\x18\x02 \x01(\x0e\x32-.otg.PatternFlowIgmpv1Checksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIgmpv1GroupAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x84\x01\n&PatternFlowIgmpv1GroupAddressMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xb3\x03\n\x1dPatternFlowIgmpv1GroupAddress\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIgmpv1GroupAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12<\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounter\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounter\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIgmpv1GroupAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"u\n\x1bPatternFlowMplsLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"{\n\x1dPatternFlowMplsLabelMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowMplsLabel\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowMplsLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x33\n\tincrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounter\x12\x33\n\tdecrement\x18\x07 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounter\x12\x37\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\".otg.PatternFlowMplsLabelMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"|\n\"PatternFlowMplsTrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x82\x01\n$PatternFlowMplsTrafficClassMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xa9\x03\n\x1bPatternFlowMplsTrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowMplsTrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounter\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounter\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowMplsTrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"}\n#PatternFlowMplsBottomOfStackCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n%PatternFlowMplsBottomOfStackMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowMplsBottomOfStack\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowMplsBottomOfStack.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x11\n\x04\x61uto\x18\x04 \x01(\rH\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounter\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounter\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowMplsBottomOfStackMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_auto\"z\n PatternFlowMplsTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n\"PatternFlowMplsTimeToLiveMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06offset\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_offsetB\t\n\x07_length\"\x9f\x03\n\x19PatternFlowMplsTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowMplsTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounter\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowMplsTimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"z\n PatternFlowSnmpv2cVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x02\n\x19PatternFlowSnmpv2cVersion\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowSnmpv2cVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowSnmpv2cVersionCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowSnmpv2cVersionCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x7f\n%PatternFlowSnmpv2cPDURequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf5\x02\n\x1ePatternFlowSnmpv2cPDURequestId\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowSnmpv2cPDURequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cPDURequestIdCounter\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowSnmpv2cPDURequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x80\x01\n&PatternFlowSnmpv2cPDUErrorIndexCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf9\x02\n\x1fPatternFlowSnmpv2cPDUErrorIndex\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowSnmpv2cPDUErrorIndex.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12>\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowSnmpv2cPDUErrorIndexCounter\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowSnmpv2cPDUErrorIndexCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x83\x01\n)PatternFlowSnmpv2cBulkPDURequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x85\x03\n\"PatternFlowSnmpv2cBulkPDURequestId\x12H\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x33.otg.PatternFlowSnmpv2cBulkPDURequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32..otg.PatternFlowSnmpv2cBulkPDURequestIdCounter\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32..otg.PatternFlowSnmpv2cBulkPDURequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xe7\x01\n%PatternFlowSnmpv2cBulkPDUNonRepeaters\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowSnmpv2cBulkPDUNonRepeaters.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\x88\x01\n.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x99\x03\n\'PatternFlowSnmpv2cBulkPDUMaxRepetitions\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitions.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x46\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x12\x46\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowSnmpv2cBulkPDUMaxRepetitionsCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowSnmpv2cVariableBindingValueIntegerValue\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueIntegerValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowSnmpv2cVariableBindingValueIpAddressValue\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueIpAddressValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowSnmpv2cVariableBindingValueCounterValue\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowSnmpv2cVariableBindingValueCounterValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowSnmpv2cVariableBindingValueCounterValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowSnmpv2cVariableBindingValueTimeticksValue\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowSnmpv2cVariableBindingValueTimeticksValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x12\x12\n\x05start\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x04H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowSnmpv2cVariableBindingValueBigCounterValue\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x04\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowSnmpv2cVariableBindingValueBigCounterValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowSnmpv2cVariableBindingValueUnsignedIntegerValueCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x82\x01\n(PatternFlowSnmpv2cCommonRequestIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x81\x03\n!PatternFlowSnmpv2cCommonRequestId\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowSnmpv2cCommonRequestId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowSnmpv2cCommonRequestIdCounter\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowSnmpv2cCommonRequestIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xd9\x02\n\x1bPatternFlowRsvpRsvpChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowRsvpRsvpChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowRsvpRsvpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\rH\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"z\n PatternFlowRsvpTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x02\n\x19PatternFlowRsvpTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowRsvpTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowRsvpTimeToLiveCounter\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowRsvpTimeToLiveCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"x\n\x1ePatternFlowRsvpReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x02\n\x17PatternFlowRsvpReserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowRsvpReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowRsvpReservedCounter\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowRsvpReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa1\x01\nGPatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x03\n@PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress\x12\x66\n\x06\x63hoice\x18\x01 \x01(\x0e\x32Q.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12_\n\tincrement\x18\x05 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x12_\n\tdecrement\x18\x06 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Ipv4TunnelEndPointAddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x90\x01\n6PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb9\x03\n/PatternFlowRSVPPathSessionLspTunnelIpv4Reserved\x12U\n\x06\x63hoice\x18\x01 \x01(\x0e\x32@.otg.PatternFlowRSVPPathSessionLspTunnelIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12N\n\tincrement\x18\x05 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4ReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x90\x01\n6PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb9\x03\n/PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId\x12U\n\x06\x63hoice\x18\x01 \x01(\x0e\x32@.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12N\n\tincrement\x18\x05 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32;.otg.PatternFlowRSVPPathSessionLspTunnelIpv4TunnelIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSessionExtTunnelIdAsInteger\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSessionExtTunnelIdAsInteger.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIntegerCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8c\x01\n2PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa9\x03\n+PatternFlowRSVPPathSessionExtTunnelIdAsIpv4\x12Q\n\x06\x63hoice\x18\x01 \x01(\x0e\x32<.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x37.otg.PatternFlowRSVPPathSessionExtTunnelIdAsIpv4Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8a\x01\n0PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa1\x03\n)PatternFlowRSVPPathRsvpHopIpv4Ipv4Address\x12O\n\x06\x63hoice\x18\x01 \x01(\x0e\x32:.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x35.otg.PatternFlowRSVPPathRsvpHopIpv4Ipv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x95\x01\n;PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n4PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle\x12Z\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x45.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandle.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12S\n\tincrement\x18\x05 \x01(\x0b\x32@.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x12S\n\tdecrement\x18\x06 \x01(\x0b\x32@.otg.PatternFlowRSVPPathRsvpHopIpv4LogicalInterfaceHandleCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x91\x01\n7PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbd\x03\n0PatternFlowRSVPPathTimeValuesType1RefreshPeriodR\x12V\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x41.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodR.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12O\n\tincrement\x18\x05 \x01(\x0b\x32<.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x12O\n\tdecrement\x18\x06 \x01(\x0b\x32<.otg.PatternFlowRSVPPathTimeValuesType1RefreshPeriodRCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x94\x01\n:PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc9\x03\n3PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12R\n\tincrement\x18\x05 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x12R\n\tdecrement\x18\x06 \x01(\x0b\x32?.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixLBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathExplicitRouteType1Ipv4PrefixIpv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x92\x01\n8PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc1\x03\n1PatternFlowRSVPPathExplicitRouteType1ASNumberLBit\x12W\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x42.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12P\n\tincrement\x18\x05 \x01(\x0b\x32=.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x12P\n\tdecrement\x18\x06 \x01(\x0b\x32=.otg.PatternFlowRSVPPathExplicitRouteType1ASNumberLBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x99\x01\n?PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n8PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved\x12^\n\x06\x63hoice\x18\x01 \x01(\x0e\x32I.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12W\n\tincrement\x18\x05 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x12W\n\tdecrement\x18\x06 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathLabelRequestWithoutLabelRangeL3pidCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa6\x01\nLPatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x91\x04\nEPatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress\x12k\n\x06\x63hoice\x18\x01 \x01(\x0e\x32V.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x64\n\tincrement\x18\x05 \x01(\x0b\x32Q.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x12\x64\n\tdecrement\x18\x06 \x01(\x0b\x32Q.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Ipv4TunnelSenderAddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x97\x01\n=PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd5\x03\n6PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32G.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12U\n\tincrement\x18\x05 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x12U\n\tdecrement\x18\x06 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4ReservedCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x94\x01\n:PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc9\x03\n3PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId\x12Y\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x44.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12R\n\tincrement\x18\x05 \x01(\x0b\x32?.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x12R\n\tdecrement\x18\x06 \x01(\x0b\x32?.otg.PatternFlowRSVPPathSenderTemplateLspTunnelIpv4LspIdCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowRSVPPathSenderTspecIntServVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowRSVPPathSenderTspecIntServVersion\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowRSVPPathSenderTspecIntServVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServVersionCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServVersionCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSenderTspecIntServReserved1\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSenderTspecIntServReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved1Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowRSVPPathSenderTspecIntServOverallLength\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServOverallLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServOverallLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x93\x01\n9PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n2PatternFlowRSVPPathSenderTspecIntServServiceHeader\x12X\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Q\n\tincrement\x18\x05 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x12Q\n\tdecrement\x18\x06 \x01(\x0b\x32>.otg.PatternFlowRSVPPathSenderTspecIntServServiceHeaderCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8d\x01\n3PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xad\x03\n,PatternFlowRSVPPathSenderTspecIntServZeroBit\x12R\n\x06\x63hoice\x18\x01 \x01(\x0e\x32=.otg.PatternFlowRSVPPathSenderTspecIntServZeroBit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x38.otg.PatternFlowRSVPPathSenderTspecIntServZeroBitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x8f\x01\n5PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb5\x03\n.PatternFlowRSVPPathSenderTspecIntServReserved2\x12T\n\x06\x63hoice\x18\x01 \x01(\x0e\x32?.otg.PatternFlowRSVPPathSenderTspecIntServReserved2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12M\n\tincrement\x18\x05 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x12M\n\tdecrement\x18\x06 \x01(\x0b\x32:.otg.PatternFlowRSVPPathSenderTspecIntServReserved2Counter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x99\x01\n?PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n8PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData\x12^\n\x06\x63hoice\x18\x01 \x01(\x0e\x32I.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceData.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12W\n\tincrement\x18\x05 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x12W\n\tdecrement\x18\x06 \x01(\x0b\x32\x44.otg.PatternFlowRSVPPathSenderTspecIntServLengthOfServiceDataCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xa1\x01\nGPatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xfd\x03\n@PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec\x12\x66\n\x06\x63hoice\x18\x01 \x01(\x0e\x32Q.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspec.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12_\n\tincrement\x18\x05 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x12_\n\tdecrement\x18\x06 \x01(\x0b\x32L.otg.PatternFlowRSVPPathSenderTspecIntServParameterIdTokenBucketTspecCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x96\x01\n<PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n5PatternFlowRSVPPathSenderTspecIntServParameter127Flag\x12[\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x46.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Flag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12T\n\tincrement\x18\x05 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x12T\n\tdecrement\x18\x06 \x01(\x0b\x32\x41.otg.PatternFlowRSVPPathSenderTspecIntServParameter127FlagCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x98\x01\n>PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x03\n7PatternFlowRSVPPathSenderTspecIntServParameter127Length\x12]\n\x06\x63hoice\x18\x01 \x01(\x0e\x32H.otg.PatternFlowRSVPPathSenderTspecIntServParameter127Length.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12V\n\tincrement\x18\x05 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x12V\n\tdecrement\x18\x06 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServParameter127LengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x98\x01\n>PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd9\x03\n7PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit\x12]\n\x06\x63hoice\x18\x01 \x01(\x0e\x32H.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12V\n\tincrement\x18\x05 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x12V\n\tdecrement\x18\x06 \x01(\x0b\x32\x43.otg.PatternFlowRSVPPathSenderTspecIntServMinimumPolicedUnitCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x97\x01\n=PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd5\x03\n6PatternFlowRSVPPathSenderTspecIntServMaximumPacketSize\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32G.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12U\n\tincrement\x18\x05 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x12U\n\tdecrement\x18\x06 \x01(\x0b\x32\x42.otg.PatternFlowRSVPPathSenderTspecIntServMaximumPacketSizeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9a\x01\n@PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x03\n9PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address\x12_\n\x06\x63hoice\x18\x01 \x01(\x0e\x32J.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4Address.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12X\n\tincrement\x18\x05 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x12X\n\tdecrement\x18\x06 \x01(\x0b\x32\x45.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressIpv4AddressCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x9b\x01\nAPatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n:PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength\x12`\n\x06\x63hoice\x18\x01 \x01(\x0e\x32K.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12Y\n\tincrement\x18\x05 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x12Y\n\tdecrement\x18\x06 \x01(\x0b\x32\x46.otg.PatternFlowRSVPPathRecordRouteType1Ipv4AddressPrefixLengthCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\xf7\x01\n-PatternFlowRSVPPathRecordRouteType1LabelFlags\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.PatternFlowRSVPPathRecordRouteType1LabelFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\xf7\x01\n-PatternFlowRSVPPathRecordRouteType1LabelCType\x12S\n\x06\x63hoice\x18\x01 \x01(\x0e\x32>.otg.PatternFlowRSVPPathRecordRouteType1LabelCType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_value\"\x85\x01\n+PatternFlowRSVPPathObjectsCustomTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x8d\x03\n$PatternFlowRSVPPathObjectsCustomType\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowRSVPPathObjectsCustomType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\r\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathObjectsCustomTypeCounter\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowRSVPPathObjectsCustomTypeCounter\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_value\"\x91\x01\n\x07Version\x12\x1d\n\x10\x61pi_spec_version\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsdk_version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x61pp_version\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_api_spec_versionB\x0e\n\x0c_sdk_versionB\x0e\n\x0c_app_version\"(\n\x07Success\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"$\n\x07\x46\x61ilure\x12\x19\n\x05\x65rror\x18\x01 \x01(\x0b\x32\n.otg.Error\"/\n\x10SetConfigRequest\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"?\n\x13UpdateConfigRequest\x12(\n\rconfig_update\x18\x01 \x01(\x0b\x32\x11.otg.ConfigUpdate\"2\n\x11SetConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"0\n\x11GetConfigResponse\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"5\n\x14UpdateConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"B\n\x16SetControlStateRequest\x12(\n\rcontrol_state\x18\x01 \x01(\x0b\x32\x11.otg.ControlState\"8\n\x17SetControlStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"E\n\x17SetControlActionRequest\x12*\n\x0e\x63ontrol_action\x18\x01 \x01(\x0b\x32\x12.otg.ControlAction\"W\n\x18SetControlActionResponse\x12;\n\x17\x63ontrol_action_response\x18\x01 \x01(\x0b\x32\x1a.otg.ControlActionResponse\"A\n\x11GetMetricsRequest\x12,\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x13.otg.MetricsRequest\"D\n\x12GetMetricsResponse\x12.\n\x10metrics_response\x18\x01 \x01(\x0b\x32\x14.otg.MetricsResponse\">\n\x10GetStatesRequest\x12*\n\x0estates_request\x18\x01 \x01(\x0b\x32\x12.otg.StatesRequest\"A\n\x11GetStatesResponse\x12,\n\x0fstates_response\x18\x01 \x01(\x0b\x32\x13.otg.StatesResponse\"A\n\x11GetCaptureRequest\x12,\n\x0f\x63\x61pture_request\x18\x01 \x01(\x0b\x32\x13.otg.CaptureRequest\",\n\x12GetCaptureResponse\x12\x16\n\x0eresponse_bytes\x18\x01 \x01(\x0c\"3\n\x12GetVersionResponse\x12\x1d\n\x07version\x18\x01 \x01(\x0b\x32\x0c.otg.Version2\xdf\x04\n\x07Openapi\x12:\n\tSetConfig\x12\x15.otg.SetConfigRequest\x1a\x16.otg.SetConfigResponse\x12;\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a\x16.otg.GetConfigResponse\x12\x43\n\x0cUpdateConfig\x12\x18.otg.UpdateConfigRequest\x1a\x19.otg.UpdateConfigResponse\x12L\n\x0fSetControlState\x12\x1b.otg.SetControlStateRequest\x1a\x1c.otg.SetControlStateResponse\x12O\n\x10SetControlAction\x12\x1c.otg.SetControlActionRequest\x1a\x1d.otg.SetControlActionResponse\x12=\n\nGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\x17.otg.GetMetricsResponse\x12:\n\tGetStates\x12\x15.otg.GetStatesRequest\x1a\x16.otg.GetStatesResponse\x12=\n\nGetCapture\x12\x16.otg.GetCaptureRequest\x1a\x17.otg.GetCaptureResponse\x12=\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x17.otg.GetVersionResponseB\x0bZ\t./otg;otgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'otg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\t./otg;otg'
  _globals['_CONFIG']._serialized_start=82
  _globals['_CONFIG']._serialized_end=347
  _globals['_CONFIGOPTIONS']._serialized_start=349
  _globals['_CONFIGOPTIONS']._serialized_end=452
  _globals['_PORT']._serialized_start=454
  _globals['_PORT']._serialized_end=524
  _globals['_PORTOPTIONS']._serialized_start=526
  _globals['_PORTOPTIONS']._serialized_end=597
  _globals['_LAG']._serialized_start=600
  _globals['_LAG']._serialized_end=736
  _globals['_LAGPORT']._serialized_start=738
  _globals['_LAGPORT']._serialized_end=860
  _globals['_LAGPROTOCOL']._serialized_start=863
  _globals['_LAGPROTOCOL']._serialized_end=1071
  _globals['_LAGPROTOCOL_CHOICE']._serialized_start=1005
  _globals['_LAGPROTOCOL_CHOICE']._serialized_end=1060
  _globals['_LAGPROTOCOL_CHOICE_ENUM']._serialized_start=1015
  _globals['_LAGPROTOCOL_CHOICE_ENUM']._serialized_end=1060
  _globals['_LAGPROTOCOLSTATIC']._serialized_start=1073
  _globals['_LAGPROTOCOLSTATIC']._serialized_end=1124
  _globals['_LAGPROTOCOLLACP']._serialized_start=1127
  _globals['_LAGPROTOCOLLACP']._serialized_end=1294
  _globals['_LAGPORTLACP']._serialized_start=1297
  _globals['_LAGPORTLACP']._serialized_end=1700
  _globals['_LAGPORTLACP_ACTORACTIVITY']._serialized_start=1517
  _globals['_LAGPORTLACP_ACTORACTIVITY']._serialized_end=1582
  _globals['_LAGPORTLACP_ACTORACTIVITY_ENUM']._serialized_start=1534
  _globals['_LAGPORTLACP_ACTORACTIVITY_ENUM']._serialized_end=1582
  _globals['_DEVICEETHERNETBASE']._serialized_start=1703
  _globals['_DEVICEETHERNETBASE']._serialized_end=1835
  _globals['_DEVICEETHERNET']._serialized_start=1838
  _globals['_DEVICEETHERNET']._serialized_end=2197
  _globals['_ETHERNETCONNECTION']._serialized_start=2200
  _globals['_ETHERNETCONNECTION']._serialized_end=2555
  _globals['_ETHERNETCONNECTION_CHOICE']._serialized_start=2404
  _globals['_ETHERNETCONNECTION_CHOICE']._serialized_end=2502
  _globals['_ETHERNETCONNECTION_CHOICE_ENUM']._serialized_start=2414
  _globals['_ETHERNETCONNECTION_CHOICE_ENUM']._serialized_end=2502
  _globals['_ETHERNETSIMULATEDLINK']._serialized_start=2558
  _globals['_ETHERNETSIMULATEDLINK']._serialized_end=2788
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE']._serialized_start=2685
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE']._serialized_end=2748
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE_ENUM']._serialized_start=2697
  _globals['_ETHERNETSIMULATEDLINK_LINKTYPE_ENUM']._serialized_end=2748
  _globals['_DEVICEVLAN']._serialized_start=2791
  _globals['_DEVICEVLAN']._serialized_end=3034
  _globals['_DEVICEVLAN_TPID']._serialized_start=2910
  _globals['_DEVICEVLAN_TPID']._serialized_end=2996
  _globals['_DEVICEVLAN_TPID_ENUM']._serialized_start=2918
  _globals['_DEVICEVLAN_TPID_ENUM']._serialized_end=2996
  _globals['_DEVICEIPV4']._serialized_start=3037
  _globals['_DEVICEIPV4']._serialized_end=3225
  _globals['_DEVICEIPV4LOOPBACK']._serialized_start=3227
  _globals['_DEVICEIPV4LOOPBACK']._serialized_end=3345
  _globals['_DEVICEIPV4GATEWAYMAC']._serialized_start=3348
  _globals['_DEVICEIPV4GATEWAYMAC']._serialized_end=3555
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE']._serialized_start=3471
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE']._serialized_end=3525
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE_ENUM']._serialized_start=3481
  _globals['_DEVICEIPV4GATEWAYMAC_CHOICE_ENUM']._serialized_end=3525
  _globals['_DEVICEIPV6']._serialized_start=3558
  _globals['_DEVICEIPV6']._serialized_end=3746
  _globals['_DEVICEIPV6LOOPBACK']._serialized_start=3748
  _globals['_DEVICEIPV6LOOPBACK']._serialized_end=3866
  _globals['_DEVICEIPV6GATEWAYMAC']._serialized_start=3869
  _globals['_DEVICEIPV6GATEWAYMAC']._serialized_end=4076
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE']._serialized_start=3471
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE']._serialized_end=3525
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE_ENUM']._serialized_start=3481
  _globals['_DEVICEIPV6GATEWAYMAC_CHOICE_ENUM']._serialized_end=3525
  _globals['_DEVICEDHCPV4CLIENT']._serialized_start=4079
  _globals['_DEVICEDHCPV4CLIENT']._serialized_end=4413
  _globals['_DEVICEDHCPV4CLIENT_CHOICE']._serialized_start=4289
  _globals['_DEVICEDHCPV4CLIENT_CHOICE']._serialized_end=4360
  _globals['_DEVICEDHCPV4CLIENT_CHOICE_ENUM']._serialized_start=4299
  _globals['_DEVICEDHCPV4CLIENT_CHOICE_ENUM']._serialized_end=4360
  _globals['_DHCPV4CLIENTPARAMS']._serialized_start=4416
  _globals['_DHCPV4CLIENTPARAMS']._serialized_end=4606
  _globals['_DEVICEDHCPV6CLIENT']._serialized_start=4609
  _globals['_DEVICEDHCPV6CLIENT']._serialized_end=4914
  _globals['_DEVICEDHCPV6CLIENTOPTIONSREQUEST']._serialized_start=4917
  _globals['_DEVICEDHCPV6CLIENTOPTIONSREQUEST']._serialized_end=5084
  _globals['_DEVICEDHCPV6CLIENTOPTIONS']._serialized_start=5087
  _globals['_DEVICEDHCPV6CLIENTOPTIONS']._serialized_end=5343
  _globals['_DEVICEDHCPV6CLIENTIATYPE']._serialized_start=5346
  _globals['_DEVICEDHCPV6CLIENTIATYPE']._serialized_end=5676
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE']._serialized_start=5590
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE']._serialized_end=5665
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE_ENUM']._serialized_start=5600
  _globals['_DEVICEDHCPV6CLIENTIATYPE_CHOICE_ENUM']._serialized_end=5665
  _globals['_DEVICEDHCPV6CLIENTIATIMEVALUE']._serialized_start=5678
  _globals['_DEVICEDHCPV6CLIENTIATIMEVALUE']._serialized_end=5757
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE']._serialized_start=5760
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE']._serialized_end=6058
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE']._serialized_start=5989
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE']._serialized_end=6047
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE_ENUM']._serialized_start=5999
  _globals['_DEVICEDHCPV6CLIENTDUIDTYPE_CHOICE_ENUM']._serialized_end=6047
  _globals['_DEVICEDHCPV6CLIENTDUIDVALUE']._serialized_start=6060
  _globals['_DEVICEDHCPV6CLIENTDUIDVALUE']._serialized_end=6173
  _globals['_DEVICEDHCPV6CLIENTNODUID']._serialized_start=6175
  _globals['_DEVICEDHCPV6CLIENTNODUID']._serialized_end=6201
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER']._serialized_start=6204
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER']._serialized_end=6619
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE']._serialized_start=6520
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE']._serialized_end=6608
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE_ENUM']._serialized_start=6530
  _globals['_DHCPV6CLIENTOPTIONSSERVERIDENTIFIER_CHOICE_ENUM']._serialized_end=6608
  _globals['_DHCPV6CLIENTOPTIONSDUIDLLT']._serialized_start=6621
  _globals['_DHCPV6CLIENTOPTIONSDUIDLLT']._serialized_end=6747
  _globals['_DHCPV6CLIENTOPTIONSDUIDEN']._serialized_start=6749
  _globals['_DHCPV6CLIENTOPTIONSDUIDEN']._serialized_end=6870
  _globals['_DHCPV6CLIENTOPTIONSDUIDLL']._serialized_start=6872
  _globals['_DHCPV6CLIENTOPTIONSDUIDLL']._serialized_end=6969
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUID']._serialized_start=6972
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUID']._serialized_end=7391
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION']._serialized_start=7394
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION']._serialized_end=7595
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE']._serialized_start=7506
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE']._serialized_end=7584
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE_ENUM']._serialized_start=7516
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVERSION_CHOICE_ENUM']._serialized_end=7584
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT']._serialized_start=7598
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT']._serialized_end=7800
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE']._serialized_start=7710
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE']._serialized_end=7789
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE_ENUM']._serialized_start=7720
  _globals['_DHCPV6CLIENTOPTIONSDUIDUUIDVARIANT_CHOICE_ENUM']._serialized_end=7789
  _globals['_DHCPV6CLIENTOPTIONSLINKLAYERADDRESS']._serialized_start=7802
  _globals['_DHCPV6CLIENTOPTIONSLINKLAYERADDRESS']._serialized_end=7869
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST']._serialized_start=7872
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST']._serialized_end=8166
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE']._serialized_start=8030
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE']._serialized_end=8155
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE_ENUM']._serialized_start=8040
  _globals['_DHCPV6CLIENTOPTIONSOPTIONSREQUEST_CHOICE_ENUM']._serialized_end=8155
  _globals['_DHCPV6CLIENTOPTIONSCUSTOM']._serialized_start=8168
  _globals['_DHCPV6CLIENTOPTIONSCUSTOM']._serialized_end=8223
  _globals['_DHCPV6CLIENTOPTIONSVENDORCLASS']._serialized_start=8226
  _globals['_DHCPV6CLIENTOPTIONSVENDORCLASS']._serialized_end=8408
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES']._serialized_start=8411
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES']._serialized_end=8649
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_start=8581
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_end=8638
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_start=8591
  _globals['_DHCPV6CLIENTOPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_end=8638
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE']._serialized_start=8652
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE']._serialized_end=8882
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE']._serialized_start=8756
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE']._serialized_end=8871
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_start=8766
  _globals['_DHCPV6CLIENTOPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_end=8871
  _globals['_DHCPV6CLIENTOPTIONSVENDORINFO']._serialized_start=8885
  _globals['_DHCPV6CLIENTOPTIONSVENDORINFO']._serialized_end=9108
  _globals['_DHCPV6SERVEROPTIONSVENDORINFO']._serialized_start=9111
  _globals['_DHCPV6SERVEROPTIONSVENDORINFO']._serialized_end=9334
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES']._serialized_start=9337
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES']._serialized_end=9575
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_start=8581
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE']._serialized_end=8638
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_start=8591
  _globals['_DHCPV6SERVEROPTIONSINCLUDEDMESSAGES_CHOICE_ENUM']._serialized_end=8638
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE']._serialized_start=9578
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE']._serialized_end=9770
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE']._serialized_start=9682
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE']._serialized_end=9759
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_start=9692
  _globals['_DHCPV6SERVEROPTIONSMESSAGETYPE_CHOICE_ENUM']._serialized_end=9759
  _globals['_DHCPV6OPTIONSVENDORSPECIFICOPTIONS']._serialized_start=9772
  _globals['_DHCPV6OPTIONSVENDORSPECIFICOPTIONS']._serialized_end=9864
  _globals['_DHCPV6CLIENTOPTIONSFQDN']._serialized_start=9867
  _globals['_DHCPV6CLIENTOPTIONSFQDN']._serialized_end=10106
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEURL']._serialized_start=10109
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEURL']._serialized_end=10308
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEPARAMS']._serialized_start=10310
  _globals['_DHCPV6SERVEROPTIONSBOOTFILEPARAMS']._serialized_end=10383
  _globals['_LAYER1']._serialized_start=10386
  _globals['_LAYER1']._serialized_end=11192
  _globals['_LAYER1_SPEED']._serialized_start=10731
  _globals['_LAYER1_SPEED']._serialized_end=11028
  _globals['_LAYER1_SPEED_ENUM']._serialized_start=10741
  _globals['_LAYER1_SPEED_ENUM']._serialized_end=11028
  _globals['_LAYER1_MEDIA']._serialized_start=11030
  _globals['_LAYER1_MEDIA']._serialized_end=11096
  _globals['_LAYER1_MEDIA_ENUM']._serialized_start=11039
  _globals['_LAYER1_MEDIA_ENUM']._serialized_end=11096
  _globals['_LAYER1AUTONEGOTIATION']._serialized_start=11195
  _globals['_LAYER1AUTONEGOTIATION']._serialized_end=11598
  _globals['_LAYER1FLOWCONTROL']._serialized_start=11601
  _globals['_LAYER1FLOWCONTROL']._serialized_end=11901
  _globals['_LAYER1FLOWCONTROL_CHOICE']._serialized_start=11800
  _globals['_LAYER1FLOWCONTROL_CHOICE']._serialized_end=11869
  _globals['_LAYER1FLOWCONTROL_CHOICE_ENUM']._serialized_start=11810
  _globals['_LAYER1FLOWCONTROL_CHOICE_ENUM']._serialized_end=11869
  _globals['_LAYER1IEEE8023X']._serialized_start=11903
  _globals['_LAYER1IEEE8023X']._serialized_end=11920
  _globals['_LAYER1IEEE8021QBB']._serialized_start=11923
  _globals['_LAYER1IEEE8021QBB']._serialized_end=12316
  _globals['_CAPTURE']._serialized_start=12319
  _globals['_CAPTURE']._serialized_end=12608
  _globals['_CAPTURE_FORMAT']._serialized_start=12503
  _globals['_CAPTURE_FORMAT']._serialized_end=12558
  _globals['_CAPTURE_FORMAT_ENUM']._serialized_start=12513
  _globals['_CAPTURE_FORMAT_ENUM']._serialized_end=12558
  _globals['_CAPTUREFILTER']._serialized_start=12611
  _globals['_CAPTUREFILTER']._serialized_end=12953
  _globals['_CAPTUREFILTER_CHOICE']._serialized_start=12853
  _globals['_CAPTUREFILTER_CHOICE']._serialized_end=12942
  _globals['_CAPTUREFILTER_CHOICE_ENUM']._serialized_start=12863
  _globals['_CAPTUREFILTER_CHOICE_ENUM']._serialized_end=12942
  _globals['_CAPTURECUSTOM']._serialized_start=12956
  _globals['_CAPTURECUSTOM']._serialized_end=13133
  _globals['_CAPTUREFIELD']._serialized_start=13135
  _globals['_CAPTUREFIELD']._serialized_end=13239
  _globals['_CAPTUREETHERNET']._serialized_start=13242
  _globals['_CAPTUREETHERNET']._serialized_end=13400
  _globals['_CAPTUREVLAN']._serialized_start=13403
  _globals['_CAPTUREVLAN']._serialized_end=13553
  _globals['_CAPTUREIPV4']._serialized_start=13556
  _globals['_CAPTUREIPV4']._serialized_end=14120
  _globals['_CAPTUREIPV6']._serialized_start=14123
  _globals['_CAPTUREIPV6']._serialized_end=14438
  _globals['_DEVICE']._serialized_start=14441
  _globals['_DEVICE']._serialized_end=14871
  _globals['_PROTOCOLOPTIONS']._serialized_start=14873
  _globals['_PROTOCOLOPTIONS']._serialized_end=14938
  _globals['_DEVICEISISROUTER']._serialized_start=14941
  _globals['_DEVICEISISROUTER']._serialized_end=15361
  _globals['_DEVICEISISMULTIINSTANCE']._serialized_start=15363
  _globals['_DEVICEISISMULTIINSTANCE']._serialized_end=15429
  _globals['_ISISINTERFACE']._serialized_start=15432
  _globals['_ISISINTERFACE']._serialized_end=16273
  _globals['_ISISINTERFACE_NETWORKTYPE']._serialized_start=16056
  _globals['_ISISINTERFACE_NETWORKTYPE']._serialized_end=16129
  _globals['_ISISINTERFACE_NETWORKTYPE_ENUM']._serialized_start=16071
  _globals['_ISISINTERFACE_NETWORKTYPE_ENUM']._serialized_end=16129
  _globals['_ISISINTERFACE_LEVELTYPE']._serialized_start=16131
  _globals['_ISISINTERFACE_LEVELTYPE']._serialized_end=16208
  _globals['_ISISINTERFACE_LEVELTYPE_ENUM']._serialized_start=16144
  _globals['_ISISINTERFACE_LEVELTYPE_ENUM']._serialized_end=16208
  _globals['_ISISINTERFACELEVEL']._serialized_start=16276
  _globals['_ISISINTERFACELEVEL']._serialized_end=16426
  _globals['_ISISMT']._serialized_start=16428
  _globals['_ISISMT']._serialized_end=16508
  _globals['_LINKSTATETE']._serialized_start=16511
  _globals['_LINKSTATETE']._serialized_end=16803
  _globals['_LINKSTATEPRIORITYBANDWIDTHS']._serialized_start=16806
  _globals['_LINKSTATEPRIORITYBANDWIDTHS']._serialized_end=17043
  _globals['_ISISINTERFACEAUTHENTICATION']._serialized_start=17046
  _globals['_ISISINTERFACEAUTHENTICATION']._serialized_end=17283
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE']._serialized_start=17190
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE']._serialized_end=17248
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM']._serialized_start=17202
  _globals['_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM']._serialized_end=17248
  _globals['_ISISINTERFACEADVANCED']._serialized_start=17286
  _globals['_ISISINTERFACEADVANCED']._serialized_end=17625
  _globals['_ISISINTERFACELINKPROTECTION']._serialized_start=17628
  _globals['_ISISINTERFACELINKPROTECTION']._serialized_end=18005
  _globals['_ISISINTERFACEADJACENCYSID']._serialized_start=18008
  _globals['_ISISINTERFACEADJACENCYSID']._serialized_end=18412
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE']._serialized_start=18269
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE']._serialized_end=18335
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE_ENUM']._serialized_start=18279
  _globals['_ISISINTERFACEADJACENCYSID_CHOICE_ENUM']._serialized_end=18335
  _globals['_ISISBASIC']._serialized_start=18415
  _globals['_ISISBASIC']._serialized_end=18628
  _globals['_ISISADVANCED']._serialized_start=18631
  _globals['_ISISADVANCED']._serialized_end=19153
  _globals['_ISISAUTHENTICATION']._serialized_start=19156
  _globals['_ISISAUTHENTICATION']._serialized_end=19330
  _globals['_ISISAUTHENTICATIONBASE']._serialized_start=19333
  _globals['_ISISAUTHENTICATIONBASE']._serialized_end=19560
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE']._serialized_start=17190
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE']._serialized_end=17248
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM']._serialized_start=17202
  _globals['_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM']._serialized_end=17248
  _globals['_ISISV4ROUTERANGE']._serialized_start=19563
  _globals['_ISISV4ROUTERANGE']._serialized_end=20206
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE']._serialized_start=19954
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE']._serialized_end=20019
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE_ENUM']._serialized_start=19968
  _globals['_ISISV4ROUTERANGE_ORIGINTYPE_ENUM']._serialized_end=20019
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_start=20021
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_end=20084
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20043
  _globals['_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20084
  _globals['_V4ROUTEADDRESS']._serialized_start=20209
  _globals['_V4ROUTEADDRESS']._serialized_end=20349
  _globals['_V6ROUTEADDRESS']._serialized_start=20352
  _globals['_V6ROUTEADDRESS']._serialized_end=20492
  _globals['_MACROUTEADDRESS']._serialized_start=20495
  _globals['_MACROUTEADDRESS']._serialized_end=20636
  _globals['_ISISSRPREFIXSID']._serialized_start=20639
  _globals['_ISISSRPREFIXSID']._serialized_end=21029
  _globals['_ISISSRPREFIXSID_CHOICE']._serialized_start=18269
  _globals['_ISISSRPREFIXSID_CHOICE']._serialized_end=18335
  _globals['_ISISSRPREFIXSID_CHOICE_ENUM']._serialized_start=18279
  _globals['_ISISSRPREFIXSID_CHOICE_ENUM']._serialized_end=18335
  _globals['_ISISV6ROUTERANGE']._serialized_start=21032
  _globals['_ISISV6ROUTERANGE']._serialized_end=21675
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE']._serialized_start=19954
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE']._serialized_end=20019
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE_ENUM']._serialized_start=19968
  _globals['_ISISV6ROUTERANGE_ORIGINTYPE_ENUM']._serialized_end=20019
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_start=20021
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE']._serialized_end=20084
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20043
  _globals['_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20084
  _globals['_ISISSEGMENTROUTING']._serialized_start=21677
  _globals['_ISISSEGMENTROUTING']._serialized_end=21751
  _globals['_ISISROUTERCAPABILITY']._serialized_start=21754
  _globals['_ISISROUTERCAPABILITY']._serialized_end=22363
  _globals['_ISISROUTERCAPABILITY_CHOICE']._serialized_start=22091
  _globals['_ISISROUTERCAPABILITY_CHOICE']._serialized_end=22191
  _globals['_ISISROUTERCAPABILITY_CHOICE_ENUM']._serialized_start=22101
  _globals['_ISISROUTERCAPABILITY_CHOICE_ENUM']._serialized_end=22191
  _globals['_ISISROUTERCAPABILITY_SBIT']._serialized_start=22193
  _globals['_ISISROUTERCAPABILITY_SBIT']._serialized_end=22250
  _globals['_ISISROUTERCAPABILITY_SBIT_ENUM']._serialized_start=22201
  _globals['_ISISROUTERCAPABILITY_SBIT_ENUM']._serialized_end=22250
  _globals['_ISISROUTERCAPABILITY_DBIT']._serialized_start=22252
  _globals['_ISISROUTERCAPABILITY_DBIT']._serialized_end=22307
  _globals['_ISISROUTERCAPABILITY_DBIT_ENUM']._serialized_start=22260
  _globals['_ISISROUTERCAPABILITY_DBIT_ENUM']._serialized_end=22307
  _globals['_ISISSRCAPABILITY']._serialized_start=22365
  _globals['_ISISSRCAPABILITY']._serialized_end=22464
  _globals['_ISISSRCAPABILITYFLAGS']._serialized_start=22466
  _globals['_ISISSRCAPABILITYFLAGS']._serialized_end=22565
  _globals['_ISISSRSRGB']._serialized_start=22567
  _globals['_ISISSRSRGB']._serialized_end=22653
  _globals['_ISISSRSRLB']._serialized_start=22655
  _globals['_ISISSRSRLB']._serialized_end=22741
  _globals['_DEVICEBGPROUTER']._serialized_start=22744
  _globals['_DEVICEBGPROUTER']._serialized_end=22891
  _globals['_DEVICEBGPMESSAGEHEADERERROR']._serialized_start=22894
  _globals['_DEVICEBGPMESSAGEHEADERERROR']._serialized_end=23166
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE']._serialized_start=22995
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE']._serialized_end=23154
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM']._serialized_start=23007
  _globals['_DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM']._serialized_end=23154
  _globals['_DEVICEBGPOPENMESSAGEERROR']._serialized_start=23169
  _globals['_DEVICEBGPOPENMESSAGEERROR']._serialized_end=23595
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE']._serialized_start=23266
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE']._serialized_end=23583
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM']._serialized_start=23278
  _globals['_DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM']._serialized_end=23583
  _globals['_DEVICEBGPUPDATEMESSAGEERROR']._serialized_start=23598
  _globals['_DEVICEBGPUPDATEMESSAGEERROR']._serialized_end=24202
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE']._serialized_start=23699
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE']._serialized_end=24190
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM']._serialized_start=23711
  _globals['_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM']._serialized_end=24190
  _globals['_DEVICEBGPHOLDTIMEREXPIRED']._serialized_start=24204
  _globals['_DEVICEBGPHOLDTIMEREXPIRED']._serialized_end=24231
  _globals['_DEVICEBGPFINITESTATEMACHINEERROR']._serialized_start=24233
  _globals['_DEVICEBGPFINITESTATEMACHINEERROR']._serialized_end=24267
  _globals['_DEVICEBGPCEASEERROR']._serialized_start=24270
  _globals['_DEVICEBGPCEASEERROR']._serialized_end=24785
  _globals['_DEVICEBGPCEASEERROR_SUBCODE']._serialized_start=24355
  _globals['_DEVICEBGPCEASEERROR_SUBCODE']._serialized_end=24773
  _globals['_DEVICEBGPCEASEERROR_SUBCODE_ENUM']._serialized_start=24367
  _globals['_DEVICEBGPCEASEERROR_SUBCODE_ENUM']._serialized_end=24773
  _globals['_DEVICEBGPCUSTOMERROR']._serialized_start=24787
  _globals['_DEVICEBGPCUSTOMERROR']._serialized_end=24871
  _globals['_BGPV4PEER']._serialized_start=24874
  _globals['_BGPV4PEER']._serialized_end=25738
  _globals['_BGPV4PEER_ASTYPE']._serialized_start=25552
  _globals['_BGPV4PEER_ASTYPE']._serialized_end=25605
  _globals['_BGPV4PEER_ASTYPE_ENUM']._serialized_start=25562
  _globals['_BGPV4PEER_ASTYPE_ENUM']._serialized_end=25605
  _globals['_BGPV4PEER_ASNUMBERWIDTH']._serialized_start=25607
  _globals['_BGPV4PEER_ASNUMBERWIDTH']._serialized_end=25666
  _globals['_BGPV4PEER_ASNUMBERWIDTH_ENUM']._serialized_start=25624
  _globals['_BGPV4PEER_ASNUMBERWIDTH_ENUM']._serialized_end=25666
  _globals['_BGPV4INTERFACE']._serialized_start=25740
  _globals['_BGPV4INTERFACE']._serialized_end=25825
  _globals['_BGPV4ETHERNETSEGMENT']._serialized_start=25828
  _globals['_BGPV4ETHERNETSEGMENT']._serialized_end=26324
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE']._serialized_start=26214
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE']._serialized_end=26286
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_start=26228
  _globals['_BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_end=26286
  _globals['_BGPETHERNETSEGMENTDFELECTION']._serialized_start=26326
  _globals['_BGPETHERNETSEGMENTDFELECTION']._serialized_end=26404
  _globals['_BGPROUTEADVANCED']._serialized_start=26407
  _globals['_BGPROUTEADVANCED']._serialized_end=26881
  _globals['_BGPROUTEADVANCED_ORIGIN']._serialized_start=26668
  _globals['_BGPROUTEADVANCED_ORIGIN']._serialized_end=26735
  _globals['_BGPROUTEADVANCED_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPROUTEADVANCED_ORIGIN_ENUM']._serialized_end=26735
  _globals['_BGPCOMMUNITY']._serialized_start=26884
  _globals['_BGPCOMMUNITY']._serialized_end=27176
  _globals['_BGPCOMMUNITY_TYPE']._serialized_start=26997
  _globals['_BGPCOMMUNITY_TYPE']._serialized_end=27139
  _globals['_BGPCOMMUNITY_TYPE_ENUM']._serialized_start=27006
  _globals['_BGPCOMMUNITY_TYPE_ENUM']._serialized_end=27139
  _globals['_BGPEXTCOMMUNITY']._serialized_start=27179
  _globals['_BGPEXTCOMMUNITY']._serialized_end=27684
  _globals['_BGPEXTCOMMUNITY_TYPE']._serialized_start=27327
  _globals['_BGPEXTCOMMUNITY_TYPE']._serialized_end=27515
  _globals['_BGPEXTCOMMUNITY_TYPE_ENUM']._serialized_start=27336
  _globals['_BGPEXTCOMMUNITY_TYPE_ENUM']._serialized_end=27515
  _globals['_BGPEXTCOMMUNITY_SUBTYPE']._serialized_start=27518
  _globals['_BGPEXTCOMMUNITY_SUBTYPE']._serialized_end=27653
  _globals['_BGPEXTCOMMUNITY_SUBTYPE_ENUM']._serialized_start=27529
  _globals['_BGPEXTCOMMUNITY_SUBTYPE_ENUM']._serialized_end=27653
  _globals['_BGPASPATH']._serialized_start=27687
  _globals['_BGPASPATH']._serialized_end=28005
  _globals['_BGPASPATH_ASSETMODE']._serialized_start=27799
  _globals['_BGPASPATH_ASSETMODE']._serialized_end=27989
  _globals['_BGPASPATH_ASSETMODE_ENUM']._serialized_start=27813
  _globals['_BGPASPATH_ASSETMODE_ENUM']._serialized_end=27989
  _globals['_BGPASPATHSEGMENT']._serialized_start=28008
  _globals['_BGPASPATHSEGMENT']._serialized_end=28202
  _globals['_BGPASPATHSEGMENT_TYPE']._serialized_start=28100
  _globals['_BGPASPATHSEGMENT_TYPE']._serialized_end=28193
  _globals['_BGPASPATHSEGMENT_TYPE_ENUM']._serialized_start=28108
  _globals['_BGPASPATHSEGMENT_TYPE_ENUM']._serialized_end=28193
  _globals['_BGPV4EVPNEVIS']._serialized_start=28205
  _globals['_BGPV4EVPNEVIS']._serialized_end=28373
  _globals['_BGPV4EVPNEVIS_CHOICE']._serialized_start=28314
  _globals['_BGPV4EVPNEVIS_CHOICE']._serialized_end=28362
  _globals['_BGPV4EVPNEVIS_CHOICE_ENUM']._serialized_start=28324
  _globals['_BGPV4EVPNEVIS_CHOICE_ENUM']._serialized_end=28362
  _globals['_BGPV4EVIVXLAN']._serialized_start=28376
  _globals['_BGPV4EVIVXLAN']._serialized_end=29115
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE']._serialized_start=28999
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE']._serialized_end=29066
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_start=29018
  _globals['_BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_end=29066
  _globals['_BGPV4EVIVXLANBROADCASTDOMAIN']._serialized_start=29118
  _globals['_BGPV4EVIVXLANBROADCASTDOMAIN']._serialized_end=29298
  _globals['_BGPCMACIPRANGE']._serialized_start=29301
  _globals['_BGPCMACIPRANGE']._serialized_end=29767
  _globals['_BGPROUTEDISTINGUISHER']._serialized_start=29770
  _globals['_BGPROUTEDISTINGUISHER']._serialized_end=30050
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE']._serialized_start=29917
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE']._serialized_end=29998
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE_ENUM']._serialized_start=29927
  _globals['_BGPROUTEDISTINGUISHER_RDTYPE_ENUM']._serialized_end=29998
  _globals['_BGPROUTETARGET']._serialized_start=30053
  _globals['_BGPROUTETARGET']._serialized_end=30255
  _globals['_BGPROUTETARGET_RTTYPE']._serialized_start=30149
  _globals['_BGPROUTETARGET_RTTYPE']._serialized_end=30230
  _globals['_BGPROUTETARGET_RTTYPE_ENUM']._serialized_start=29927
  _globals['_BGPROUTETARGET_RTTYPE_ENUM']._serialized_end=29998
  _globals['_BGPADVANCED']._serialized_start=30258
  _globals['_BGPADVANCED']._serialized_end=30645
  _globals['_BGPCAPABILITY']._serialized_start=30648
  _globals['_BGPCAPABILITY']._serialized_end=31945
  _globals['_BGPLEARNEDINFORMATIONFILTER']._serialized_start=31948
  _globals['_BGPLEARNEDINFORMATIONFILTER']._serialized_end=32093
  _globals['_BGPV4ROUTERANGE']._serialized_start=32096
  _globals['_BGPV4ROUTERANGE']._serialized_end=32884
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE']._serialized_start=32648
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE']._serialized_end=32712
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_start=32663
  _globals['_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_end=32712
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_start=32714
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_end=32779
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=32736
  _globals['_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=32779
  _globals['_BGPADDPATH']._serialized_start=32886
  _globals['_BGPADDPATH']._serialized_end=32932
  _globals['_BGPEXTENDEDCOMMUNITY']._serialized_start=32935
  _globals['_BGPEXTENDEDCOMMUNITY']._serialized_end=33818
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE']._serialized_start=33576
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE']._serialized_end=33807
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE_ENUM']._serialized_start=33587
  _globals['_BGPEXTENDEDCOMMUNITY_CHOICE_ENUM']._serialized_end=33807
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_start=33821
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_end=33980
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_start=33983
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_end=34142
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_start=34145
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_end=34549
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=34453
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_start=34552
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_end=34718
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_start=34721
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_end=34887
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_start=34890
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_end=35306
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_start=34453
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_start=35309
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_end=35468
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_start=35471
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_end=35630
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_start=35633
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_end=36037
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_start=34453
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_start=36039
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_end=36146
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_start=36149
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_end=36282
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_start=36285
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_end=36665
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_start=36575
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_end=36654
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_start=36585
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_end=36654
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPEROUTERMAC']._serialized_start=36667
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPEROUTERMAC']._serialized_end=36756
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE']._serialized_start=36759
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE']._serialized_end=37029
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE']._serialized_start=36961
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE']._serialized_end=37018
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE_ENUM']._serialized_start=36971
  _globals['_BGPEXTENDEDCOMMUNITYTRANSITIVEEVPNTYPE_CHOICE_ENUM']._serialized_end=37018
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_start=37032
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_end=37180
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_start=37183
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_end=37486
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=37414
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=37475
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=37424
  _globals['_BGPEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=37475
  _globals['_BGPEXTENDEDCOMMUNITYCUSTOMTYPE']._serialized_start=37489
  _globals['_BGPEXTENDEDCOMMUNITYCUSTOMTYPE']._serialized_end=37653
  _globals['_BGPV6ROUTERANGE']._serialized_start=37656
  _globals['_BGPV6ROUTERANGE']._serialized_end=38444
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE']._serialized_start=32648
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE']._serialized_end=32712
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_start=32663
  _globals['_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM']._serialized_end=32712
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_start=32714
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE']._serialized_end=32779
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=32736
  _globals['_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=32779
  _globals['_BGPSRTEV4POLICY']._serialized_start=38447
  _globals['_BGPSRTEV4POLICY']._serialized_end=39338
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE']._serialized_start=32648
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE']._serialized_end=32712
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM']._serialized_start=32663
  _globals['_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM']._serialized_end=32712
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE']._serialized_start=32714
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE']._serialized_end=32779
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=32736
  _globals['_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=32779
  _globals['_BGPSRTEV4TUNNELTLV']._serialized_start=39341
  _globals['_BGPSRTEV4TUNNELTLV']._serialized_end=39907
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV']._serialized_start=39910
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV']._serialized_end=40228
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY']._serialized_start=40101
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY']._serialized_end=40161
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM']._serialized_start=32736
  _globals['_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM']._serialized_end=32779
  _globals['_BGPSRTECOLORSUBTLV']._serialized_start=40230
  _globals['_BGPSRTECOLORSUBTLV']._serialized_end=40280
  _globals['_BGPSRTEBINDINGSUBTLV']._serialized_start=40283
  _globals['_BGPSRTEBINDINGSUBTLV']._serialized_end=40645
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE']._serialized_start=40479
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE']._serialized_end=40570
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM']._serialized_start=40497
  _globals['_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM']._serialized_end=40570
  _globals['_BGPSRTEPREFERENCESUBTLV']._serialized_start=40647
  _globals['_BGPSRTEPREFERENCESUBTLV']._serialized_end=40712
  _globals['_BGPSRTEPOLICYPRIORITYSUBTLV']._serialized_start=40714
  _globals['_BGPSRTEPOLICYPRIORITYSUBTLV']._serialized_end=40793
  _globals['_BGPSRTEPOLICYNAMESUBTLV']._serialized_start=40795
  _globals['_BGPSRTEPOLICYNAMESUBTLV']._serialized_end=40862
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV']._serialized_start=40865
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV']._serialized_end=41207
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY']._serialized_start=41019
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY']._serialized_end=41176
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM']._serialized_start=41047
  _globals['_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM']._serialized_end=41176
  _globals['_BGPSRTESEGMENTLIST']._serialized_start=41210
  _globals['_BGPSRTESEGMENTLIST']._serialized_end=41361
  _globals['_BGPSRTESEGMENT']._serialized_start=41364
  _globals['_BGPSRTESEGMENT']._serialized_end=42224
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE']._serialized_start=42016
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE']._serialized_end=42187
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE_ENUM']._serialized_start=42032
  _globals['_BGPSRTESEGMENT_SEGMENTTYPE_ENUM']._serialized_end=42187
  _globals['_BGPSRTESRMPLSSID']._serialized_start=42227
  _globals['_BGPSRTESRMPLSSID']._serialized_end=42355
  _globals['_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_start=42358
  _globals['_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_end=42560
  _globals['_BGPSRTESEGMENTATYPESUBTLV']._serialized_start=42563
  _globals['_BGPSRTESEGMENTATYPESUBTLV']._serialized_end=42730
  _globals['_BGPSRTESEGMENTBTYPESUBTLV']._serialized_start=42733
  _globals['_BGPSRTESEGMENTBTYPESUBTLV']._serialized_end=42911
  _globals['_BGPSRTESEGMENTCTYPESUBTLV']._serialized_start=42914
  _globals['_BGPSRTESEGMENTCTYPESUBTLV']._serialized_end=43113
  _globals['_BGPSRTESEGMENTDTYPESUBTLV']._serialized_start=43116
  _globals['_BGPSRTESEGMENTDTYPESUBTLV']._serialized_end=43315
  _globals['_BGPSRTESEGMENTETYPESUBTLV']._serialized_start=43318
  _globals['_BGPSRTESEGMENTETYPESUBTLV']._serialized_end=43529
  _globals['_BGPSRTESEGMENTFTYPESUBTLV']._serialized_start=43532
  _globals['_BGPSRTESEGMENTFTYPESUBTLV']._serialized_end=43747
  _globals['_BGPSRTESEGMENTGTYPESUBTLV']._serialized_start=43750
  _globals['_BGPSRTESEGMENTGTYPESUBTLV']._serialized_end=44099
  _globals['_BGPSRTESEGMENTHTYPESUBTLV']._serialized_start=44102
  _globals['_BGPSRTESEGMENTHTYPESUBTLV']._serialized_end=44317
  _globals['_BGPSRTESEGMENTITYPESUBTLV']._serialized_start=44320
  _globals['_BGPSRTESEGMENTITYPESUBTLV']._serialized_end=44552
  _globals['_BGPSRTESEGMENTJTYPESUBTLV']._serialized_start=44555
  _globals['_BGPSRTESEGMENTJTYPESUBTLV']._serialized_end=45025
  _globals['_BGPSRTESEGMENTKTYPESUBTLV']._serialized_start=45028
  _globals['_BGPSRTESEGMENTKTYPESUBTLV']._serialized_end=45364
  _globals['_BGPSRTEV6POLICY']._serialized_start=45367
  _globals['_BGPSRTEV6POLICY']._serialized_end=46257
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE']._serialized_start=32648
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE']._serialized_end=32712
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM']._serialized_start=32663
  _globals['_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM']._serialized_end=32712
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE']._serialized_start=32714
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE']._serialized_end=32779
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_start=32736
  _globals['_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM']._serialized_end=32779
  _globals['_BGPSRTEV6TUNNELTLV']._serialized_start=46260
  _globals['_BGPSRTEV6TUNNELTLV']._serialized_end=46826
  _globals['_BGPGRACEFULRESTART']._serialized_start=46829
  _globals['_BGPGRACEFULRESTART']._serialized_end=47071
  _globals['_BGPUPDATEREPLAY']._serialized_start=47074
  _globals['_BGPUPDATEREPLAY']._serialized_end=47314
  _globals['_BGPUPDATEREPLAY_CHOICE']._serialized_start=47234
  _globals['_BGPUPDATEREPLAY_CHOICE']._serialized_end=47303
  _globals['_BGPUPDATEREPLAY_CHOICE_ENUM']._serialized_start=47244
  _globals['_BGPUPDATEREPLAY_CHOICE_ENUM']._serialized_end=47303
  _globals['_BGPRAWBYTES']._serialized_start=47316
  _globals['_BGPRAWBYTES']._serialized_end=47371
  _globals['_BGPONEUPDATEREPLAY']._serialized_start=47373
  _globals['_BGPONEUPDATEREPLAY']._serialized_end=47473
  _globals['_BGPSTRUCTUREDPDUS']._serialized_start=47475
  _globals['_BGPSTRUCTUREDPDUS']._serialized_end=47546
  _globals['_BGPONESTRUCTUREDUPDATEREPLAY']._serialized_start=47549
  _globals['_BGPONESTRUCTUREDUPDATEREPLAY']._serialized_end=47796
  _globals['_BGPONETRADITIONALNLRIPREFIX']._serialized_start=47799
  _globals['_BGPONETRADITIONALNLRIPREFIX']._serialized_end=47937
  _globals['_BGPONEIPV4NLRIPREFIX']._serialized_start=47940
  _globals['_BGPONEIPV4NLRIPREFIX']._serialized_end=48071
  _globals['_BGPONEIPV6NLRIPREFIX']._serialized_start=48074
  _globals['_BGPONEIPV6NLRIPREFIX']._serialized_end=48205
  _globals['_BGPNLRIPREFIXPATHID']._serialized_start=48207
  _globals['_BGPNLRIPREFIXPATHID']._serialized_end=48258
  _globals['_BGPIPV4SRPOLICYNLRIPREFIX']._serialized_start=48261
  _globals['_BGPIPV4SRPOLICYNLRIPREFIX']._serialized_end=48400
  _globals['_BGPIPV6SRPOLICYNLRIPREFIX']._serialized_start=48403
  _globals['_BGPIPV6SRPOLICYNLRIPREFIX']._serialized_end=48542
  _globals['_BGPATTRIBUTES']._serialized_start=48545
  _globals['_BGPATTRIBUTES']._serialized_end=49552
  _globals['_BGPATTRIBUTES_ORIGIN']._serialized_start=26668
  _globals['_BGPATTRIBUTES_ORIGIN']._serialized_end=26735
  _globals['_BGPATTRIBUTES_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPATTRIBUTES_ORIGIN_ENUM']._serialized_end=26735
  _globals['_BGPATTRIBUTESOTHERATTRIBUTE']._serialized_start=49555
  _globals['_BGPATTRIBUTESOTHERATTRIBUTE']._serialized_end=49850
  _globals['_BGPATTRIBUTESASPATH']._serialized_start=49853
  _globals['_BGPATTRIBUTESASPATH']._serialized_end=50156
  _globals['_BGPATTRIBUTESASPATH_CHOICE']._serialized_start=50067
  _globals['_BGPATTRIBUTESASPATH_CHOICE']._serialized_end=50145
  _globals['_BGPATTRIBUTESASPATH_CHOICE_ENUM']._serialized_start=50077
  _globals['_BGPATTRIBUTESASPATH_CHOICE_ENUM']._serialized_end=50145
  _globals['_BGPATTRIBUTESASPATHFOURBYTEASPATH']._serialized_start=50158
  _globals['_BGPATTRIBUTESASPATHFOURBYTEASPATH']._serialized_end=50252
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT']._serialized_start=50255
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT']._serialized_end=50485
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE']._serialized_start=28100
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE']._serialized_end=28193
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_start=28108
  _globals['_BGPATTRIBUTESFOURBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_end=28193
  _globals['_BGPATTRIBUTESASPATHTWOBYTEASPATH']._serialized_start=50487
  _globals['_BGPATTRIBUTESASPATHTWOBYTEASPATH']._serialized_end=50579
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT']._serialized_start=50582
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT']._serialized_end=50810
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE']._serialized_start=28100
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE']._serialized_end=28193
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_start=28108
  _globals['_BGPATTRIBUTESTWOBYTEASPATHSEGMENT_TYPE_ENUM']._serialized_end=28193
  _globals['_BGPATTRIBUTESAS4PATH']._serialized_start=50812
  _globals['_BGPATTRIBUTESAS4PATH']._serialized_end=50893
  _globals['_BGPATTRIBUTESAGGREGATOR']._serialized_start=50896
  _globals['_BGPATTRIBUTESAGGREGATOR']._serialized_end=51195
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE']._serialized_start=51066
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE']._serialized_end=51134
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE_ENUM']._serialized_start=51076
  _globals['_BGPATTRIBUTESAGGREGATOR_CHOICE_ENUM']._serialized_end=51134
  _globals['_BGPATTRIBUTESAS4AGGREGATOR']._serialized_start=51197
  _globals['_BGPATTRIBUTESAS4AGGREGATOR']._serialized_end=51301
  _globals['_BGPATTRIBUTESCOMMUNITY']._serialized_start=51304
  _globals['_BGPATTRIBUTESCOMMUNITY']._serialized_end=51609
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE']._serialized_start=51454
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE']._serialized_end=51598
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE_ENUM']._serialized_start=51465
  _globals['_BGPATTRIBUTESCOMMUNITY_CHOICE_ENUM']._serialized_end=51598
  _globals['_BGPATTRIBUTESCUSTOMCOMMUNITY']._serialized_start=51611
  _globals['_BGPATTRIBUTESCUSTOMCOMMUNITY']._serialized_end=51711
  _globals['_BGPATTRIBUTESNEXTHOP']._serialized_start=51714
  _globals['_BGPATTRIBUTESNEXTHOP']._serialized_end=52013
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE']._serialized_start=51907
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE']._serialized_end=51984
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE_ENUM']._serialized_start=51917
  _globals['_BGPATTRIBUTESNEXTHOP_CHOICE_ENUM']._serialized_end=51984
  _globals['_BGPATTRIBUTESNEXTHOPIPV6TWOADDRESSES']._serialized_start=52015
  _globals['_BGPATTRIBUTESNEXTHOPIPV6TWOADDRESSES']._serialized_end=52115
  _globals['_BGPATTRIBUTESMPREACHNLRI']._serialized_start=52118
  _globals['_BGPATTRIBUTESMPREACHNLRI']._serialized_end=52581
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE']._serialized_start=52463
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE']._serialized_end=52570
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE_ENUM']._serialized_start=52473
  _globals['_BGPATTRIBUTESMPREACHNLRI_CHOICE_ENUM']._serialized_end=52570
  _globals['_BGPATTRIBUTESMPUNREACHNLRI']._serialized_start=52584
  _globals['_BGPATTRIBUTESMPUNREACHNLRI']._serialized_end=53006
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE']._serialized_start=52463
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE']._serialized_end=52570
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE_ENUM']._serialized_start=52473
  _globals['_BGPATTRIBUTESMPUNREACHNLRI_CHOICE_ENUM']._serialized_end=52570
  _globals['_BGPATTRIBUTESMULTIEXITDISCRIMINATOR']._serialized_start=53008
  _globals['_BGPATTRIBUTESMULTIEXITDISCRIMINATOR']._serialized_end=53075
  _globals['_BGPATTRIBUTESLOCALPREFERENCE']._serialized_start=53077
  _globals['_BGPATTRIBUTESLOCALPREFERENCE']._serialized_end=53137
  _globals['_BGPATTRIBUTESORIGINATORID']._serialized_start=53139
  _globals['_BGPATTRIBUTESORIGINATORID']._serialized_end=53196
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION']._serialized_start=53199
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION']._serialized_end=53425
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE']._serialized_start=53366
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE']._serialized_end=53414
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE_ENUM']._serialized_start=53376
  _globals['_BGPATTRIBUTESTUNNELENCAPSULATION_CHOICE_ENUM']._serialized_end=53414
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICY']._serialized_start=53428
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICY']._serialized_end=53984
  _globals['_BGPATTRIBUTESBSID']._serialized_start=53987
  _globals['_BGPATTRIBUTESBSID']._serialized_end=54213
  _globals['_BGPATTRIBUTESBSID_CHOICE']._serialized_start=54149
  _globals['_BGPATTRIBUTESBSID_CHOICE']._serialized_end=54202
  _globals['_BGPATTRIBUTESBSID_CHOICE_ENUM']._serialized_start=54159
  _globals['_BGPATTRIBUTESBSID_CHOICE_ENUM']._serialized_end=54202
  _globals['_BGPATTRIBUTESBSIDMPLS']._serialized_start=54216
  _globals['_BGPATTRIBUTESBSIDMPLS']._serialized_end=54416
  _globals['_BGPATTRIBUTESBSIDSRV6']._serialized_start=54419
  _globals['_BGPATTRIBUTESBSIDSRV6']._serialized_end=54612
  _globals['_BGPATTRIBUTESSRV6BSID']._serialized_start=54615
  _globals['_BGPATTRIBUTESSRV6BSID']._serialized_end=54989
  _globals['_BGPATTRIBUTESSIDMPLS']._serialized_start=54992
  _globals['_BGPATTRIBUTESSIDMPLS']._serialized_end=55152
  _globals['_BGPATTRIBUTESSIDSRV6']._serialized_start=55154
  _globals['_BGPATTRIBUTESSIDSRV6']._serialized_end=55200
  _globals['_BGPATTRIBUTESSRPOLICYPREFERENCE']._serialized_start=55202
  _globals['_BGPATTRIBUTESSRPOLICYPREFERENCE']._serialized_end=55265
  _globals['_BGPATTRIBUTESSRPOLICYPRIORITY']._serialized_start=55267
  _globals['_BGPATTRIBUTESSRPOLICYPRIORITY']._serialized_end=55328
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYCANDIDATENAME']._serialized_start=55330
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYCANDIDATENAME']._serialized_end=55402
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYNAME']._serialized_start=55404
  _globals['_BGPATTRIBUTESSRPOLICYPOLICYNAME']._serialized_end=55467
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY']._serialized_start=55470
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY']._serialized_end=55719
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE']._serialized_start=55592
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE']._serialized_end=55708
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE_ENUM']._serialized_start=55602
  _globals['_BGPATTRIBUTESSRPOLICYEXPLICITNULLPOLICY_CHOICE_ENUM']._serialized_end=55708
  _globals['_BGPATTRIBUTESSRPOLICYSEGMENTLIST']._serialized_start=55722
  _globals['_BGPATTRIBUTESSRPOLICYSEGMENTLIST']._serialized_end=55905
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTWEIGHT']._serialized_start=55907
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTWEIGHT']._serialized_end=55989
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT']._serialized_start=55992
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT']._serialized_end=56987
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE']._serialized_start=56810
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE']._serialized_end=56976
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE_ENUM']._serialized_start=42032
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSEGMENTLISTSEGMENT_CHOICE_ENUM']._serialized_end=42187
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEA']._serialized_start=56990
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEA']._serialized_end=57139
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEB']._serialized_start=57142
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEB']._serialized_end=57389
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEC']._serialized_start=57392
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEC']._serialized_end=57642
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPED']._serialized_start=57645
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPED']._serialized_end=57895
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEE']._serialized_start=57898
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEE']._serialized_end=58160
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEF']._serialized_start=58163
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEF']._serialized_end=58429
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEG']._serialized_start=58432
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEG']._serialized_end=58832
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEH']._serialized_start=58835
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEH']._serialized_end=59101
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEI']._serialized_start=59104
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEI']._serialized_end=59458
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEJ']._serialized_start=59461
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEJ']._serialized_end=60009
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEK']._serialized_start=60012
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEK']._serialized_end=60426
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEFLAGS']._serialized_start=60429
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYTYPEFLAGS']._serialized_end=60601
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_start=60604
  _globals['_BGPATTRIBUTESSEGMENTROUTINGPOLICYSRV6SIDENDPOINTBEHAVIORANDSTRUCTURE']._serialized_end=60888
  _globals['_BGPNLRIPREFIXSEGMENTROUTINGDISTINGUISHER']._serialized_start=60890
  _globals['_BGPNLRIPREFIXSEGMENTROUTINGDISTINGUISHER']._serialized_end=60962
  _globals['_BGPV6PEER']._serialized_start=60965
  _globals['_BGPV6PEER']._serialized_end=61880
  _globals['_BGPV6PEER_ASTYPE']._serialized_start=25552
  _globals['_BGPV6PEER_ASTYPE']._serialized_end=25605
  _globals['_BGPV6PEER_ASTYPE_ENUM']._serialized_start=25562
  _globals['_BGPV6PEER_ASTYPE_ENUM']._serialized_end=25605
  _globals['_BGPV6PEER_ASNUMBERWIDTH']._serialized_start=25607
  _globals['_BGPV6PEER_ASNUMBERWIDTH']._serialized_end=25666
  _globals['_BGPV6PEER_ASNUMBERWIDTH_ENUM']._serialized_start=25624
  _globals['_BGPV6PEER_ASNUMBERWIDTH_ENUM']._serialized_end=25666
  _globals['_BGPV6INTERFACE']._serialized_start=61882
  _globals['_BGPV6INTERFACE']._serialized_end=61967
  _globals['_BGPV6SEGMENTROUTING']._serialized_start=61970
  _globals['_BGPV6SEGMENTROUTING']._serialized_end=62467
  _globals['_BGPV6ETHERNETSEGMENT']._serialized_start=62470
  _globals['_BGPV6ETHERNETSEGMENT']._serialized_end=62966
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE']._serialized_start=26214
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE']._serialized_end=26286
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_start=26228
  _globals['_BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM']._serialized_end=26286
  _globals['_BGPV6EVPNEVIS']._serialized_start=62969
  _globals['_BGPV6EVPNEVIS']._serialized_end=63137
  _globals['_BGPV6EVPNEVIS_CHOICE']._serialized_start=28314
  _globals['_BGPV6EVPNEVIS_CHOICE']._serialized_end=28362
  _globals['_BGPV6EVPNEVIS_CHOICE_ENUM']._serialized_start=28324
  _globals['_BGPV6EVPNEVIS_CHOICE_ENUM']._serialized_end=28362
  _globals['_BGPV6EVIVXLAN']._serialized_start=63140
  _globals['_BGPV6EVIVXLAN']._serialized_end=63879
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE']._serialized_start=28999
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE']._serialized_end=29066
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_start=29018
  _globals['_BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM']._serialized_end=29066
  _globals['_BGPV6EVIVXLANBROADCASTDOMAIN']._serialized_start=63882
  _globals['_BGPV6EVIVXLANBROADCASTDOMAIN']._serialized_end=64062
  _globals['_DEVICEVXLAN']._serialized_start=64064
  _globals['_DEVICEVXLAN']._serialized_end=64157
  _globals['_VXLANV4TUNNEL']._serialized_start=64160
  _globals['_VXLANV4TUNNEL']._serialized_end=64347
  _globals['_VXLANV6TUNNEL']._serialized_start=64350
  _globals['_VXLANV6TUNNEL']._serialized_end=64537
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE']._serialized_start=64540
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE']._serialized_end=64842
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE']._serialized_start=64770
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE']._serialized_end=64831
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_start=64780
  _globals['_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_end=64831
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE']._serialized_start=64845
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE']._serialized_end=65147
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE']._serialized_start=64770
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE']._serialized_end=64831
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_start=64780
  _globals['_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM']._serialized_end=64831
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICAST']._serialized_start=65149
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICAST']._serialized_end=65251
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICAST']._serialized_start=65253
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICAST']._serialized_end=65355
  _globals['_VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE']._serialized_start=65358
  _globals['_VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE']._serialized_end=65508
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_start=65511
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_end=65704
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_start=65707
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP']._serialized_end=65900
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEMULTICAST']._serialized_start=65902
  _globals['_VXLANV4TUNNELDESTINATIONIPMODEMULTICAST']._serialized_end=65977
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEMULTICAST']._serialized_start=65979
  _globals['_VXLANV6TUNNELDESTINATIONIPMODEMULTICAST']._serialized_end=66054
  _globals['_DEVICERSVP']._serialized_start=66057
  _globals['_DEVICERSVP']._serialized_end=66202
  _globals['_RSVPIPV4INTERFACE']._serialized_start=66205
  _globals['_RSVPIPV4INTERFACE']._serialized_end=66786
  _globals['_RSVPLSPIPV4INTERFACE']._serialized_start=66789
  _globals['_RSVPLSPIPV4INTERFACE']._serialized_end=66997
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP']._serialized_start=67000
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP']._serialized_end=67497
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE']._serialized_start=67285
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE']._serialized_end=67377
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM']._serialized_start=67305
  _globals['_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM']._serialized_end=67377
  _globals['_RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP']._serialized_start=67500
  _globals['_RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP']._serialized_end=68055
  _globals['_RSVPSESSIONATTRIBUTE']._serialized_start=68058
  _globals['_RSVPSESSIONATTRIBUTE']._serialized_end=68682
  _globals['_RSVPRESOURCEAFFINITIES']._serialized_start=68685
  _globals['_RSVPRESOURCEAFFINITIES']._serialized_end=68835
  _globals['_RSVPTSPEC']._serialized_start=68838
  _globals['_RSVPTSPEC']._serialized_end=69125
  _globals['_RSVPFASTREROUTE']._serialized_start=69128
  _globals['_RSVPFASTREROUTE']._serialized_end=69583
  _globals['_RSVPERO']._serialized_start=69586
  _globals['_RSVPERO']._serialized_end=69882
  _globals['_RSVPERO_PREPENDNEIGHBORIP']._serialized_start=69739
  _globals['_RSVPERO_PREPENDNEIGHBORIP']._serialized_end=69840
  _globals['_RSVPERO_PREPENDNEIGHBORIP_ENUM']._serialized_start=69760
  _globals['_RSVPERO_PREPENDNEIGHBORIP_ENUM']._serialized_end=69840
  _globals['_RSVPEROSUBOBJECT']._serialized_start=69885
  _globals['_RSVPEROSUBOBJECT']._serialized_end=70281
  _globals['_RSVPEROSUBOBJECT_TYPE']._serialized_start=70095
  _globals['_RSVPEROSUBOBJECT_TYPE']._serialized_end=70151
  _globals['_RSVPEROSUBOBJECT_TYPE_ENUM']._serialized_start=70103
  _globals['_RSVPEROSUBOBJECT_TYPE_ENUM']._serialized_end=70151
  _globals['_RSVPEROSUBOBJECT_HOPTYPE']._serialized_start=70153
  _globals['_RSVPEROSUBOBJECT_HOPTYPE']._serialized_end=70210
  _globals['_RSVPEROSUBOBJECT_HOPTYPE_ENUM']._serialized_start=70164
  _globals['_RSVPEROSUBOBJECT_HOPTYPE_ENUM']._serialized_end=70210
  _globals['_DEVICEDHCPSERVER']._serialized_start=70283
  _globals['_DEVICEDHCPSERVER']._serialized_end=70389
  _globals['_DHCPSERVERV4']._serialized_start=70391
  _globals['_DHCPSERVERV4']._serialized_end=70517
  _globals['_DHCPSERVERV4POOL']._serialized_start=70520
  _globals['_DHCPSERVERV4POOL']._serialized_end=70802
  _globals['_DHCPSERVERV4POOLOPTION']._serialized_start=70805
  _globals['_DHCPSERVERV4POOLOPTION']._serialized_end=71057
  _globals['_DHCPSERVERV6']._serialized_start=71060
  _globals['_DHCPSERVERV6']._serialized_end=71341
  _globals['_DHCPV6SERVEROPTIONS']._serialized_start=71344
  _globals['_DHCPV6SERVEROPTIONS']._serialized_end=71516
  _globals['_DHCPV6SERVERLEASE']._serialized_start=71518
  _globals['_DHCPV6SERVERLEASE']._serialized_end=71619
  _globals['_DHCPV6SERVERIATYPE']._serialized_start=71622
  _globals['_DHCPV6SERVERIATYPE']._serialized_end=71964
  _globals['_DHCPV6SERVERIATYPE_CHOICE']._serialized_start=5590
  _globals['_DHCPV6SERVERIATYPE_CHOICE']._serialized_end=5665
  _globals['_DHCPV6SERVERIATYPE_CHOICE_ENUM']._serialized_start=5600
  _globals['_DHCPV6SERVERIATYPE_CHOICE_ENUM']._serialized_end=5665
  _globals['_DHCPV6SERVERPOOLINFO']._serialized_start=71967
  _globals['_DHCPV6SERVERPOOLINFO']._serialized_end=72131
  _globals['_DHCPV6SERVERIAPDPOOLINFO']._serialized_start=72134
  _globals['_DHCPV6SERVERIAPDPOOLINFO']._serialized_end=72428
  _globals['_DHCPV6SERVERIANAPDPOOLINFO']._serialized_start=72430
  _globals['_DHCPV6SERVERIANAPDPOOLINFO']._serialized_end=72544
  _globals['_DHCPV6SERVERDNS']._serialized_start=72546
  _globals['_DHCPV6SERVERDNS']._serialized_end=72651
  _globals['_DHCPV6SERVERSECONDARYDNS']._serialized_start=72653
  _globals['_DHCPV6SERVERSECONDARYDNS']._serialized_end=72703
  _globals['_DEVICEOSPFV2ROUTER']._serialized_start=72706
  _globals['_DEVICEOSPFV2ROUTER']._serialized_end=73258
  _globals['_OSPFV2ROUTERID']._serialized_start=73261
  _globals['_OSPFV2ROUTERID']._serialized_end=73439
  _globals['_OSPFV2ROUTERID_CHOICE']._serialized_start=73354
  _globals['_OSPFV2ROUTERID_CHOICE']._serialized_end=73417
  _globals['_OSPFV2ROUTERID_CHOICE_ENUM']._serialized_start=73364
  _globals['_OSPFV2ROUTERID_CHOICE_ENUM']._serialized_end=73417
  _globals['_OSPFV2OPTIONS']._serialized_start=73442
  _globals['_OSPFV2OPTIONS']._serialized_end=73791
  _globals['_OSPFV2GRACEFULRESTART']._serialized_start=73793
  _globals['_OSPFV2GRACEFULRESTART']._serialized_end=73858
  _globals['_OSPFV2INTERFACE']._serialized_start=73861
  _globals['_OSPFV2INTERFACE']._serialized_end=74276
  _globals['_OSPFV2INTERFACEAREA']._serialized_start=74279
  _globals['_OSPFV2INTERFACEAREA']._serialized_end=74469
  _globals['_OSPFV2INTERFACEAREA_CHOICE']._serialized_start=74395
  _globals['_OSPFV2INTERFACEAREA_CHOICE']._serialized_end=74444
  _globals['_OSPFV2INTERFACEAREA_CHOICE_ENUM']._serialized_start=74405
  _globals['_OSPFV2INTERFACEAREA_CHOICE_ENUM']._serialized_end=74444
  _globals['_OSPFV2INTERFACENETWORKTYPE']._serialized_start=74472
  _globals['_OSPFV2INTERFACENETWORKTYPE']._serialized_end=74731
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE']._serialized_start=74627
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE']._serialized_end=74720
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_start=74637
  _globals['_OSPFV2INTERFACENETWORKTYPE_CHOICE_ENUM']._serialized_end=74720
  _globals['_OSPFV2INTERFACENEIGHBOR']._serialized_start=74733
  _globals['_OSPFV2INTERFACENEIGHBOR']._serialized_end=74800
  _globals['_OSPFV2INTERFACEADVANCED']._serialized_start=74803
  _globals['_OSPFV2INTERFACEADVANCED']._serialized_end=75068
  _globals['_OSPFV2INTERFACEOPTIONS']._serialized_start=75071
  _globals['_OSPFV2INTERFACEOPTIONS']._serialized_end=75353
  _globals['_OSPFV2INTERFACEAUTHENTICATION']._serialized_start=75356
  _globals['_OSPFV2INTERFACEAUTHENTICATION']._serialized_end=75612
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE']._serialized_start=75527
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE']._serialized_end=75586
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE_ENUM']._serialized_start=75537
  _globals['_OSPFV2INTERFACEAUTHENTICATION_CHOICE_ENUM']._serialized_end=75586
  _globals['_OSPFV2AUTHENTICATIONMD5']._serialized_start=75614
  _globals['_OSPFV2AUTHENTICATIONMD5']._serialized_end=75697
  _globals['_OSPFV2INTERFACELINKPROTECTION']._serialized_start=75700
  _globals['_OSPFV2INTERFACELINKPROTECTION']._serialized_end=76079
  _globals['_OSPFV2V4ROUTERANGE']._serialized_start=76082
  _globals['_OSPFV2V4ROUTERANGE']._serialized_end=76252
  _globals['_OSPFV2V4RRROUTEORIGIN']._serialized_start=76255
  _globals['_OSPFV2V4RRROUTEORIGIN']._serialized_end=76732
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE']._serialized_start=76595
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE']._serialized_end=76721
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE_ENUM']._serialized_start=76605
  _globals['_OSPFV2V4RRROUTEORIGIN_CHOICE_ENUM']._serialized_end=76721
  _globals['_OSPFV2V4RRINTRAAREA']._serialized_start=76734
  _globals['_OSPFV2V4RRINTRAAREA']._serialized_end=76802
  _globals['_OSPFV2V4RRINTERAREA']._serialized_start=76804
  _globals['_OSPFV2V4RRINTERAREA']._serialized_end=76872
  _globals['_OSPFV2V4RREXTERNALTYPE1']._serialized_start=76874
  _globals['_OSPFV2V4RREXTERNALTYPE1']._serialized_end=76946
  _globals['_OSPFV2V4RREXTERNALTYPE2']._serialized_start=76948
  _globals['_OSPFV2V4RREXTERNALTYPE2']._serialized_end=77020
  _globals['_OSPFV2V4RRNSSAEXTERNAL']._serialized_start=77022
  _globals['_OSPFV2V4RRNSSAEXTERNAL']._serialized_end=77135
  _globals['_OSPFV2V4RREXTDPREFIXFLAGS']._serialized_start=77137
  _globals['_OSPFV2V4RREXTDPREFIXFLAGS']._serialized_end=77228
  _globals['_DEVICEMACSEC']._serialized_start=77230
  _globals['_DEVICEMACSEC']._serialized_end=77309
  _globals['_DEVICEMACSECETHERNETINTERFACE']._serialized_start=77311
  _globals['_DEVICEMACSECETHERNETINTERFACE']._serialized_end=77420
  _globals['_SECUREENTITY']._serialized_start=77423
  _globals['_SECUREENTITY']._serialized_end=77586
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL']._serialized_start=77589
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL']._serialized_end=77839
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE']._serialized_start=77770
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE']._serialized_end=77828
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE_ENUM']._serialized_start=77780
  _globals['_SECUREENTITYKEYGENERATIONPROTOCOL_CHOICE_ENUM']._serialized_end=77828
  _globals['_SECUREENTITYDATAPLANE']._serialized_start=77842
  _globals['_SECUREENTITYDATAPLANE']._serialized_end=78077
  _globals['_SECUREENTITYDATAPLANE_CHOICE']._serialized_start=77992
  _globals['_SECUREENTITYDATAPLANE_CHOICE']._serialized_end=78066
  _globals['_SECUREENTITYDATAPLANE_CHOICE_ENUM']._serialized_start=78002
  _globals['_SECUREENTITYDATAPLANE_CHOICE_ENUM']._serialized_end=78066
  _globals['_SECUREENTITYDATAPLANEENCAPSULATION']._serialized_start=78080
  _globals['_SECUREENTITYDATAPLANEENCAPSULATION']._serialized_end=78254
  _globals['_SECUREENTITYDATAPLANETX']._serialized_start=78256
  _globals['_SECUREENTITYDATAPLANETX']._serialized_end=78365
  _globals['_SECUREENTITYDATAPLANERX']._serialized_start=78367
  _globals['_SECUREENTITYDATAPLANERX']._serialized_end=78492
  _globals['_SECUREENTITYCRYPTOENGINE']._serialized_start=78495
  _globals['_SECUREENTITYCRYPTOENGINE']._serialized_end=78713
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE']._serialized_start=78651
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE']._serialized_end=78702
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE_ENUM']._serialized_start=78661
  _globals['_SECUREENTITYCRYPTOENGINE_CHOICE_ENUM']._serialized_end=78702
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLY']._serialized_start=78716
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLY']._serialized_end=78905
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSC']._serialized_start=78907
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSC']._serialized_end=79013
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN']._serialized_start=79016
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN']._serialized_end=79367
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE']._serialized_start=79288
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE']._serialized_end=79356
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE_ENUM']._serialized_start=79298
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTXSCTXPN_CHOICE_ENUM']._serialized_end=79356
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYFIXEDPN']._serialized_start=79369
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYFIXEDPN']._serialized_end=79463
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYINCREMENTINGPN']._serialized_start=79466
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYINCREMENTINGPN']._serialized_end=79633
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTRAFFICOPTIONS']._serialized_start=79635
  _globals['_SECUREENTITYCRYPTOENGINEENCRYPTONLYTRAFFICOPTIONS']._serialized_end=79744
  _globals['_MKA']._serialized_start=79746
  _globals['_MKA']._serialized_end=79872
  _globals['_MKABASIC']._serialized_start=79875
  _globals['_MKABASIC']._serialized_end=81025
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION']._serialized_start=80501
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION']._serialized_end=80585
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION_ENUM']._serialized_start=80526
  _globals['_MKABASIC_KEYDERIVATIONFUNCTION_ENUM']._serialized_end=80585
  _globals['_MKABASIC_MACSECCAPABILITY']._serialized_start=80588
  _globals['_MKABASIC_MACSECCAPABILITY']._serialized_end=80809
  _globals['_MKABASIC_MACSECCAPABILITY_ENUM']._serialized_start=80609
  _globals['_MKABASIC_MACSECCAPABILITY_ENUM']._serialized_end=80809
  _globals['_MKABASICSUPPORTEDCIPHERSUITES']._serialized_start=81028
  _globals['_MKABASICSUPPORTEDCIPHERSUITES']._serialized_end=81243
  _globals['_MKABASICKEYSOURCE']._serialized_start=81246
  _globals['_MKABASICKEYSOURCE']._serialized_end=81427
  _globals['_MKABASICKEYSOURCE_CHOICE']._serialized_start=81365
  _globals['_MKABASICKEYSOURCE_CHOICE']._serialized_end=81416
  _globals['_MKABASICKEYSOURCE_CHOICE_ENUM']._serialized_start=81375
  _globals['_MKABASICKEYSOURCE_CHOICE_ENUM']._serialized_end=81416
  _globals['_MKABASICKEYSOURCEPSK']._serialized_start=81430
  _globals['_MKABASICKEYSOURCEPSK']._serialized_end=81636
  _globals['_MKABASICSTARTOFFSETTIME']._serialized_start=81638
  _globals['_MKABASICSTARTOFFSETTIME']._serialized_end=81711
  _globals['_MKABASICENDOFFSETTIME']._serialized_start=81713
  _globals['_MKABASICENDOFFSETTIME']._serialized_end=81784
  _globals['_MKABASICPSKCHAINSTARTTIME']._serialized_start=81787
  _globals['_MKABASICPSKCHAINSTARTTIME']._serialized_end=81969
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE']._serialized_start=81916
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE']._serialized_end=81958
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE_ENUM']._serialized_start=81926
  _globals['_MKABASICPSKCHAINSTARTTIME_CHOICE_ENUM']._serialized_end=81958
  _globals['_MKABASICTIMEUTC']._serialized_start=81972
  _globals['_MKABASICTIMEUTC']._serialized_end=82165
  _globals['_MKABASICREKEYMODE']._serialized_start=82168
  _globals['_MKABASICREKEYMODE']._serialized_end=82392
  _globals['_MKABASICREKEYMODE_CHOICE']._serialized_start=82301
  _globals['_MKABASICREKEYMODE_CHOICE']._serialized_end=82381
  _globals['_MKABASICREKEYMODE_CHOICE_ENUM']._serialized_start=82311
  _globals['_MKABASICREKEYMODE_CHOICE_ENUM']._serialized_end=82381
  _globals['_MKABASICREKEYMODETIMERBASED']._serialized_start=82395
  _globals['_MKABASICREKEYMODETIMERBASED']._serialized_end=82648
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE']._serialized_start=82542
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE']._serialized_end=82608
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_start=82552
  _globals['_MKABASICREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_end=82608
  _globals['_MKAKEYSERVER']._serialized_start=82651
  _globals['_MKAKEYSERVER']._serialized_end=83388
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET']._serialized_start=82951
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET']._serialized_end=83130
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET_ENUM']._serialized_start=82976
  _globals['_MKAKEYSERVER_CONFIDENTIALTYOFFSET_ENUM']._serialized_end=83130
  _globals['_MKAKEYSERVER_CIPHERSUITE']._serialized_start=83132
  _globals['_MKAKEYSERVER_CIPHERSUITE']._serialized_end=83246
  _globals['_MKAKEYSERVER_CIPHERSUITE_ENUM']._serialized_start=83147
  _globals['_MKAKEYSERVER_CIPHERSUITE_ENUM']._serialized_end=83246
  _globals['_MKATX']._serialized_start=83390
  _globals['_MKATX']._serialized_end=83436
  _globals['_MKATXSC']._serialized_start=83439
  _globals['_MKATXSC']._serialized_end=83614
  _globals['_SECUREENTITYSTATICKEY']._serialized_start=83617
  _globals['_SECUREENTITYSTATICKEY']._serialized_end=84181
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE']._serialized_start=83132
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE']._serialized_end=83246
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE_ENUM']._serialized_start=83147
  _globals['_SECUREENTITYSTATICKEY_CIPHERSUITE_ENUM']._serialized_end=83246
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET']._serialized_start=84036
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET']._serialized_end=84117
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET_ENUM']._serialized_start=84061
  _globals['_SECUREENTITYSTATICKEY_CONFIDENTIALITYOFFSET_ENUM']._serialized_end=84117
  _globals['_SECUREENTITYSTATICKEYREKEYMODE']._serialized_start=84184
  _globals['_SECUREENTITYSTATICKEYREKEYMODE']._serialized_end=84447
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE']._serialized_start=82301
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE']._serialized_end=82381
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE_ENUM']._serialized_start=82311
  _globals['_SECUREENTITYSTATICKEYREKEYMODE_CHOICE_ENUM']._serialized_end=82381
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED']._serialized_start=84450
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED']._serialized_end=84729
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE']._serialized_start=82542
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE']._serialized_end=82608
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_start=82552
  _globals['_SECUREENTITYSTATICKEYREKEYMODETIMERBASED_CHOICE_ENUM']._serialized_end=82608
  _globals['_SECUREENTITYSTATICKEYSAK']._serialized_start=84731
  _globals['_SECUREENTITYSTATICKEYSAK']._serialized_end=84839
  _globals['_SECUREENTITYSTATICKEYTX']._serialized_start=84842
  _globals['_SECUREENTITYSTATICKEYTX']._serialized_end=84981
  _globals['_SECUREENTITYSTATICKEYTXSC']._serialized_start=84984
  _globals['_SECUREENTITYSTATICKEYTXSC']._serialized_end=85128
  _globals['_SECUREENTITYSTATICKEYRX']._serialized_start=85130
  _globals['_SECUREENTITYSTATICKEYRX']._serialized_end=85212
  _globals['_SECUREENTITYSTATICKEYRXSC']._serialized_start=85215
  _globals['_SECUREENTITYSTATICKEYRXSC']._serialized_end=85433
  _globals['_FLOW']._serialized_start=85436
  _globals['_FLOW']._serialized_end=85703
  _globals['_FLOWTXRX']._serialized_start=85706
  _globals['_FLOWTXRX']._serialized_end=85894
  _globals['_FLOWTXRX_CHOICE']._serialized_start=85828
  _globals['_FLOWTXRX_CHOICE']._serialized_end=85883
  _globals['_FLOWTXRX_CHOICE_ENUM']._serialized_start=85838
  _globals['_FLOWTXRX_CHOICE_ENUM']._serialized_end=85883
  _globals['_FLOWPORT']._serialized_start=85896
  _globals['_FLOWPORT']._serialized_end=85992
  _globals['_FLOWROUTER']._serialized_start=85995
  _globals['_FLOWROUTER']._serialized_end=86157
  _globals['_FLOWROUTER_MODE']._serialized_start=86091
  _globals['_FLOWROUTER_MODE']._serialized_end=86148
  _globals['_FLOWROUTER_MODE_ENUM']._serialized_start=86099
  _globals['_FLOWROUTER_MODE_ENUM']._serialized_end=86148
  _globals['_FLOWHEADER']._serialized_start=86160
  _globals['_FLOWHEADER']._serialized_end=87161
  _globals['_FLOWHEADER_CHOICE']._serialized_start=86882
  _globals['_FLOWHEADER_CHOICE']._serialized_end=87150
  _globals['_FLOWHEADER_CHOICE_ENUM']._serialized_start=86893
  _globals['_FLOWHEADER_CHOICE_ENUM']._serialized_end=87150
  _globals['_FLOWCUSTOM']._serialized_start=87163
  _globals['_FLOWCUSTOM']._serialized_end=87252
  _globals['_FLOWCUSTOMMETRICTAG']._serialized_start=87254
  _globals['_FLOWCUSTOMMETRICTAG']._serialized_end=87367
  _globals['_FLOWETHERNET']._serialized_start=87370
  _globals['_FLOWETHERNET']._serialized_end=87576
  _globals['_FLOWVLAN']._serialized_start=87579
  _globals['_FLOWVLAN']._serialized_end=87751
  _globals['_FLOWVXLAN']._serialized_start=87754
  _globals['_FLOWVXLAN']._serialized_end=87949
  _globals['_FLOWIPV4']._serialized_start=87952
  _globals['_FLOWIPV4']._serialized_end=88724
  _globals['_FLOWIPV4OPTIONS']._serialized_start=88727
  _globals['_FLOWIPV4OPTIONS']._serialized_end=88919
  _globals['_FLOWIPV4OPTIONS_CHOICE']._serialized_start=88845
  _globals['_FLOWIPV4OPTIONS_CHOICE']._serialized_end=88908
  _globals['_FLOWIPV4OPTIONS_CHOICE_ENUM']._serialized_start=88855
  _globals['_FLOWIPV4OPTIONS_CHOICE_ENUM']._serialized_end=88908
  _globals['_FLOWIPV4OPTIONSCUSTOM']._serialized_start=88922
  _globals['_FLOWIPV4OPTIONSCUSTOM']._serialized_end=89071
  _globals['_FLOWIPV4OPTIONSCUSTOMTYPE']._serialized_start=89074
  _globals['_FLOWIPV4OPTIONSCUSTOMTYPE']._serialized_end=89317
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH']._serialized_start=89320
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH']._serialized_end=89541
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWIPV4OPTIONSCUSTOMLENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWIPV4PRIORITY']._serialized_start=89544
  _globals['_FLOWIPV4PRIORITY']._serialized_end=89802
  _globals['_FLOWIPV4PRIORITY_CHOICE']._serialized_start=89730
  _globals['_FLOWIPV4PRIORITY_CHOICE']._serialized_end=89791
  _globals['_FLOWIPV4PRIORITY_CHOICE_ENUM']._serialized_start=89740
  _globals['_FLOWIPV4PRIORITY_CHOICE_ENUM']._serialized_end=89791
  _globals['_FLOWIPV4DSCP']._serialized_start=89804
  _globals['_FLOWIPV4DSCP']._serialized_end=89902
  _globals['_FLOWIPV4TOS']._serialized_start=89905
  _globals['_FLOWIPV4TOS']._serialized_end=90228
  _globals['_FLOWIPV4AUTO']._serialized_start=90230
  _globals['_FLOWIPV4AUTO']._serialized_end=90352
  _globals['_FLOWIPV4AUTO_CHOICE']._serialized_start=90298
  _globals['_FLOWIPV4AUTO_CHOICE']._serialized_end=90341
  _globals['_FLOWIPV4AUTO_CHOICE_ENUM']._serialized_start=90308
  _globals['_FLOWIPV4AUTO_CHOICE_ENUM']._serialized_end=90341
  _globals['_FLOWIPV6']._serialized_start=90355
  _globals['_FLOWIPV6']._serialized_end=90756
  _globals['_FLOWIPV6AUTO']._serialized_start=90758
  _globals['_FLOWIPV6AUTO']._serialized_end=90880
  _globals['_FLOWIPV6AUTO_CHOICE']._serialized_start=90298
  _globals['_FLOWIPV6AUTO_CHOICE']._serialized_end=90341
  _globals['_FLOWIPV6AUTO_CHOICE_ENUM']._serialized_start=90308
  _globals['_FLOWIPV6AUTO_CHOICE_ENUM']._serialized_end=90341
  _globals['_FLOWPFCPAUSE']._serialized_start=90883
  _globals['_FLOWPFCPAUSE']._serialized_end=91652
  _globals['_FLOWETHERNETPAUSE']._serialized_start=91655
  _globals['_FLOWETHERNETPAUSE']._serialized_end=91946
  _globals['_FLOWTCP']._serialized_start=91949
  _globals['_FLOWTCP']._serialized_end=92676
  _globals['_FLOWUDP']._serialized_start=92679
  _globals['_FLOWUDP']._serialized_end=92870
  _globals['_FLOWGRE']._serialized_start=92873
  _globals['_FLOWGRE']._serialized_end=93181
  _globals['_FLOWGTPV1']._serialized_start=93184
  _globals['_FLOWGTPV1']._serialized_end=93887
  _globals['_FLOWGTPEXTENSION']._serialized_start=93890
  _globals['_FLOWGTPEXTENSION']._serialized_end=94115
  _globals['_FLOWGTPV2']._serialized_start=94118
  _globals['_FLOWGTPV2']._serialized_end=94601
  _globals['_FLOWARP']._serialized_start=94604
  _globals['_FLOWARP']._serialized_end=95170
  _globals['_FLOWICMP']._serialized_start=95173
  _globals['_FLOWICMP']._serialized_end=95320
  _globals['_FLOWICMP_CHOICE']._serialized_start=95266
  _globals['_FLOWICMP_CHOICE']._serialized_end=95309
  _globals['_FLOWICMP_CHOICE_ENUM']._serialized_start=95276
  _globals['_FLOWICMP_CHOICE_ENUM']._serialized_end=95309
  _globals['_FLOWICMPECHO']._serialized_start=95323
  _globals['_FLOWICMPECHO']._serialized_end=95598
  _globals['_FLOWICMPV6']._serialized_start=95601
  _globals['_FLOWICMPV6']._serialized_end=95754
  _globals['_FLOWICMPV6_CHOICE']._serialized_start=95266
  _globals['_FLOWICMPV6_CHOICE']._serialized_end=95309
  _globals['_FLOWICMPV6_CHOICE_ENUM']._serialized_start=95276
  _globals['_FLOWICMPV6_CHOICE_ENUM']._serialized_end=95309
  _globals['_FLOWICMPV6ECHO']._serialized_start=95757
  _globals['_FLOWICMPV6ECHO']._serialized_end=96044
  _globals['_FLOWPPP']._serialized_start=96047
  _globals['_FLOWPPP']._serialized_end=96202
  _globals['_FLOWIGMPV1']._serialized_start=96205
  _globals['_FLOWIGMPV1']._serialized_end=96462
  _globals['_FLOWMPLS']._serialized_start=96465
  _globals['_FLOWMPLS']._serialized_end=96688
  _globals['_FLOWSNMPV2C']._serialized_start=96691
  _globals['_FLOWSNMPV2C']._serialized_end=96827
  _globals['_FLOWSNMPV2CDATA']._serialized_start=96830
  _globals['_FLOWSNMPV2CDATA']._serialized_end=97436
  _globals['_FLOWSNMPV2CDATA_CHOICE']._serialized_start=97250
  _globals['_FLOWSNMPV2CDATA_CHOICE']._serialized_end=97425
  _globals['_FLOWSNMPV2CDATA_CHOICE_ENUM']._serialized_start=97261
  _globals['_FLOWSNMPV2CDATA_CHOICE_ENUM']._serialized_end=97425
  _globals['_FLOWSNMPV2CPDU']._serialized_start=97439
  _globals['_FLOWSNMPV2CPDU']._serialized_end=98098
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS']._serialized_start=97699
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS']._serialized_end=98081
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS_ENUM']._serialized_start=97715
  _globals['_FLOWSNMPV2CPDU_ERRORSTATUS_ENUM']._serialized_end=98081
  _globals['_FLOWSNMPV2CBULKPDU']._serialized_start=98101
  _globals['_FLOWSNMPV2CBULKPDU']._serialized_end=98380
  _globals['_FLOWSNMPV2CVARIABLEBINDING']._serialized_start=98383
  _globals['_FLOWSNMPV2CVARIABLEBINDING']._serialized_end=98518
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE']._serialized_start=98521
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE']._serialized_end=99582
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE']._serialized_start=99275
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE']._serialized_end=99523
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE_ENUM']._serialized_start=99286
  _globals['_FLOWSNMPV2CVARIABLEBINDINGVALUE_CHOICE_ENUM']._serialized_end=99523
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE']._serialized_start=99585
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE']._serialized_end=99823
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE']._serialized_start=99741
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE']._serialized_end=99794
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE_ENUM']._serialized_start=99751
  _globals['_FLOWSNMPV2CVARIABLEBINDINGSTRINGVALUE_CHOICE_ENUM']._serialized_end=99794
  _globals['_FLOWRSVP']._serialized_start=99826
  _globals['_FLOWRSVP']._serialized_end=100267
  _globals['_FLOWRSVP_FLAG']._serialized_start=100149
  _globals['_FLOWRSVP_FLAG']._serialized_end=100246
  _globals['_FLOWRSVP_FLAG_ENUM']._serialized_start=100157
  _globals['_FLOWRSVP_FLAG_ENUM']._serialized_end=100246
  _globals['_FLOWRSVPLENGTH']._serialized_start=100270
  _globals['_FLOWRSVPLENGTH']._serialized_end=100465
  _globals['_FLOWRSVPLENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPLENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPLENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPLENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPMESSAGE']._serialized_start=100468
  _globals['_FLOWRSVPMESSAGE']._serialized_end=100636
  _globals['_FLOWRSVPMESSAGE_CHOICE']._serialized_start=100582
  _globals['_FLOWRSVPMESSAGE_CHOICE']._serialized_end=100625
  _globals['_FLOWRSVPMESSAGE_CHOICE_ENUM']._serialized_start=100592
  _globals['_FLOWRSVPMESSAGE_CHOICE_ENUM']._serialized_end=100625
  _globals['_FLOWRSVPPATHMESSAGE']._serialized_start=100638
  _globals['_FLOWRSVPPATHMESSAGE']._serialized_end=100702
  _globals['_FLOWRSVPPATHOBJECTS']._serialized_start=100704
  _globals['_FLOWRSVPPATHOBJECTS']._serialized_end=100775
  _globals['_FLOWRSVPOBJECTLENGTH']._serialized_start=100778
  _globals['_FLOWRSVPOBJECTLENGTH']._serialized_end=100985
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPOBJECTLENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPPATHOBJECTSCLASS']._serialized_start=100988
  _globals['_FLOWRSVPPATHOBJECTSCLASS']._serialized_end=101928
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE']._serialized_start=101708
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE']._serialized_end=101917
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE_ENUM']._serialized_start=101719
  _globals['_FLOWRSVPPATHOBJECTSCLASS_CHOICE_ENUM']._serialized_end=101917
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSION']._serialized_start=101931
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSION']._serialized_end=102061
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE']._serialized_start=102064
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE']._serialized_end=102299
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE']._serialized_start=102234
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE']._serialized_end=102288
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE_ENUM']._serialized_start=102244
  _globals['_FLOWRSVPPATHOBJECTSSESSIONCTYPE_CHOICE_ENUM']._serialized_end=102288
  _globals['_FLOWRSVPPATHSESSIONLSPTUNNELIPV4']._serialized_start=102302
  _globals['_FLOWRSVPPATHSESSIONLSPTUNNELIPV4']._serialized_end=102656
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID']._serialized_start=102659
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID']._serialized_end=102976
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE']._serialized_start=102903
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE']._serialized_end=102965
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE_ENUM']._serialized_start=102913
  _globals['_FLOWRSVPPATHSESSIONEXTTUNNELID_CHOICE_ENUM']._serialized_end=102965
  _globals['_FLOWRSVPPATHOBJECTSCLASSRSVPHOP']._serialized_start=102979
  _globals['_FLOWRSVPPATHOBJECTSCLASSRSVPHOP']._serialized_end=103109
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE']._serialized_start=103112
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE']._serialized_end=103316
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE']._serialized_start=103262
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE']._serialized_end=103305
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE_ENUM']._serialized_start=32736
  _globals['_FLOWRSVPPATHOBJECTSRSVPHOPCTYPE_CHOICE_ENUM']._serialized_end=32769
  _globals['_FLOWRSVPPATHRSVPHOPIPV4']._serialized_start=103319
  _globals['_FLOWRSVPPATHRSVPHOPIPV4']._serialized_end=103507
  _globals['_FLOWRSVPPATHOBJECTSCLASSTIMEVALUES']._serialized_start=103510
  _globals['_FLOWRSVPPATHOBJECTSCLASSTIMEVALUES']._serialized_end=103646
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE']._serialized_start=103649
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE']._serialized_end=103867
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE']._serialized_start=103811
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE']._serialized_end=103856
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE_ENUM']._serialized_start=103821
  _globals['_FLOWRSVPPATHOBJECTSTIMEVALUESCTYPE_CHOICE_ENUM']._serialized_end=103856
  _globals['_FLOWRSVPPATHTIMEVALUESTYPE1']._serialized_start=103869
  _globals['_FLOWRSVPPATHTIMEVALUESTYPE1']._serialized_end=103979
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTE']._serialized_start=103982
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTE']._serialized_end=104129
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE']._serialized_start=104132
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE']._serialized_end=104369
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE']._serialized_start=103811
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE']._serialized_end=103856
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE_ENUM']._serialized_start=103821
  _globals['_FLOWRSVPPATHOBJECTSCLASSEXPLICITROUTECTYPE_CHOICE_ENUM']._serialized_end=103856
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1']._serialized_start=104371
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1']._serialized_end=104466
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTS']._serialized_start=104468
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTS']._serialized_end=104567
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE']._serialized_start=104570
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE']._serialized_end=104902
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE']._serialized_start=104826
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE']._serialized_end=104891
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE_ENUM']._serialized_start=104836
  _globals['_FLOWRSVPTYPE1EXPLICITROUTESUBOBJECTSTYPE_CHOICE_ENUM']._serialized_end=104891
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIX']._serialized_start=104905
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIX']._serialized_end=105189
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBER']._serialized_start=105192
  _globals['_FLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBER']._serialized_end=105399
  _globals['_FLOWRSVPEXPLICITROUTELENGTH']._serialized_start=105402
  _globals['_FLOWRSVPEXPLICITROUTELENGTH']._serialized_end=105623
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPEXPLICITROUTELENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH']._serialized_start=105626
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH']._serialized_end=105863
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPEXPLICITROUTEASNUMBERLENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPPATHOBJECTSCLASSLABELREQUEST']._serialized_start=105866
  _globals['_FLOWRSVPPATHOBJECTSCLASSLABELREQUEST']._serialized_end=106006
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE']._serialized_start=106009
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE']._serialized_end=106271
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE']._serialized_start=106202
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE']._serialized_end=106260
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE_ENUM']._serialized_start=106212
  _globals['_FLOWRSVPPATHOBJECTSLABELREQUESTCTYPE_CHOICE_ENUM']._serialized_end=106260
  _globals['_FLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGE']._serialized_start=106274
  _globals['_FLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGE']._serialized_end=106473
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSIONATTRIBUTE']._serialized_start=106476
  _globals['_FLOWRSVPPATHOBJECTSCLASSSESSIONATTRIBUTE']._serialized_end=106624
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE']._serialized_start=106627
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE']._serialized_end=106963
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE']._serialized_start=106884
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE']._serialized_end=106952
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE_ENUM']._serialized_start=106894
  _globals['_FLOWRSVPPATHOBJECTSSESSIONATTRIBUTECTYPE_CHOICE_ENUM']._serialized_end=106952
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNEL']._serialized_start=106966
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNEL']._serialized_end=107254
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNELRA']._serialized_start=107257
  _globals['_FLOWRSVPPATHSESSIONATTRIBUTELSPTUNNELRA']._serialized_end=107673
  _globals['_FLOWRSVPLSPTUNNELFLAG']._serialized_start=107676
  _globals['_FLOWRSVPLSPTUNNELFLAG']._serialized_end=107887
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE']._serialized_start=107762
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE']._serialized_end=107876
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE_ENUM']._serialized_start=107772
  _globals['_FLOWRSVPLSPTUNNELFLAG_CHOICE_ENUM']._serialized_end=107876
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH']._serialized_start=107890
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH']._serialized_end=108125
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPSESSIONATTRIBUTENAMELENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTEMPLATE']._serialized_start=108128
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTEMPLATE']._serialized_end=108272
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE']._serialized_start=108275
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE']._serialized_end=108531
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE']._serialized_start=102234
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE']._serialized_end=102288
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE_ENUM']._serialized_start=102244
  _globals['_FLOWRSVPPATHOBJECTSSENDERTEMPLATECTYPE_CHOICE_ENUM']._serialized_end=102288
  _globals['_FLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4']._serialized_start=108534
  _globals['_FLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4']._serialized_end=108840
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTSPEC']._serialized_start=108843
  _globals['_FLOWRSVPPATHOBJECTSCLASSSENDERTSPEC']._serialized_end=108981
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE']._serialized_start=108984
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE']._serialized_end=109211
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE']._serialized_start=109153
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE']._serialized_end=109200
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE_ENUM']._serialized_start=109163
  _globals['_FLOWRSVPPATHOBJECTSSENDERTSPECCTYPE_CHOICE_ENUM']._serialized_end=109200
  _globals['_FLOWRSVPPATHSENDERTSPECINTSERV']._serialized_start=109214
  _globals['_FLOWRSVPPATHSENDERTSPECINTSERV']._serialized_end=110414
  _globals['_FLOWRSVPPATHOBJECTSCLASSRECORDROUTE']._serialized_start=110417
  _globals['_FLOWRSVPPATHOBJECTSCLASSRECORDROUTE']._serialized_end=110555
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE']._serialized_start=110558
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE']._serialized_end=110779
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE']._serialized_start=103811
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE']._serialized_end=103856
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE_ENUM']._serialized_start=103821
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTECTYPE_CHOICE_ENUM']._serialized_end=103856
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1']._serialized_start=110781
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1']._serialized_end=110872
  _globals['_FLOWRSVPTYPE1RECORDROUTESUBOBJECTS']._serialized_start=110874
  _globals['_FLOWRSVPTYPE1RECORDROUTESUBOBJECTS']._serialized_end=110974
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE']._serialized_start=110977
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE']._serialized_end=111303
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE']._serialized_start=111230
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE']._serialized_end=111292
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE_ENUM']._serialized_start=111240
  _globals['_FLOWRSVPPATHOBJECTSRECORDROUTESUBOBJECTTYPE_CHOICE_ENUM']._serialized_end=111292
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESS']._serialized_start=111306
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESS']._serialized_end=111618
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG']._serialized_start=111621
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG']._serialized_end=111824
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE']._serialized_start=111719
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE']._serialized_end=111813
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE_ENUM']._serialized_start=111729
  _globals['_FLOWRSVPRECORDROUTEIPV4FLAG_CHOICE_ENUM']._serialized_end=111813
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1LABEL']._serialized_start=111827
  _globals['_FLOWRSVPPATHRECORDROUTETYPE1LABEL']._serialized_end=112095
  _globals['_FLOWRSVPPATHRECORDROUTELABEL']._serialized_start=112098
  _globals['_FLOWRSVPPATHRECORDROUTELABEL']._serialized_end=112342
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE']._serialized_start=112244
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE']._serialized_end=112305
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE_ENUM']._serialized_start=112254
  _globals['_FLOWRSVPPATHRECORDROUTELABEL_CHOICE_ENUM']._serialized_end=112305
  _globals['_FLOWRSVPROUTERECORDLENGTH']._serialized_start=112345
  _globals['_FLOWRSVPROUTERECORDLENGTH']._serialized_end=112562
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE']._serialized_start=3471
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE']._serialized_end=3525
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE_ENUM']._serialized_start=3481
  _globals['_FLOWRSVPROUTERECORDLENGTH_CHOICE_ENUM']._serialized_end=3525
  _globals['_FLOWRSVPPATHOBJECTSCUSTOM']._serialized_start=112565
  _globals['_FLOWRSVPPATHOBJECTSCUSTOM']._serialized_end=112722
  _globals['_FLOWSIZE']._serialized_start=112725
  _globals['_FLOWSIZE']._serialized_end=113043
  _globals['_FLOWSIZE_CHOICE']._serialized_start=112933
  _globals['_FLOWSIZE_CHOICE']._serialized_end=113022
  _globals['_FLOWSIZE_CHOICE_ENUM']._serialized_start=112943
  _globals['_FLOWSIZE_CHOICE_ENUM']._serialized_end=113022
  _globals['_FLOWSIZEINCREMENT']._serialized_start=113045
  _globals['_FLOWSIZEINCREMENT']._serialized_end=113148
  _globals['_FLOWSIZERANDOM']._serialized_start=113150
  _globals['_FLOWSIZERANDOM']._serialized_end=113218
  _globals['_FLOWSIZEWEIGHTPAIRS']._serialized_start=113221
  _globals['_FLOWSIZEWEIGHTPAIRS']._serialized_end=113618
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE']._serialized_start=113418
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE']._serialized_end=113479
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM']._serialized_start=113428
  _globals['_FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM']._serialized_end=113479
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED']._serialized_start=113481
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED']._serialized_end=113592
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM']._serialized_start=113495
  _globals['_FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM']._serialized_end=113592
  _globals['_FLOWSIZEWEIGHTPAIRSCUSTOM']._serialized_start=113620
  _globals['_FLOWSIZEWEIGHTPAIRSCUSTOM']._serialized_end=113707
  _globals['_FLOWRATE']._serialized_start=113710
  _globals['_FLOWRATE']._serialized_end=114054
  _globals['_FLOWRATE_CHOICE']._serialized_start=113888
  _globals['_FLOWRATE_CHOICE']._serialized_end=113985
  _globals['_FLOWRATE_CHOICE_ENUM']._serialized_start=113898
  _globals['_FLOWRATE_CHOICE_ENUM']._serialized_end=113985
  _globals['_FLOWDURATION']._serialized_start=114057
  _globals['_FLOWDURATION']._serialized_end=114398
  _globals['_FLOWDURATION_CHOICE']._serialized_start=114289
  _globals['_FLOWDURATION_CHOICE']._serialized_end=114387
  _globals['_FLOWDURATION_CHOICE_ENUM']._serialized_start=114299
  _globals['_FLOWDURATION_CHOICE_ENUM']._serialized_end=114387
  _globals['_FLOWCONTINUOUS']._serialized_start=114400
  _globals['_FLOWCONTINUOUS']._serialized_end=114473
  _globals['_FLOWDELAY']._serialized_start=114476
  _globals['_FLOWDELAY']._serialized_end=114744
  _globals['_FLOWDELAY_CHOICE']._serialized_start=114611
  _globals['_FLOWDELAY_CHOICE']._serialized_end=114690
  _globals['_FLOWDELAY_CHOICE_ENUM']._serialized_start=114621
  _globals['_FLOWDELAY_CHOICE_ENUM']._serialized_end=114690
  _globals['_FLOWFIXEDPACKETS']._serialized_start=114746
  _globals['_FLOWFIXEDPACKETS']._serialized_end=114855
  _globals['_FLOWFIXEDSECONDS']._serialized_start=114857
  _globals['_FLOWFIXEDSECONDS']._serialized_end=114966
  _globals['_FLOWBURST']._serialized_start=114969
  _globals['_FLOWBURST']._serialized_end=115129
  _globals['_FLOWDURATIONINTERBURSTGAP']._serialized_start=115132
  _globals['_FLOWDURATIONINTERBURSTGAP']._serialized_end=115432
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE']._serialized_start=114611
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE']._serialized_end=114690
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM']._serialized_start=114621
  _globals['_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM']._serialized_end=114690
  _globals['_FLOWMETRICS']._serialized_start=115435
  _globals['_FLOWMETRICS']._serialized_end=115688
  _globals['_FLOWLATENCYMETRICS']._serialized_start=115691
  _globals['_FLOWLATENCYMETRICS']._serialized_end=115875
  _globals['_FLOWLATENCYMETRICS_MODE']._serialized_start=115788
  _globals['_FLOWLATENCYMETRICS_MODE']._serialized_end=115855
  _globals['_FLOWLATENCYMETRICS_MODE_ENUM']._serialized_start=115796
  _globals['_FLOWLATENCYMETRICS_MODE_ENUM']._serialized_end=115855
  _globals['_FLOWPREDEFINEDTAGS']._serialized_start=115877
  _globals['_FLOWPREDEFINEDTAGS']._serialized_end=115931
  _globals['_FLOWRXTXRATIO']._serialized_start=115934
  _globals['_FLOWRXTXRATIO']._serialized_end=116148
  _globals['_FLOWRXTXRATIO_CHOICE']._serialized_start=116069
  _globals['_FLOWRXTXRATIO_CHOICE']._serialized_end=116127
  _globals['_FLOWRXTXRATIO_CHOICE_ENUM']._serialized_start=116079
  _globals['_FLOWRXTXRATIO_CHOICE_ENUM']._serialized_end=116127
  _globals['_FLOWRXTXRATIORXCOUNT']._serialized_start=116150
  _globals['_FLOWRXTXRATIORXCOUNT']._serialized_end=116172
  _globals['_EVENT']._serialized_start=116174
  _globals['_EVENT']._serialized_end=116259
  _globals['_EVENTCPEVENTS']._serialized_start=116261
  _globals['_EVENTCPEVENTS']._serialized_end=116308
  _globals['_EVENTDPEVENTS']._serialized_start=116310
  _globals['_EVENTDPEVENTS']._serialized_end=116411
  _globals['_EVENTREQUEST']._serialized_start=116414
  _globals['_EVENTREQUEST']._serialized_end=116659
  _globals['_EVENTREQUEST_TYPE']._serialized_start=116490
  _globals['_EVENTREQUEST_TYPE']._serialized_end=116659
  _globals['_EVENTREQUEST_TYPE_ENUM']._serialized_start=116499
  _globals['_EVENTREQUEST_TYPE_ENUM']._serialized_end=116659
  _globals['_EVENTSUBSCRIPTION']._serialized_start=116661
  _globals['_EVENTSUBSCRIPTION']._serialized_end=116759
  _globals['_LLDP']._serialized_start=116762
  _globals['_LLDP']._serialized_end=117092
  _globals['_LLDPCONNECTION']._serialized_start=117095
  _globals['_LLDPCONNECTION']._serialized_end=117264
  _globals['_LLDPCONNECTION_CHOICE']._serialized_start=117191
  _globals['_LLDPCONNECTION_CHOICE']._serialized_end=117239
  _globals['_LLDPCONNECTION_CHOICE_ENUM']._serialized_start=2414
  _globals['_LLDPCONNECTION_CHOICE_ENUM']._serialized_end=2452
  _globals['_LLDPCHASSISID']._serialized_start=117267
  _globals['_LLDPCHASSISID']._serialized_end=117620
  _globals['_LLDPCHASSISID_CHOICE']._serialized_start=117459
  _globals['_LLDPCHASSISID_CHOICE']._serialized_end=117564
  _globals['_LLDPCHASSISID_CHOICE_ENUM']._serialized_start=117469
  _globals['_LLDPCHASSISID_CHOICE_ENUM']._serialized_end=117564
  _globals['_LLDPPORTID']._serialized_start=117623
  _globals['_LLDPPORTID']._serialized_end=117974
  _globals['_LLDPPORTID_CHOICE']._serialized_start=117459
  _globals['_LLDPPORTID_CHOICE']._serialized_end=117564
  _globals['_LLDPPORTID_CHOICE_ENUM']._serialized_start=117469
  _globals['_LLDPPORTID_CHOICE_ENUM']._serialized_end=117564
  _globals['_LLDPCHASSISMACSUBTYPE']._serialized_start=117977
  _globals['_LLDPCHASSISMACSUBTYPE']._serialized_end=118186
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE']._serialized_start=3471
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE']._serialized_end=3525
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE_ENUM']._serialized_start=3481
  _globals['_LLDPCHASSISMACSUBTYPE_CHOICE_ENUM']._serialized_end=3525
  _globals['_LLDPPORTINTERFACENAMESUBTYPE']._serialized_start=118189
  _globals['_LLDPPORTINTERFACENAMESUBTYPE']._serialized_end=118412
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE']._serialized_start=3471
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE']._serialized_end=3525
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM']._serialized_start=3481
  _globals['_LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM']._serialized_end=3525
  _globals['_LLDPSYSTEMNAME']._serialized_start=118415
  _globals['_LLDPSYSTEMNAME']._serialized_end=118610
  _globals['_LLDPSYSTEMNAME_CHOICE']._serialized_start=3471
  _globals['_LLDPSYSTEMNAME_CHOICE']._serialized_end=3525
  _globals['_LLDPSYSTEMNAME_CHOICE_ENUM']._serialized_start=3481
  _globals['_LLDPSYSTEMNAME_CHOICE_ENUM']._serialized_end=3525
  _globals['_LLDPORGINFO']._serialized_start=118612
  _globals['_LLDPORGINFO']._serialized_end=118728
  _globals['_LLDPORGINFOTYPE']._serialized_start=118731
  _globals['_LLDPORGINFOTYPE']._serialized_end=118887
  _globals['_LLDPORGINFOTYPE_CHOICE']._serialized_start=118824
  _globals['_LLDPORGINFOTYPE_CHOICE']._serialized_end=118867
  _globals['_LLDPORGINFOTYPE_CHOICE_ENUM']._serialized_start=118834
  _globals['_LLDPORGINFOTYPE_CHOICE_ENUM']._serialized_end=118867
  _globals['_ERROR']._serialized_start=118890
  _globals['_ERROR']._serialized_end=119054
  _globals['_ERROR_KIND']._serialized_start=118975
  _globals['_ERROR_KIND']._serialized_end=119036
  _globals['_ERROR_KIND_ENUM']._serialized_start=118983
  _globals['_ERROR_KIND_ENUM']._serialized_end=119036
  _globals['_WARNING']._serialized_start=119056
  _globals['_WARNING']._serialized_end=119083
  _globals['_CONFIGUPDATE']._serialized_start=119086
  _globals['_CONFIGUPDATE']._serialized_end=119242
  _globals['_CONFIGUPDATE_CHOICE']._serialized_start=119187
  _globals['_CONFIGUPDATE_CHOICE']._serialized_end=119231
  _globals['_CONFIGUPDATE_CHOICE_ENUM']._serialized_start=119197
  _globals['_CONFIGUPDATE_CHOICE_ENUM']._serialized_end=119231
  _globals['_FLOWSUPDATE']._serialized_start=119245
  _globals['_FLOWSUPDATE']._serialized_end=119407
  _globals['_FLOWSUPDATE_PROPERTYNAMES']._serialized_start=119347
  _globals['_FLOWSUPDATE_PROPERTYNAMES']._serialized_end=119407
  _globals['_FLOWSUPDATE_PROPERTYNAMES_ENUM']._serialized_start=119364
  _globals['_FLOWSUPDATE_PROPERTYNAMES_ENUM']._serialized_end=119407
  _globals['_CONTROLSTATE']._serialized_start=119410
  _globals['_CONTROLSTATE']._serialized_end=119663
  _globals['_CONTROLSTATE_CHOICE']._serialized_start=119582
  _globals['_CONTROLSTATE_CHOICE']._serialized_end=119652
  _globals['_CONTROLSTATE_CHOICE_ENUM']._serialized_start=119592
  _globals['_CONTROLSTATE_CHOICE_ENUM']._serialized_end=119652
  _globals['_STATEPORT']._serialized_start=119666
  _globals['_STATEPORT']._serialized_end=119869
  _globals['_STATEPORT_CHOICE']._serialized_start=119802
  _globals['_STATEPORT_CHOICE']._serialized_end=119858
  _globals['_STATEPORT_CHOICE_ENUM']._serialized_start=119812
  _globals['_STATEPORT_CHOICE_ENUM']._serialized_end=119858
  _globals['_STATETRAFFIC']._serialized_start=119872
  _globals['_STATETRAFFIC']._serialized_end=120057
  _globals['_STATETRAFFIC_CHOICE']._serialized_start=119994
  _globals['_STATETRAFFIC_CHOICE']._serialized_end=120046
  _globals['_STATETRAFFIC_CHOICE_ENUM']._serialized_start=120004
  _globals['_STATETRAFFIC_CHOICE_ENUM']._serialized_end=120046
  _globals['_STATEPROTOCOL']._serialized_start=120060
  _globals['_STATEPROTOCOL']._serialized_end=120465
  _globals['_STATEPROTOCOL_CHOICE']._serialized_start=120360
  _globals['_STATEPROTOCOL_CHOICE']._serialized_end=120454
  _globals['_STATEPROTOCOL_CHOICE_ENUM']._serialized_start=120370
  _globals['_STATEPROTOCOL_CHOICE_ENUM']._serialized_end=120454
  _globals['_STATEPORTLINK']._serialized_start=120468
  _globals['_STATEPORTLINK']._serialized_end=120616
  _globals['_STATEPORTLINK_STATE']._serialized_start=120556
  _globals['_STATEPORTLINK_STATE']._serialized_end=120606
  _globals['_STATEPORTLINK_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPORTLINK_STATE_ENUM']._serialized_end=20084
  _globals['_STATEPORTCAPTURE']._serialized_start=120619
  _globals['_STATEPORTCAPTURE']._serialized_end=120776
  _globals['_STATEPORTCAPTURE_STATE']._serialized_start=120713
  _globals['_STATEPORTCAPTURE_STATE']._serialized_end=120766
  _globals['_STATEPORTCAPTURE_STATE_ENUM']._serialized_start=120722
  _globals['_STATEPORTCAPTURE_STATE_ENUM']._serialized_end=120766
  _globals['_STATETRAFFICFLOWTRANSMIT']._serialized_start=120779
  _globals['_STATETRAFFICFLOWTRANSMIT']._serialized_end=120975
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE']._serialized_start=120889
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE']._serialized_end=120965
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE_ENUM']._serialized_start=120898
  _globals['_STATETRAFFICFLOWTRANSMIT_STATE_ENUM']._serialized_end=120965
  _globals['_STATEPROTOCOLALL']._serialized_start=120978
  _globals['_STATEPROTOCOLALL']._serialized_end=121115
  _globals['_STATEPROTOCOLALL_STATE']._serialized_start=120713
  _globals['_STATEPROTOCOLALL_STATE']._serialized_end=120766
  _globals['_STATEPROTOCOLALL_STATE_ENUM']._serialized_start=120722
  _globals['_STATEPROTOCOLALL_STATE_ENUM']._serialized_end=120766
  _globals['_STATEPROTOCOLROUTE']._serialized_start=121118
  _globals['_STATEPROTOCOLROUTE']._serialized_end=121282
  _globals['_STATEPROTOCOLROUTE_STATE']._serialized_start=121211
  _globals['_STATEPROTOCOLROUTE_STATE']._serialized_end=121272
  _globals['_STATEPROTOCOLROUTE_STATE_ENUM']._serialized_start=121220
  _globals['_STATEPROTOCOLROUTE_STATE_ENUM']._serialized_end=121272
  _globals['_STATEPROTOCOLLACP']._serialized_start=121285
  _globals['_STATEPROTOCOLLACP']._serialized_end=121537
  _globals['_STATEPROTOCOLLACP_CHOICE']._serialized_start=121464
  _globals['_STATEPROTOCOLLACP_CHOICE']._serialized_end=121526
  _globals['_STATEPROTOCOLLACP_CHOICE_ENUM']._serialized_start=121474
  _globals['_STATEPROTOCOLLACP_CHOICE_ENUM']._serialized_end=121526
  _globals['_STATEPROTOCOLLACPADMIN']._serialized_start=121540
  _globals['_STATEPROTOCOLLACPADMIN']._serialized_end=121712
  _globals['_STATEPROTOCOLLACPADMIN_STATE']._serialized_start=120556
  _globals['_STATEPROTOCOLLACPADMIN_STATE']._serialized_end=120606
  _globals['_STATEPROTOCOLLACPADMIN_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPROTOCOLLACPADMIN_STATE_ENUM']._serialized_end=20084
  _globals['_STATEPROTOCOLLACPMEMBERPORTS']._serialized_start=121715
  _globals['_STATEPROTOCOLLACPMEMBERPORTS']._serialized_end=121899
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE']._serialized_start=120556
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE']._serialized_end=120606
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPROTOCOLLACPMEMBERPORTS_STATE_ENUM']._serialized_end=20084
  _globals['_STATEPROTOCOLBGP']._serialized_start=121902
  _globals['_STATEPROTOCOLBGP']._serialized_end=122076
  _globals['_STATEPROTOCOLBGP_CHOICE']._serialized_start=122021
  _globals['_STATEPROTOCOLBGP_CHOICE']._serialized_end=122065
  _globals['_STATEPROTOCOLBGP_CHOICE_ENUM']._serialized_start=122031
  _globals['_STATEPROTOCOLBGP_CHOICE_ENUM']._serialized_end=122065
  _globals['_STATEPROTOCOLBGPPEERS']._serialized_start=122079
  _globals['_STATEPROTOCOLBGPPEERS']._serialized_end=122243
  _globals['_STATEPROTOCOLBGPPEERS_STATE']._serialized_start=120556
  _globals['_STATEPROTOCOLBGPPEERS_STATE']._serialized_end=120606
  _globals['_STATEPROTOCOLBGPPEERS_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPROTOCOLBGPPEERS_STATE_ENUM']._serialized_end=20084
  _globals['_STATEPROTOCOLISIS']._serialized_start=122246
  _globals['_STATEPROTOCOLISIS']._serialized_end=122429
  _globals['_STATEPROTOCOLISIS_CHOICE']._serialized_start=122372
  _globals['_STATEPROTOCOLISIS_CHOICE']._serialized_end=122418
  _globals['_STATEPROTOCOLISIS_CHOICE_ENUM']._serialized_start=122382
  _globals['_STATEPROTOCOLISIS_CHOICE_ENUM']._serialized_end=122418
  _globals['_STATEPROTOCOLISISROUTERS']._serialized_start=122432
  _globals['_STATEPROTOCOLISISROUTERS']._serialized_end=122604
  _globals['_STATEPROTOCOLISISROUTERS_STATE']._serialized_start=120556
  _globals['_STATEPROTOCOLISISROUTERS_STATE']._serialized_end=120606
  _globals['_STATEPROTOCOLISISROUTERS_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPROTOCOLISISROUTERS_STATE_ENUM']._serialized_end=20084
  _globals['_STATEPROTOCOLOSPFV2']._serialized_start=122607
  _globals['_STATEPROTOCOLOSPFV2']._serialized_end=122796
  _globals['_STATEPROTOCOLOSPFV2_CHOICE']._serialized_start=122372
  _globals['_STATEPROTOCOLOSPFV2_CHOICE']._serialized_end=122418
  _globals['_STATEPROTOCOLOSPFV2_CHOICE_ENUM']._serialized_start=122382
  _globals['_STATEPROTOCOLOSPFV2_CHOICE_ENUM']._serialized_end=122418
  _globals['_STATEPROTOCOLOSPFV2ROUTERS']._serialized_start=122799
  _globals['_STATEPROTOCOLOSPFV2ROUTERS']._serialized_end=122975
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE']._serialized_start=120556
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE']._serialized_end=120606
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE_ENUM']._serialized_start=20043
  _globals['_STATEPROTOCOLOSPFV2ROUTERS_STATE_ENUM']._serialized_end=20084
  _globals['_CONTROLACTION']._serialized_start=122978
  _globals['_CONTROLACTION']._serialized_end=123145
  _globals['_CONTROLACTION_CHOICE']._serialized_start=123087
  _globals['_CONTROLACTION_CHOICE']._serialized_end=123134
  _globals['_CONTROLACTION_CHOICE_ENUM']._serialized_start=123097
  _globals['_CONTROLACTION_CHOICE_ENUM']._serialized_end=123134
  _globals['_CONTROLACTIONRESPONSE']._serialized_start=123147
  _globals['_CONTROLACTIONRESPONSE']._serialized_end=123227
  _globals['_ACTIONRESPONSE']._serialized_start=123230
  _globals['_ACTIONRESPONSE']._serialized_end=123407
  _globals['_ACTIONRESPONSE_CHOICE']._serialized_start=123087
  _globals['_ACTIONRESPONSE_CHOICE']._serialized_end=123134
  _globals['_ACTIONRESPONSE_CHOICE_ENUM']._serialized_start=123097
  _globals['_ACTIONRESPONSE_CHOICE_ENUM']._serialized_end=123134
  _globals['_ACTIONPROTOCOL']._serialized_start=123410
  _globals['_ACTIONPROTOCOL']._serialized_end=123670
  _globals['_ACTIONPROTOCOL_CHOICE']._serialized_start=123597
  _globals['_ACTIONPROTOCOL_CHOICE']._serialized_end=123659
  _globals['_ACTIONPROTOCOL_CHOICE_ENUM']._serialized_start=123607
  _globals['_ACTIONPROTOCOL_CHOICE_ENUM']._serialized_end=123659
  _globals['_ACTIONRESPONSEPROTOCOL']._serialized_start=123673
  _globals['_ACTIONRESPONSEPROTOCOL']._serialized_end=123919
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE']._serialized_start=123855
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE']._serialized_end=123908
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE_ENUM']._serialized_start=32736
  _globals['_ACTIONRESPONSEPROTOCOL_CHOICE_ENUM']._serialized_end=32779
  _globals['_ACTIONPROTOCOLIPV4']._serialized_start=123922
  _globals['_ACTIONPROTOCOLIPV4']._serialized_end=124099
  _globals['_ACTIONPROTOCOLIPV4_CHOICE']._serialized_start=124045
  _globals['_ACTIONPROTOCOLIPV4_CHOICE']._serialized_end=124088
  _globals['_ACTIONPROTOCOLIPV4_CHOICE_ENUM']._serialized_start=124055
  _globals['_ACTIONPROTOCOLIPV4_CHOICE_ENUM']._serialized_end=124088
  _globals['_ACTIONRESPONSEPROTOCOLIPV4']._serialized_start=124102
  _globals['_ACTIONRESPONSEPROTOCOLIPV4']._serialized_end=124303
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE']._serialized_start=124045
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE']._serialized_end=124088
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM']._serialized_start=124055
  _globals['_ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM']._serialized_end=124088
  _globals['_ACTIONPROTOCOLIPV4PING']._serialized_start=124305
  _globals['_ACTIONPROTOCOLIPV4PING']._serialized_end=124383
  _globals['_ACTIONPROTOCOLIPV4PINGREQUEST']._serialized_start=124385
  _globals['_ACTIONPROTOCOLIPV4PINGREQUEST']._serialized_end=124484
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PING']._serialized_start=124486
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PING']._serialized_end=124582
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE']._serialized_start=124585
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE']._serialized_end=124844
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT']._serialized_start=124749
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT']._serialized_end=124809
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM']._serialized_start=124759
  _globals['_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM']._serialized_end=124809
  _globals['_ACTIONPROTOCOLIPV6']._serialized_start=124847
  _globals['_ACTIONPROTOCOLIPV6']._serialized_end=125024
  _globals['_ACTIONPROTOCOLIPV6_CHOICE']._serialized_start=124045
  _globals['_ACTIONPROTOCOLIPV6_CHOICE']._serialized_end=124088
  _globals['_ACTIONPROTOCOLIPV6_CHOICE_ENUM']._serialized_start=124055
  _globals['_ACTIONPROTOCOLIPV6_CHOICE_ENUM']._serialized_end=124088
  _globals['_ACTIONRESPONSEPROTOCOLIPV6']._serialized_start=125027
  _globals['_ACTIONRESPONSEPROTOCOLIPV6']._serialized_end=125228
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE']._serialized_start=124045
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE']._serialized_end=124088
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM']._serialized_start=124055
  _globals['_ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM']._serialized_end=124088
  _globals['_ACTIONPROTOCOLIPV6PING']._serialized_start=125230
  _globals['_ACTIONPROTOCOLIPV6PING']._serialized_end=125308
  _globals['_ACTIONPROTOCOLIPV6PINGREQUEST']._serialized_start=125310
  _globals['_ACTIONPROTOCOLIPV6PINGREQUEST']._serialized_end=125409
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PING']._serialized_start=125411
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PING']._serialized_end=125507
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE']._serialized_start=125510
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE']._serialized_end=125769
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT']._serialized_start=124749
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT']._serialized_end=124809
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM']._serialized_start=124759
  _globals['_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM']._serialized_end=124809
  _globals['_ACTIONPROTOCOLBGP']._serialized_start=125772
  _globals['_ACTIONPROTOCOLBGP']._serialized_end=126083
  _globals['_ACTIONPROTOCOLBGP_CHOICE']._serialized_start=125990
  _globals['_ACTIONPROTOCOLBGP_CHOICE']._serialized_end=126072
  _globals['_ACTIONPROTOCOLBGP_CHOICE_ENUM']._serialized_start=126000
  _globals['_ACTIONPROTOCOLBGP_CHOICE_ENUM']._serialized_end=126072
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION']._serialized_start=126086
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION']._serialized_end=126811
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE']._serialized_start=126611
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE']._serialized_end=126800
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM']._serialized_start=126622
  _globals['_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM']._serialized_end=126800
  _globals['_ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART']._serialized_start=126814
  _globals['_ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART']._serialized_end=126995
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION']._serialized_start=126998
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION']._serialized_end=127738
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE']._serialized_start=126611
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE']._serialized_end=126800
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE_ENUM']._serialized_start=126622
  _globals['_ACTIONPROTOCOLBGPGRACEFULRESTARTNOTIFICATION_CHOICE_ENUM']._serialized_end=126800
  _globals['_METRICSREQUEST']._serialized_start=127741
  _globals['_METRICSREQUEST']._serialized_end=128822
  _globals['_METRICSREQUEST_CHOICE']._serialized_start=128560
  _globals['_METRICSREQUEST_CHOICE']._serialized_end=128811
  _globals['_METRICSREQUEST_CHOICE_ENUM']._serialized_start=128571
  _globals['_METRICSREQUEST_CHOICE_ENUM']._serialized_end=128811
  _globals['_METRICSRESPONSE']._serialized_start=128825
  _globals['_METRICSRESPONSE']._serialized_end=130015
  _globals['_METRICSRESPONSE_CHOICE']._serialized_start=129649
  _globals['_METRICSRESPONSE_CHOICE']._serialized_end=130004
  _globals['_METRICSRESPONSE_CHOICE_ENUM']._serialized_start=129660
  _globals['_METRICSRESPONSE_CHOICE_ENUM']._serialized_end=130004
  _globals['_PORTMETRICSREQUEST']._serialized_start=130018
  _globals['_PORTMETRICSREQUEST']._serialized_end=130368
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES']._serialized_start=130125
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES']._serialized_end=130368
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=130141
  _globals['_PORTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=130368
  _globals['_PORTMETRIC']._serialized_start=130371
  _globals['_PORTMETRIC']._serialized_end=131187
  _globals['_PORTMETRIC_LINK']._serialized_start=130813
  _globals['_PORTMETRIC_LINK']._serialized_end=130862
  _globals['_PORTMETRIC_LINK_ENUM']._serialized_start=20043
  _globals['_PORTMETRIC_LINK_ENUM']._serialized_end=20084
  _globals['_PORTMETRIC_CAPTURE']._serialized_start=130864
  _globals['_PORTMETRIC_CAPTURE']._serialized_end=130924
  _globals['_PORTMETRIC_CAPTURE_ENUM']._serialized_start=130875
  _globals['_PORTMETRIC_CAPTURE_ENUM']._serialized_end=130924
  _globals['_PORTMETRIC_TRANSMIT']._serialized_start=130926
  _globals['_PORTMETRIC_TRANSMIT']._serialized_end=130987
  _globals['_PORTMETRIC_TRANSMIT_ENUM']._serialized_start=130875
  _globals['_PORTMETRIC_TRANSMIT_ENUM']._serialized_end=130924
  _globals['_FLOWMETRICSREQUEST']._serialized_start=131190
  _globals['_FLOWMETRICSREQUEST']._serialized_end=131686
  _globals['_FLOWMETRICSREQUEST_METRICNAMES']._serialized_start=131351
  _globals['_FLOWMETRICSREQUEST_METRICNAMES']._serialized_end=131686
  _globals['_FLOWMETRICSREQUEST_METRICNAMES_ENUM']._serialized_start=131367
  _globals['_FLOWMETRICSREQUEST_METRICNAMES_ENUM']._serialized_end=131686
  _globals['_FLOWTAGGEDMETRICSFILTER']._serialized_start=131689
  _globals['_FLOWTAGGEDMETRICSFILTER']._serialized_end=132246
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES']._serialized_start=131887
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES']._serialized_end=132208
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_start=131903
  _globals['_FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM']._serialized_end=132208
  _globals['_FLOWMETRICTAGFILTER']._serialized_start=132248
  _globals['_FLOWMETRICTAGFILTER']._serialized_end=132313
  _globals['_FLOWMETRIC']._serialized_start=132316
  _globals['_FLOWMETRIC']._serialized_end=133412
  _globals['_FLOWMETRIC_TRANSMIT']._serialized_start=133018
  _globals['_FLOWMETRIC_TRANSMIT']._serialized_end=133091
  _globals['_FLOWMETRIC_TRANSMIT_ENUM']._serialized_start=133030
  _globals['_FLOWMETRIC_TRANSMIT_ENUM']._serialized_end=133091
  _globals['_FLOWTAGGEDMETRIC']._serialized_start=133415
  _globals['_FLOWTAGGEDMETRIC']._serialized_end=134266
  _globals['_FLOWMETRICTAG']._serialized_start=134268
  _globals['_FLOWMETRICTAG']._serialized_end=134351
  _globals['_FLOWMETRICTAGVALUE']._serialized_start=134354
  _globals['_FLOWMETRICTAGVALUE']._serialized_end=134548
  _globals['_FLOWMETRICTAGVALUE_CHOICE']._serialized_start=134470
  _globals['_FLOWMETRICTAGVALUE_CHOICE']._serialized_end=134521
  _globals['_FLOWMETRICTAGVALUE_CHOICE_ENUM']._serialized_start=134480
  _globals['_FLOWMETRICTAGVALUE_CHOICE_ENUM']._serialized_end=134521
  _globals['_METRICTIMESTAMP']._serialized_start=134550
  _globals['_METRICTIMESTAMP']._serialized_end=134677
  _globals['_METRICLATENCY']._serialized_start=134680
  _globals['_METRICLATENCY']._serialized_end=134815
  _globals['_BGPV4METRICSREQUEST']._serialized_start=134818
  _globals['_BGPV4METRICSREQUEST']._serialized_end=135323
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES']._serialized_start=134927
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES']._serialized_end=135323
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=134943
  _globals['_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=135323
  _globals['_BGPV4METRIC']._serialized_start=135326
  _globals['_BGPV4METRIC']._serialized_end=136456
  _globals['_BGPV4METRIC_SESSIONSTATE']._serialized_start=135929
  _globals['_BGPV4METRIC_SESSIONSTATE']._serialized_end=135986
  _globals['_BGPV4METRIC_SESSIONSTATE_ENUM']._serialized_start=20043
  _globals['_BGPV4METRIC_SESSIONSTATE_ENUM']._serialized_end=20084
  _globals['_BGPV4METRIC_FSMSTATE']._serialized_start=135988
  _globals['_BGPV4METRIC_FSMSTATE']._serialized_end=136106
  _globals['_BGPV4METRIC_FSMSTATE_ENUM']._serialized_start=136000
  _globals['_BGPV4METRIC_FSMSTATE_ENUM']._serialized_end=136106
  _globals['_BGPV6METRICSREQUEST']._serialized_start=136459
  _globals['_BGPV6METRICSREQUEST']._serialized_end=136964
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES']._serialized_start=134927
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES']._serialized_end=135323
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=134943
  _globals['_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=135323
  _globals['_BGPV6METRIC']._serialized_start=136967
  _globals['_BGPV6METRIC']._serialized_end=138097
  _globals['_BGPV6METRIC_SESSIONSTATE']._serialized_start=135929
  _globals['_BGPV6METRIC_SESSIONSTATE']._serialized_end=135986
  _globals['_BGPV6METRIC_SESSIONSTATE_ENUM']._serialized_start=20043
  _globals['_BGPV6METRIC_SESSIONSTATE_ENUM']._serialized_end=20084
  _globals['_BGPV6METRIC_FSMSTATE']._serialized_start=135988
  _globals['_BGPV6METRIC_FSMSTATE']._serialized_end=136106
  _globals['_BGPV6METRIC_FSMSTATE_ENUM']._serialized_start=136000
  _globals['_BGPV6METRIC_FSMSTATE_ENUM']._serialized_end=136106
  _globals['_ISISMETRICSREQUEST']._serialized_start=138100
  _globals['_ISISMETRICSREQUEST']._serialized_end=138886
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES']._serialized_start=138209
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES']._serialized_end=138886
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=138225
  _globals['_ISISMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=138886
  _globals['_ISISMETRIC']._serialized_start=138889
  _globals['_ISISMETRIC']._serialized_end=140413
  _globals['_LAGMETRICSREQUEST']._serialized_start=140416
  _globals['_LAGMETRICSREQUEST']._serialized_end=140733
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES']._serialized_start=140520
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES']._serialized_end=140733
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=140536
  _globals['_LAGMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=140733
  _globals['_LAGMETRIC']._serialized_start=140736
  _globals['_LAGMETRIC']._serialized_end=141292
  _globals['_LAGMETRIC_OPERSTATUS']._serialized_start=141064
  _globals['_LAGMETRIC_OPERSTATUS']._serialized_end=141119
  _globals['_LAGMETRIC_OPERSTATUS_ENUM']._serialized_start=20043
  _globals['_LAGMETRIC_OPERSTATUS_ENUM']._serialized_end=20084
  _globals['_LACPMETRICSREQUEST']._serialized_start=141295
  _globals['_LACPMETRICSREQUEST']._serialized_end=141731
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES']._serialized_start=141432
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES']._serialized_end=141731
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=141448
  _globals['_LACPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=141731
  _globals['_LACPMETRIC']._serialized_start=141734
  _globals['_LACPMETRIC']._serialized_end=142771
  _globals['_LACPMETRIC_ACTIVITY']._serialized_start=142300
  _globals['_LACPMETRIC_ACTIVITY']._serialized_end=142360
  _globals['_LACPMETRIC_ACTIVITY_ENUM']._serialized_start=142312
  _globals['_LACPMETRIC_ACTIVITY_ENUM']._serialized_end=142360
  _globals['_LACPMETRIC_TIMEOUT']._serialized_start=142362
  _globals['_LACPMETRIC_TIMEOUT']._serialized_end=142417
  _globals['_LACPMETRIC_TIMEOUT_ENUM']._serialized_start=142373
  _globals['_LACPMETRIC_TIMEOUT_ENUM']._serialized_end=142417
  _globals['_LACPMETRIC_SYNCHRONIZATION']._serialized_start=142419
  _globals['_LACPMETRIC_SYNCHRONIZATION']._serialized_end=142488
  _globals['_LACPMETRIC_SYNCHRONIZATION_ENUM']._serialized_start=142438
  _globals['_LACPMETRIC_SYNCHRONIZATION_ENUM']._serialized_end=142488
  _globals['_LLDPMETRICSREQUEST']._serialized_start=142774
  _globals['_LLDPMETRICSREQUEST']._serialized_end=143027
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES']._serialized_start=142881
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES']._serialized_end=143027
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=142897
  _globals['_LLDPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=143027
  _globals['_LLDPMETRIC']._serialized_start=143030
  _globals['_LLDPMETRIC']._serialized_end=143332
  _globals['_RSVPMETRICSREQUEST']._serialized_start=143335
  _globals['_RSVPMETRICSREQUEST']._serialized_end=144041
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES']._serialized_start=143444
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES']._serialized_end=144041
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=143460
  _globals['_RSVPMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=144041
  _globals['_RSVPMETRIC']._serialized_start=144044
  _globals['_RSVPMETRIC']._serialized_end=145440
  _globals['_DHCPV4CLIENTMETRICSREQUEST']._serialized_start=145443
  _globals['_DHCPV4CLIENTMETRICSREQUEST']._serialized_end=145744
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_start=145568
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_end=145744
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=145584
  _globals['_DHCPV4CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=145744
  _globals['_DHCPV4CLIENTMETRIC']._serialized_start=145747
  _globals['_DHCPV4CLIENTMETRIC']._serialized_end=146125
  _globals['_DHCPV4SERVERMETRICSREQUEST']._serialized_start=146128
  _globals['_DHCPV4SERVERMETRICSREQUEST']._serialized_end=146433
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_start=146253
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_end=146433
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=146269
  _globals['_DHCPV4SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=146433
  _globals['_DHCPV4SERVERMETRIC']._serialized_start=146436
  _globals['_DHCPV4SERVERMETRIC']._serialized_end=146822
  _globals['_DHCPV6CLIENTMETRICSREQUEST']._serialized_start=146825
  _globals['_DHCPV6CLIENTMETRICSREQUEST']._serialized_end=147305
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_start=146950
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES']._serialized_end=147305
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=146966
  _globals['_DHCPV6CLIENTMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=147305
  _globals['_DHCPV6CLIENTMETRIC']._serialized_start=147308
  _globals['_DHCPV6CLIENTMETRIC']._serialized_end=148092
  _globals['_DHCPV6SERVERMETRICSREQUEST']._serialized_start=148095
  _globals['_DHCPV6SERVERMETRICSREQUEST']._serialized_end=148611
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_start=148220
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES']._serialized_end=148611
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=148236
  _globals['_DHCPV6SERVERMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=148611
  _globals['_DHCPV6SERVERMETRIC']._serialized_start=148614
  _globals['_DHCPV6SERVERMETRIC']._serialized_end=149486
  _globals['_OSPFV2METRICSREQUEST']._serialized_start=149489
  _globals['_OSPFV2METRICSREQUEST']._serialized_end=150358
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES']._serialized_start=149602
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES']._serialized_end=150358
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=149618
  _globals['_OSPFV2METRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=150358
  _globals['_OSPFV2METRIC']._serialized_start=150361
  _globals['_OSPFV2METRIC']._serialized_end=152101
  _globals['_CONVERGENCEREQUEST']._serialized_start=152103
  _globals['_CONVERGENCEREQUEST']._serialized_end=152143
  _globals['_CONVERGENCEMETRIC']._serialized_start=152146
  _globals['_CONVERGENCEMETRIC']._serialized_end=152400
  _globals['_CONVERGENCEEVENT']._serialized_start=152403
  _globals['_CONVERGENCEEVENT']._serialized_end=152794
  _globals['_CONVERGENCEEVENT_TYPE']._serialized_start=116490
  _globals['_CONVERGENCEEVENT_TYPE']._serialized_end=116659
  _globals['_CONVERGENCEEVENT_TYPE_ENUM']._serialized_start=116499
  _globals['_CONVERGENCEEVENT_TYPE_ENUM']._serialized_end=116659
  _globals['_MACSECMETRICSREQUEST']._serialized_start=152797
  _globals['_MACSECMETRICSREQUEST']._serialized_end=153381
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES']._serialized_start=152917
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES']._serialized_end=153381
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=152933
  _globals['_MACSECMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=153381
  _globals['_MACSECMETRIC']._serialized_start=153384
  _globals['_MACSECMETRIC']._serialized_end=154524
  _globals['_MACSECMETRIC_SESSIONSTATE']._serialized_start=135929
  _globals['_MACSECMETRIC_SESSIONSTATE']._serialized_end=135986
  _globals['_MACSECMETRIC_SESSIONSTATE_ENUM']._serialized_start=20043
  _globals['_MACSECMETRIC_SESSIONSTATE_ENUM']._serialized_end=20084
  _globals['_MKAMETRICSREQUEST']._serialized_start=154527
  _globals['_MKAMETRICSREQUEST']._serialized_end=154888
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES']._serialized_start=154632
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES']._serialized_end=154888
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_start=154648
  _globals['_MKAMETRICSREQUEST_COLUMNNAMES_ENUM']._serialized_end=154888
  _globals['_MKAMETRIC']._serialized_start=154891
  _globals['_MKAMETRIC']._serialized_end=155537
  _globals['_MKAMETRIC_SESSIONSTATE']._serialized_start=135929
  _globals['_MKAMETRIC_SESSIONSTATE']._serialized_end=135986
  _globals['_MKAMETRIC_SESSIONSTATE_ENUM']._serialized_start=20043
  _globals['_MKAMETRIC_SESSIONSTATE_ENUM']._serialized_end=20084
  _globals['_STATESREQUEST']._serialized_start=155540
  _globals['_STATESREQUEST']._serialized_end=156451
  _globals['_STATESREQUEST_CHOICE']._serialized_start=156197
  _globals['_STATESREQUEST_CHOICE']._serialized_end=156440
  _globals['_STATESREQUEST_CHOICE_ENUM']._serialized_start=156208
  _globals['_STATESREQUEST_CHOICE_ENUM']._serialized_end=156440
  _globals['_STATESRESPONSE']._serialized_start=156454
  _globals['_STATESRESPONSE']._serialized_end=157291
  _globals['_STATESRESPONSE_CHOICE']._serialized_start=156197
  _globals['_STATESRESPONSE_CHOICE']._serialized_end=156440
  _globals['_STATESRESPONSE_CHOICE_ENUM']._serialized_start=156208
  _globals['_STATESRESPONSE_CHOICE_ENUM']._serialized_end=156440
  _globals['_NEIGHBORSV4STATESREQUEST']._serialized_start=157293
  _globals['_NEIGHBORSV4STATESREQUEST']._serialized_end=157343
  _globals['_NEIGHBORSV4STATE']._serialized_start=157346
  _globals['_NEIGHBORSV4STATE']._serialized_end=157510
  _globals['_NEIGHBORSV6STATESREQUEST']._serialized_start=157512
  _globals['_NEIGHBORSV6STATESREQUEST']._serialized_end=157562
  _globals['_NEIGHBORSV6STATE']._serialized_start=157565
  _globals['_NEIGHBORSV6STATE']._serialized_end=157729
  _globals['_BGPPREFIXSTATEREQUEST']._serialized_start=157732
  _globals['_BGPPREFIXSTATEREQUEST']._serialized_end=158054
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS']._serialized_start=157978
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS']._serialized_end=158054
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM']._serialized_start=52473
  _globals['_BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM']._serialized_end=52532
  _globals['_BGPPREFIXIPV4UNICASTFILTER']._serialized_start=158057
  _globals['_BGPPREFIXIPV4UNICASTFILTER']._serialized_end=158330
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN']._serialized_start=26668
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN']._serialized_end=26735
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM']._serialized_end=26735
  _globals['_BGPPREFIXIPV6UNICASTFILTER']._serialized_start=158333
  _globals['_BGPPREFIXIPV6UNICASTFILTER']._serialized_end=158606
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN']._serialized_start=26668
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN']._serialized_end=26735
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM']._serialized_end=26735
  _globals['_BGPPREFIXESSTATE']._serialized_start=158609
  _globals['_BGPPREFIXESSTATE']._serialized_end=158799
  _globals['_BGPPREFIXIPV4UNICASTSTATE']._serialized_start=158802
  _globals['_BGPPREFIXIPV4UNICASTSTATE']._serialized_end=159455
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN']._serialized_start=26668
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN']._serialized_end=26735
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM']._serialized_end=26735
  _globals['_BGPPREFIXIPV6UNICASTSTATE']._serialized_start=159458
  _globals['_BGPPREFIXIPV6UNICASTSTATE']._serialized_end=160111
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN']._serialized_start=26668
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN']._serialized_end=26735
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM']._serialized_start=26678
  _globals['_BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM']._serialized_end=26735
  _globals['_RESULTEXTENDEDCOMMUNITY']._serialized_start=160113
  _globals['_RESULTEXTENDEDCOMMUNITY']._serialized_end=160224
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED']._serialized_start=160227
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED']._serialized_end=160985
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE']._serialized_start=160781
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE']._serialized_end=160974
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE_ENUM']._serialized_start=160792
  _globals['_RESULTEXTENDEDCOMMUNITYSTRUCTURED_CHOICE_ENUM']._serialized_end=160974
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_start=160988
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTETARGET']._serialized_end=161150
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_start=161153
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPEROUTEORIGIN']._serialized_end=161315
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_start=161318
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE']._serialized_end=161734
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=34453
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_start=161737
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTEORIGIN']._serialized_end=161906
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_start=161909
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPEROUTETARGET']._serialized_end=162078
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_start=162081
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE']._serialized_end=162509
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_start=34453
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEIPV4ADDRESSTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_start=162512
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTETARGET']._serialized_end=162674
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_start=162677
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPEROUTEORIGIN']._serialized_end=162839
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_start=162842
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE']._serialized_end=163258
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_start=34453
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_start=34463
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVE4OCTETASTYPE_CHOICE_ENUM']._serialized_end=34538
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_start=163260
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPECOLOR']._serialized_end=163370
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_start=163373
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPEENCAPSULATION']._serialized_end=163509
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_start=163512
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE']._serialized_end=163904
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_start=36575
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE']._serialized_end=36654
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_start=36585
  _globals['_RESULTEXTENDEDCOMMUNITYTRANSITIVEOPAQUETYPE_CHOICE_ENUM']._serialized_end=36654
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_start=163907
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPELINKBANDWIDTH']._serialized_end=164058
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_start=164061
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE']._serialized_end=164373
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_start=37414
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE']._serialized_end=37475
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_start=37424
  _globals['_RESULTEXTENDEDCOMMUNITYNONTRANSITIVE2OCTETASTYPE_CHOICE_ENUM']._serialized_end=37475
  _globals['_RESULTBGPCOMMUNITY']._serialized_start=164376
  _globals['_RESULTBGPCOMMUNITY']._serialized_end=164680
  _globals['_RESULTBGPCOMMUNITY_TYPE']._serialized_start=26997
  _globals['_RESULTBGPCOMMUNITY_TYPE']._serialized_end=27139
  _globals['_RESULTBGPCOMMUNITY_TYPE_ENUM']._serialized_start=27006
  _globals['_RESULTBGPCOMMUNITY_TYPE_ENUM']._serialized_end=27139
  _globals['_RESULTBGPASPATH']._serialized_start=164682
  _globals['_RESULTBGPASPATH']._serialized_end=164746
  _globals['_RESULTBGPASPATHSEGMENT']._serialized_start=164749
  _globals['_RESULTBGPASPATHSEGMENT']._serialized_end=164955
  _globals['_RESULTBGPASPATHSEGMENT_TYPE']._serialized_start=28100
  _globals['_RESULTBGPASPATHSEGMENT_TYPE']._serialized_end=28193
  _globals['_RESULTBGPASPATHSEGMENT_TYPE_ENUM']._serialized_start=28108
  _globals['_RESULTBGPASPATHSEGMENT_TYPE_ENUM']._serialized_end=28193
  _globals['_ISISLSPSSTATEREQUEST']._serialized_start=164957
  _globals['_ISISLSPSSTATEREQUEST']._serialized_end=165006
  _globals['_ISISLSPSSTATE']._serialized_start=165008
  _globals['_ISISLSPSSTATE']._serialized_end=165108
  _globals['_ISISLSPSTATE']._serialized_start=165111
  _globals['_ISISLSPSTATE']._serialized_end=165533
  _globals['_ISISLSPSTATE_PDUTYPE']._serialized_start=165379
  _globals['_ISISLSPSTATE_PDUTYPE']._serialized_end=165439
  _globals['_ISISLSPSTATE_PDUTYPE_ENUM']._serialized_start=16144
  _globals['_ISISLSPSTATE_PDUTYPE_ENUM']._serialized_end=16193
  _globals['_ISISLSPTLVS']._serialized_start=165536
  _globals['_ISISLSPTLVS']._serialized_end=166097
  _globals['_ISISLSPHOSTNAME']._serialized_start=166099
  _globals['_ISISLSPHOSTNAME']._serialized_end=166152
  _globals['_ISISLSPFLAGS']._serialized_start=166155
  _globals['_ISISLSPFLAGS']._serialized_end=166457
  _globals['_ISISLSPISREACHABILITYTLV']._serialized_start=166459
  _globals['_ISISLSPISREACHABILITYTLV']._serialized_end=166526
  _globals['_ISISLSPEXTENDEDISREACHABILITYTLV']._serialized_start=166528
  _globals['_ISISLSPEXTENDEDISREACHABILITYTLV']._serialized_end=166611
  _globals['_ISISLSPNEIGHBOR']._serialized_start=166613
  _globals['_ISISLSPNEIGHBOR']._serialized_end=166668
  _globals['_ISISLSPEXTENDEDNEIGHBOR']._serialized_start=166670
  _globals['_ISISLSPEXTENDEDNEIGHBOR']._serialized_end=166783
  _globals['_ISISLSPIPV4INTERNALREACHABILITYTLV']._serialized_start=166785
  _globals['_ISISLSPIPV4INTERNALREACHABILITYTLV']._serialized_end=166861
  _globals['_ISISLSPIPV4EXTERNALREACHABILITYTLV']._serialized_start=166863
  _globals['_ISISLSPIPV4EXTERNALREACHABILITYTLV']._serialized_end=166939
  _globals['_ISISLSPV4PREFIX']._serialized_start=166942
  _globals['_ISISLSPV4PREFIX']._serialized_end=167413
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20021
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20084
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20043
  _globals['_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20084
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE']._serialized_start=19954
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE']._serialized_end=20019
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE_ENUM']._serialized_start=19968
  _globals['_ISISLSPV4PREFIX_ORIGINTYPE_ENUM']._serialized_end=20019
  _globals['_ISISLSPEXTENDEDIPV4REACHABILITYTLV']._serialized_start=167415
  _globals['_ISISLSPEXTENDEDIPV4REACHABILITYTLV']._serialized_end=167499
  _globals['_ISISLSPEXTENDEDV4PREFIX']._serialized_start=167502
  _globals['_ISISLSPEXTENDEDV4PREFIX']._serialized_end=167927
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20021
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20084
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20043
  _globals['_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20084
  _globals['_ISISLSPIPV6REACHABILITYTLV']._serialized_start=167929
  _globals['_ISISLSPIPV6REACHABILITYTLV']._serialized_end=167997
  _globals['_ISISLSPV6PREFIX']._serialized_start=168000
  _globals['_ISISLSPV6PREFIX']._serialized_end=168556
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE']._serialized_start=20021
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE']._serialized_end=20084
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_start=20043
  _globals['_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM']._serialized_end=20084
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE']._serialized_start=19954
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE']._serialized_end=20019
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE_ENUM']._serialized_start=19968
  _globals['_ISISLSPV6PREFIX_ORIGINTYPE_ENUM']._serialized_end=20019
  _globals['_ISISLSPPREFIXATTRIBUTES']._serialized_start=168558
  _globals['_ISISLSPPREFIXATTRIBUTES']._serialized_end=168679
  _globals['_ISISLSPPREFIXSID']._serialized_start=168681
  _globals['_ISISLSPPREFIXSID']._serialized_end=168794
  _globals['_ISISLSPCAPABILITY']._serialized_start=168797
  _globals['_ISISLSPCAPABILITY']._serialized_end=169214
  _globals['_ISISLSPCAPABILITY_SBIT']._serialized_start=22193
  _globals['_ISISLSPCAPABILITY_SBIT']._serialized_end=22250
  _globals['_ISISLSPCAPABILITY_SBIT_ENUM']._serialized_start=22201
  _globals['_ISISLSPCAPABILITY_SBIT_ENUM']._serialized_end=22250
  _globals['_ISISLSPCAPABILITY_DBIT']._serialized_start=22252
  _globals['_ISISLSPCAPABILITY_DBIT']._serialized_end=22307
  _globals['_ISISLSPCAPABILITY_DBIT_ENUM']._serialized_start=22260
  _globals['_ISISLSPCAPABILITY_DBIT_ENUM']._serialized_end=22307
  _globals['_ISISLSPSRCAPABILITY']._serialized_start=169216
  _globals['_ISISLSPSRCAPABILITY']._serialized_end=169315
  _globals['_ISISLSPCAPASFLAGS']._serialized_start=169317
  _globals['_ISISLSPCAPASFLAGS']._serialized_end=169412
  _globals['_ISISLSPSRGB']._serialized_start=169414
  _globals['_ISISLSPSRGB']._serialized_end=169501
  _globals['_ISISLSPSRLB']._serialized_start=169503
  _globals['_ISISLSPSRLB']._serialized_end=169590
  _globals['_ISISLSPADJACENCYSID']._serialized_start=169593
  _globals['_ISISLSPADJACENCYSID']._serialized_end=169827
  _globals['_ISISLSPADJACENCYSID_TYPE']._serialized_start=169746
  _globals['_ISISLSPADJACENCYSID_TYPE']._serialized_end=169807
  _globals['_ISISLSPADJACENCYSID_TYPE_ENUM']._serialized_start=169754
  _globals['_ISISLSPADJACENCYSID_TYPE_ENUM']._serialized_end=169807
  _globals['_ISISLSPPREFIXSIDFLAGS']._serialized_start=169830
  _globals['_ISISLSPPREFIXSIDFLAGS']._serialized_end=170045
  _globals['_ISISLSPADJSIDFLAGS']._serialized_start=170048
  _globals['_ISISLSPADJSIDFLAGS']._serialized_end=170260
  _globals['_LLDPNEIGHBORSSTATEREQUEST']._serialized_start=170262
  _globals['_LLDPNEIGHBORSSTATEREQUEST']._serialized_end=170338
  _globals['_LLDPNEIGHBORSSTATE']._serialized_start=170341
  _globals['_LLDPNEIGHBORSSTATE']._serialized_end=171504
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE']._serialized_start=170920
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE']._serialized_end=171094
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM']._serialized_start=170938
  _globals['_LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM']._serialized_end=171094
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE']._serialized_start=171097
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE']._serialized_end=171267
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM']._serialized_start=171112
  _globals['_LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM']._serialized_end=171267
  _globals['_LLDPCUSTOMTLVSTATE']._serialized_start=171507
  _globals['_LLDPCUSTOMTLVSTATE']._serialized_end=171679
  _globals['_LLDPCAPABILITYSTATE']._serialized_start=171682
  _globals['_LLDPCAPABILITYSTATE']._serialized_end=172082
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME']._serialized_start=171815
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME']._serialized_end=172039
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM']._serialized_start=171834
  _globals['_LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM']._serialized_end=172039
  _globals['_RSVPLSPSSTATEREQUEST']._serialized_start=172084
  _globals['_RSVPLSPSSTATEREQUEST']._serialized_end=172133
  _globals['_RSVPLSPSSTATE']._serialized_start=172135
  _globals['_RSVPLSPSSTATE']._serialized_end=172244
  _globals['_RSVPIPV4LSPSTATE']._serialized_start=172247
  _globals['_RSVPIPV4LSPSTATE']._serialized_end=172473
  _globals['_RSVPLSPSTATE']._serialized_start=172476
  _globals['_RSVPLSPSTATE']._serialized_end=173040
  _globals['_RSVPLSPSTATE_SESSIONSTATUS']._serialized_start=172770
  _globals['_RSVPLSPSTATE_SESSIONSTATUS']._serialized_end=172828
  _globals['_RSVPLSPSTATE_SESSIONSTATUS_ENUM']._serialized_start=20043
  _globals['_RSVPLSPSTATE_SESSIONSTATUS_ENUM']._serialized_end=20084
  _globals['_RSVPLSPSTATE_LASTFLAPREASON']._serialized_start=172830
  _globals['_RSVPLSPSTATE_LASTFLAPREASON']._serialized_end=172919
  _globals['_RSVPLSPSTATE_LASTFLAPREASON_ENUM']._serialized_start=172848
  _globals['_RSVPLSPSTATE_LASTFLAPREASON_ENUM']._serialized_end=172919
  _globals['_RSVPLSPIPV4RRO']._serialized_start=173042
  _globals['_RSVPLSPIPV4RRO']._serialized_end=173140
  _globals['_RSVPLSPIPV4ERO']._serialized_start=173143
  _globals['_RSVPLSPIPV4ERO']._serialized_end=173385
  _globals['_RSVPLSPIPV4ERO_TYPE']._serialized_start=173250
  _globals['_RSVPLSPIPV4ERO_TYPE']._serialized_end=173357
  _globals['_RSVPLSPIPV4ERO_TYPE_ENUM']._serialized_start=173258
  _globals['_RSVPLSPIPV4ERO_TYPE_ENUM']._serialized_end=173357
  _globals['_DHCPV4INTERFACESTATEREQUEST']._serialized_start=173387
  _globals['_DHCPV4INTERFACESTATEREQUEST']._serialized_end=173443
  _globals['_DHCPV4INTERFACESTATE']._serialized_start=173446
  _globals['_DHCPV4INTERFACESTATE']._serialized_end=173782
  _globals['_DHCPV4LEASESTATEREQUEST']._serialized_start=173784
  _globals['_DHCPV4LEASESTATEREQUEST']._serialized_end=173836
  _globals['_DHCPV4LEASESSTATE']._serialized_start=173838
  _globals['_DHCPV4LEASESSTATE']._serialized_end=173948
  _globals['_DHCPV4LEASESTATE']._serialized_start=173951
  _globals['_DHCPV4LEASESTATE']._serialized_end=174289
  _globals['_DHCPV6INTERFACESTATEREQUEST']._serialized_start=174291
  _globals['_DHCPV6INTERFACESTATEREQUEST']._serialized_end=174347
  _globals['_DHCPV6INTERFACESTATE']._serialized_start=174350
  _globals['_DHCPV6INTERFACESTATE']._serialized_end=174520
  _globals['_DHCPV6INTERFACEIAPD']._serialized_start=174523
  _globals['_DHCPV6INTERFACEIAPD']._serialized_end=174664
  _globals['_DHCPV6INTERFACEIA']._serialized_start=174666
  _globals['_DHCPV6INTERFACEIA']._serialized_end=174793
  _globals['_DHCPV6LEASESTATEREQUEST']._serialized_start=174795
  _globals['_DHCPV6LEASESTATEREQUEST']._serialized_end=174847
  _globals['_DHCPV6LEASESSTATE']._serialized_start=174849
  _globals['_DHCPV6LEASESSTATE']._serialized_end=174965
  _globals['_DHCPV6SERVERLEASESTATE']._serialized_start=174968
  _globals['_DHCPV6SERVERLEASESTATE']._serialized_end=175316
  _globals['_OSPFV2LSASSTATEREQUEST']._serialized_start=175318
  _globals['_OSPFV2LSASSTATEREQUEST']._serialized_end=175364
  _globals['_OSPFV2LSASTATE']._serialized_start=175367
  _globals['_OSPFV2LSASTATE']._serialized_end=175757
  _globals['_OSPFV2ROUTERLSA']._serialized_start=175759
  _globals['_OSPFV2ROUTERLSA']._serialized_end=175846
  _globals['_OSPFV2NETWORKLSA']._serialized_start=175849
  _globals['_OSPFV2NETWORKLSA']._serialized_end=175978
  _globals['_OSPFV2NETWORKSUMMARYLSA']._serialized_start=175981
  _globals['_OSPFV2NETWORKSUMMARYLSA']._serialized_end=176120
  _globals['_OSPFV2SUMMARYASLSA']._serialized_start=176123
  _globals['_OSPFV2SUMMARYASLSA']._serialized_end=176257
  _globals['_OSPFV2EXTERNALASLSA']._serialized_start=176260
  _globals['_OSPFV2EXTERNALASLSA']._serialized_end=176437
  _globals['_OSPFV2NSSALSA']._serialized_start=176440
  _globals['_OSPFV2NSSALSA']._serialized_end=176667
  _globals['_OSPFV2OPAQUELSA']._serialized_start=176670
  _globals['_OSPFV2OPAQUELSA']._serialized_end=176851
  _globals['_OSPFV2OPAQUELSA_TYPE']._serialized_start=176778
  _globals['_OSPFV2OPAQUELSA_TYPE']._serialized_end=176842
  _globals['_OSPFV2OPAQUELSA_TYPE_ENUM']._serialized_start=176786
  _globals['_OSPFV2OPAQUELSA_TYPE_ENUM']._serialized_end=176842
  _globals['_OSPFV2LSAHEADER']._serialized_start=176854
  _globals['_OSPFV2LSAHEADER']._serialized_end=177083
  _globals['_OSPFV2LINK']._serialized_start=177086
  _globals['_OSPFV2LINK']._serialized_end=177326
  _globals['_OSPFV2LINK_TYPE']._serialized_start=177203
  _globals['_OSPFV2LINK_TYPE']._serialized_end=177290
  _globals['_OSPFV2LINK_TYPE_ENUM']._serialized_start=177211
  _globals['_OSPFV2LINK_TYPE_ENUM']._serialized_end=177290
  _globals['_CAPTUREREQUEST']._serialized_start=177328
  _globals['_CAPTUREREQUEST']._serialized_end=177382
  _globals['_PATTERNFLOWETHERNETDSTCOUNTER']._serialized_start=177384
  _globals['_PATTERNFLOWETHERNETDSTCOUNTER']._serialized_end=177503
  _globals['_PATTERNFLOWETHERNETDSTMETRICTAG']._serialized_start=177505
  _globals['_PATTERNFLOWETHERNETDSTMETRICTAG']._serialized_end=177630
  _globals['_PATTERNFLOWETHERNETDST']._serialized_start=177633
  _globals['_PATTERNFLOWETHERNETDST']._serialized_end=178071
  _globals['_PATTERNFLOWETHERNETDST_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWETHERNETDST_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWETHERNETDST_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWETHERNETDST_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWETHERNETSRCCOUNTER']._serialized_start=178073
  _globals['_PATTERNFLOWETHERNETSRCCOUNTER']._serialized_end=178192
  _globals['_PATTERNFLOWETHERNETSRCMETRICTAG']._serialized_start=178194
  _globals['_PATTERNFLOWETHERNETSRCMETRICTAG']._serialized_end=178319
  _globals['_PATTERNFLOWETHERNETSRC']._serialized_start=178322
  _globals['_PATTERNFLOWETHERNETSRC']._serialized_end=178722
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETSRC_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETETHERTYPECOUNTER']._serialized_start=178724
  _globals['_PATTERNFLOWETHERNETETHERTYPECOUNTER']._serialized_end=178849
  _globals['_PATTERNFLOWETHERNETETHERTYPEMETRICTAG']._serialized_start=178852
  _globals['_PATTERNFLOWETHERNETETHERTYPEMETRICTAG']._serialized_end=178983
  _globals['_PATTERNFLOWETHERNETETHERTYPE']._serialized_start=178986
  _globals['_PATTERNFLOWETHERNETETHERTYPE']._serialized_end=179454
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWETHERNETPFCQUEUECOUNTER']._serialized_start=179456
  _globals['_PATTERNFLOWETHERNETPFCQUEUECOUNTER']._serialized_end=179580
  _globals['_PATTERNFLOWETHERNETPFCQUEUEMETRICTAG']._serialized_start=179583
  _globals['_PATTERNFLOWETHERNETPFCQUEUEMETRICTAG']._serialized_end=179713
  _globals['_PATTERNFLOWETHERNETPFCQUEUE']._serialized_start=179716
  _globals['_PATTERNFLOWETHERNETPFCQUEUE']._serialized_end=180141
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVLANPRIORITYCOUNTER']._serialized_start=180143
  _globals['_PATTERNFLOWVLANPRIORITYCOUNTER']._serialized_end=180263
  _globals['_PATTERNFLOWVLANPRIORITYMETRICTAG']._serialized_start=180265
  _globals['_PATTERNFLOWVLANPRIORITYMETRICTAG']._serialized_end=180391
  _globals['_PATTERNFLOWVLANPRIORITY']._serialized_start=180394
  _globals['_PATTERNFLOWVLANPRIORITY']._serialized_end=180799
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVLANCFICOUNTER']._serialized_start=180801
  _globals['_PATTERNFLOWVLANCFICOUNTER']._serialized_end=180916
  _globals['_PATTERNFLOWVLANCFIMETRICTAG']._serialized_start=180918
  _globals['_PATTERNFLOWVLANCFIMETRICTAG']._serialized_end=181039
  _globals['_PATTERNFLOWVLANCFI']._serialized_start=181042
  _globals['_PATTERNFLOWVLANCFI']._serialized_end=181422
  _globals['_PATTERNFLOWVLANCFI_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVLANCFI_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVLANCFI_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVLANCFI_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVLANIDCOUNTER']._serialized_start=181424
  _globals['_PATTERNFLOWVLANIDCOUNTER']._serialized_end=181538
  _globals['_PATTERNFLOWVLANIDMETRICTAG']._serialized_start=181540
  _globals['_PATTERNFLOWVLANIDMETRICTAG']._serialized_end=181660
  _globals['_PATTERNFLOWVLANID']._serialized_start=181663
  _globals['_PATTERNFLOWVLANID']._serialized_end=182038
  _globals['_PATTERNFLOWVLANID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVLANID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVLANID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVLANID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVLANTPIDCOUNTER']._serialized_start=182040
  _globals['_PATTERNFLOWVLANTPIDCOUNTER']._serialized_end=182156
  _globals['_PATTERNFLOWVLANTPIDMETRICTAG']._serialized_start=182158
  _globals['_PATTERNFLOWVLANTPIDMETRICTAG']._serialized_end=182280
  _globals['_PATTERNFLOWVLANTPID']._serialized_start=182283
  _globals['_PATTERNFLOWVLANTPID']._serialized_end=182668
  _globals['_PATTERNFLOWVLANTPID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVLANTPID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVLANTPID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVLANTPID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANFLAGSCOUNTER']._serialized_start=182670
  _globals['_PATTERNFLOWVXLANFLAGSCOUNTER']._serialized_end=182788
  _globals['_PATTERNFLOWVXLANFLAGSMETRICTAG']._serialized_start=182790
  _globals['_PATTERNFLOWVXLANFLAGSMETRICTAG']._serialized_end=182914
  _globals['_PATTERNFLOWVXLANFLAGS']._serialized_start=182917
  _globals['_PATTERNFLOWVXLANFLAGS']._serialized_end=183312
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANRESERVED0COUNTER']._serialized_start=183314
  _globals['_PATTERNFLOWVXLANRESERVED0COUNTER']._serialized_end=183436
  _globals['_PATTERNFLOWVXLANRESERVED0METRICTAG']._serialized_start=183439
  _globals['_PATTERNFLOWVXLANRESERVED0METRICTAG']._serialized_end=183567
  _globals['_PATTERNFLOWVXLANRESERVED0']._serialized_start=183570
  _globals['_PATTERNFLOWVXLANRESERVED0']._serialized_end=183985
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANVNICOUNTER']._serialized_start=183987
  _globals['_PATTERNFLOWVXLANVNICOUNTER']._serialized_end=184103
  _globals['_PATTERNFLOWVXLANVNIMETRICTAG']._serialized_start=184105
  _globals['_PATTERNFLOWVXLANVNIMETRICTAG']._serialized_end=184227
  _globals['_PATTERNFLOWVXLANVNI']._serialized_start=184230
  _globals['_PATTERNFLOWVXLANVNI']._serialized_end=184653
  _globals['_PATTERNFLOWVXLANVNI_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWVXLANVNI_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWVXLANVNI_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWVXLANVNI_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWVXLANRESERVED1COUNTER']._serialized_start=184655
  _globals['_PATTERNFLOWVXLANRESERVED1COUNTER']._serialized_end=184777
  _globals['_PATTERNFLOWVXLANRESERVED1METRICTAG']._serialized_start=184780
  _globals['_PATTERNFLOWVXLANRESERVED1METRICTAG']._serialized_end=184908
  _globals['_PATTERNFLOWVXLANRESERVED1']._serialized_start=184911
  _globals['_PATTERNFLOWVXLANRESERVED1']._serialized_end=185326
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4VERSIONCOUNTER']._serialized_start=185328
  _globals['_PATTERNFLOWIPV4VERSIONCOUNTER']._serialized_end=185447
  _globals['_PATTERNFLOWIPV4VERSIONMETRICTAG']._serialized_start=185449
  _globals['_PATTERNFLOWIPV4VERSIONMETRICTAG']._serialized_end=185574
  _globals['_PATTERNFLOWIPV4VERSION']._serialized_start=185577
  _globals['_PATTERNFLOWIPV4VERSION']._serialized_end=185977
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4VERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4HEADERLENGTHCOUNTER']._serialized_start=185979
  _globals['_PATTERNFLOWIPV4HEADERLENGTHCOUNTER']._serialized_end=186103
  _globals['_PATTERNFLOWIPV4HEADERLENGTHMETRICTAG']._serialized_start=186106
  _globals['_PATTERNFLOWIPV4HEADERLENGTHMETRICTAG']._serialized_end=186236
  _globals['_PATTERNFLOWIPV4HEADERLENGTH']._serialized_start=186239
  _globals['_PATTERNFLOWIPV4HEADERLENGTH']._serialized_end=186702
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4TOTALLENGTHCOUNTER']._serialized_start=186704
  _globals['_PATTERNFLOWIPV4TOTALLENGTHCOUNTER']._serialized_end=186827
  _globals['_PATTERNFLOWIPV4TOTALLENGTHMETRICTAG']._serialized_start=186830
  _globals['_PATTERNFLOWIPV4TOTALLENGTHMETRICTAG']._serialized_end=186959
  _globals['_PATTERNFLOWIPV4TOTALLENGTH']._serialized_start=186962
  _globals['_PATTERNFLOWIPV4TOTALLENGTH']._serialized_end=187420
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER']._serialized_start=187422
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER']._serialized_end=187548
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG']._serialized_start=187551
  _globals['_PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG']._serialized_end=187683
  _globals['_PATTERNFLOWIPV4IDENTIFICATION']._serialized_start=187686
  _globals['_PATTERNFLOWIPV4IDENTIFICATION']._serialized_end=188121
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4RESERVEDCOUNTER']._serialized_start=188123
  _globals['_PATTERNFLOWIPV4RESERVEDCOUNTER']._serialized_end=188243
  _globals['_PATTERNFLOWIPV4RESERVEDMETRICTAG']._serialized_start=188245
  _globals['_PATTERNFLOWIPV4RESERVEDMETRICTAG']._serialized_end=188371
  _globals['_PATTERNFLOWIPV4RESERVED']._serialized_start=188374
  _globals['_PATTERNFLOWIPV4RESERVED']._serialized_end=188779
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER']._serialized_start=188781
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER']._serialized_end=188905
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG']._serialized_start=188908
  _globals['_PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG']._serialized_end=189038
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT']._serialized_start=189041
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT']._serialized_end=189466
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER']._serialized_start=189468
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER']._serialized_end=189593
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG']._serialized_start=189596
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG']._serialized_end=189727
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS']._serialized_start=189730
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS']._serialized_end=190160
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER']._serialized_start=190162
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER']._serialized_end=190288
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG']._serialized_start=190291
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG']._serialized_end=190423
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET']._serialized_start=190426
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET']._serialized_end=190861
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TIMETOLIVECOUNTER']._serialized_start=190863
  _globals['_PATTERNFLOWIPV4TIMETOLIVECOUNTER']._serialized_end=190985
  _globals['_PATTERNFLOWIPV4TIMETOLIVEMETRICTAG']._serialized_start=190988
  _globals['_PATTERNFLOWIPV4TIMETOLIVEMETRICTAG']._serialized_end=191116
  _globals['_PATTERNFLOWIPV4TIMETOLIVE']._serialized_start=191119
  _globals['_PATTERNFLOWIPV4TIMETOLIVE']._serialized_end=191534
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4PROTOCOLCOUNTER']._serialized_start=191536
  _globals['_PATTERNFLOWIPV4PROTOCOLCOUNTER']._serialized_end=191656
  _globals['_PATTERNFLOWIPV4PROTOCOLMETRICTAG']._serialized_start=191658
  _globals['_PATTERNFLOWIPV4PROTOCOLMETRICTAG']._serialized_end=191784
  _globals['_PATTERNFLOWIPV4PROTOCOL']._serialized_start=191787
  _globals['_PATTERNFLOWIPV4PROTOCOL']._serialized_end=192230
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM']._serialized_start=192233
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM']._serialized_end=192584
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWIPV4SRCCOUNTER']._serialized_start=192586
  _globals['_PATTERNFLOWIPV4SRCCOUNTER']._serialized_end=192701
  _globals['_PATTERNFLOWIPV4SRCMETRICTAG']._serialized_start=192703
  _globals['_PATTERNFLOWIPV4SRCMETRICTAG']._serialized_end=192824
  _globals['_PATTERNFLOWIPV4SRCRANDOM']._serialized_start=192827
  _globals['_PATTERNFLOWIPV4SRCRANDOM']._serialized_end=192963
  _globals['_PATTERNFLOWIPV4SRC']._serialized_start=192966
  _globals['_PATTERNFLOWIPV4SRC']._serialized_end=193448
  _globals['_PATTERNFLOWIPV4SRC_CHOICE']._serialized_start=193319
  _globals['_PATTERNFLOWIPV4SRC_CHOICE']._serialized_end=193427
  _globals['_PATTERNFLOWIPV4SRC_CHOICE_ENUM']._serialized_start=193329
  _globals['_PATTERNFLOWIPV4SRC_CHOICE_ENUM']._serialized_end=193427
  _globals['_PATTERNFLOWIPV4DSTCOUNTER']._serialized_start=193450
  _globals['_PATTERNFLOWIPV4DSTCOUNTER']._serialized_end=193565
  _globals['_PATTERNFLOWIPV4DSTMETRICTAG']._serialized_start=193567
  _globals['_PATTERNFLOWIPV4DSTMETRICTAG']._serialized_end=193688
  _globals['_PATTERNFLOWIPV4DSTRANDOM']._serialized_start=193691
  _globals['_PATTERNFLOWIPV4DSTRANDOM']._serialized_end=193827
  _globals['_PATTERNFLOWIPV4DST']._serialized_start=193830
  _globals['_PATTERNFLOWIPV4DST']._serialized_end=194312
  _globals['_PATTERNFLOWIPV4DST_CHOICE']._serialized_start=193319
  _globals['_PATTERNFLOWIPV4DST_CHOICE']._serialized_end=193427
  _globals['_PATTERNFLOWIPV4DST_CHOICE_ENUM']._serialized_start=193329
  _globals['_PATTERNFLOWIPV4DST_CHOICE_ENUM']._serialized_end=193427
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAGCOUNTER']._serialized_start=194315
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAGCOUNTER']._serialized_end=194454
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG']._serialized_start=194457
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG']._serialized_end=194878
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPECOPIEDFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASSCOUNTER']._serialized_start=194881
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASSCOUNTER']._serialized_end=195021
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS']._serialized_start=195024
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS']._serialized_end=195449
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONCLASS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBERCOUNTER']._serialized_start=195452
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBERCOUNTER']._serialized_end=195593
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER']._serialized_start=195596
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER']._serialized_end=196025
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4OPTIONSCUSTOMTYPEOPTIONNUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4PRIORITYRAWCOUNTER']._serialized_start=196027
  _globals['_PATTERNFLOWIPV4PRIORITYRAWCOUNTER']._serialized_end=196150
  _globals['_PATTERNFLOWIPV4PRIORITYRAWMETRICTAG']._serialized_start=196153
  _globals['_PATTERNFLOWIPV4PRIORITYRAWMETRICTAG']._serialized_end=196282
  _globals['_PATTERNFLOWIPV4PRIORITYRAW']._serialized_start=196285
  _globals['_PATTERNFLOWIPV4PRIORITYRAW']._serialized_end=196705
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DSCPPHBCOUNTER']._serialized_start=196707
  _globals['_PATTERNFLOWIPV4DSCPPHBCOUNTER']._serialized_end=196826
  _globals['_PATTERNFLOWIPV4DSCPPHBMETRICTAG']._serialized_start=196828
  _globals['_PATTERNFLOWIPV4DSCPPHBMETRICTAG']._serialized_end=196953
  _globals['_PATTERNFLOWIPV4DSCPPHB']._serialized_start=196956
  _globals['_PATTERNFLOWIPV4DSCPPHB']._serialized_end=197356
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DSCPECNCOUNTER']._serialized_start=197358
  _globals['_PATTERNFLOWIPV4DSCPECNCOUNTER']._serialized_end=197477
  _globals['_PATTERNFLOWIPV4DSCPECNMETRICTAG']._serialized_start=197479
  _globals['_PATTERNFLOWIPV4DSCPECNMETRICTAG']._serialized_end=197604
  _globals['_PATTERNFLOWIPV4DSCPECN']._serialized_start=197607
  _globals['_PATTERNFLOWIPV4DSCPECN']._serialized_end=198007
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER']._serialized_start=198009
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER']._serialized_end=198134
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG']._serialized_start=198137
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG']._serialized_end=198268
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE']._serialized_start=198271
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE']._serialized_end=198701
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSDELAYCOUNTER']._serialized_start=198703
  _globals['_PATTERNFLOWIPV4TOSDELAYCOUNTER']._serialized_end=198823
  _globals['_PATTERNFLOWIPV4TOSDELAYMETRICTAG']._serialized_start=198825
  _globals['_PATTERNFLOWIPV4TOSDELAYMETRICTAG']._serialized_end=198951
  _globals['_PATTERNFLOWIPV4TOSDELAY']._serialized_start=198954
  _globals['_PATTERNFLOWIPV4TOSDELAY']._serialized_end=199359
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER']._serialized_start=199361
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER']._serialized_end=199486
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG']._serialized_start=199489
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG']._serialized_end=199620
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT']._serialized_start=199623
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT']._serialized_end=200053
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER']._serialized_start=200055
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER']._serialized_end=200181
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG']._serialized_start=200184
  _globals['_PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG']._serialized_end=200316
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY']._serialized_start=200319
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY']._serialized_end=200754
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSMONETARYCOUNTER']._serialized_start=200756
  _globals['_PATTERNFLOWIPV4TOSMONETARYCOUNTER']._serialized_end=200879
  _globals['_PATTERNFLOWIPV4TOSMONETARYMETRICTAG']._serialized_start=200882
  _globals['_PATTERNFLOWIPV4TOSMONETARYMETRICTAG']._serialized_end=201011
  _globals['_PATTERNFLOWIPV4TOSMONETARY']._serialized_start=201014
  _globals['_PATTERNFLOWIPV4TOSMONETARY']._serialized_end=201434
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSUNUSEDCOUNTER']._serialized_start=201436
  _globals['_PATTERNFLOWIPV4TOSUNUSEDCOUNTER']._serialized_end=201557
  _globals['_PATTERNFLOWIPV4TOSUNUSEDMETRICTAG']._serialized_start=201559
  _globals['_PATTERNFLOWIPV4TOSUNUSEDMETRICTAG']._serialized_end=201686
  _globals['_PATTERNFLOWIPV4TOSUNUSED']._serialized_start=201689
  _globals['_PATTERNFLOWIPV4TOSUNUSED']._serialized_end=202099
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6VERSIONCOUNTER']._serialized_start=202101
  _globals['_PATTERNFLOWIPV6VERSIONCOUNTER']._serialized_end=202220
  _globals['_PATTERNFLOWIPV6VERSIONMETRICTAG']._serialized_start=202222
  _globals['_PATTERNFLOWIPV6VERSIONMETRICTAG']._serialized_end=202347
  _globals['_PATTERNFLOWIPV6VERSION']._serialized_start=202350
  _globals['_PATTERNFLOWIPV6VERSION']._serialized_end=202750
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV6VERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER']._serialized_start=202752
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER']._serialized_end=202876
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG']._serialized_start=202879
  _globals['_PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG']._serialized_end=203009
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS']._serialized_start=203012
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS']._serialized_end=203437
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6FLOWLABELCOUNTER']._serialized_start=203439
  _globals['_PATTERNFLOWIPV6FLOWLABELCOUNTER']._serialized_end=203560
  _globals['_PATTERNFLOWIPV6FLOWLABELMETRICTAG']._serialized_start=203562
  _globals['_PATTERNFLOWIPV6FLOWLABELMETRICTAG']._serialized_end=203689
  _globals['_PATTERNFLOWIPV6FLOWLABELRANDOM']._serialized_start=203692
  _globals['_PATTERNFLOWIPV6FLOWLABELRANDOM']._serialized_end=203834
  _globals['_PATTERNFLOWIPV6FLOWLABEL']._serialized_start=203837
  _globals['_PATTERNFLOWIPV6FLOWLABEL']._serialized_end=204312
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE']._serialized_start=204193
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE']._serialized_end=204291
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM']._serialized_start=204203
  _globals['_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM']._serialized_end=204291
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER']._serialized_start=204314
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER']._serialized_end=204439
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG']._serialized_start=204442
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG']._serialized_end=204573
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH']._serialized_start=204576
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH']._serialized_end=205044
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIPV6NEXTHEADERCOUNTER']._serialized_start=205046
  _globals['_PATTERNFLOWIPV6NEXTHEADERCOUNTER']._serialized_end=205168
  _globals['_PATTERNFLOWIPV6NEXTHEADERMETRICTAG']._serialized_start=205171
  _globals['_PATTERNFLOWIPV6NEXTHEADERMETRICTAG']._serialized_end=205299
  _globals['_PATTERNFLOWIPV6NEXTHEADER']._serialized_start=205302
  _globals['_PATTERNFLOWIPV6NEXTHEADER']._serialized_end=205755
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIPV6HOPLIMITCOUNTER']._serialized_start=205757
  _globals['_PATTERNFLOWIPV6HOPLIMITCOUNTER']._serialized_end=205877
  _globals['_PATTERNFLOWIPV6HOPLIMITMETRICTAG']._serialized_start=205879
  _globals['_PATTERNFLOWIPV6HOPLIMITMETRICTAG']._serialized_end=206005
  _globals['_PATTERNFLOWIPV6HOPLIMIT']._serialized_start=206008
  _globals['_PATTERNFLOWIPV6HOPLIMIT']._serialized_end=206413
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIPV6SRCCOUNTER']._serialized_start=206415
  _globals['_PATTERNFLOWIPV6SRCCOUNTER']._serialized_end=206530
  _globals['_PATTERNFLOWIPV6SRCMETRICTAG']._serialized_start=206532
  _globals['_PATTERNFLOWIPV6SRCMETRICTAG']._serialized_end=206653
  _globals['_PATTERNFLOWIPV6SRC']._serialized_start=206656
  _globals['_PATTERNFLOWIPV6SRC']._serialized_end=207079
  _globals['_PATTERNFLOWIPV6SRC_CHOICE']._serialized_start=206962
  _globals['_PATTERNFLOWIPV6SRC_CHOICE']._serialized_end=207058
  _globals['_PATTERNFLOWIPV6SRC_CHOICE_ENUM']._serialized_start=193329
  _globals['_PATTERNFLOWIPV6SRC_CHOICE_ENUM']._serialized_end=193415
  _globals['_PATTERNFLOWIPV6DSTCOUNTER']._serialized_start=207081
  _globals['_PATTERNFLOWIPV6DSTCOUNTER']._serialized_end=207196
  _globals['_PATTERNFLOWIPV6DSTMETRICTAG']._serialized_start=207198
  _globals['_PATTERNFLOWIPV6DSTMETRICTAG']._serialized_end=207319
  _globals['_PATTERNFLOWIPV6DST']._serialized_start=207322
  _globals['_PATTERNFLOWIPV6DST']._serialized_end=207745
  _globals['_PATTERNFLOWIPV6DST_CHOICE']._serialized_start=206962
  _globals['_PATTERNFLOWIPV6DST_CHOICE']._serialized_end=207058
  _globals['_PATTERNFLOWIPV6DST_CHOICE_ENUM']._serialized_start=193329
  _globals['_PATTERNFLOWIPV6DST_CHOICE_ENUM']._serialized_end=193415
  _globals['_PATTERNFLOWPFCPAUSEDSTCOUNTER']._serialized_start=207747
  _globals['_PATTERNFLOWPFCPAUSEDSTCOUNTER']._serialized_end=207866
  _globals['_PATTERNFLOWPFCPAUSEDSTMETRICTAG']._serialized_start=207868
  _globals['_PATTERNFLOWPFCPAUSEDSTMETRICTAG']._serialized_end=207993
  _globals['_PATTERNFLOWPFCPAUSEDST']._serialized_start=207996
  _globals['_PATTERNFLOWPFCPAUSEDST']._serialized_end=208396
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSESRCCOUNTER']._serialized_start=208398
  _globals['_PATTERNFLOWPFCPAUSESRCCOUNTER']._serialized_end=208517
  _globals['_PATTERNFLOWPFCPAUSESRCMETRICTAG']._serialized_start=208519
  _globals['_PATTERNFLOWPFCPAUSESRCMETRICTAG']._serialized_end=208644
  _globals['_PATTERNFLOWPFCPAUSESRC']._serialized_start=208647
  _globals['_PATTERNFLOWPFCPAUSESRC']._serialized_end=209047
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER']._serialized_start=209049
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER']._serialized_end=209174
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG']._serialized_start=209177
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG']._serialized_end=209308
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE']._serialized_start=209311
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE']._serialized_end=209741
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER']._serialized_start=209744
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER']._serialized_end=209873
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG']._serialized_start=209876
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG']._serialized_end=210011
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE']._serialized_start=210014
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE']._serialized_end=210464
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER']._serialized_start=210467
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER']._serialized_end=210600
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG']._serialized_start=210603
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG']._serialized_end=210742
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR']._serialized_start=210745
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR']._serialized_end=211215
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER']._serialized_start=211217
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER']._serialized_end=211344
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG']._serialized_start=211347
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG']._serialized_end=211480
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0']._serialized_start=211483
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0']._serialized_end=211923
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER']._serialized_start=211925
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER']._serialized_end=212052
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG']._serialized_start=212055
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG']._serialized_end=212188
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1']._serialized_start=212191
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1']._serialized_end=212631
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER']._serialized_start=212633
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER']._serialized_end=212760
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG']._serialized_start=212763
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG']._serialized_end=212896
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2']._serialized_start=212899
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2']._serialized_end=213339
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER']._serialized_start=213341
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER']._serialized_end=213468
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG']._serialized_start=213471
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG']._serialized_end=213604
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3']._serialized_start=213607
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3']._serialized_end=214047
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER']._serialized_start=214049
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER']._serialized_end=214176
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG']._serialized_start=214179
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG']._serialized_end=214312
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4']._serialized_start=214315
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4']._serialized_end=214755
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER']._serialized_start=214757
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER']._serialized_end=214884
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG']._serialized_start=214887
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG']._serialized_end=215020
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5']._serialized_start=215023
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5']._serialized_end=215463
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER']._serialized_start=215465
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER']._serialized_end=215592
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG']._serialized_start=215595
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG']._serialized_end=215728
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6']._serialized_start=215731
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6']._serialized_end=216171
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER']._serialized_start=216173
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER']._serialized_end=216300
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG']._serialized_start=216303
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG']._serialized_end=216436
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7']._serialized_start=216439
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7']._serialized_end=216879
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSEDSTCOUNTER']._serialized_start=216881
  _globals['_PATTERNFLOWETHERNETPAUSEDSTCOUNTER']._serialized_end=217005
  _globals['_PATTERNFLOWETHERNETPAUSEDSTMETRICTAG']._serialized_start=217008
  _globals['_PATTERNFLOWETHERNETPAUSEDSTMETRICTAG']._serialized_end=217138
  _globals['_PATTERNFLOWETHERNETPAUSEDST']._serialized_start=217141
  _globals['_PATTERNFLOWETHERNETPAUSEDST']._serialized_end=217566
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSESRCCOUNTER']._serialized_start=217568
  _globals['_PATTERNFLOWETHERNETPAUSESRCCOUNTER']._serialized_end=217692
  _globals['_PATTERNFLOWETHERNETPAUSESRCMETRICTAG']._serialized_start=217695
  _globals['_PATTERNFLOWETHERNETPAUSESRCMETRICTAG']._serialized_end=217825
  _globals['_PATTERNFLOWETHERNETPAUSESRC']._serialized_start=217828
  _globals['_PATTERNFLOWETHERNETPAUSESRC']._serialized_end=218253
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER']._serialized_start=218256
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER']._serialized_end=218386
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG']._serialized_start=218389
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG']._serialized_end=218525
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE']._serialized_start=218528
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE']._serialized_end=218983
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER']._serialized_start=218986
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER']._serialized_end=219120
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG']._serialized_start=219123
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG']._serialized_end=219263
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE']._serialized_start=219266
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE']._serialized_end=219741
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSETIMECOUNTER']._serialized_start=219743
  _globals['_PATTERNFLOWETHERNETPAUSETIMECOUNTER']._serialized_end=219868
  _globals['_PATTERNFLOWETHERNETPAUSETIMEMETRICTAG']._serialized_start=219871
  _globals['_PATTERNFLOWETHERNETPAUSETIMEMETRICTAG']._serialized_end=220002
  _globals['_PATTERNFLOWETHERNETPAUSETIME']._serialized_start=220005
  _globals['_PATTERNFLOWETHERNETPAUSETIME']._serialized_end=220435
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPSRCPORTCOUNTER']._serialized_start=220437
  _globals['_PATTERNFLOWTCPSRCPORTCOUNTER']._serialized_end=220555
  _globals['_PATTERNFLOWTCPSRCPORTMETRICTAG']._serialized_start=220557
  _globals['_PATTERNFLOWTCPSRCPORTMETRICTAG']._serialized_end=220681
  _globals['_PATTERNFLOWTCPSRCPORTRANDOM']._serialized_start=220684
  _globals['_PATTERNFLOWTCPSRCPORTRANDOM']._serialized_end=220823
  _globals['_PATTERNFLOWTCPSRCPORT']._serialized_start=220826
  _globals['_PATTERNFLOWTCPSRCPORT']._serialized_end=221283
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE']._serialized_start=204193
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE']._serialized_end=204291
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM']._serialized_start=204203
  _globals['_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM']._serialized_end=204291
  _globals['_PATTERNFLOWTCPDSTPORTCOUNTER']._serialized_start=221285
  _globals['_PATTERNFLOWTCPDSTPORTCOUNTER']._serialized_end=221403
  _globals['_PATTERNFLOWTCPDSTPORTMETRICTAG']._serialized_start=221405
  _globals['_PATTERNFLOWTCPDSTPORTMETRICTAG']._serialized_end=221529
  _globals['_PATTERNFLOWTCPDSTPORTRANDOM']._serialized_start=221532
  _globals['_PATTERNFLOWTCPDSTPORTRANDOM']._serialized_end=221671
  _globals['_PATTERNFLOWTCPDSTPORT']._serialized_start=221674
  _globals['_PATTERNFLOWTCPDSTPORT']._serialized_end=222131
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE']._serialized_start=204193
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE']._serialized_end=204291
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM']._serialized_start=204203
  _globals['_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM']._serialized_end=204291
  _globals['_PATTERNFLOWTCPSEQNUMCOUNTER']._serialized_start=222133
  _globals['_PATTERNFLOWTCPSEQNUMCOUNTER']._serialized_end=222250
  _globals['_PATTERNFLOWTCPSEQNUMMETRICTAG']._serialized_start=222252
  _globals['_PATTERNFLOWTCPSEQNUMMETRICTAG']._serialized_end=222375
  _globals['_PATTERNFLOWTCPSEQNUM']._serialized_start=222378
  _globals['_PATTERNFLOWTCPSEQNUM']._serialized_end=222768
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPACKNUMCOUNTER']._serialized_start=222770
  _globals['_PATTERNFLOWTCPACKNUMCOUNTER']._serialized_end=222887
  _globals['_PATTERNFLOWTCPACKNUMMETRICTAG']._serialized_start=222889
  _globals['_PATTERNFLOWTCPACKNUMMETRICTAG']._serialized_end=223012
  _globals['_PATTERNFLOWTCPACKNUM']._serialized_start=223015
  _globals['_PATTERNFLOWTCPACKNUM']._serialized_end=223405
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPACKNUM_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPDATAOFFSETCOUNTER']._serialized_start=223407
  _globals['_PATTERNFLOWTCPDATAOFFSETCOUNTER']._serialized_end=223528
  _globals['_PATTERNFLOWTCPDATAOFFSETMETRICTAG']._serialized_start=223530
  _globals['_PATTERNFLOWTCPDATAOFFSETMETRICTAG']._serialized_end=223657
  _globals['_PATTERNFLOWTCPDATAOFFSET']._serialized_start=223660
  _globals['_PATTERNFLOWTCPDATAOFFSET']._serialized_end=224070
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNNSCOUNTER']._serialized_start=224072
  _globals['_PATTERNFLOWTCPECNNSCOUNTER']._serialized_end=224188
  _globals['_PATTERNFLOWTCPECNNSMETRICTAG']._serialized_start=224190
  _globals['_PATTERNFLOWTCPECNNSMETRICTAG']._serialized_end=224312
  _globals['_PATTERNFLOWTCPECNNS']._serialized_start=224315
  _globals['_PATTERNFLOWTCPECNNS']._serialized_end=224700
  _globals['_PATTERNFLOWTCPECNNS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPECNNS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNNS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPECNNS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNCWRCOUNTER']._serialized_start=224702
  _globals['_PATTERNFLOWTCPECNCWRCOUNTER']._serialized_end=224819
  _globals['_PATTERNFLOWTCPECNCWRMETRICTAG']._serialized_start=224821
  _globals['_PATTERNFLOWTCPECNCWRMETRICTAG']._serialized_end=224944
  _globals['_PATTERNFLOWTCPECNCWR']._serialized_start=224947
  _globals['_PATTERNFLOWTCPECNCWR']._serialized_end=225337
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPECNCWR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNECHOCOUNTER']._serialized_start=225339
  _globals['_PATTERNFLOWTCPECNECHOCOUNTER']._serialized_end=225457
  _globals['_PATTERNFLOWTCPECNECHOMETRICTAG']._serialized_start=225459
  _globals['_PATTERNFLOWTCPECNECHOMETRICTAG']._serialized_end=225583
  _globals['_PATTERNFLOWTCPECNECHO']._serialized_start=225586
  _globals['_PATTERNFLOWTCPECNECHO']._serialized_end=225981
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPECNECHO_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLURGCOUNTER']._serialized_start=225983
  _globals['_PATTERNFLOWTCPCTLURGCOUNTER']._serialized_end=226100
  _globals['_PATTERNFLOWTCPCTLURGMETRICTAG']._serialized_start=226102
  _globals['_PATTERNFLOWTCPCTLURGMETRICTAG']._serialized_end=226225
  _globals['_PATTERNFLOWTCPCTLURG']._serialized_start=226228
  _globals['_PATTERNFLOWTCPCTLURG']._serialized_end=226618
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLURG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLACKCOUNTER']._serialized_start=226620
  _globals['_PATTERNFLOWTCPCTLACKCOUNTER']._serialized_end=226737
  _globals['_PATTERNFLOWTCPCTLACKMETRICTAG']._serialized_start=226739
  _globals['_PATTERNFLOWTCPCTLACKMETRICTAG']._serialized_end=226862
  _globals['_PATTERNFLOWTCPCTLACK']._serialized_start=226865
  _globals['_PATTERNFLOWTCPCTLACK']._serialized_end=227255
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLACK_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLPSHCOUNTER']._serialized_start=227257
  _globals['_PATTERNFLOWTCPCTLPSHCOUNTER']._serialized_end=227374
  _globals['_PATTERNFLOWTCPCTLPSHMETRICTAG']._serialized_start=227376
  _globals['_PATTERNFLOWTCPCTLPSHMETRICTAG']._serialized_end=227499
  _globals['_PATTERNFLOWTCPCTLPSH']._serialized_start=227502
  _globals['_PATTERNFLOWTCPCTLPSH']._serialized_end=227892
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLRSTCOUNTER']._serialized_start=227894
  _globals['_PATTERNFLOWTCPCTLRSTCOUNTER']._serialized_end=228011
  _globals['_PATTERNFLOWTCPCTLRSTMETRICTAG']._serialized_start=228013
  _globals['_PATTERNFLOWTCPCTLRSTMETRICTAG']._serialized_end=228136
  _globals['_PATTERNFLOWTCPCTLRST']._serialized_start=228139
  _globals['_PATTERNFLOWTCPCTLRST']._serialized_end=228529
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLRST_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLSYNCOUNTER']._serialized_start=228531
  _globals['_PATTERNFLOWTCPCTLSYNCOUNTER']._serialized_end=228648
  _globals['_PATTERNFLOWTCPCTLSYNMETRICTAG']._serialized_start=228650
  _globals['_PATTERNFLOWTCPCTLSYNMETRICTAG']._serialized_end=228773
  _globals['_PATTERNFLOWTCPCTLSYN']._serialized_start=228776
  _globals['_PATTERNFLOWTCPCTLSYN']._serialized_end=229166
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLFINCOUNTER']._serialized_start=229168
  _globals['_PATTERNFLOWTCPCTLFINCOUNTER']._serialized_end=229285
  _globals['_PATTERNFLOWTCPCTLFINMETRICTAG']._serialized_start=229287
  _globals['_PATTERNFLOWTCPCTLFINMETRICTAG']._serialized_end=229410
  _globals['_PATTERNFLOWTCPCTLFIN']._serialized_start=229413
  _globals['_PATTERNFLOWTCPCTLFIN']._serialized_end=229803
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPWINDOWCOUNTER']._serialized_start=229805
  _globals['_PATTERNFLOWTCPWINDOWCOUNTER']._serialized_end=229922
  _globals['_PATTERNFLOWTCPWINDOWMETRICTAG']._serialized_start=229924
  _globals['_PATTERNFLOWTCPWINDOWMETRICTAG']._serialized_end=230047
  _globals['_PATTERNFLOWTCPWINDOW']._serialized_start=230050
  _globals['_PATTERNFLOWTCPWINDOW']._serialized_end=230440
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWTCPWINDOW_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWTCPCHECKSUM']._serialized_start=230443
  _globals['_PATTERNFLOWTCPCHECKSUM']._serialized_end=230773
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWTCPCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWTCPCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWUDPSRCPORTCOUNTER']._serialized_start=230775
  _globals['_PATTERNFLOWUDPSRCPORTCOUNTER']._serialized_end=230893
  _globals['_PATTERNFLOWUDPSRCPORTMETRICTAG']._serialized_start=230895
  _globals['_PATTERNFLOWUDPSRCPORTMETRICTAG']._serialized_end=231019
  _globals['_PATTERNFLOWUDPSRCPORTRANDOM']._serialized_start=231022
  _globals['_PATTERNFLOWUDPSRCPORTRANDOM']._serialized_end=231161
  _globals['_PATTERNFLOWUDPSRCPORT']._serialized_start=231164
  _globals['_PATTERNFLOWUDPSRCPORT']._serialized_end=231621
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE']._serialized_start=204193
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE']._serialized_end=204291
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM']._serialized_start=204203
  _globals['_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM']._serialized_end=204291
  _globals['_PATTERNFLOWUDPDSTPORTCOUNTER']._serialized_start=231623
  _globals['_PATTERNFLOWUDPDSTPORTCOUNTER']._serialized_end=231741
  _globals['_PATTERNFLOWUDPDSTPORTMETRICTAG']._serialized_start=231743
  _globals['_PATTERNFLOWUDPDSTPORTMETRICTAG']._serialized_end=231867
  _globals['_PATTERNFLOWUDPDSTPORTRANDOM']._serialized_start=231870
  _globals['_PATTERNFLOWUDPDSTPORTRANDOM']._serialized_end=232009
  _globals['_PATTERNFLOWUDPDSTPORT']._serialized_start=232012
  _globals['_PATTERNFLOWUDPDSTPORT']._serialized_end=232469
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE']._serialized_start=204193
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE']._serialized_end=204291
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM']._serialized_start=204203
  _globals['_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM']._serialized_end=204291
  _globals['_PATTERNFLOWUDPLENGTHCOUNTER']._serialized_start=232471
  _globals['_PATTERNFLOWUDPLENGTHCOUNTER']._serialized_end=232588
  _globals['_PATTERNFLOWUDPLENGTHMETRICTAG']._serialized_start=232590
  _globals['_PATTERNFLOWUDPLENGTHMETRICTAG']._serialized_end=232713
  _globals['_PATTERNFLOWUDPLENGTH']._serialized_start=232716
  _globals['_PATTERNFLOWUDPLENGTH']._serialized_end=233106
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWUDPLENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWUDPCHECKSUM']._serialized_start=233109
  _globals['_PATTERNFLOWUDPCHECKSUM']._serialized_end=233439
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER']._serialized_start=233441
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER']._serialized_end=233567
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG']._serialized_start=233570
  _globals['_PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG']._serialized_end=233702
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT']._serialized_start=233705
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT']._serialized_end=234140
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGRERESERVED0COUNTER']._serialized_start=234142
  _globals['_PATTERNFLOWGRERESERVED0COUNTER']._serialized_end=234262
  _globals['_PATTERNFLOWGRERESERVED0METRICTAG']._serialized_start=234264
  _globals['_PATTERNFLOWGRERESERVED0METRICTAG']._serialized_end=234390
  _globals['_PATTERNFLOWGRERESERVED0']._serialized_start=234393
  _globals['_PATTERNFLOWGRERESERVED0']._serialized_end=234798
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGRERESERVED0_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGREVERSIONCOUNTER']._serialized_start=234800
  _globals['_PATTERNFLOWGREVERSIONCOUNTER']._serialized_end=234918
  _globals['_PATTERNFLOWGREVERSIONMETRICTAG']._serialized_start=234920
  _globals['_PATTERNFLOWGREVERSIONMETRICTAG']._serialized_end=235044
  _globals['_PATTERNFLOWGREVERSION']._serialized_start=235047
  _globals['_PATTERNFLOWGREVERSION']._serialized_end=235442
  _globals['_PATTERNFLOWGREVERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGREVERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGREVERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGREVERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGREPROTOCOLCOUNTER']._serialized_start=235444
  _globals['_PATTERNFLOWGREPROTOCOLCOUNTER']._serialized_end=235563
  _globals['_PATTERNFLOWGREPROTOCOLMETRICTAG']._serialized_start=235565
  _globals['_PATTERNFLOWGREPROTOCOLMETRICTAG']._serialized_end=235690
  _globals['_PATTERNFLOWGREPROTOCOL']._serialized_start=235693
  _globals['_PATTERNFLOWGREPROTOCOL']._serialized_end=236131
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE']._serialized_start=206962
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE']._serialized_end=207058
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM']._serialized_start=193329
  _globals['_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM']._serialized_end=193415
  _globals['_PATTERNFLOWGRECHECKSUM']._serialized_start=236134
  _globals['_PATTERNFLOWGRECHECKSUM']._serialized_end=236464
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWGRERESERVED1COUNTER']._serialized_start=236466
  _globals['_PATTERNFLOWGRERESERVED1COUNTER']._serialized_end=236586
  _globals['_PATTERNFLOWGRERESERVED1METRICTAG']._serialized_start=236588
  _globals['_PATTERNFLOWGRERESERVED1METRICTAG']._serialized_end=236714
  _globals['_PATTERNFLOWGRERESERVED1']._serialized_start=236717
  _globals['_PATTERNFLOWGRERESERVED1']._serialized_end=237122
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGRERESERVED1_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1VERSIONCOUNTER']._serialized_start=237124
  _globals['_PATTERNFLOWGTPV1VERSIONCOUNTER']._serialized_end=237244
  _globals['_PATTERNFLOWGTPV1VERSIONMETRICTAG']._serialized_start=237246
  _globals['_PATTERNFLOWGTPV1VERSIONMETRICTAG']._serialized_end=237372
  _globals['_PATTERNFLOWGTPV1VERSION']._serialized_start=237375
  _globals['_PATTERNFLOWGTPV1VERSION']._serialized_end=237780
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER']._serialized_start=237782
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER']._serialized_end=237907
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG']._serialized_start=237910
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG']._serialized_end=238041
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE']._serialized_start=238044
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE']._serialized_end=238474
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1RESERVEDCOUNTER']._serialized_start=238476
  _globals['_PATTERNFLOWGTPV1RESERVEDCOUNTER']._serialized_end=238597
  _globals['_PATTERNFLOWGTPV1RESERVEDMETRICTAG']._serialized_start=238599
  _globals['_PATTERNFLOWGTPV1RESERVEDMETRICTAG']._serialized_end=238726
  _globals['_PATTERNFLOWGTPV1RESERVED']._serialized_start=238729
  _globals['_PATTERNFLOWGTPV1RESERVED']._serialized_end=239139
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1EFLAGCOUNTER']._serialized_start=239141
  _globals['_PATTERNFLOWGTPV1EFLAGCOUNTER']._serialized_end=239259
  _globals['_PATTERNFLOWGTPV1EFLAGMETRICTAG']._serialized_start=239261
  _globals['_PATTERNFLOWGTPV1EFLAGMETRICTAG']._serialized_end=239385
  _globals['_PATTERNFLOWGTPV1EFLAG']._serialized_start=239388
  _globals['_PATTERNFLOWGTPV1EFLAG']._serialized_end=239783
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1SFLAGCOUNTER']._serialized_start=239785
  _globals['_PATTERNFLOWGTPV1SFLAGCOUNTER']._serialized_end=239903
  _globals['_PATTERNFLOWGTPV1SFLAGMETRICTAG']._serialized_start=239905
  _globals['_PATTERNFLOWGTPV1SFLAGMETRICTAG']._serialized_end=240029
  _globals['_PATTERNFLOWGTPV1SFLAG']._serialized_start=240032
  _globals['_PATTERNFLOWGTPV1SFLAG']._serialized_end=240427
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1PNFLAGCOUNTER']._serialized_start=240429
  _globals['_PATTERNFLOWGTPV1PNFLAGCOUNTER']._serialized_end=240548
  _globals['_PATTERNFLOWGTPV1PNFLAGMETRICTAG']._serialized_start=240550
  _globals['_PATTERNFLOWGTPV1PNFLAGMETRICTAG']._serialized_end=240675
  _globals['_PATTERNFLOWGTPV1PNFLAG']._serialized_start=240678
  _globals['_PATTERNFLOWGTPV1PNFLAG']._serialized_end=241078
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1MESSAGETYPECOUNTER']._serialized_start=241080
  _globals['_PATTERNFLOWGTPV1MESSAGETYPECOUNTER']._serialized_end=241204
  _globals['_PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG']._serialized_start=241207
  _globals['_PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG']._serialized_end=241337
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE']._serialized_start=241340
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE']._serialized_end=241765
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER']._serialized_start=241767
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER']._serialized_end=241893
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG']._serialized_start=241896
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG']._serialized_end=242028
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH']._serialized_start=242031
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH']._serialized_end=242466
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1TEIDCOUNTER']._serialized_start=242468
  _globals['_PATTERNFLOWGTPV1TEIDCOUNTER']._serialized_end=242585
  _globals['_PATTERNFLOWGTPV1TEIDMETRICTAG']._serialized_start=242587
  _globals['_PATTERNFLOWGTPV1TEIDMETRICTAG']._serialized_end=242710
  _globals['_PATTERNFLOWGTPV1TEID']._serialized_start=242713
  _globals['_PATTERNFLOWGTPV1TEID']._serialized_end=243103
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1TEID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER']._serialized_start=243105
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER']._serialized_end=243231
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG']._serialized_start=243234
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG']._serialized_end=243366
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER']._serialized_start=243369
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER']._serialized_end=243804
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER']._serialized_start=243806
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER']._serialized_end=243929
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG']._serialized_start=243932
  _globals['_PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG']._serialized_end=244061
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER']._serialized_start=244064
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER']._serialized_end=244484
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER']._serialized_start=244487
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER']._serialized_end=244623
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG']._serialized_start=244626
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG']._serialized_end=244768
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE']._serialized_start=244771
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE']._serialized_end=245256
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER']._serialized_start=245259
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER']._serialized_end=245394
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG']._serialized_start=245397
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG']._serialized_end=245538
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH']._serialized_start=245541
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH']._serialized_end=246021
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER']._serialized_start=246024
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER']._serialized_end=246152
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG']._serialized_start=246155
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG']._serialized_end=246289
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS']._serialized_start=246292
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS']._serialized_end=246737
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER']._serialized_start=246740
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER']._serialized_end=246879
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG']._serialized_start=246882
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG']._serialized_end=247027
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER']._serialized_start=247030
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER']._serialized_end=247530
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2VERSIONCOUNTER']._serialized_start=247532
  _globals['_PATTERNFLOWGTPV2VERSIONCOUNTER']._serialized_end=247652
  _globals['_PATTERNFLOWGTPV2VERSIONMETRICTAG']._serialized_start=247654
  _globals['_PATTERNFLOWGTPV2VERSIONMETRICTAG']._serialized_end=247780
  _globals['_PATTERNFLOWGTPV2VERSION']._serialized_start=247783
  _globals['_PATTERNFLOWGTPV2VERSION']._serialized_end=248188
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER']._serialized_start=248191
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER']._serialized_end=248320
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG']._serialized_start=248323
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG']._serialized_end=248458
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG']._serialized_start=248461
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG']._serialized_end=248911
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2TEIDFLAGCOUNTER']._serialized_start=248913
  _globals['_PATTERNFLOWGTPV2TEIDFLAGCOUNTER']._serialized_end=249034
  _globals['_PATTERNFLOWGTPV2TEIDFLAGMETRICTAG']._serialized_start=249036
  _globals['_PATTERNFLOWGTPV2TEIDFLAGMETRICTAG']._serialized_end=249163
  _globals['_PATTERNFLOWGTPV2TEIDFLAG']._serialized_start=249166
  _globals['_PATTERNFLOWGTPV2TEIDFLAG']._serialized_end=249576
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SPARE1COUNTER']._serialized_start=249578
  _globals['_PATTERNFLOWGTPV2SPARE1COUNTER']._serialized_end=249697
  _globals['_PATTERNFLOWGTPV2SPARE1METRICTAG']._serialized_start=249699
  _globals['_PATTERNFLOWGTPV2SPARE1METRICTAG']._serialized_end=249824
  _globals['_PATTERNFLOWGTPV2SPARE1']._serialized_start=249827
  _globals['_PATTERNFLOWGTPV2SPARE1']._serialized_end=250227
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2MESSAGETYPECOUNTER']._serialized_start=250229
  _globals['_PATTERNFLOWGTPV2MESSAGETYPECOUNTER']._serialized_end=250353
  _globals['_PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG']._serialized_start=250356
  _globals['_PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG']._serialized_end=250486
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE']._serialized_start=250489
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE']._serialized_end=250914
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER']._serialized_start=250916
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER']._serialized_end=251042
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG']._serialized_start=251045
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG']._serialized_end=251177
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH']._serialized_start=251180
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH']._serialized_end=251615
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2TEIDCOUNTER']._serialized_start=251617
  _globals['_PATTERNFLOWGTPV2TEIDCOUNTER']._serialized_end=251734
  _globals['_PATTERNFLOWGTPV2TEIDMETRICTAG']._serialized_start=251736
  _globals['_PATTERNFLOWGTPV2TEIDMETRICTAG']._serialized_end=251859
  _globals['_PATTERNFLOWGTPV2TEID']._serialized_start=251862
  _globals['_PATTERNFLOWGTPV2TEID']._serialized_end=252252
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2TEID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER']._serialized_start=252254
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER']._serialized_end=252381
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG']._serialized_start=252384
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG']._serialized_end=252517
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER']._serialized_start=252520
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER']._serialized_end=252960
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SPARE2COUNTER']._serialized_start=252962
  _globals['_PATTERNFLOWGTPV2SPARE2COUNTER']._serialized_end=253081
  _globals['_PATTERNFLOWGTPV2SPARE2METRICTAG']._serialized_start=253083
  _globals['_PATTERNFLOWGTPV2SPARE2METRICTAG']._serialized_end=253208
  _globals['_PATTERNFLOWGTPV2SPARE2']._serialized_start=253211
  _globals['_PATTERNFLOWGTPV2SPARE2']._serialized_end=253611
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPHARDWARETYPECOUNTER']._serialized_start=253613
  _globals['_PATTERNFLOWARPHARDWARETYPECOUNTER']._serialized_end=253736
  _globals['_PATTERNFLOWARPHARDWARETYPEMETRICTAG']._serialized_start=253739
  _globals['_PATTERNFLOWARPHARDWARETYPEMETRICTAG']._serialized_end=253868
  _globals['_PATTERNFLOWARPHARDWARETYPE']._serialized_start=253871
  _globals['_PATTERNFLOWARPHARDWARETYPE']._serialized_end=254291
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPPROTOCOLTYPECOUNTER']._serialized_start=254293
  _globals['_PATTERNFLOWARPPROTOCOLTYPECOUNTER']._serialized_end=254416
  _globals['_PATTERNFLOWARPPROTOCOLTYPEMETRICTAG']._serialized_start=254419
  _globals['_PATTERNFLOWARPPROTOCOLTYPEMETRICTAG']._serialized_end=254548
  _globals['_PATTERNFLOWARPPROTOCOLTYPE']._serialized_start=254551
  _globals['_PATTERNFLOWARPPROTOCOLTYPE']._serialized_end=254971
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPHARDWARELENGTHCOUNTER']._serialized_start=254973
  _globals['_PATTERNFLOWARPHARDWARELENGTHCOUNTER']._serialized_end=255098
  _globals['_PATTERNFLOWARPHARDWARELENGTHMETRICTAG']._serialized_start=255101
  _globals['_PATTERNFLOWARPHARDWARELENGTHMETRICTAG']._serialized_end=255232
  _globals['_PATTERNFLOWARPHARDWARELENGTH']._serialized_start=255235
  _globals['_PATTERNFLOWARPHARDWARELENGTH']._serialized_end=255665
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER']._serialized_start=255667
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER']._serialized_end=255792
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG']._serialized_start=255795
  _globals['_PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG']._serialized_end=255926
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH']._serialized_start=255929
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH']._serialized_end=256359
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPOPERATIONCOUNTER']._serialized_start=256361
  _globals['_PATTERNFLOWARPOPERATIONCOUNTER']._serialized_end=256481
  _globals['_PATTERNFLOWARPOPERATIONMETRICTAG']._serialized_start=256483
  _globals['_PATTERNFLOWARPOPERATIONMETRICTAG']._serialized_end=256609
  _globals['_PATTERNFLOWARPOPERATION']._serialized_start=256612
  _globals['_PATTERNFLOWARPOPERATION']._serialized_end=257017
  _globals['_PATTERNFLOWARPOPERATION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPOPERATION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPOPERATION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPOPERATION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER']._serialized_start=257020
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER']._serialized_end=257149
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG']._serialized_start=257152
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG']._serialized_end=257287
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR']._serialized_start=257290
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR']._serialized_end=257740
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER']._serialized_start=257743
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER']._serialized_end=257872
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG']._serialized_start=257875
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG']._serialized_end=258010
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR']._serialized_start=258013
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR']._serialized_end=258463
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER']._serialized_start=258466
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER']._serialized_end=258595
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG']._serialized_start=258598
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG']._serialized_end=258733
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR']._serialized_start=258736
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR']._serialized_end=259186
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER']._serialized_start=259189
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER']._serialized_end=259318
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG']._serialized_start=259321
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG']._serialized_end=259456
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR']._serialized_start=259459
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR']._serialized_end=259909
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOTYPECOUNTER']._serialized_start=259911
  _globals['_PATTERNFLOWICMPECHOTYPECOUNTER']._serialized_end=260031
  _globals['_PATTERNFLOWICMPECHOTYPEMETRICTAG']._serialized_start=260033
  _globals['_PATTERNFLOWICMPECHOTYPEMETRICTAG']._serialized_end=260159
  _globals['_PATTERNFLOWICMPECHOTYPE']._serialized_start=260162
  _globals['_PATTERNFLOWICMPECHOTYPE']._serialized_end=260567
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOCODECOUNTER']._serialized_start=260569
  _globals['_PATTERNFLOWICMPECHOCODECOUNTER']._serialized_end=260689
  _globals['_PATTERNFLOWICMPECHOCODEMETRICTAG']._serialized_start=260691
  _globals['_PATTERNFLOWICMPECHOCODEMETRICTAG']._serialized_end=260817
  _globals['_PATTERNFLOWICMPECHOCODE']._serialized_start=260820
  _globals['_PATTERNFLOWICMPECHOCODE']._serialized_end=261225
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOCHECKSUM']._serialized_start=261228
  _globals['_PATTERNFLOWICMPECHOCHECKSUM']._serialized_end=261573
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER']._serialized_start=261575
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER']._serialized_end=261701
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG']._serialized_start=261704
  _globals['_PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG']._serialized_end=261836
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER']._serialized_start=261839
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER']._serialized_end=262274
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER']._serialized_start=262277
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER']._serialized_end=262407
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG']._serialized_start=262410
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG']._serialized_end=262546
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER']._serialized_start=262549
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER']._serialized_end=263004
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM']._serialized_start=263007
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM']._serialized_end=263358
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER']._serialized_start=263361
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER']._serialized_end=263493
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG']._serialized_start=263496
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG']._serialized_end=263634
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER']._serialized_start=263637
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER']._serialized_end=264102
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER']._serialized_start=264105
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER']._serialized_end=264241
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG']._serialized_start=264244
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG']._serialized_end=264386
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER']._serialized_start=264389
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER']._serialized_end=264874
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOTYPECOUNTER']._serialized_start=264876
  _globals['_PATTERNFLOWICMPV6ECHOTYPECOUNTER']._serialized_end=264998
  _globals['_PATTERNFLOWICMPV6ECHOTYPEMETRICTAG']._serialized_start=265001
  _globals['_PATTERNFLOWICMPV6ECHOTYPEMETRICTAG']._serialized_end=265129
  _globals['_PATTERNFLOWICMPV6ECHOTYPE']._serialized_start=265132
  _globals['_PATTERNFLOWICMPV6ECHOTYPE']._serialized_end=265547
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOCODECOUNTER']._serialized_start=265549
  _globals['_PATTERNFLOWICMPV6ECHOCODECOUNTER']._serialized_end=265671
  _globals['_PATTERNFLOWICMPV6ECHOCODEMETRICTAG']._serialized_start=265674
  _globals['_PATTERNFLOWICMPV6ECHOCODEMETRICTAG']._serialized_end=265802
  _globals['_PATTERNFLOWICMPV6ECHOCODE']._serialized_start=265805
  _globals['_PATTERNFLOWICMPV6ECHOCODE']._serialized_end=266220
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER']._serialized_start=266223
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER']._serialized_end=266351
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG']._serialized_start=266354
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG']._serialized_end=266488
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER']._serialized_start=266491
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER']._serialized_end=266936
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER']._serialized_start=266939
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER']._serialized_end=267071
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG']._serialized_start=267074
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG']._serialized_end=267212
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER']._serialized_start=267215
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER']._serialized_end=267680
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM']._serialized_start=267683
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM']._serialized_end=268034
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM']._serialized_start=268037
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM']._serialized_end=268394
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWPPPADDRESSCOUNTER']._serialized_start=268396
  _globals['_PATTERNFLOWPPPADDRESSCOUNTER']._serialized_end=268514
  _globals['_PATTERNFLOWPPPADDRESSMETRICTAG']._serialized_start=268516
  _globals['_PATTERNFLOWPPPADDRESSMETRICTAG']._serialized_end=268640
  _globals['_PATTERNFLOWPPPADDRESS']._serialized_start=268643
  _globals['_PATTERNFLOWPPPADDRESS']._serialized_end=269038
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPPPADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPPPCONTROLCOUNTER']._serialized_start=269040
  _globals['_PATTERNFLOWPPPCONTROLCOUNTER']._serialized_end=269158
  _globals['_PATTERNFLOWPPPCONTROLMETRICTAG']._serialized_start=269160
  _globals['_PATTERNFLOWPPPCONTROLMETRICTAG']._serialized_end=269284
  _globals['_PATTERNFLOWPPPCONTROL']._serialized_start=269287
  _globals['_PATTERNFLOWPPPCONTROL']._serialized_end=269682
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWPPPCONTROL_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWPPPPROTOCOLTYPECOUNTER']._serialized_start=269684
  _globals['_PATTERNFLOWPPPPROTOCOLTYPECOUNTER']._serialized_end=269807
  _globals['_PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG']._serialized_start=269810
  _globals['_PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG']._serialized_end=269939
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE']._serialized_start=269942
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE']._serialized_end=270400
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWIGMPV1VERSIONCOUNTER']._serialized_start=270402
  _globals['_PATTERNFLOWIGMPV1VERSIONCOUNTER']._serialized_end=270523
  _globals['_PATTERNFLOWIGMPV1VERSIONMETRICTAG']._serialized_start=270525
  _globals['_PATTERNFLOWIGMPV1VERSIONMETRICTAG']._serialized_end=270652
  _globals['_PATTERNFLOWIGMPV1VERSION']._serialized_start=270655
  _globals['_PATTERNFLOWIGMPV1VERSION']._serialized_end=271065
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1TYPECOUNTER']._serialized_start=271067
  _globals['_PATTERNFLOWIGMPV1TYPECOUNTER']._serialized_end=271185
  _globals['_PATTERNFLOWIGMPV1TYPEMETRICTAG']._serialized_start=271187
  _globals['_PATTERNFLOWIGMPV1TYPEMETRICTAG']._serialized_end=271311
  _globals['_PATTERNFLOWIGMPV1TYPE']._serialized_start=271314
  _globals['_PATTERNFLOWIGMPV1TYPE']._serialized_end=271709
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1UNUSEDCOUNTER']._serialized_start=271711
  _globals['_PATTERNFLOWIGMPV1UNUSEDCOUNTER']._serialized_end=271831
  _globals['_PATTERNFLOWIGMPV1UNUSEDMETRICTAG']._serialized_start=271833
  _globals['_PATTERNFLOWIGMPV1UNUSEDMETRICTAG']._serialized_end=271959
  _globals['_PATTERNFLOWIGMPV1UNUSED']._serialized_start=271962
  _globals['_PATTERNFLOWIGMPV1UNUSED']._serialized_end=272367
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1CHECKSUM']._serialized_start=272370
  _globals['_PATTERNFLOWIGMPV1CHECKSUM']._serialized_end=272709
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER']._serialized_start=272711
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER']._serialized_end=272837
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG']._serialized_start=272840
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG']._serialized_end=272972
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS']._serialized_start=272975
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS']._serialized_end=273410
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWMPLSLABELCOUNTER']._serialized_start=273412
  _globals['_PATTERNFLOWMPLSLABELCOUNTER']._serialized_end=273529
  _globals['_PATTERNFLOWMPLSLABELMETRICTAG']._serialized_start=273531
  _globals['_PATTERNFLOWMPLSLABELMETRICTAG']._serialized_end=273654
  _globals['_PATTERNFLOWMPLSLABEL']._serialized_start=273657
  _globals['_PATTERNFLOWMPLSLABEL']._serialized_end=274085
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWMPLSLABEL_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER']._serialized_start=274087
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER']._serialized_end=274211
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG']._serialized_start=274214
  _globals['_PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG']._serialized_end=274344
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS']._serialized_start=274347
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS']._serialized_end=274772
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER']._serialized_start=274774
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER']._serialized_end=274899
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG']._serialized_start=274902
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG']._serialized_end=275033
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK']._serialized_start=275036
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK']._serialized_end=275504
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE']._serialized_start=177945
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE']._serialized_end=178041
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM']._serialized_end=178041
  _globals['_PATTERNFLOWMPLSTIMETOLIVECOUNTER']._serialized_start=275506
  _globals['_PATTERNFLOWMPLSTIMETOLIVECOUNTER']._serialized_end=275628
  _globals['_PATTERNFLOWMPLSTIMETOLIVEMETRICTAG']._serialized_start=275631
  _globals['_PATTERNFLOWMPLSTIMETOLIVEMETRICTAG']._serialized_end=275759
  _globals['_PATTERNFLOWMPLSTIMETOLIVE']._serialized_start=275762
  _globals['_PATTERNFLOWMPLSTIMETOLIVE']._serialized_end=276177
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVERSIONCOUNTER']._serialized_start=276179
  _globals['_PATTERNFLOWSNMPV2CVERSIONCOUNTER']._serialized_end=276301
  _globals['_PATTERNFLOWSNMPV2CVERSION']._serialized_start=276304
  _globals['_PATTERNFLOWSNMPV2CVERSION']._serialized_end=276657
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTIDCOUNTER']._serialized_start=276659
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTIDCOUNTER']._serialized_end=276786
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID']._serialized_start=276789
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID']._serialized_end=277162
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CPDUREQUESTID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEXCOUNTER']._serialized_start=277165
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEXCOUNTER']._serialized_end=277293
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX']._serialized_start=277296
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX']._serialized_end=277673
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CPDUERRORINDEX_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTIDCOUNTER']._serialized_start=277676
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTIDCOUNTER']._serialized_end=277807
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID']._serialized_start=277810
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID']._serialized_end=278199
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CBULKPDUREQUESTID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS']._serialized_start=278202
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS']._serialized_end=278433
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE']._serialized_start=278356
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE']._serialized_end=278412
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWSNMPV2CBULKPDUNONREPEATERS_CHOICE_ENUM']._serialized_end=178001
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONSCOUNTER']._serialized_start=278436
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONSCOUNTER']._serialized_end=278572
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS']._serialized_start=278575
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS']._serialized_end=278984
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CBULKPDUMAXREPETITIONS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUECOUNTER']._serialized_start=278987
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUECOUNTER']._serialized_end=279134
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE']._serialized_start=279137
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE']._serialized_end=279590
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEINTEGERVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUECOUNTER']._serialized_start=279593
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUECOUNTER']._serialized_end=279742
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE']._serialized_start=279745
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE']._serialized_end=280206
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEIPADDRESSVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUECOUNTER']._serialized_start=280209
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUECOUNTER']._serialized_end=280356
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE']._serialized_start=280359
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE']._serialized_end=280812
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUECOUNTERVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUECOUNTER']._serialized_start=280815
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUECOUNTER']._serialized_end=280964
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE']._serialized_start=280967
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE']._serialized_end=281428
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUETIMETICKSVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUECOUNTER']._serialized_start=281431
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUECOUNTER']._serialized_end=281581
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE']._serialized_start=281584
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE']._serialized_end=282049
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEBIGCOUNTERVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUECOUNTER']._serialized_start=282052
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUECOUNTER']._serialized_end=282207
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE']._serialized_start=282210
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE']._serialized_end=282695
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CVARIABLEBINDINGVALUEUNSIGNEDINTEGERVALUE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTIDCOUNTER']._serialized_start=282698
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTIDCOUNTER']._serialized_end=282828
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID']._serialized_start=282831
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID']._serialized_end=283216
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWSNMPV2CCOMMONREQUESTID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM']._serialized_start=283219
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM']._serialized_end=283564
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE']._serialized_start=192431
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE']._serialized_end=192491
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE_ENUM']._serialized_start=192441
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_CHOICE_ENUM']._serialized_end=192491
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED']._serialized_start=192493
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED']._serialized_end=192548
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED_ENUM']._serialized_start=192506
  _globals['_PATTERNFLOWRSVPRSVPCHECKSUM_GENERATED_ENUM']._serialized_end=192548
  _globals['_PATTERNFLOWRSVPTIMETOLIVECOUNTER']._serialized_start=283566
  _globals['_PATTERNFLOWRSVPTIMETOLIVECOUNTER']._serialized_end=283688
  _globals['_PATTERNFLOWRSVPTIMETOLIVE']._serialized_start=283691
  _globals['_PATTERNFLOWRSVPTIMETOLIVE']._serialized_end=284044
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPTIMETOLIVE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPRESERVEDCOUNTER']._serialized_start=284046
  _globals['_PATTERNFLOWRSVPRESERVEDCOUNTER']._serialized_end=284166
  _globals['_PATTERNFLOWRSVPRESERVED']._serialized_start=284169
  _globals['_PATTERNFLOWRSVPRESERVED']._serialized_end=284514
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPRESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESSCOUNTER']._serialized_start=284517
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESSCOUNTER']._serialized_end=284678
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS']._serialized_start=284681
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS']._serialized_end=285190
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4IPV4TUNNELENDPOINTADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVEDCOUNTER']._serialized_start=285193
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVEDCOUNTER']._serialized_end=285337
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED']._serialized_start=285340
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED']._serialized_end=285781
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELIDCOUNTER']._serialized_start=285784
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELIDCOUNTER']._serialized_end=285928
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID']._serialized_start=285931
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID']._serialized_end=286372
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSESSIONLSPTUNNELIPV4TUNNELID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGERCOUNTER']._serialized_start=286375
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGERCOUNTER']._serialized_end=286518
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER']._serialized_start=286521
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER']._serialized_end=286958
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASINTEGER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4COUNTER']._serialized_start=286961
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4COUNTER']._serialized_end=287101
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4']._serialized_start=287104
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4']._serialized_end=287529
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSESSIONEXTTUNNELIDASIPV4_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESSCOUNTER']._serialized_start=287532
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESSCOUNTER']._serialized_end=287670
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS']._serialized_start=287673
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS']._serialized_end=288090
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4IPV4ADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLECOUNTER']._serialized_start=288093
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLECOUNTER']._serialized_end=288242
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE']._serialized_start=288245
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE']._serialized_end=288706
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHRSVPHOPIPV4LOGICALINTERFACEHANDLE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODRCOUNTER']._serialized_start=288709
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODRCOUNTER']._serialized_end=288854
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR']._serialized_start=288857
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR']._serialized_end=289302
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHTIMEVALUESTYPE1REFRESHPERIODR_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBITCOUNTER']._serialized_start=289305
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBITCOUNTER']._serialized_end=289453
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT']._serialized_start=289456
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT']._serialized_end=289913
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXLBIT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESSCOUNTER']._serialized_start=289916
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESSCOUNTER']._serialized_end=290071
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS']._serialized_start=290074
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS']._serialized_end=290559
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1IPV4PREFIXIPV4ADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBITCOUNTER']._serialized_start=290562
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBITCOUNTER']._serialized_end=290708
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT']._serialized_start=290711
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT']._serialized_end=291160
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHEXPLICITROUTETYPE1ASNUMBERLBIT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVEDCOUNTER']._serialized_start=291163
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVEDCOUNTER']._serialized_end=291316
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED']._serialized_start=291319
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED']._serialized_end=291796
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGERESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PIDCOUNTER']._serialized_start=291799
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PIDCOUNTER']._serialized_end=291949
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID']._serialized_start=291952
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID']._serialized_end=292417
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHLABELREQUESTWITHOUTLABELRANGEL3PID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESSCOUNTER']._serialized_start=292420
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESSCOUNTER']._serialized_end=292586
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS']._serialized_start=292589
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS']._serialized_end=293118
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4IPV4TUNNELSENDERADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVEDCOUNTER']._serialized_start=293121
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVEDCOUNTER']._serialized_end=293272
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED']._serialized_start=293275
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED']._serialized_end=293744
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4RESERVED_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPIDCOUNTER']._serialized_start=293747
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPIDCOUNTER']._serialized_end=293895
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID']._serialized_start=293898
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID']._serialized_end=294355
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTEMPLATELSPTUNNELIPV4LSPID_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSIONCOUNTER']._serialized_start=294358
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSIONCOUNTER']._serialized_end=294499
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION']._serialized_start=294502
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION']._serialized_end=294931
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVVERSION_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1COUNTER']._serialized_start=294934
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1COUNTER']._serialized_end=295077
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1']._serialized_start=295080
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1']._serialized_end=295517
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED1_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTHCOUNTER']._serialized_start=295520
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTHCOUNTER']._serialized_end=295667
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH']._serialized_start=295670
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH']._serialized_end=296123
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVOVERALLLENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADERCOUNTER']._serialized_start=296126
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADERCOUNTER']._serialized_end=296273
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER']._serialized_start=296276
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER']._serialized_end=296729
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVSERVICEHEADER_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBITCOUNTER']._serialized_start=296732
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBITCOUNTER']._serialized_end=296873
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT']._serialized_start=296876
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT']._serialized_end=297305
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVZEROBIT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2COUNTER']._serialized_start=297308
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2COUNTER']._serialized_end=297451
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2']._serialized_start=297454
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2']._serialized_end=297891
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVRESERVED2_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATACOUNTER']._serialized_start=297894
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATACOUNTER']._serialized_end=298047
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA']._serialized_start=298050
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA']._serialized_end=298527
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVLENGTHOFSERVICEDATA_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPECCOUNTER']._serialized_start=298530
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPECCOUNTER']._serialized_end=298691
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC']._serialized_start=298694
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC']._serialized_end=299203
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETERIDTOKENBUCKETTSPEC_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAGCOUNTER']._serialized_start=299206
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAGCOUNTER']._serialized_end=299356
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG']._serialized_start=299359
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG']._serialized_end=299824
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127FLAG_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTHCOUNTER']._serialized_start=299827
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTHCOUNTER']._serialized_end=299979
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH']._serialized_start=299982
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH']._serialized_end=300455
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVPARAMETER127LENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNITCOUNTER']._serialized_start=300458
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNITCOUNTER']._serialized_end=300610
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT']._serialized_start=300613
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT']._serialized_end=301086
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMINIMUMPOLICEDUNIT_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZECOUNTER']._serialized_start=301089
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZECOUNTER']._serialized_end=301240
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE']._serialized_start=301243
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE']._serialized_end=301712
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHSENDERTSPECINTSERVMAXIMUMPACKETSIZE_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESSCOUNTER']._serialized_start=301715
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESSCOUNTER']._serialized_end=301869
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS']._serialized_start=301872
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS']._serialized_end=302353
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSIPV4ADDRESS_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTHCOUNTER']._serialized_start=302356
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTHCOUNTER']._serialized_end=302511
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH']._serialized_start=302514
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH']._serialized_end=302999
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1IPV4ADDRESSPREFIXLENGTH_CHOICE_ENUM']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS']._serialized_start=303002
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS']._serialized_end=303249
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE']._serialized_start=278356
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE']._serialized_end=278412
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELFLAGS_CHOICE_ENUM']._serialized_end=178001
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE']._serialized_start=303252
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE']._serialized_end=303499
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE']._serialized_start=278356
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE']._serialized_end=278412
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE_ENUM']._serialized_start=177955
  _globals['_PATTERNFLOWRSVPPATHRECORDROUTETYPE1LABELCTYPE_CHOICE_ENUM']._serialized_end=178001
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPECOUNTER']._serialized_start=303502
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPECOUNTER']._serialized_end=303635
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE']._serialized_start=303638
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE']._serialized_end=304035
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE']._serialized_start=178615
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE']._serialized_end=178701
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE_ENUM']._serialized_start=178625
  _globals['_PATTERNFLOWRSVPPATHOBJECTSCUSTOMTYPE_CHOICE_ENUM']._serialized_end=178701
  _globals['_VERSION']._serialized_start=304038
  _globals['_VERSION']._serialized_end=304183
  _globals['_SUCCESS']._serialized_start=304185
  _globals['_SUCCESS']._serialized_end=304225
  _globals['_FAILURE']._serialized_start=304227
  _globals['_FAILURE']._serialized_end=304263
  _globals['_SETCONFIGREQUEST']._serialized_start=304265
  _globals['_SETCONFIGREQUEST']._serialized_end=304312
  _globals['_UPDATECONFIGREQUEST']._serialized_start=304314
  _globals['_UPDATECONFIGREQUEST']._serialized_end=304377
  _globals['_SETCONFIGRESPONSE']._serialized_start=304379
  _globals['_SETCONFIGRESPONSE']._serialized_end=304429
  _globals['_GETCONFIGRESPONSE']._serialized_start=304431
  _globals['_GETCONFIGRESPONSE']._serialized_end=304479
  _globals['_UPDATECONFIGRESPONSE']._serialized_start=304481
  _globals['_UPDATECONFIGRESPONSE']._serialized_end=304534
  _globals['_SETCONTROLSTATEREQUEST']._serialized_start=304536
  _globals['_SETCONTROLSTATEREQUEST']._serialized_end=304602
  _globals['_SETCONTROLSTATERESPONSE']._serialized_start=304604
  _globals['_SETCONTROLSTATERESPONSE']._serialized_end=304660
  _globals['_SETCONTROLACTIONREQUEST']._serialized_start=304662
  _globals['_SETCONTROLACTIONREQUEST']._serialized_end=304731
  _globals['_SETCONTROLACTIONRESPONSE']._serialized_start=304733
  _globals['_SETCONTROLACTIONRESPONSE']._serialized_end=304820
  _globals['_GETMETRICSREQUEST']._serialized_start=304822
  _globals['_GETMETRICSREQUEST']._serialized_end=304887
  _globals['_GETMETRICSRESPONSE']._serialized_start=304889
  _globals['_GETMETRICSRESPONSE']._serialized_end=304957
  _globals['_GETSTATESREQUEST']._serialized_start=304959
  _globals['_GETSTATESREQUEST']._serialized_end=305021
  _globals['_GETSTATESRESPONSE']._serialized_start=305023
  _globals['_GETSTATESRESPONSE']._serialized_end=305088
  _globals['_GETCAPTUREREQUEST']._serialized_start=305090
  _globals['_GETCAPTUREREQUEST']._serialized_end=305155
  _globals['_GETCAPTURERESPONSE']._serialized_start=305157
  _globals['_GETCAPTURERESPONSE']._serialized_end=305201
  _globals['_GETVERSIONRESPONSE']._serialized_start=305203
  _globals['_GETVERSIONRESPONSE']._serialized_end=305254
  _globals['_OPENAPI']._serialized_start=305257
  _globals['_OPENAPI']._serialized_end=305864
# @@protoc_insertion_point(module_scope)
